/* Generated by Cython 0.29.33 */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_33"
#define CYTHON_HEX_VERSION 0x001D21F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PY_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 0
  #elif !defined(CYTHON_FAST_THREAD_STATE)
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL (PY_VERSION_HEX < 0x030A0000)
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #if PY_VERSION_HEX >= 0x030B00A4
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if PY_VERSION_HEX >= 0x030B00A1
    static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *kwds=NULL, *argcount=NULL, *posonlyargcount=NULL, *kwonlyargcount=NULL;
        PyObject *nlocals=NULL, *stacksize=NULL, *flags=NULL, *replace=NULL, *call_result=NULL, *empty=NULL;
        const char *fn_cstr=NULL;
        const char *name_cstr=NULL;
        PyCodeObject* co=NULL;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        if (!(kwds=PyDict_New())) goto end;
        if (!(argcount=PyLong_FromLong(a))) goto end;
        if (PyDict_SetItemString(kwds, "co_argcount", argcount) != 0) goto end;
        if (!(posonlyargcount=PyLong_FromLong(0))) goto end;
        if (PyDict_SetItemString(kwds, "co_posonlyargcount", posonlyargcount) != 0) goto end;
        if (!(kwonlyargcount=PyLong_FromLong(k))) goto end;
        if (PyDict_SetItemString(kwds, "co_kwonlyargcount", kwonlyargcount) != 0) goto end;
        if (!(nlocals=PyLong_FromLong(l))) goto end;
        if (PyDict_SetItemString(kwds, "co_nlocals", nlocals) != 0) goto end;
        if (!(stacksize=PyLong_FromLong(s))) goto end;
        if (PyDict_SetItemString(kwds, "co_stacksize", stacksize) != 0) goto end;
        if (!(flags=PyLong_FromLong(f))) goto end;
        if (PyDict_SetItemString(kwds, "co_flags", flags) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_code", code) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_consts", c) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_names", n) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_varnames", v) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_freevars", fv) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_cellvars", cell) != 0) goto end;
        if (PyDict_SetItemString(kwds, "co_linetable", lnos) != 0) goto end;
        if (!(fn_cstr=PyUnicode_AsUTF8AndSize(fn, NULL))) goto end;
        if (!(name_cstr=PyUnicode_AsUTF8AndSize(name, NULL))) goto end;
        if (!(co = PyCode_NewEmpty(fn_cstr, name_cstr, fline))) goto end;
        if (!(replace = PyObject_GetAttrString((PyObject*)co, "replace"))) goto cleanup_code_too;
        if (!(empty = PyTuple_New(0))) goto cleanup_code_too; // unfortunately __pyx_empty_tuple isn't available here
        if (!(call_result = PyObject_Call(replace, empty, kwds))) goto cleanup_code_too;
        Py_XDECREF((PyObject*)co);
        co = (PyCodeObject*)call_result;
        call_result = NULL;
        if (0) {
            cleanup_code_too:
            Py_XDECREF((PyObject*)co);
            co = NULL;
        }
        end:
        Py_XDECREF(kwds);
        Py_XDECREF(argcount);
        Py_XDECREF(posonlyargcount);
        Py_XDECREF(kwonlyargcount);
        Py_XDECREF(nlocals);
        Py_XDECREF(stacksize);
        Py_XDECREF(replace);
        Py_XDECREF(call_result);
        Py_XDECREF(empty);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return co;
    }
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__alacorder__cal
#define __PYX_HAVE_API__alacorder__cal
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "cal.pyx",
};

/*--- Type declarations ---*/
struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText;
struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr;

/* "alacorder/cal.pyx":1086
 * #   #   #   #           GETTER METHODS         #   #   #   #
 * 
 * def getPDFText(path) -> str:             # <<<<<<<<<<<<<<
 *      """
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 */
struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText {
  PyObject_HEAD
  PyObject *__pyx_v_pg;
};


/* "alacorder/cal.pyx":1097
 *      for pg in doc:
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))             # <<<<<<<<<<<<<<
 *           except:
 *                pass
 */
struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr {
  PyObject_HEAD
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *__pyx_outer_scope;
  PyObject *__pyx_v_x;
};


/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if CYTHON_FAST_PYCALL
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif // CYTHON_FAST_PYCALL
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* PyObjectLookupSpecial.proto */
#if CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_LookupSpecial(PyObject* obj, PyObject* attr_name) {
    PyObject *res;
    PyTypeObject *tp = Py_TYPE(obj);
#if PY_MAJOR_VERSION < 3
    if (unlikely(PyInstance_Check(obj)))
        return __Pyx_PyObject_GetAttrStr(obj, attr_name);
#endif
    res = _PyType_Lookup(tp, attr_name);
    if (likely(res)) {
        descrgetfunc f = Py_TYPE(res)->tp_descr_get;
        if (!f) {
            Py_INCREF(res);
        } else {
            res = f(res, obj, (PyObject *)tp);
        }
    } else {
        PyErr_SetObject(PyExc_AttributeError, attr_name);
    }
    return res;
}
#else
#define __Pyx_PyObject_LookupSpecial(o,n) __Pyx_PyObject_GetAttrStr(o,n)
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_str(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_str(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* GCCDiagnostics.proto */
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* pyobject_as_double.proto */
static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyInt_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?\
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchInspect.proto */
static PyObject* __Pyx_patch_inspect(PyObject* module);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'alacorder.cal' */
static PyTypeObject *__pyx_ptype_9alacorder_3cal___pyx_scope_struct__getPDFText = 0;
static PyTypeObject *__pyx_ptype_9alacorder_3cal___pyx_scope_struct_1_genexpr = 0;
#define __Pyx_MODULE_NAME "alacorder.cal"
extern int __pyx_module_is_main_alacorder__cal;
int __pyx_module_is_main_alacorder__cal = 0;

/* Implementation of 'alacorder.cal' */
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_range;
static const char __pyx_k_A[] = "A";
static const char __pyx_k_C[] = "C$";
static const char __pyx_k_D[] = "D";
static const char __pyx_k_J[] = "J";
static const char __pyx_k_L[] = "L";
static const char __pyx_k_P[] = "P";
static const char __pyx_k_S[] = "S";
static const char __pyx_k_T[] = "T";
static const char __pyx_k_Y[] = "Y";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_d[] = "[^\\d/]";
static const char __pyx_k_h[] = "-h";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_m[] = "m";
static const char __pyx_k_n[] = "\\n";
static const char __pyx_k_r[] = "r";
static const char __pyx_k_s[] = "[\\$\\s]";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_AL[] = "AL";
static const char __pyx_k_By[] = "By";
static const char __pyx_k_ID[] = "ID";
static const char __pyx_k__8[] = "";
static const char __pyx_k_ac[] = "ac";
static const char __pyx_k_af[] = "af";
static const char __pyx_k_ar[] = "ar";
static const char __pyx_k_by[] = "by";
static const char __pyx_k_ca[] = "ca";
static const char __pyx_k_cf[] = "cf";
static const char __pyx_k_ch[] = "ch";
static const char __pyx_k_df[] = "df";
static const char __pyx_k_fs[] = "fs";
static const char __pyx_k_ft[] = "ft";
static const char __pyx_k_mm[] = "mm";
static const char __pyx_k_on[] = "on";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_pg[] = "pg";
static const char __pyx_k_pl[] = "pl";
static const char __pyx_k_pp[] = "pp";
static const char __pyx_k_qs[] = "qs";
static const char __pyx_k_re[] = "re";
static const char __pyx_k_0_9[] = "[^0-9]";
static const char __pyx_k_ALL[] = "ALL";
static const char __pyx_k_A_Z[] = "[A-Z].+";
static const char __pyx_k_C_2[] = "C";
static const char __pyx_k_DOB[] = "DOB";
static const char __pyx_k_Num[] = "Num";
static const char __pyx_k_PDF[] = "PDF";
static const char __pyx_k_SSN[] = "SSN";
static const char __pyx_k_S_N[] = "[S|N]$";
static const char __pyx_k_Sex[] = "Sex";
static const char __pyx_k_Zip[] = "(?:Zip: )(.+)";
static const char __pyx_k__28[] = ":";
static const char __pyx_k__42[] = "/";
static const char __pyx_k__51[] = "\"";
static const char __pyx_k__52[] = ", ";
static const char __pyx_k__63[] = "-";
static const char __pyx_k__64[] = " ";
static const char __pyx_k__69[] = "; ";
static const char __pyx_k__82[] = "\002";
static const char __pyx_k__85[] = "\\$";
static const char __pyx_k__88[] = "$";
static const char __pyx_k__90[] = "\\$|\\.";
static const char __pyx_k__92[] = "_";
static const char __pyx_k__96[] = "#";
static const char __pyx_k__97[] = ") (";
static const char __pyx_k_agg[] = "agg";
static const char __pyx_k_all[] = "all";
static const char __pyx_k_arr[] = "arr";
static const char __pyx_k_cID[] = "cID";
static const char __pyx_k_col[] = "col";
static const char __pyx_k_csv[] = ".csv";
static const char __pyx_k_dob[] = "dob";
static const char __pyx_k_doc[] = "doc";
static const char __pyx_k_ext[] = "ext";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_how[] = "how";
static const char __pyx_k_lit[] = "lit";
static const char __pyx_k_mmm[] = "mmm";
static const char __pyx_k_n_s[] = "[\\n\\s]";
static const char __pyx_k_now[] = "now";
static const char __pyx_k_opt[] = "opt";
static const char __pyx_k_out[] = "out";
static const char __pyx_k_pdf[] = "**/*.pdf";
static const char __pyx_k_pts[] = "pts";
static const char __pyx_k_pwd[] = "pwd";
static const char __pyx_k_set[] = "set";
static const char __pyx_k_ssn[] = "ssn";
static const char __pyx_k_str[] = "str";
static const char __pyx_k_sub[] = "sub";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_txt[] = ".txt";
static const char __pyx_k_uID[] = "uID";
static const char __pyx_k_url[] = "url";
static const char __pyx_k_xls[] = ".xls";
static const char __pyx_k_zip[] = ".zip";
static const char __pyx_k_0_00[] = "$0.00";
static const char __pyx_k_1000[] = "1000";
static const char __pyx_k_Cite[] = "Cite";
static const char __pyx_k_City[] = "City";
static const char __pyx_k_Code[] = "Code";
static const char __pyx_k_D999[] = "D999";
static const char __pyx_k_Eyes[] = "Eyes";
static const char __pyx_k_Fees[] = "Fees";
static const char __pyx_k_Hair[] = "Hair";
static const char __pyx_k_NAME[] = "NAME";
static const char __pyx_k_Name[] = "Name";
static const char __pyx_k_None[] = "None";
static const char __pyx_k_Path[] = "Path";
static const char __pyx_k_Race[] = "Race";
static const char __pyx_k_Sort[] = "Sort";
static const char __pyx_k_TEMP[] = "TEMP_";
static const char __pyx_k__109[] = "\n";
static const char __pyx_k__111[] = " \n ";
static const char __pyx_k__115[] = ".";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_cast[] = "cast";
static const char __pyx_k_city[] = "city";
static const char __pyx_k_conf[] = "conf";
static const char __pyx_k_d999[] = "d999";
static const char __pyx_k_dlog[] = "dlog";
static const char __pyx_k_drop[] = "drop";
static const char __pyx_k_exit[] = "__exit__";
static const char __pyx_k_fees[] = "fees";
static const char __pyx_k_fitz[] = "fitz";
static const char __pyx_k_glob[] = "glob";
static const char __pyx_k_good[] = "good";
static const char __pyx_k_help[] = "--help";
static const char __pyx_k_href[] = "href";
static const char __pyx_k_init[] = "init";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_json[] = ".json";
static const char __pyx_k_left[] = "left";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_math[] = "math";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_none[] = "none";
static const char __pyx_k_null[] = "(null;?)";
static const char __pyx_k_open[] = "open";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_qmax[] = "qmax";
static const char __pyx_k_read[] = "read";
static const char __pyx_k_rich[] = "rich";
static const char __pyx_k_rows[] = "rows";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_tbal[] = "tbal";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_text[] = "text";
static const char __pyx_k_then[] = "then";
static const char __pyx_k_time[] = "time";
static const char __pyx_k_tqdm[] = "tqdm";
static const char __pyx_k_when[] = "when";
static const char __pyx_k_xlsx[] = ".xlsx";
static const char __pyx_k_0_9_2[] = "[^0-9\\.]";
static const char __pyx_k_0_9_s[] = "[^0-9|\\.|\\s|\\$]";
static const char __pyx_k_A_Z_2[] = "[A-Z]|\\$";
static const char __pyx_k_Alias[] = "Alias";
static const char __pyx_k_COUNT[] = "COUNT";
static const char __pyx_k_DEBUG[] = "DEBUG";
static const char __pyx_k_DLRAW[] = "DLRAW";
static const char __pyx_k_FETCH[] = "FETCH";
static const char __pyx_k_FOUND[] = "FOUND";
static const char __pyx_k_Found[] = "Found ";
static const char __pyx_k_Int64[] = "Int64";
static const char __pyx_k_Judge[] = "Judge";
static const char __pyx_k_Payee[] = "Payee";
static const char __pyx_k_Payor[] = "Payor";
static const char __pyx_k_Phone[] = "(Phone: )(.+)";
static const char __pyx_k_QUEUE[] = "QUEUE";
static const char __pyx_k_SEG_2[] = "SEG_2";
static const char __pyx_k_Split[] = "Split";
static const char __pyx_k_State[] = "State";
static const char __pyx_k_TABLE[] = "TABLE";
static const char __pyx_k_TBNV1[] = "TBNV1";
static const char __pyx_k_TBNV2[] = "TBNV2";
static const char __pyx_k_Total[] = "Total";
static const char __pyx_k_Zip_2[] = "(Zip: )(.+)";
static const char __pyx_k_alias[] = "alias";
static const char __pyx_k_apply[] = "apply";
static const char __pyx_k_aptxt[] = "aptxt";
static const char __pyx_k_cases[] = "cases";
static const char __pyx_k_click[] = "click";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_d999m[] = "d999m";
static const char __pyx_k_d_1_2[] = "(?:\\$\\d{1,2})( )";
static const char __pyx_k_d_d_2[] = "\\$\\d+\\.\\d{2}";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_enter[] = "__enter__";
static const char __pyx_k_fetch[] = "fetch";
static const char __pyx_k_fname[] = "fname";
static const char __pyx_k_force[] = "force";
static const char __pyx_k_found[] = "found";
static const char __pyx_k_frame[] = "frame";
static const char __pyx_k_group[] = "group";
static const char __pyx_k_image[] = "(<image\\:.+?>)";
static const char __pyx_k_inarc[] = "inarc";
static const char __pyx_k_isdir[] = "isdir";
static const char __pyx_k_itype[] = "itype";
static const char __pyx_k_login[] = "login";
static const char __pyx_k_multi[] = "multi";
static const char __pyx_k_n_s_2[] = "[\\n\\s:\\-]";
static const char __pyx_k_named[] = "named";
static const char __pyx_k_pages[] = "pages";
static const char __pyx_k_prefs[] = "prefs";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_qskip[] = "qskip";
static const char __pyx_k_query[] = "query";
static const char __pyx_k_queue[] = "queue";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_shape[] = "shape";
static const char __pyx_k_sleep[] = "sleep";
static const char __pyx_k_slice[] = "slice";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_table[] = "table";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_upper[] = "upper";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_write[] = "write";
static const char __pyx_k_0_00_2[] = "0.00";
static const char __pyx_k_79_2_7[] = "79.2.8";
static const char __pyx_k_ACTIVE[] = "ACTIVE";
static const char __pyx_k_APPEND[] = "APPEND";
static const char __pyx_k_AmtDue[] = "AmtDue";
static const char __pyx_k_COUNTY[] = "COUNTY";
static const char __pyx_k_Chrome[] = "Chrome";
static const char __pyx_k_Config[] = "Config";
static const char __pyx_k_County[] = "County";
static const char __pyx_k_FELONY[] = "FELONY";
static const char __pyx_k_Felony[] = "Felony";
static const char __pyx_k_Filing[] = "Filing";
static const char __pyx_k_Height[] = "Height";
static const char __pyx_k_INPUTS[] = "INPUTS";
static const char __pyx_k_Payee1[] = "Payee1";
static const char __pyx_k_Payee2[] = "Payee2";
static const char __pyx_k_Payor1[] = "Payor1";
static const char __pyx_k_Payor2[] = "Payor2";
static const char __pyx_k_SIDRAW[] = "SIDRAW";
static const char __pyx_k_Select[] = "Select";
static const char __pyx_k_Series[] = "Series";
static const char __pyx_k_TOTALS[] = "TOTALS";
static const char __pyx_k_WINDOW[] = "WINDOW";
static const char __pyx_k_Weight[] = "Weight";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_blocks[] = "blocks";
static const char __pyx_k_brotli[] = "brotli";
static const char __pyx_k_common[] = "common";
static const char __pyx_k_concat[] = "concat";
static const char __pyx_k_county[] = "county";
static const char __pyx_k_d999mm[] = "d999mm";
static const char __pyx_k_driver[] = "driver";
static const char __pyx_k_getDOB[] = "getDOB";
static const char __pyx_k_getSSN[] = "getSSN";
static const char __pyx_k_getSex[] = "getSex";
static const char __pyx_k_hovers[] = "hovers";
static const char __pyx_k_ignore[] = "ignore";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_inpath[] = "inpath";
static const char __pyx_k_inputs[] = "inputs";
static const char __pyx_k_is_not[] = "is_not";
static const char __pyx_k_isfile[] = "isfile";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_option[] = "option";
static const char __pyx_k_outarc[] = "outarc";
static const char __pyx_k_polars[] = "polars";
static const char __pyx_k_pscols[] = "pscols";
static const char __pyx_k_qwrite[] = "qwrite";
static const char __pyx_k_rsplit[] = "rsplit";
static const char __pyx_k_rstrip[] = "rstrip";
static const char __pyx_k_search[] = "search";
static const char __pyx_k_select[] = "select";
static const char __pyx_k_series[] = "series";
static const char __pyx_k_snappy[] = "snappy";
static const char __pyx_k_strict[] = "strict";
static const char __pyx_k_tables[] = "tables";
static const char __pyx_k_window[] = "window";
static const char __pyx_k_0_9_s_2[] = "[^0-9\\.\\s]";
static const char __pyx_k_ALABAMA[] = "ALABAMA";
static const char __pyx_k_ARCHIVE[] = "ARCHIVE";
static const char __pyx_k_AmtHold[] = "AmtHold";
static const char __pyx_k_AmtPaid[] = "AmtPaid";
static const char __pyx_k_Balance[] = "Balance";
static const char __pyx_k_BondAmt[] = "BondAmt";
static const char __pyx_k_Charges[] = "Charges";
static const char __pyx_k_Country[] = "Country";
static const char __pyx_k_FEE_SEP[] = "FEE_SEP";
static const char __pyx_k_Float64[] = "Float64";
static const char __pyx_k_Options[] = "Options";
static const char __pyx_k_Phone_2[] = "(Phone.+)";
static const char __pyx_k_Phone_3[] = "Phone";
static const char __pyx_k_Phone_4[] = "Phone.+";
static const char __pyx_k_RE_Fees[] = "RE_Fees";
static const char __pyx_k_StateID[] = "StateID";
static const char __pyx_k_Total_2[] = "Total:";
static const char __pyx_k_Total_n[] = "(Total:.+\\$[^\\n]*)";
static const char __pyx_k_ZipCode[] = "ZipCode";
static const char __pyx_k_archive[] = "archive";
static const char __pyx_k_autofit[] = "autofit";
static const char __pyx_k_cID_box[] = "cID_box";
static const char __pyx_k_cal_pyx[] = "cal.pyx";
static const char __pyx_k_charges[] = "charges";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_d_d_2_2[] = "\\d+\\.\\d{2}";
static const char __pyx_k_dirpath[] = "dirpath";
static const char __pyx_k_explode[] = "explode";
static const char __pyx_k_extract[] = "extract";
static const char __pyx_k_findall[] = "findall";
static const char __pyx_k_genexpr[] = "genexpr";
static const char __pyx_k_getCity[] = "getCity";
static const char __pyx_k_getEyes[] = "getEyes";
static const char __pyx_k_getHair[] = "getHair";
static const char __pyx_k_getName[] = "getName";
static const char __pyx_k_getRace[] = "getRace";
static const char __pyx_k_groupby[] = "groupby";
static const char __pyx_k_inspect[] = "inspect";
static const char __pyx_k_literal[] = "literal";
static const char __pyx_k_n_chars[] = "n_chars";
static const char __pyx_k_next_pg[] = "next_pg";
static const char __pyx_k_options[] = "options";
static const char __pyx_k_outpath[] = "outpath";
static const char __pyx_k_outputs[] = "outputs";
static const char __pyx_k_parquet[] = ".parquet";
static const char __pyx_k_pwd_box[] = "pwd_box";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_results[] = "results";
static const char __pyx_k_s_d_d_2[] = "\\s\\$\\d+\\.\\d{2}";
static const char __pyx_k_scounty[] = "scounty";
static const char __pyx_k_ssn_box[] = "ssn_box";
static const char __pyx_k_street1[] = "street1";
static const char __pyx_k_street2[] = "street2";
static const char __pyx_k_success[] = "success";
static const char __pyx_k_version[] = "version";
static const char __pyx_k_zipcode[] = "zipcode";
static const char __pyx_k_0000_A_Z[] = "-0000$|[A-Z].+";
static const char __pyx_k_Address1[] = "Address1";
static const char __pyx_k_Address2[] = "Address2";
static const char __pyx_k_AdminFee[] = "AdminFee";
static const char __pyx_k_AmtHold1[] = "AmtHold1";
static const char __pyx_k_AppealTo[] = "AppealTo";
static const char __pyx_k_BondType[] = "BondType";
static const char __pyx_k_Category[] = "Category";
static const char __pyx_k_DIVISION[] = "DIVISION";
static const char __pyx_k_NEEDTEXT[] = "NEEDTEXT";
static const char __pyx_k_NO_WRITE[] = "NO_WRITE";
static const char __pyx_k_PROGRESS[] = "PROGRESS";
static const char __pyx_k_R0_9_d_3[] = "[^R0-9]\\d{3}";
static const char __pyx_k_RE_Phone[] = "RE_Phone";
static const char __pyx_k_TEMP_DOB[] = "TEMP_DOB";
static const char __pyx_k_TEMP_SSN[] = "TEMP_SSN";
static const char __pyx_k_Weight_d[] = "Weight: (\\d+)";
static const char __pyx_k_Workbook[] = "Workbook";
static const char __pyx_k_alac_899[] = "alac 899";
static const char __pyx_k_alac_931[] = "alac 931";
static const char __pyx_k_alac_945[] = "alac 945";
static const char __pyx_k_alac_965[] = "alac 965";
static const char __pyx_k_alac_989[] = "alac 989";
static const char __pyx_k_alac_994[] = "alac 994";
static const char __pyx_k_all_fees[] = "all_fees";
static const char __pyx_k_contains[] = "contains";
static const char __pyx_k_division[] = "division";
static const char __pyx_k_getAlias[] = "getAlias";
static const char __pyx_k_getJudge[] = "getJudge";
static const char __pyx_k_getPhone[] = "getPhone";
static const char __pyx_k_getState[] = "getState";
static const char __pyx_k_getTBNV1[] = "getTBNV1";
static const char __pyx_k_getTBNV2[] = "getTBNV2";
static const char __pyx_k_get_text[] = "get_text";
static const char __pyx_k_no_write[] = "no_write";
static const char __pyx_k_pdflinks[] = "pdflinks";
static const char __pyx_k_platform[] = "platform";
static const char __pyx_k_read_csv[] = "read_csv";
static const char __pyx_k_selenium[] = "selenium";
static const char __pyx_k_splitext[] = "splitext";
static const char __pyx_k_tempcols[] = "tempcols";
static const char __pyx_k_w_2_d_12[] = "(\\w{2}\\d{12})";
static const char __pyx_k_warnings[] = "warnings";
static const char __pyx_k_workbook[] = "workbook";
static const char __pyx_k_ALACORDER[] = "ALACORDER";
static const char __pyx_k_Address_2[] = "(?:Address 2:)(.+)";
static const char __pyx_k_AdminFee1[] = "AdminFee1";
static const char __pyx_k_AgencyORI[] = "AgencyORI";
static const char __pyx_k_CASE_YEAR[] = "CASE_YEAR";
static const char __pyx_k_CONVICTED[] = "CONVICTED";
static const char __pyx_k_Country_2[] = "Country:";
static const char __pyx_k_Country_w[] = "Country: (\\w*+)";
static const char __pyx_k_DataFrame[] = "DataFrame";
static const char __pyx_k_FETCH_MAX[] = "FETCH_MAX";
static const char __pyx_k_FeeStatus[] = "FeeStatus";
static const char __pyx_k_NO_PROMPT[] = "NO_PROMPT";
static const char __pyx_k_NO_UPDATE[] = "NO_UPDATE";
static const char __pyx_k_OVERWRITE[] = "OVERWRITE";
static const char __pyx_k_RAWHEIGHT[] = "RAWHEIGHT";
static const char __pyx_k_RETRIEVED[] = "RETRIEVED";
static const char __pyx_k_Retrieved[] = "Retrieved";
static const char __pyx_k_SPACE_SEP[] = "SPACE_SEP";
static const char __pyx_k_TEMP_NAME[] = "TEMP_NAME";
static const char __pyx_k_Timestamp[] = "Timestamp";
static const char __pyx_k_TrialType[] = "TrialType";
static const char __pyx_k_alac_1004[] = "alac 1004";
static const char __pyx_k_alac_1026[] = "alac 1026";
static const char __pyx_k_alac_1040[] = "alac 1040";
static const char __pyx_k_case_year[] = "case_year";
static const char __pyx_k_dataframe[] = "dataframe";
static const char __pyx_k_directory[] = "directory";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_fill_null[] = "fill_null";
static const char __pyx_k_getCounty[] = "getCounty";
static const char __pyx_k_getHeight[] = "getHeight";
static const char __pyx_k_getWeight[] = "getWeight";
static const char __pyx_k_goodquery[] = "goodquery";
static const char __pyx_k_menuHover[] = "menuHover";
static const char __pyx_k_no_prompt[] = "no_prompt";
static const char __pyx_k_no_update[] = "no_update";
static const char __pyx_k_otherwise[] = "otherwise";
static const char __pyx_k_outputext[] = "outputext";
static const char __pyx_k_overwrite[] = "overwrite";
static const char __pyx_k_querypath[] = "querypath";
static const char __pyx_k_read_json[] = "read_json";
static const char __pyx_k_recursive[] = "recursive";
static const char __pyx_k_sdivision[] = "sdivision";
static const char __pyx_k_send_keys[] = "send_keys";
static const char __pyx_k_threading[] = "threading";
static const char __pyx_k_webdriver[] = "webdriver";
static const char __pyx_k_worksheet[] = "worksheet";
static const char __pyx_k_write_csv[] = "write_csv";
static const char __pyx_k_2050000000[] = "2050000000";
static const char __pyx_k_A_S_C_DISQ[] = "A_S_C_DISQ";
static const char __pyx_k_A_Z0_9_s_n[] = "[^A-Z0-9|\\.|\\s|\\$|\\n]";
static const char __pyx_k_AppealDate[] = "AppealDate";
static const char __pyx_k_ArrestDate[] = "ArrestDate";
static const char __pyx_k_CLASS_NAME[] = "CLASS_NAME";
static const char __pyx_k_CaseNumber[] = "CaseNumber";
static const char __pyx_k_City_State[] = "(?:City: )(.*)(?:State: )(.*)";
static const char __pyx_k_Conviction[] = "Conviction";
static const char __pyx_k_County_d_2[] = "(?:County: )(\\d{2})";
static const char __pyx_k_Defendants[] = "Defendants";
static const char __pyx_k_FETCH_SKIP[] = "FETCH_SKIP";
static const char __pyx_k_FeeStatus1[] = "FeeStatus1";
static const char __pyx_k_FeeStatus2[] = "FeeStatus2";
static const char __pyx_k_FilingDate[] = "FilingDate";
static const char __pyx_k_INPUT_TYPE[] = "INPUT_TYPE";
static const char __pyx_k_JuryDemand[] = "JuryDemand";
static const char __pyx_k_Logging_in[] = "Logging in...";
static const char __pyx_k_NO_RECORDS[] = "NO_RECORDS";
static const char __pyx_k_OUTPUT_EXT[] = "OUTPUT_EXT";
static const char __pyx_k_PARTY_TYPE[] = "PARTY_TYPE";
static const char __pyx_k_Plaintiffs[] = "Plaintiffs";
static const char __pyx_k_RE_Charges[] = "RE_Charges";
static const char __pyx_k_SuretyCode[] = "SuretyCode";
static const char __pyx_k_Updated_By[] = "(Updated By:)";
static const char __pyx_k_concat_str[] = "concat_str";
static const char __pyx_k_defendants[] = "defendants";
static const char __pyx_k_drop_nulls[] = "drop_nulls";
static const char __pyx_k_exceptions[] = "exceptions";
static const char __pyx_k_getAddress[] = "getAddress";
static const char __pyx_k_getBondAmt[] = "getBondAmt";
static const char __pyx_k_getCountry[] = "getCountry";
static const char __pyx_k_getPDFText[] = "getPDFText";
static const char __pyx_k_getStateID[] = "getStateID";
static const char __pyx_k_getZipCode[] = "getZipCode";
static const char __pyx_k_has_window[] = "has_window";
static const char __pyx_k_multitable[] = "multitable";
static const char __pyx_k_party_type[] = "party_type";
static const char __pyx_k_plaintiffs[] = "plaintiffs";
static const char __pyx_k_read_excel[] = "read_excel";
static const char __pyx_k_read_query[] = "read_query";
static const char __pyx_k_scase_year[] = "scase_year";
static const char __pyx_k_split_fees[] = "split_fees";
static const char __pyx_k_write_json[] = "write_json";
static const char __pyx_k_xlsxwriter[] = "xlsxwriter";
static const char __pyx_k_0_000000_00[] = "0-000000-00";
static const char __pyx_k_AL000000000[] = "AL000000000";
static const char __pyx_k_ALA_USER_ID[] = "ALA_USER_ID";
static const char __pyx_k_AppealCourt[] = "AppealCourt";
static const char __pyx_k_B_W_H_A_F_M[] = "(B|W|H|A)/(?:F|M)";
static const char __pyx_k_BondCompany[] = "BondCompany";
static const char __pyx_k_Bond_Type_w[] = "Bond Type: (\\w)";
static const char __pyx_k_CASES_FOUND[] = "CASES_FOUND";
static const char __pyx_k_CLEAN_Phone[] = "CLEAN_Phone";
static const char __pyx_k_COMPLETE_AA[] = "COMPLETE-AA";
static const char __pyx_k_COMPLETE_MA[] = "COMPLETE-MA";
static const char __pyx_k_COMPLETE_SQ[] = "COMPLETE-SQ";
static const char __pyx_k_COMPLETE_TB[] = "COMPLETE-TB";
static const char __pyx_k_Case_Number[] = "Case Number:";
static const char __pyx_k_CourtAction[] = "CourtAction";
static const char __pyx_k_Description[] = "Description";
static const char __pyx_k_Disposition[] = "Disposition";
static const char __pyx_k_FILED_AFTER[] = "FILED_AFTER";
static const char __pyx_k_Filing_Date[] = "Filing Date: ";
static const char __pyx_k_GUILTY_PLEA[] = "GUILTY PLEA";
static const char __pyx_k_Judge_A_Z_s[] = "Judge: ([A-Z\\-\\.\\s]+)";
static const char __pyx_k_Last_Update[] = "(Last Update:)";
static const char __pyx_k_MISDEMEANOR[] = "MISDEMEANOR";
static const char __pyx_k_OUTPUT_PATH[] = "OUTPUT_PATH";
static const char __pyx_k_OffenseDate[] = "OffenseDate";
static const char __pyx_k_SHORTCASENO[] = "SHORTCASENO";
static const char __pyx_k_SHORTCOUNTY[] = "SHORTCOUNTY";
static const char __pyx_k_TEMP_COUNTY[] = "TEMP_COUNTY";
static const char __pyx_k_TotalAmtDue[] = "TotalAmtDue";
static const char __pyx_k_all_charges[] = "all_charges";
static const char __pyx_k_compression[] = "compression";
static const char __pyx_k_current_url[] = "current_url";
static const char __pyx_k_downloadPDF[] = "downloadPDF";
static const char __pyx_k_empty_query[] = "empty_query";
static const char __pyx_k_extract_all[] = "extract_all";
static const char __pyx_k_filed_after[] = "filed_after";
static const char __pyx_k_fshort_name[] = "fshort_name";
static const char __pyx_k_getAddress1[] = "getAddress1";
static const char __pyx_k_getAddress2[] = "getAddress2";
static const char __pyx_k_getAppealTo[] = "getAppealTo";
static const char __pyx_k_getBondType[] = "getBondType";
static const char __pyx_k_getCaseYear[] = "getCaseYear";
static const char __pyx_k_getLastName[] = "getLastName";
static const char __pyx_k_getTotalRow[] = "getTotalRow";
static const char __pyx_k_group_index[] = "group_index";
static const char __pyx_k_next_button[] = "next_button";
static const char __pyx_k_old_archive[] = "old_archive";
static const char __pyx_k_replace_all[] = "replace_all";
static const char __pyx_k_set_verbose[] = "set_verbose";
static const char __pyx_k_sheet_names[] = "sheet_names";
static const char __pyx_k_sno_records[] = "sno_records";
static const char __pyx_k_split_cases[] = "split_cases";
static const char __pyx_k_write_excel[] = "write_excel";
static const char __pyx_k_ALA_PASSWORD[] = "ALA_PASSWORD";
static const char __pyx_k_AllPagesText[] = "AllPagesText";
static const char __pyx_k_AppealStatus[] = "AppealStatus";
static const char __pyx_k_AppealToDesc[] = "AppealToDesc";
static const char __pyx_k_BondTypeDesc[] = "BondTypeDesc";
static const char __pyx_k_FILED_BEFORE[] = "FILED_BEFORE";
static const char __pyx_k_Height_d_d_2[] = "Height : (\\d'\\d{2})";
static const char __pyx_k_RelatedCases[] = "RelatedCases";
static const char __pyx_k_SentenceDate[] = "SentenceDate";
static const char __pyx_k_TotalAmtHold[] = "TotalAmtHold";
static const char __pyx_k_TotalAmtPaid[] = "TotalAmtPaid";
static const char __pyx_k_TotalBalance[] = "TotalBalance";
static const char __pyx_k_TransferDesc[] = "TransferDesc";
static const char __pyx_k_YouthfulDate[] = "YouthfulDate";
static const char __pyx_k_filed_before[] = "filed_before";
static const char __pyx_k_find_element[] = "find_element";
static const char __pyx_k_getAgencyORI[] = "getAgencyORI";
static const char __pyx_k_getFirstName[] = "getFirstName";
static const char __pyx_k_getRetrieved[] = "getRetrieved";
static const char __pyx_k_getTrialType[] = "getTrialType";
static const char __pyx_k_is_full_text[] = "is_full_text";
static const char __pyx_k_login_button[] = "login_button";
static const char __pyx_k_login_screen[] = "login_screen";
static const char __pyx_k_long_version[] = "long_version";
static const char __pyx_k_page_counter[] = "page_counter";
static const char __pyx_k_pager_select[] = "pager_select";
static const char __pyx_k_party_search[] = "party_search";
static const char __pyx_k_read_parquet[] = "read_parquet";
static const char __pyx_k_searchButton[] = "searchButton";
static const char __pyx_k_set_tbl_cols[] = "set_tbl_cols";
static const char __pyx_k_set_tbl_rows[] = "set_tbl_rows";
static const char __pyx_k_username_box[] = "username_box";
static const char __pyx_k_with_columns[] = "with_columns";
static const char __pyx_k_0_000000_00_2[] = "(0-000000-00)";
static const char __pyx_k_B_W_H_A_F_M_2[] = "(?:B|W|H|A)/(F|M)";
static const char __pyx_k_B_W_H_A_F_M_3[] = "(B|W|H|A)/(F|M)";
static const char __pyx_k_ChromeOptions[] = "ChromeOptions";
static const char __pyx_k_GUILTY_PLEA_2[] = "GUILTY_PLEA";
static const char __pyx_k_PROGRESS_TEXT[] = "PROGRESS-TEXT";
static const char __pyx_k_Sentence_Date[] = "(Sentence Date: )";
static const char __pyx_k_StreetAddress[] = "StreetAddress";
static const char __pyx_k_TEMP_DIVISION[] = "TEMP_DIVISION";
static const char __pyx_k_Transfer_Desc[] = "(Transfer Desc:)";
static const char __pyx_k_alacorder_cal[] = "alacorder.cal";
static const char __pyx_k_clean_ch_list[] = "clean_ch_list";
static const char __pyx_k_clean_fs_list[] = "clean_fs_list";
static const char __pyx_k_continueLogIn[] = "continueLogIn";
static const char __pyx_k_county_select[] = "county_select";
static const char __pyx_k_d_Bond_Amount[] = "([\\d\\.]+) Bond Amount:";
static const char __pyx_k_drop_in_place[] = "drop_in_place";
static const char __pyx_k_find_elements[] = "find_elements";
static const char __pyx_k_getAppealDate[] = "getAppealDate";
static const char __pyx_k_getArrestDate[] = "getArrestDate";
static const char __pyx_k_getCaseNumber[] = "getCaseNumber";
static const char __pyx_k_getFilingDate[] = "getFilingDate";
static const char __pyx_k_getJuryDemand[] = "getJuryDemand";
static const char __pyx_k_getMiddleName[] = "getMiddleName";
static const char __pyx_k_getSuretyCode[] = "getSuretyCode";
static const char __pyx_k_get_attribute[] = "get_attribute";
static const char __pyx_k_partymountain[] = "partymountain";
static const char __pyx_k_results_count[] = "results_count";
static const char __pyx_k_search_button[] = "search_button";
static const char __pyx_k_split_charges[] = "split_charges";
static const char __pyx_k_write_parquet[] = "write_parquet";
static const char __pyx_k_AdminUpdatedBy[] = "AdminUpdatedBy";
static const char __pyx_k_CERVDisqCharge[] = "CERVDisqCharge";
static const char __pyx_k_IndictmentDate[] = "IndictmentDate";
static const char __pyx_k_OriginOfAppeal[] = "OriginOfAppeal";
static const char __pyx_k_PROGRESS_TOTAL[] = "PROGRESS_TOTAL";
static const char __pyx_k_QUERY_COMPLETE[] = "QUERY_COMPLETE";
static const char __pyx_k_SSN_5_75_Alias[] = "(?:SSN)(.{5,75})(?:Alias)";
static const char __pyx_k_Search_Results[] = "Search Results: ";
static const char __pyx_k_TEMP_CASE_YEAR[] = "TEMP_CASE_YEAR";
static const char __pyx_k_Trial_Type_A_Z[] = "Trial Type: ([A-Z]+)";
static const char __pyx_k_Updated_By_w_3[] = "Updated By: (\\w{3})";
static const char __pyx_k_append_archive[] = "append_archive";
static const char __pyx_k_filterwarnings[] = "filterwarnings";
static const char __pyx_k_getAppealCourt[] = "getAppealCourt";
static const char __pyx_k_getChargesRows[] = "getChargesRows";
static const char __pyx_k_getCourtAction[] = "getCourtAction";
static const char __pyx_k_getDescription[] = "getDescription";
static const char __pyx_k_getOffenseDate[] = "getOffenseDate";
static const char __pyx_k_getTotalAmtDue[] = "getTotalAmtDue";
static const char __pyx_k_party_name_box[] = "party_name_box";
static const char __pyx_k_tracebacklimit[] = "tracebacklimit";
static const char __pyx_k_ACTIVE_n_D999_n[] = "(ACTIVE[^\\n]+D999[^\\n]+)";
static const char __pyx_k_ALA_CUSTOMER_ID[] = "ALA_CUSTOMER_ID";
static const char __pyx_k_Address_1_Phone[] = "(?:Address 1:)(.+)(?:Phone)*?";
static const char __pyx_k_BondReleaseDate[] = "BondReleaseDate";
static const char __pyx_k_CERV_DISQ_MATCH[] = "CERV_DISQ_MATCH";
static const char __pyx_k_CourtActionDate[] = "CourtActionDate";
static const char __pyx_k_DefendantStatus[] = "DefendantStatus";
static const char __pyx_k_DriverLicenseNo[] = "DriverLicenseNo";
static const char __pyx_k_EXISTING_OUTPUT[] = "EXISTING_OUTPUT";
static const char __pyx_k_Extracting_text[] = "Extracting text...";
static const char __pyx_k_Jury_Demand_A_Z[] = "Jury Demand: ([A-Z]+)";
static const char __pyx_k_PERM_DISQ_MATCH[] = "PERM_DISQ_MATCH";
static const char __pyx_k_Parsing_charges[] = "Parsing charges...";
static const char __pyx_k_ProbationPeriod[] = "ProbationPeriod";
static const char __pyx_k_ProbationRevoke[] = "ProbationRevoke";
static const char __pyx_k_SUPPORT_ARCHIVE[] = "SUPPORT_ARCHIVE";
static const char __pyx_k_SentenceEndDate[] = "SentenceEndDate";
static const char __pyx_k_TEMP_NO_RECORDS[] = "TEMP_NO_RECORDS";
static const char __pyx_k_TEMP_PARTY_TYPE[] = "TEMP_PARTY_TYPE";
static const char __pyx_k_TypeDescription[] = "TypeDescription";
static const char __pyx_k_division_select[] = "division_select";
static const char __pyx_k_existing_output[] = "existing_output";
static const char __pyx_k_filed_after_box[] = "filed_after_box";
static const char __pyx_k_float_precision[] = "float_precision";
static const char __pyx_k_getAppealStatus[] = "getAppealStatus";
static const char __pyx_k_getAppealToDesc[] = "getAppealToDesc";
static const char __pyx_k_getBondTypeDesc[] = "getBondTypeDesc";
static const char __pyx_k_getFeeSheetRows[] = "getFeeSheetRows";
static const char __pyx_k_getRelatedCases[] = "getRelatedCases";
static const char __pyx_k_getSentenceDate[] = "getSentenceDate";
static const char __pyx_k_getTotalAmtHold[] = "getTotalAmtHold";
static const char __pyx_k_getTotalAmtPaid[] = "getTotalAmtPaid";
static const char __pyx_k_getTotalBalance[] = "getTotalBalance";
static const char __pyx_k_getTransferDesc[] = "getTransferDesc";
static const char __pyx_k_getYouthfulDate[] = "getYouthfulDate";
static const char __pyx_k_implicitly_wait[] = "implicitly_wait";
static const char __pyx_k_support_archive[] = "support_archive";
static const char __pyx_k_w_2_d_4_d_6_d_2[] = "(\\w{2}\\-\\d{4}\\-\\d{6}\\.\\d{2})";
static const char __pyx_k_A_Z_a_z_A_Za_z_s[] = "[A-Z][a-z][A-Za-z\\s\\$]+.+";
static const char __pyx_k_Agency_ORI_A_Z_s[] = "Agency ORI: ([A-Z\\s]+)";
static const char __pyx_k_ArrestingOfficer[] = "ArrestingOfficer";
static const char __pyx_k_CONTEXT_SETTINGS[] = "CONTEXT_SETTINGS";
static const char __pyx_k_Charge_A_Z_0_9_s[] = "Charge: ([A-Z\\.0-9\\-\\s]+)";
static const char __pyx_k_DomesticViolence[] = "DomesticViolence";
static const char __pyx_k_Found_no_results[] = ": Found no results.";
static const char __pyx_k_JailCreditPeriod[] = "JailCreditPeriod";
static const char __pyx_k_NumberOfWarrants[] = "NumberOfWarrants";
static const char __pyx_k_PardonDisqCharge[] = "PardonDisqCharge";
static const char __pyx_k_PaymentToRestore[] = "PaymentToRestore";
static const char __pyx_k_Probation_Period[] = "Probation Period: ([^\\.]+)";
static const char __pyx_k_Probation_Revoke[] = "Probation Revoke: ";
static const char __pyx_k_TEMP_FILED_AFTER[] = "TEMP_FILED_AFTER";
static const char __pyx_k_Updated_By_w_3_2[] = "Updated By: (\\w{3}?)";
static const char __pyx_k_case_year_select[] = "case_year_select";
static const char __pyx_k_filed_before_box[] = "filed_before_box";
static const char __pyx_k_records_returned[] = " records returned)";
static const char __pyx_k_Enforcement_Party[] = "(Enforcement|Party)";
static const char __pyx_k_Eyes_Hair_w_3_w_3[] = "Eyes/Hair: (\\w{3})/(\\w{3})";
static const char __pyx_k_LicenseSuspPeriod[] = "LicenseSuspPeriod";
static const char __pyx_k_NumberOfSubpoenas[] = "NumberOfSubpoenas";
static const char __pyx_k_PARDON_DISQ_MATCH[] = "PARDON_DISQ_MATCH";
static const char __pyx_k_SentenceStartDate[] = "SentenceStartDate";
static const char __pyx_k_SentenceUpdatedBy[] = "SentenceUpdatedBy";
static const char __pyx_k_Sentence_End_Date[] = "(Sentence End Date:)";
static const char __pyx_k_TEMP_FILED_BEFORE[] = "TEMP_FILED_BEFORE";
static const char __pyx_k_WarrantActionDate[] = "WarrantActionDate";
static const char __pyx_k_Writing_to_export[] = "Writing to export...";
static const char __pyx_k_d_1_2_d_d_d_d_d_d[] = "(\\d{1,2}/\\d\\d/\\d\\d\\d\\d)";
static const char __pyx_k_date_of_birth_box[] = "date_of_birth_box";
static const char __pyx_k_getAdminUpdatedBy[] = "getAdminUpdatedBy";
static const char __pyx_k_getIndictmentDate[] = "getIndictmentDate";
static const char __pyx_k_getOriginOfAppeal[] = "getOriginOfAppeal";
static const char __pyx_k_help_option_names[] = "help_option_names";
static const char __pyx_k_no_records_select[] = "no_records_select";
static const char __pyx_k_party_type_select[] = "party_type_select";
static const char __pyx_k_results_indicator[] = "results_indicator";
static const char __pyx_k_w_2_d_4_d_6_d_2_2[] = "(\\w{2}\\-\\d{4}-\\d{6}\\.\\d{2})";
static const char __pyx_k_w_2_d_4_d_6_d_2_3[] = "\\w{2}\\-(\\d{4})-\\d{6}\\.\\d{2}";
static const char __pyx_k_write_event_value[] = "write_event_value";
static const char __pyx_k_A_Z0_9_11_State_ID[] = "([A-Z0-9]{11}?) State ID:";
static const char __pyx_k_Appeal_To_w_Appeal[] = "Appeal To: (\\w?) Appeal";
static const char __pyx_k_CERVDisqConviction[] = "CERVDisqConviction";
static const char __pyx_k_CaseInitiationDate[] = "CaseInitiationDate";
static const char __pyx_k_CaseInitiationType[] = "CaseInitiationType";
static const char __pyx_k_Extracting_charges[] = "Extracting charges...";
static const char __pyx_k_FailedToAppearDate[] = "FailedToAppearDate";
static const char __pyx_k_Jail_Credit_Period[] = "Jail Credit Period: ([^\\.]+)";
static const char __pyx_k_ProbationBeginDate[] = "ProbationBeginDate";
static const char __pyx_k_Probation_Revoke_2[] = "(Probation Revoke:)";
static const char __pyx_k_SUPPORT_MULTITABLE[] = "SUPPORT_MULTITABLE";
static const char __pyx_k_SentenceLastUpdate[] = "SentenceLastUpdate";
static const char __pyx_k_SentenceProvisions[] = "SentenceProvisions";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_frmIndexSearchForm[] = "frmIndexSearchForm";
static const char __pyx_k_getBondReleaseDate[] = "getBondReleaseDate";
static const char __pyx_k_getCourtActionDate[] = "getCourtActionDate";
static const char __pyx_k_getDefendantStatus[] = "getDefendantStatus";
static const char __pyx_k_getDriverLicenseNo[] = "getDriverLicenseNo";
static const char __pyx_k_getProbationPeriod[] = "getProbationPeriod";
static const char __pyx_k_getProbationRevoke[] = "getProbationRevoke";
static const char __pyx_k_getSentenceEndDate[] = "getSentenceEndDate";
static const char __pyx_k_getShortCaseNumber[] = "getShortCaseNumber";
static const char __pyx_k_n_s_d_Appeal_Court[] = "([\\n\\s/\\d]*?) Appeal Court:";
static const char __pyx_k_records_returned_2[] = " records returned.";
static const char __pyx_k_set_tbl_formatting[] = "set_tbl_formatting";
static const char __pyx_k_support_multitable[] = "support_multitable";
static const char __pyx_k_Appeal_Status_A_Z_s[] = "Appeal Status: ([A-Z\\-\\s]+)";
static const char __pyx_k_ArrestingAgencyType[] = "ArrestingAgencyType";
static const char __pyx_k_Bond_Company_A_Z0_9[] = "Bond Company: ([A-Z0-9]+)";
static const char __pyx_k_CM_d_d_CMUR_CAPITAL[] = "(CM\\d\\d|CMUR)|(CAPITAL)";
static const char __pyx_k_License_Susp_Period[] = "License Susp Period: ([^\\.]+)";
static const char __pyx_k_PROGRESS_TEXT_TOTAL[] = "PROGRESS-TEXT-TOTAL";
static const char __pyx_k_Parsing_fees_tables[] = "Parsing fees tables...";
static const char __pyx_k_PermanentDisqCharge[] = "PermanentDisqCharge";
static const char __pyx_k_ProbationOfficeName[] = "ProbationOfficeName";
static const char __pyx_k_SUPPORT_SINGLETABLE[] = "SUPPORT_SINGLETABLE";
static const char __pyx_k_Sentence_Provisions[] = "(Sentence Provisions:)";
static const char __pyx_k_Sentence_Start_Date[] = "(Sentence Start Date:)";
static const char __pyx_k_TRAFFIC_MISDEMEANOR[] = "TRAFFIC MISDEMEANOR";
static const char __pyx_k_UTF8_FULL_CONDENSED[] = "UTF8_FULL_CONDENSED";
static const char __pyx_k_WarrantActionStatus[] = "WarrantActionStatus";
static const char __pyx_k_WarrantIssuanceDate[] = "WarrantIssuanceDate";
static const char __pyx_k_d_2_d_2_d_4_0_5_DOB[] = "(\\d{2}/\\d{2}/\\d{4})(?:.{0,5}DOB:)";
static const char __pyx_k_getArrestingOfficer[] = "getArrestingOfficer";
static const char __pyx_k_getDomesticViolence[] = "getDomesticViolence";
static const char __pyx_k_getJailCreditPeriod[] = "getJailCreditPeriod";
static const char __pyx_k_getNumberOfWarrants[] = "getNumberOfWarrants";
static const char __pyx_k_getPaymentToRestore[] = "getPaymentToRestore";
static const char __pyx_k_set_fmt_str_lengths[] = "set_fmt_str_lengths";
static const char __pyx_k_support_singletable[] = "support_singletable";
static const char __pyx_k_Appeal_To_Desc_A_Z_s[] = "Appeal To Desc: ([A-Z\\-\\s]+)";
static const char __pyx_k_Bond_Type_Desc_A_Z_s[] = "Bond Type Desc: ([A-Z\\s]+)";
static const char __pyx_k_Case_Initiation_Date[] = "Case Initiation Date: ";
static const char __pyx_k_Extracting_case_info[] = "Extracting case info...";
static const char __pyx_k_Jail_Credit_Period_2[] = "(Jail Credit Period:)";
static const char __pyx_k_LowerCourtAppealDate[] = "LowerCourtAppealDate";
static const char __pyx_k_PardonDisqConviction[] = "PardonDisqConviction";
static const char __pyx_k_Probation_Begin_Date[] = "(Probation Begin Date:)";
static const char __pyx_k_Probation_Office_0_9[] = "Probation Office \\#: ([0-9\\-]+)";
static const char __pyx_k_Surety_Code_A_Z0_9_4[] = "Surety Code: ([A-Z0-9]{4})";
static const char __pyx_k_getLicenseSuspPeriod[] = "getLicenseSuspPeriod";
static const char __pyx_k_getNumberOfSubpoenas[] = "getNumberOfSubpoenas";
static const char __pyx_k_getSentenceStartDate[] = "getSentenceStartDate";
static const char __pyx_k_getSentenceUpdatedBy[] = "getSentenceUpdatedBy";
static const char __pyx_k_getWarrantActionDate[] = "getWarrantActionDate";
static const char __pyx_k_BondsmanProcessReturn[] = "BondsmanProcessReturn";
static const char __pyx_k_Extracting_fee_sheets[] = "Extracting fee sheets...";
static const char __pyx_k_License_Susp_Period_2[] = "(License Susp Period:)";
static const char __pyx_k_Orgin_Of_Appeal_A_Z_s[] = "Orgin Of Appeal: ([A-Z\\-\\s]+)";
static const char __pyx_k_SSN_X_d_3_X_d_2_X_d_4[] = "SSN: ([X\\d]{3}\\-[X\\d]{2}-[X\\d]{4})";
static const char __pyx_k_TrafficCitationNumber[] = "TrafficCitationNumber";
static const char __pyx_k_WarrantIssuanceStatus[] = "WarrantIssuanceStatus";
static const char __pyx_k_WarrantLocationStatus[] = "WarrantLocationStatus";
static const char __pyx_k_getCaseInitiationDate[] = "getCaseInitiationDate";
static const char __pyx_k_getCaseInitiationType[] = "getCaseInitiationType";
static const char __pyx_k_getFailedToAppearDate[] = "getFailedToAppearDate";
static const char __pyx_k_getProbationBeginDate[] = "getProbationBeginDate";
static const char __pyx_k_getSentenceLastUpdate[] = "getSentenceLastUpdate";
static const char __pyx_k_getSentenceProvisions[] = "getSentenceProvisions";
static const char __pyx_k_Connecting_to_Alacourt[] = "Connecting to Alacourt...";
static const char __pyx_k_Defendant_Status_A_Z_s[] = "Defendant Status: ([A-Z\\s]+)";
static const char __pyx_k_NoSuchElementException[] = "NoSuchElementException";
static const char __pyx_k_PreviousDUIConvictions[] = "PreviousDUIConvictions";
static const char __pyx_k_TransferToAdminDocDate[] = "TransferToAdminDocDate";
static const char __pyx_k_getArrestingAgencyType[] = "getArrestingAgencyType";
static const char __pyx_k_getProbationOfficeName[] = "getProbationOfficeName";
static const char __pyx_k_getWarrantActionStatus[] = "getWarrantActionStatus";
static const char __pyx_k_getWarrantIssuanceDate[] = "getWarrantIssuanceDate";
static const char __pyx_k_select_by_visible_text[] = "select_by_visible_text";
static const char __pyx_k_Arresting_Officer_A_Z_s[] = "Arresting Officer: ([A-Z\\s]+)";
static const char __pyx_k_BondsmanProcessIssuance[] = "BondsmanProcessIssuance";
static const char __pyx_k_DispositionDateOfAppeal[] = "DispositionDateOfAppeal";
static const char __pyx_k_DispositionTypeOfAppeal[] = "DispositionTypeOfAppeal";
static const char __pyx_k_Driver_License_N_A_Z0_9[] = "Driver License N\302\260: ([A-Z0-9]+)";
static const char __pyx_k_Number_of_Subponeas_d_3[] = "Number of Subponeas: (\\d{3})";
static const char __pyx_k_PermanentDisqConviction[] = "PermanentDisqConviction";
static const char __pyx_k_Sentence_Provisions_Y_N[] = "Sentence Provisions: ([Y|N]?)";
static const char __pyx_k_Successfully_configured[] = "Successfully configured.";
static const char __pyx_k_Traffic_Citation_A_Z0_9[] = "Traffic Citation \\#: ([A-Z0-9]+)";
static const char __pyx_k_Warrant_Action_Status_w[] = "Warrant Action Status: (\\w)";
static const char __pyx_k_add_experimental_option[] = "add_experimental_option";
static const char __pyx_k_getLowerCourtAppealDate[] = "getLowerCourtAppealDate";
static const char __pyx_k_n_Requrements_Completed[] = "[\\n:]|Requrements Completed";
static const char __pyx_k_A_Z_s_Appeal_Case_Number[] = "([A-Z\\-\\s]+) Appeal Case Number";
static const char __pyx_k_Case_Number_d_d_w_County[] = "Case Number: (\\d\\d-\\w+) County:";
static const char __pyx_k_Completed_query_template[] = "Completed query template.";
static const char __pyx_k_Domestic_Violence_YES_NO[] = "Domestic Violence: ([YES|NO])";
static const char __pyx_k_PROBATIONOFFICENUMBERRAW[] = "PROBATIONOFFICENUMBERRAW";
static const char __pyx_k_getBondsmanProcessReturn[] = "getBondsmanProcessReturn";
static const char __pyx_k_getProbationOfficeNumber[] = "getProbationOfficeNumber";
static const char __pyx_k_getTrafficCitationNumber[] = "getTrafficCitationNumber";
static const char __pyx_k_getWarrantIssuanceStatus[] = "getWarrantIssuanceStatus";
static const char __pyx_k_getWarrantLocationStatus[] = "getWarrantLocationStatus";
static const char __pyx_k_0_9_Arresting_Agency_Type[] = "([^0-9]+) Arresting Agency Type:";
static const char __pyx_k_ALInstitutionalServiceNum[] = "ALInstitutionalServiceNum";
static const char __pyx_k_Defendant_Information_JID[] = "Defendant Information|JID:.+";
static const char __pyx_k_Enforcement_Party_Country[] = "(Enforcement|Party|Country)";
static const char __pyx_k_InpatientTreatmentOrdered[] = "InpatientTreatmentOrdered";
static const char __pyx_k_Warrant_Issuance_Status_w[] = "Warrant Issuance Status: (\\w)";
static const char __pyx_k_Warrant_Location_Status_w[] = "Warrant Location Status: (\\w)";
static const char __pyx_k_getPDFText_locals_genexpr[] = "getPDFText.<locals>.genexpr";
static const char __pyx_k_getPreviousDUIConvictions[] = "getPreviousDUIConvictions";
static const char __pyx_k_getTransferToAdminDocDate[] = "getTransferToAdminDocDate";
static const char __pyx_k_Case_Initiation_Type_A_Z_s[] = "Case Initiation Type: ([A-Z\\s]+)";
static const char __pyx_k_ContentPlaceHolder_btLogin[] = "ContentPlaceHolder_btLogin";
static const char __pyx_k_download_default_directory[] = "download.default_directory";
static const char __pyx_k_download_directory_upgrade[] = "download.directory_upgrade";
static const char __pyx_k_getBondsmanProcessIssuance[] = "getBondsmanProcessIssuance";
static const char __pyx_k_getDispositionDateOfAppeal[] = "getDispositionDateOfAppeal";
static const char __pyx_k_getDispositionTypeOfAppeal[] = "getDispositionTypeOfAppeal";
static const char __pyx_k_Arrest_Date_d_d_d_d_d_d_d_d[] = "Arrest Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Enforcement_Party_Country_2[] = "(Enforcement|Party|Country:)";
static const char __pyx_k_Filing_Date_d_d_d_d_d_d_d_d[] = "Filing Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Last_Update_d_d_d_d_d_d_d_d[] = "Last Update: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Submitted_party_search_form[] = "Submitted party search form...";
static const char __pyx_k_split_charges_locals_lambda[] = "split_charges.<locals>.<lambda>";
static const char __pyx_k_Alacourt_com_d_d_d_d_d_d_d_d[] = "Alacourt\\.com (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Number_Of_Warrants_d_3_s_d_3[] = "Number Of Warrants: (\\d{3}\\s\\d{3})";
static const char __pyx_k_Offense_Date_d_d_d_d_d_d_d_d[] = "Offense Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Previous_DUI_Convictions_d_3[] = "Previous DUI Convictions: (\\d{3})";
static const char __pyx_k_Probation_Office_Name_A_Z0_9[] = "Probation Office Name: ([A-Z0-9]+)";
static const char __pyx_k_Release_Date_d_d_d_d_d_d_d_d[] = "Release Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Requrements_Completed_YES_NO[] = "(?:Requrements Completed: )([YES|NO]?)";
static const char __pyx_k_download_prompt_for_download[] = "download.prompt_for_download";
static const char __pyx_k_getInpatientTreatmentOrdered[] = "getInpatientTreatmentOrdered";
static const char __pyx_k_selenium_webdriver_common_by[] = "selenium.webdriver.common.by";
static const char __pyx_k_ACTIVE_n_n_ACTIVE_n_n_Total_n[] = "(ACTIVE [^\\(\\n]+\\$[^\\(\\n]+ACTIVE[^\\(\\n]+[^\\n]|Total:.+\\$[^\\n]*)";
static const char __pyx_k_A_ATT_ATTEMPT_S_SOLICIT_CONSP[] = "(A ATT|ATTEMPT|S SOLICIT|CONSP)";
static const char __pyx_k_Sentence_Date_d_d_d_d_d_d_d_d[] = "(?:Sentence Date: )(\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Youthful_Date_d_d_d_d_d_d_d_d[] = "Youthful Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_selenium_webdriver_support_ui[] = "selenium.webdriver.support.ui";
static const char __pyx_k_A_Z0_9_3_A_Z0_9_3_A_Z0_9_3_0_1[] = "[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\\({0,1}[A-Z]{0,1}\\){0,1}\\.{0,1}\\d{0,1}";
static const char __pyx_k_BOUND_GUILTY_PLEA_WAIVED_TO_GJ[] = "(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\\. FORF\\.)";
static const char __pyx_k_Failed_to_determine_input_type[] = "Failed to determine input type.";
static const char __pyx_k_VS_V_VS_V_VS_VS_1_A_Z_s_10_100[] = "(?:VS\\.|V\\.| VS | V | VS: |-VS-{1})([A-Z\\s]{10,100})(Case Number)*";
static const char __pyx_k_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a[] = "(\\d{3}\\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\\n]{10,75})";
static const char __pyx_k_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z[] = "(ACTIVE [^\\(\\n]+\\$[^\\(\\n]+ACTIVE[^\\(\\n]+[^\\n]|Total:.+\\$[^A-Za-z\\n]*)";
static const char __pyx_k_ALCOHOL_BOND_CONSERVATION_DOCKE[] = "(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)";
static const char __pyx_k_AL_Institutional_Service_Num_na[] = "AL Institutional Service Num: ([^\\na-z])";
static const char __pyx_k_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A[] = "[A-Z0-9]{3}\\s{0,1}-[A-Z0-9]{3}\\s{0,1}-[A-Z0-9]{3}\\({0,1}?[A-Z]{0,1}?\\){0,1}?\\.{0,1}?\\d{0,1}?";
static const char __pyx_k_Append_failed_Archive_at_output[] = "Append failed! Archive at output path could not be read.";
static const char __pyx_k_ContentPlaceHolder1_dg_ibtnNext[] = "ContentPlaceHolder1_dg_ibtnNext";
static const char __pyx_k_Could_not_find_column_Timestamp[] = "Could not find column Timestamp in archive.";
static const char __pyx_k_Court_Action_Date_d_d_d_d_d_d_d[] = "Court Action Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Date_Trial_Began_but_No_Verdict[] = "Date Trial Began but No Verdict \\(TBNV1\\): ([^\\n]+)";
static const char __pyx_k_Disposition_Type_Of_Appeal_A_Za[] = "Disposition Type Of Appeal: [^A-Za-z]+";
static const char __pyx_k_Failed_to_Appear_Date_d_d_d_d_d[] = "Failed to Appear Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Indictment_Date_d_d_d_d_d_d_d_d[] = "Indictment Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Inpatient_Treatment_Ordered_YES[] = "Inpatient Treatment Ordered: ([YES|NO]?)";
static const char __pyx_k_Job_not_specified_Select_a_mode[] = "Job not specified. Select a mode and reconfigure to start.";
static const char __pyx_k_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A[] = "(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)";
static const char __pyx_k_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S[] = "(RAP1|RAP2|SOD1|SOD2|STSA|SXA1|SXA2|ECHI|SX12|CSSC|FTCS|MURD|MRDI|MURR|FMUR|PMIO|POBM|MIPR|POMA|INCE)";
static const char __pyx_k_Sentence_Date_d_d_d_d_d_d_d_d_2[] = "(Sentence Date: )(\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Sentence_End_Date_d_d_d_d_d_d_d[] = "Sentence End Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Sentence_Start_Date_d_d_d_d_d_d[] = "Sentence Start Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_SentencingRequirementsCompleted[] = "SentencingRequirementsCompleted";
static const char __pyx_k_TRAFFIC_MISDEMEANOR_BOND_FELONY[] = "(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)";
static const char __pyx_k_Warrant_Action_Date_d_d_d_d_d_d[] = "Warrant Action Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_alacorder_on_polars_Dependencie[] = "\n alacorder on polars\n \342\224\214\342\224\200\342\224\220\342\224\214\342\224\200\342\224\220\342\224\254\342\224\200\342\224\220\342\224\214\342\224\254\342\224\220\342\224\254 \342\224\254\342\224\214\342\224\254\342\224\220\342\224\214\342\224\200\342\224\220\342\224\254 \342\224\254\342\224\214\342\224\220\342\224\214\342\224\214\342\224\254\342\224\220\342\224\214\342\224\200\342\224\220\342\224\254\342\224\214\342\224\220\342\224\214\n \342\224\234\342\224\200\342\224\230\342\224\234\342\224\200\342\224\244\342\224\234\342\224\254\342\224\230 \342\224\202 \342\224\224\342\224\254\342\224\230\342\224\202\342\224\202\342\224\202\342\224\202 \342\224\202\342\224\202 \342\224\202\342\224\202\342\224\202\342\224\202 \342\224\202 \342\224\234\342\224\200\342\224\244\342\224\202\342\224\202\342\224\202\342\224\202\n \342\224\264  \342\224\264 \342\224\264\342\224\264\342\224\224\342\224\200 \342\224\264  \342\224\264 \342\224\264 \342\224\264\342\224\224\342\224\200\342\224\230\342\224\224\342\224\200\342\224\230\342\224\230\342\224\224\342\224\230 \342\224\264 \342\224\264 \342\224\264\342\224\264\342\224\230\342\224\224\342\224\230\n Dependencies: python>=3.9, selenium, polars, PyMuPDF, PySimpleGUI, click, tqdm, xlsxwriter, xlsx2csv\n (c) 2023 Sam Robson <sbrobson@crimson.ua.edu>\n";
static const char __pyx_k_ctl00_ContentPlaceHolder1_txtTo[] = "ctl00$ContentPlaceHolder1$txtTo";
static const char __pyx_k_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10[] = "(\\d{3}\\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})";
static const char __pyx_k_d_d_d_d_d_d_d_d_Warrant_Issuanc[] = "(\\d\\d?/\\d\\d?/\\d\\d\\d\\d) Warrant Issuance Date:";
static const char __pyx_k_queries_found_in_input_query_fi[] = " queries found in input query file.";
static const char __pyx_k_results_fetching_URLs_and_downl[] = " results, fetching URLs and downloading PDFs...";
static const char __pyx_k_Bondsman_Process_Issuance_n_Bond[] = "Bondsman Process Issuance: ([^\\n]*?) Bondsman Process Return:";
static const char __pyx_k_Bondsman_Process_Return_Number_o[] = "Bondsman Process Return: (.*?) Number of Subponeas";
static const char __pyx_k_Case_Initiation_Date_d_d_d_d_d_d[] = "Case Initiation Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_ContentPlaceHolder1_dg_tcPageXof[] = "ContentPlaceHolder1_dg_tcPageXofY";
static const char __pyx_k_ContentPlaceHolder1_lblResultCou[] = "ContentPlaceHolder1_lblResultCount";
static const char __pyx_k_Could_not_find_column_Path_in_ar[] = "Could not find column Path in archive.";
static const char __pyx_k_Could_not_write_to_output_path_b[] = "Could not write to output path because overwrite mode is not enabled.";
static const char __pyx_k_Court_Action_BOUND_GUILTY_PLEA_W[] = "Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\\. FORF\\.)";
static const char __pyx_k_Disposition_Date_Of_Appeal_d_d_d[] = "Disposition Date Of Appeal: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_JID_w_3_Hardship_Defendant_Infor[] = "JID: \\w{3} Hardship.*|Defendant Information.*";
static const char __pyx_k_LowerCourt_Appeal_Date_d_d_d_d_d[] = "LowerCourt Appeal Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_NoSuchElementException_on_alac_p[] = "NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value=\"ctl00$ContentPlaceHolder1$txtName\")";
static const char __pyx_k_Probation_Begin_Date_d_d_d_d_d_d[] = "Probation Begin Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Probation_Revoke_d_d_d_d_d_d_d_d[] = "Probation Revoke: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Single_table_export_choice_requi[] = "Single table export choice required! (cases, charges, fees)";
static const char __pyx_k_Starting_browser_Do_not_close_wh[] = "Starting browser... Do not close while in progress!";
static const char __pyx_k_Successfully_connected_and_logge[] = "Successfully connected and logged into Alacourt!";
static const char __pyx_k_Transfer_Desc_A_Z_s_0_15_d_d_d_d[] = "Transfer Desc: ([A-Z\\s]{0,15} \\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Transfer_to_Admin_Doc_Date_d_d_d[] = "Transfer to Admin Doc Date: (\\d\\d?/\\d\\d?/\\d\\d\\d\\d)";
static const char __pyx_k_Try_again_with_at_least_one_vali[] = "Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]";
static const char __pyx_k_ctl00_ContentPlaceHolder1_UcddlD[] = "ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision";
static const char __pyx_k_ctl00_ContentPlaceHolder1_ddlCas[] = "ctl00$ContentPlaceHolder1$ddlCaseYear";
static const char __pyx_k_ctl00_ContentPlaceHolder1_ddlCou[] = "ctl00$ContentPlaceHolder1$ddlCounties";
static const char __pyx_k_ctl00_ContentPlaceHolder1_ddlNum[] = "ctl00$ContentPlaceHolder1$ddlNumberOfRecords";
static const char __pyx_k_ctl00_ContentPlaceHolder1_dg_ctl[] = "ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages";
static const char __pyx_k_ctl00_ContentPlaceHolder1_rdlPar[] = "ctl00$ContentPlaceHolder1$rdlPartyType";
static const char __pyx_k_ctl00_ContentPlaceHolder1_txtDOB[] = "ctl00$ContentPlaceHolder1$txtDOB";
static const char __pyx_k_ctl00_ContentPlaceHolder1_txtFro[] = "ctl00$ContentPlaceHolder1$txtFrom";
static const char __pyx_k_ctl00_ContentPlaceHolder1_txtNam[] = "ctl00$ContentPlaceHolder1$txtName";
static const char __pyx_k_ctl00_ContentPlaceHolder1_txtSSN[] = "ctl00$ContentPlaceHolder1$txtSSN";
static const char __pyx_k_ctl00_ContentPlaceHolder_btnCont[] = "ctl00$ContentPlaceHolder$btnContinueLogin";
static const char __pyx_k_ctl00_ContentPlaceHolder_txtCusi[] = "ctl00$ContentPlaceHolder$txtCusid";
static const char __pyx_k_ctl00_ContentPlaceHolder_txtPass[] = "ctl00$ContentPlaceHolder$txtPassword";
static const char __pyx_k_ctl00_ContentPlaceHolder_txtUser[] = "ctl00$ContentPlaceHolder$txtUserId";
static const char __pyx_k_getSentencingRequirementsComplet[] = "getSentencingRequirementsCompleted";
static const char __pyx_k_https_v2_alacourt_com_frmIndexSe[] = "https://v2.alacourt.com/frmIndexSearchForm.aspx";
static const char __pyx_k_https_v2_alacourt_com_frmlogin_a[] = "https://v2.alacourt.com/frmlogin.aspx";
static const char __pyx_k_plugins_always_open_pdf_external[] = "plugins.always_open_pdf_externally";
static const char __pyx_k_selenium_webdriver_chrome_option[] = "selenium.webdriver.chrome.options";
static const char __pyx_k_Date_Trial_Began_but_No_Verdict_2[] = "Date Trial Began but No Verdict \\(TBNV2\\): ([^\\n]+)";
static const char __pyx_k_https_v2_alacourt_com_frmIndexSe_2[] = "https:v2.alacourt.com/frmIndexSearchForm.aspx";
static PyObject *__pyx_kp_u_0000_A_Z;
static PyObject *__pyx_kp_u_0_00;
static PyObject *__pyx_kp_u_0_000000_00;
static PyObject *__pyx_kp_u_0_000000_00_2;
static PyObject *__pyx_kp_u_0_00_2;
static PyObject *__pyx_kp_u_0_9;
static PyObject *__pyx_kp_u_0_9_2;
static PyObject *__pyx_kp_u_0_9_Arresting_Agency_Type;
static PyObject *__pyx_kp_u_0_9_s;
static PyObject *__pyx_kp_u_0_9_s_2;
static PyObject *__pyx_kp_u_1000;
static PyObject *__pyx_kp_u_2050000000;
static PyObject *__pyx_kp_u_79_2_7;
static PyObject *__pyx_n_u_A;
static PyObject *__pyx_n_u_ACTIVE;
static PyObject *__pyx_kp_u_ACTIVE_n_D999_n;
static PyObject *__pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z;
static PyObject *__pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_n;
static PyObject *__pyx_n_u_AL;
static PyObject *__pyx_n_u_AL000000000;
static PyObject *__pyx_n_u_ALABAMA;
static PyObject *__pyx_n_u_ALACORDER;
static PyObject *__pyx_n_u_ALA_CUSTOMER_ID;
static PyObject *__pyx_n_u_ALA_PASSWORD;
static PyObject *__pyx_n_u_ALA_USER_ID;
static PyObject *__pyx_kp_u_ALCOHOL_BOND_CONSERVATION_DOCKE;
static PyObject *__pyx_n_u_ALInstitutionalServiceNum;
static PyObject *__pyx_n_u_ALL;
static PyObject *__pyx_kp_u_AL_Institutional_Service_Num_na;
static PyObject *__pyx_n_u_APPEND;
static PyObject *__pyx_n_u_ARCHIVE;
static PyObject *__pyx_kp_u_A_ATT_ATTEMPT_S_SOLICIT_CONSP;
static PyObject *__pyx_n_u_A_S_C_DISQ;
static PyObject *__pyx_kp_u_A_Z;
static PyObject *__pyx_kp_u_A_Z0_9_11_State_ID;
static PyObject *__pyx_kp_u_A_Z0_9_3_A_Z0_9_3_A_Z0_9_3_0_1;
static PyObject *__pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A;
static PyObject *__pyx_kp_u_A_Z0_9_s_n;
static PyObject *__pyx_kp_u_A_Z_2;
static PyObject *__pyx_kp_u_A_Z_a_z_A_Za_z_s;
static PyObject *__pyx_kp_u_A_Z_s_Appeal_Case_Number;
static PyObject *__pyx_n_u_Address1;
static PyObject *__pyx_n_u_Address2;
static PyObject *__pyx_kp_u_Address_1_Phone;
static PyObject *__pyx_kp_u_Address_2;
static PyObject *__pyx_n_u_AdminFee;
static PyObject *__pyx_n_u_AdminFee1;
static PyObject *__pyx_n_u_AdminUpdatedBy;
static PyObject *__pyx_n_u_AgencyORI;
static PyObject *__pyx_kp_u_Agency_ORI_A_Z_s;
static PyObject *__pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_u_Alias;
static PyObject *__pyx_n_u_AllPagesText;
static PyObject *__pyx_n_u_AmtDue;
static PyObject *__pyx_n_u_AmtHold;
static PyObject *__pyx_n_u_AmtHold1;
static PyObject *__pyx_n_u_AmtPaid;
static PyObject *__pyx_n_u_AppealCourt;
static PyObject *__pyx_n_u_AppealDate;
static PyObject *__pyx_n_u_AppealStatus;
static PyObject *__pyx_n_u_AppealTo;
static PyObject *__pyx_n_u_AppealToDesc;
static PyObject *__pyx_kp_u_Appeal_Status_A_Z_s;
static PyObject *__pyx_kp_u_Appeal_To_Desc_A_Z_s;
static PyObject *__pyx_kp_u_Appeal_To_w_Appeal;
static PyObject *__pyx_kp_u_Append_failed_Archive_at_output;
static PyObject *__pyx_n_u_ArrestDate;
static PyObject *__pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_u_ArrestingAgencyType;
static PyObject *__pyx_n_u_ArrestingOfficer;
static PyObject *__pyx_kp_u_Arresting_Officer_A_Z_s;
static PyObject *__pyx_kp_u_BOUND_GUILTY_PLEA_WAIVED_TO_GJ;
static PyObject *__pyx_kp_u_B_W_H_A_F_M;
static PyObject *__pyx_kp_u_B_W_H_A_F_M_2;
static PyObject *__pyx_kp_u_B_W_H_A_F_M_3;
static PyObject *__pyx_n_u_Balance;
static PyObject *__pyx_n_u_BondAmt;
static PyObject *__pyx_n_u_BondCompany;
static PyObject *__pyx_n_u_BondReleaseDate;
static PyObject *__pyx_n_u_BondType;
static PyObject *__pyx_n_u_BondTypeDesc;
static PyObject *__pyx_kp_u_Bond_Company_A_Z0_9;
static PyObject *__pyx_kp_u_Bond_Type_Desc_A_Z_s;
static PyObject *__pyx_kp_u_Bond_Type_w;
static PyObject *__pyx_n_u_BondsmanProcessIssuance;
static PyObject *__pyx_n_u_BondsmanProcessReturn;
static PyObject *__pyx_kp_u_Bondsman_Process_Issuance_n_Bond;
static PyObject *__pyx_kp_u_Bondsman_Process_Return_Number_o;
static PyObject *__pyx_n_s_By;
static PyObject *__pyx_kp_u_C;
static PyObject *__pyx_n_u_CASES_FOUND;
static PyObject *__pyx_n_u_CASE_YEAR;
static PyObject *__pyx_n_u_CERVDisqCharge;
static PyObject *__pyx_n_u_CERVDisqConviction;
static PyObject *__pyx_n_u_CERV_DISQ_MATCH;
static PyObject *__pyx_n_s_CLASS_NAME;
static PyObject *__pyx_n_u_CLEAN_Phone;
static PyObject *__pyx_kp_u_CM_d_d_CMUR_CAPITAL;
static PyObject *__pyx_kp_u_COMPLETE_AA;
static PyObject *__pyx_kp_u_COMPLETE_MA;
static PyObject *__pyx_kp_u_COMPLETE_SQ;
static PyObject *__pyx_kp_u_COMPLETE_TB;
static PyObject *__pyx_n_s_CONTEXT_SETTINGS;
static PyObject *__pyx_n_u_CONVICTED;
static PyObject *__pyx_n_u_COUNT;
static PyObject *__pyx_n_u_COUNTY;
static PyObject *__pyx_n_u_C_2;
static PyObject *__pyx_n_u_CaseInitiationDate;
static PyObject *__pyx_n_u_CaseInitiationType;
static PyObject *__pyx_n_u_CaseNumber;
static PyObject *__pyx_kp_u_Case_Initiation_Date;
static PyObject *__pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Case_Initiation_Type_A_Z_s;
static PyObject *__pyx_kp_u_Case_Number;
static PyObject *__pyx_kp_u_Case_Number_d_d_w_County;
static PyObject *__pyx_n_u_Category;
static PyObject *__pyx_kp_u_Charge_A_Z_0_9_s;
static PyObject *__pyx_n_u_Charges;
static PyObject *__pyx_n_s_Chrome;
static PyObject *__pyx_n_s_ChromeOptions;
static PyObject *__pyx_n_u_Cite;
static PyObject *__pyx_n_u_City;
static PyObject *__pyx_kp_u_City_State;
static PyObject *__pyx_n_u_Code;
static PyObject *__pyx_kp_u_Completed_query_template;
static PyObject *__pyx_n_s_Config;
static PyObject *__pyx_kp_u_Connecting_to_Alacourt;
static PyObject *__pyx_n_u_ContentPlaceHolder1_dg_ibtnNext;
static PyObject *__pyx_n_u_ContentPlaceHolder1_dg_tcPageXof;
static PyObject *__pyx_n_u_ContentPlaceHolder1_lblResultCou;
static PyObject *__pyx_n_u_ContentPlaceHolder_btLogin;
static PyObject *__pyx_n_u_Conviction;
static PyObject *__pyx_kp_u_Could_not_find_column_Path_in_ar;
static PyObject *__pyx_kp_u_Could_not_find_column_Timestamp;
static PyObject *__pyx_kp_u_Could_not_write_to_output_path_b;
static PyObject *__pyx_n_u_Country;
static PyObject *__pyx_kp_u_Country_2;
static PyObject *__pyx_kp_u_Country_w;
static PyObject *__pyx_n_u_County;
static PyObject *__pyx_kp_u_County_d_2;
static PyObject *__pyx_n_u_CourtAction;
static PyObject *__pyx_n_u_CourtActionDate;
static PyObject *__pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W;
static PyObject *__pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d;
static PyObject *__pyx_n_u_D;
static PyObject *__pyx_n_u_D999;
static PyObject *__pyx_n_u_DEBUG;
static PyObject *__pyx_n_u_DIVISION;
static PyObject *__pyx_n_u_DLRAW;
static PyObject *__pyx_n_u_DOB;
static PyObject *__pyx_n_s_DataFrame;
static PyObject *__pyx_kp_u_Date_Trial_Began_but_No_Verdict;
static PyObject *__pyx_kp_u_Date_Trial_Began_but_No_Verdict_2;
static PyObject *__pyx_n_u_DefendantStatus;
static PyObject *__pyx_kp_u_Defendant_Information_JID;
static PyObject *__pyx_kp_u_Defendant_Status_A_Z_s;
static PyObject *__pyx_n_u_Defendants;
static PyObject *__pyx_n_u_Description;
static PyObject *__pyx_n_u_Disposition;
static PyObject *__pyx_n_u_DispositionDateOfAppeal;
static PyObject *__pyx_n_u_DispositionTypeOfAppeal;
static PyObject *__pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d;
static PyObject *__pyx_kp_u_Disposition_Type_Of_Appeal_A_Za;
static PyObject *__pyx_n_u_DomesticViolence;
static PyObject *__pyx_kp_u_Domestic_Violence_YES_NO;
static PyObject *__pyx_n_u_DriverLicenseNo;
static PyObject *__pyx_kp_u_Driver_License_N_A_Z0_9;
static PyObject *__pyx_n_u_EXISTING_OUTPUT;
static PyObject *__pyx_kp_u_Enforcement_Party;
static PyObject *__pyx_kp_u_Enforcement_Party_Country;
static PyObject *__pyx_kp_u_Enforcement_Party_Country_2;
static PyObject *__pyx_kp_u_Extracting_case_info;
static PyObject *__pyx_kp_u_Extracting_charges;
static PyObject *__pyx_kp_u_Extracting_fee_sheets;
static PyObject *__pyx_kp_u_Extracting_text;
static PyObject *__pyx_n_u_Eyes;
static PyObject *__pyx_kp_u_Eyes_Hair_w_3_w_3;
static PyObject *__pyx_n_u_FEE_SEP;
static PyObject *__pyx_n_u_FELONY;
static PyObject *__pyx_n_u_FETCH;
static PyObject *__pyx_n_u_FETCH_MAX;
static PyObject *__pyx_n_u_FETCH_SKIP;
static PyObject *__pyx_n_u_FILED_AFTER;
static PyObject *__pyx_n_u_FILED_BEFORE;
static PyObject *__pyx_n_u_FOUND;
static PyObject *__pyx_n_u_FailedToAppearDate;
static PyObject *__pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d;
static PyObject *__pyx_kp_u_Failed_to_determine_input_type;
static PyObject *__pyx_n_u_FeeStatus;
static PyObject *__pyx_n_u_FeeStatus1;
static PyObject *__pyx_n_u_FeeStatus2;
static PyObject *__pyx_n_u_Fees;
static PyObject *__pyx_n_u_Felony;
static PyObject *__pyx_n_u_Filing;
static PyObject *__pyx_n_u_FilingDate;
static PyObject *__pyx_kp_u_Filing_Date;
static PyObject *__pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_s_Float64;
static PyObject *__pyx_kp_u_Found;
static PyObject *__pyx_kp_u_Found_no_results;
static PyObject *__pyx_kp_u_GUILTY_PLEA;
static PyObject *__pyx_n_u_GUILTY_PLEA_2;
static PyObject *__pyx_n_u_Hair;
static PyObject *__pyx_n_u_Height;
static PyObject *__pyx_kp_u_Height_d_d_2;
static PyObject *__pyx_n_s_ID;
static PyObject *__pyx_n_u_INPUTS;
static PyObject *__pyx_n_u_INPUT_TYPE;
static PyObject *__pyx_n_u_IndictmentDate;
static PyObject *__pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_u_InpatientTreatmentOrdered;
static PyObject *__pyx_kp_u_Inpatient_Treatment_Ordered_YES;
static PyObject *__pyx_n_s_Int64;
static PyObject *__pyx_n_u_J;
static PyObject *__pyx_kp_u_JID_w_3_Hardship_Defendant_Infor;
static PyObject *__pyx_n_u_JailCreditPeriod;
static PyObject *__pyx_kp_u_Jail_Credit_Period;
static PyObject *__pyx_kp_u_Jail_Credit_Period_2;
static PyObject *__pyx_kp_u_Job_not_specified_Select_a_mode;
static PyObject *__pyx_n_u_Judge;
static PyObject *__pyx_kp_u_Judge_A_Z_s;
static PyObject *__pyx_n_u_JuryDemand;
static PyObject *__pyx_kp_u_Jury_Demand_A_Z;
static PyObject *__pyx_n_u_L;
static PyObject *__pyx_kp_u_Last_Update;
static PyObject *__pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_u_LicenseSuspPeriod;
static PyObject *__pyx_kp_u_License_Susp_Period;
static PyObject *__pyx_kp_u_License_Susp_Period_2;
static PyObject *__pyx_kp_u_Logging_in;
static PyObject *__pyx_n_u_LowerCourtAppealDate;
static PyObject *__pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d;
static PyObject *__pyx_n_u_MISDEMEANOR;
static PyObject *__pyx_n_s_NAME;
static PyObject *__pyx_n_u_NAME;
static PyObject *__pyx_n_u_NEEDTEXT;
static PyObject *__pyx_n_u_NO_PROMPT;
static PyObject *__pyx_n_u_NO_RECORDS;
static PyObject *__pyx_n_u_NO_UPDATE;
static PyObject *__pyx_n_u_NO_WRITE;
static PyObject *__pyx_n_u_Name;
static PyObject *__pyx_n_s_NoSuchElementException;
static PyObject *__pyx_kp_u_NoSuchElementException_on_alac_p;
static PyObject *__pyx_n_u_None;
static PyObject *__pyx_n_u_Num;
static PyObject *__pyx_n_u_NumberOfSubpoenas;
static PyObject *__pyx_n_u_NumberOfWarrants;
static PyObject *__pyx_kp_u_Number_Of_Warrants_d_3_s_d_3;
static PyObject *__pyx_kp_u_Number_of_Subponeas_d_3;
static PyObject *__pyx_kp_u_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A;
static PyObject *__pyx_n_u_OUTPUT_EXT;
static PyObject *__pyx_n_u_OUTPUT_PATH;
static PyObject *__pyx_n_u_OVERWRITE;
static PyObject *__pyx_n_u_OffenseDate;
static PyObject *__pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_s_Options;
static PyObject *__pyx_kp_u_Orgin_Of_Appeal_A_Z_s;
static PyObject *__pyx_n_u_OriginOfAppeal;
static PyObject *__pyx_n_u_P;
static PyObject *__pyx_n_u_PARDON_DISQ_MATCH;
static PyObject *__pyx_n_u_PARTY_TYPE;
static PyObject *__pyx_n_u_PDF;
static PyObject *__pyx_n_u_PERM_DISQ_MATCH;
static PyObject *__pyx_n_u_PROBATIONOFFICENUMBERRAW;
static PyObject *__pyx_n_u_PROGRESS;
static PyObject *__pyx_kp_u_PROGRESS_TEXT;
static PyObject *__pyx_kp_u_PROGRESS_TEXT_TOTAL;
static PyObject *__pyx_n_u_PROGRESS_TOTAL;
static PyObject *__pyx_n_u_PardonDisqCharge;
static PyObject *__pyx_n_u_PardonDisqConviction;
static PyObject *__pyx_kp_u_Parsing_charges;
static PyObject *__pyx_kp_u_Parsing_fees_tables;
static PyObject *__pyx_n_u_Path;
static PyObject *__pyx_n_u_Payee;
static PyObject *__pyx_n_u_Payee1;
static PyObject *__pyx_n_u_Payee2;
static PyObject *__pyx_n_u_PaymentToRestore;
static PyObject *__pyx_n_u_Payor;
static PyObject *__pyx_n_u_Payor1;
static PyObject *__pyx_n_u_Payor2;
static PyObject *__pyx_n_u_PermanentDisqCharge;
static PyObject *__pyx_n_u_PermanentDisqConviction;
static PyObject *__pyx_kp_u_Phone;
static PyObject *__pyx_kp_u_Phone_2;
static PyObject *__pyx_n_u_Phone_3;
static PyObject *__pyx_kp_u_Phone_4;
static PyObject *__pyx_n_u_Plaintiffs;
static PyObject *__pyx_n_u_PreviousDUIConvictions;
static PyObject *__pyx_kp_u_Previous_DUI_Convictions_d_3;
static PyObject *__pyx_n_u_ProbationBeginDate;
static PyObject *__pyx_n_u_ProbationOfficeName;
static PyObject *__pyx_n_u_ProbationPeriod;
static PyObject *__pyx_n_u_ProbationRevoke;
static PyObject *__pyx_kp_u_Probation_Begin_Date;
static PyObject *__pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Probation_Office_0_9;
static PyObject *__pyx_kp_u_Probation_Office_Name_A_Z0_9;
static PyObject *__pyx_kp_u_Probation_Period;
static PyObject *__pyx_kp_u_Probation_Revoke;
static PyObject *__pyx_kp_u_Probation_Revoke_2;
static PyObject *__pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d;
static PyObject *__pyx_n_u_QUERY_COMPLETE;
static PyObject *__pyx_n_u_QUEUE;
static PyObject *__pyx_kp_u_R0_9_d_3;
static PyObject *__pyx_kp_u_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S;
static PyObject *__pyx_n_u_RAWHEIGHT;
static PyObject *__pyx_n_u_RETRIEVED;
static PyObject *__pyx_n_u_RE_Charges;
static PyObject *__pyx_n_u_RE_Fees;
static PyObject *__pyx_n_u_RE_Phone;
static PyObject *__pyx_n_u_Race;
static PyObject *__pyx_n_u_RelatedCases;
static PyObject *__pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Requrements_Completed_YES_NO;
static PyObject *__pyx_n_u_Retrieved;
static PyObject *__pyx_n_u_S;
static PyObject *__pyx_n_u_SEG_2;
static PyObject *__pyx_n_u_SHORTCASENO;
static PyObject *__pyx_n_u_SHORTCOUNTY;
static PyObject *__pyx_n_u_SIDRAW;
static PyObject *__pyx_n_u_SPACE_SEP;
static PyObject *__pyx_n_u_SSN;
static PyObject *__pyx_kp_u_SSN_5_75_Alias;
static PyObject *__pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4;
static PyObject *__pyx_n_u_SUPPORT_ARCHIVE;
static PyObject *__pyx_n_u_SUPPORT_MULTITABLE;
static PyObject *__pyx_n_u_SUPPORT_SINGLETABLE;
static PyObject *__pyx_kp_u_S_N;
static PyObject *__pyx_kp_u_Search_Results;
static PyObject *__pyx_n_s_Select;
static PyObject *__pyx_n_u_SentenceDate;
static PyObject *__pyx_n_u_SentenceEndDate;
static PyObject *__pyx_n_u_SentenceLastUpdate;
static PyObject *__pyx_n_u_SentenceProvisions;
static PyObject *__pyx_n_u_SentenceStartDate;
static PyObject *__pyx_n_u_SentenceUpdatedBy;
static PyObject *__pyx_kp_u_Sentence_Date;
static PyObject *__pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2;
static PyObject *__pyx_kp_u_Sentence_End_Date;
static PyObject *__pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Sentence_Provisions;
static PyObject *__pyx_kp_u_Sentence_Provisions_Y_N;
static PyObject *__pyx_kp_u_Sentence_Start_Date;
static PyObject *__pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d;
static PyObject *__pyx_n_u_SentencingRequirementsCompleted;
static PyObject *__pyx_n_s_Series;
static PyObject *__pyx_n_u_Sex;
static PyObject *__pyx_kp_u_Single_table_export_choice_requi;
static PyObject *__pyx_n_u_Sort;
static PyObject *__pyx_n_u_Split;
static PyObject *__pyx_kp_u_Starting_browser_Do_not_close_wh;
static PyObject *__pyx_n_u_State;
static PyObject *__pyx_n_u_StateID;
static PyObject *__pyx_n_u_StreetAddress;
static PyObject *__pyx_kp_u_Submitted_party_search_form;
static PyObject *__pyx_kp_u_Successfully_configured;
static PyObject *__pyx_kp_u_Successfully_connected_and_logge;
static PyObject *__pyx_n_u_SuretyCode;
static PyObject *__pyx_kp_u_Surety_Code_A_Z0_9_4;
static PyObject *__pyx_n_u_T;
static PyObject *__pyx_n_u_TABLE;
static PyObject *__pyx_n_u_TBNV1;
static PyObject *__pyx_n_u_TBNV2;
static PyObject *__pyx_n_u_TEMP;
static PyObject *__pyx_n_u_TEMP_CASE_YEAR;
static PyObject *__pyx_n_u_TEMP_COUNTY;
static PyObject *__pyx_n_u_TEMP_DIVISION;
static PyObject *__pyx_n_u_TEMP_DOB;
static PyObject *__pyx_n_u_TEMP_FILED_AFTER;
static PyObject *__pyx_n_u_TEMP_FILED_BEFORE;
static PyObject *__pyx_n_u_TEMP_NAME;
static PyObject *__pyx_n_u_TEMP_NO_RECORDS;
static PyObject *__pyx_n_u_TEMP_PARTY_TYPE;
static PyObject *__pyx_n_u_TEMP_SSN;
static PyObject *__pyx_n_u_TOTALS;
static PyObject *__pyx_kp_u_TRAFFIC_MISDEMEANOR;
static PyObject *__pyx_kp_u_TRAFFIC_MISDEMEANOR_BOND_FELONY;
static PyObject *__pyx_n_u_Timestamp;
static PyObject *__pyx_n_u_Total;
static PyObject *__pyx_n_u_TotalAmtDue;
static PyObject *__pyx_n_u_TotalAmtHold;
static PyObject *__pyx_n_u_TotalAmtPaid;
static PyObject *__pyx_n_u_TotalBalance;
static PyObject *__pyx_kp_u_Total_2;
static PyObject *__pyx_kp_u_Total_n;
static PyObject *__pyx_n_u_TrafficCitationNumber;
static PyObject *__pyx_kp_u_Traffic_Citation_A_Z0_9;
static PyObject *__pyx_n_u_TransferDesc;
static PyObject *__pyx_n_u_TransferToAdminDocDate;
static PyObject *__pyx_kp_u_Transfer_Desc;
static PyObject *__pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d;
static PyObject *__pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d;
static PyObject *__pyx_n_u_TrialType;
static PyObject *__pyx_kp_u_Trial_Type_A_Z;
static PyObject *__pyx_kp_u_Try_again_with_at_least_one_vali;
static PyObject *__pyx_n_u_TypeDescription;
static PyObject *__pyx_n_u_UTF8_FULL_CONDENSED;
static PyObject *__pyx_kp_u_Updated_By;
static PyObject *__pyx_kp_u_Updated_By_w_3;
static PyObject *__pyx_kp_u_Updated_By_w_3_2;
static PyObject *__pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100;
static PyObject *__pyx_n_u_WINDOW;
static PyObject *__pyx_n_u_WarrantActionDate;
static PyObject *__pyx_n_u_WarrantActionStatus;
static PyObject *__pyx_n_u_WarrantIssuanceDate;
static PyObject *__pyx_n_u_WarrantIssuanceStatus;
static PyObject *__pyx_n_u_WarrantLocationStatus;
static PyObject *__pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Warrant_Action_Status_w;
static PyObject *__pyx_kp_u_Warrant_Issuance_Status_w;
static PyObject *__pyx_kp_u_Warrant_Location_Status_w;
static PyObject *__pyx_n_u_Weight;
static PyObject *__pyx_kp_u_Weight_d;
static PyObject *__pyx_n_s_Workbook;
static PyObject *__pyx_kp_u_Writing_to_export;
static PyObject *__pyx_n_u_Y;
static PyObject *__pyx_n_u_YouthfulDate;
static PyObject *__pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_Zip;
static PyObject *__pyx_n_u_ZipCode;
static PyObject *__pyx_kp_u_Zip_2;
static PyObject *__pyx_kp_u__109;
static PyObject *__pyx_kp_u__111;
static PyObject *__pyx_kp_u__115;
static PyObject *__pyx_kp_u__28;
static PyObject *__pyx_kp_u__42;
static PyObject *__pyx_kp_u__51;
static PyObject *__pyx_kp_u__52;
static PyObject *__pyx_kp_u__63;
static PyObject *__pyx_kp_u__64;
static PyObject *__pyx_kp_u__69;
static PyObject *__pyx_kp_u__8;
static PyObject *__pyx_kp_u__82;
static PyObject *__pyx_kp_u__85;
static PyObject *__pyx_kp_u__88;
static PyObject *__pyx_kp_u__90;
static PyObject *__pyx_n_u__92;
static PyObject *__pyx_kp_u__96;
static PyObject *__pyx_kp_u__97;
static PyObject *__pyx_n_s_a;
static PyObject *__pyx_n_s_ac;
static PyObject *__pyx_n_s_add_experimental_option;
static PyObject *__pyx_n_s_af;
static PyObject *__pyx_n_s_agg;
static PyObject *__pyx_kp_u_alac_1004;
static PyObject *__pyx_kp_u_alac_1026;
static PyObject *__pyx_kp_u_alac_1040;
static PyObject *__pyx_kp_u_alac_899;
static PyObject *__pyx_kp_u_alac_931;
static PyObject *__pyx_kp_u_alac_945;
static PyObject *__pyx_kp_u_alac_965;
static PyObject *__pyx_kp_u_alac_989;
static PyObject *__pyx_kp_u_alac_994;
static PyObject *__pyx_n_s_alacorder_cal;
static PyObject *__pyx_n_s_alias;
static PyObject *__pyx_n_u_all;
static PyObject *__pyx_n_s_all_charges;
static PyObject *__pyx_n_s_all_fees;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_append_archive;
static PyObject *__pyx_n_s_apply;
static PyObject *__pyx_n_s_aptxt;
static PyObject *__pyx_n_s_ar;
static PyObject *__pyx_n_s_archive;
static PyObject *__pyx_n_u_archive;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_arr;
static PyObject *__pyx_n_s_autofit;
static PyObject *__pyx_n_u_blocks;
static PyObject *__pyx_n_u_brotli;
static PyObject *__pyx_n_s_by;
static PyObject *__pyx_n_s_cID;
static PyObject *__pyx_n_s_cID_box;
static PyObject *__pyx_n_s_ca;
static PyObject *__pyx_kp_s_cal_pyx;
static PyObject *__pyx_n_s_case_year;
static PyObject *__pyx_n_s_case_year_select;
static PyObject *__pyx_n_s_cases;
static PyObject *__pyx_n_u_cases;
static PyObject *__pyx_n_s_cast;
static PyObject *__pyx_n_s_cf;
static PyObject *__pyx_n_s_ch;
static PyObject *__pyx_n_s_charges;
static PyObject *__pyx_n_u_charges;
static PyObject *__pyx_n_s_city;
static PyObject *__pyx_n_s_clean_ch_list;
static PyObject *__pyx_n_s_clean_fs_list;
static PyObject *__pyx_n_s_click;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_col;
static PyObject *__pyx_n_s_columns;
static PyObject *__pyx_n_s_common;
static PyObject *__pyx_n_s_compression;
static PyObject *__pyx_n_s_concat;
static PyObject *__pyx_n_s_concat_str;
static PyObject *__pyx_n_s_conf;
static PyObject *__pyx_n_s_contains;
static PyObject *__pyx_n_s_continueLogIn;
static PyObject *__pyx_n_s_count;
static PyObject *__pyx_n_s_county;
static PyObject *__pyx_n_s_county_select;
static PyObject *__pyx_kp_u_csv;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_UcddlD;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_ddlCas;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_ddlCou;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_ddlNum;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_dg_ctl;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_rdlPar;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_txtDOB;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_txtFro;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_txtNam;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_txtSSN;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder1_txtTo;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder_btnCont;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder_txtCusi;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder_txtPass;
static PyObject *__pyx_kp_u_ctl00_ContentPlaceHolder_txtUser;
static PyObject *__pyx_n_s_current_url;
static PyObject *__pyx_kp_u_d;
static PyObject *__pyx_n_s_d999;
static PyObject *__pyx_n_s_d999m;
static PyObject *__pyx_n_s_d999mm;
static PyObject *__pyx_kp_u_d_1_2;
static PyObject *__pyx_kp_u_d_1_2_d_d_d_d_d_d;
static PyObject *__pyx_kp_u_d_2_d_2_d_4_0_5_DOB;
static PyObject *__pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10;
static PyObject *__pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a;
static PyObject *__pyx_kp_u_d_Bond_Amount;
static PyObject *__pyx_kp_u_d_d_2;
static PyObject *__pyx_kp_u_d_d_2_2;
static PyObject *__pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc;
static PyObject *__pyx_n_s_dataframe;
static PyObject *__pyx_n_s_date_of_birth_box;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_u_defendants;
static PyObject *__pyx_n_s_df;
static PyObject *__pyx_n_u_directory;
static PyObject *__pyx_n_s_dirpath;
static PyObject *__pyx_n_s_division;
static PyObject *__pyx_n_s_division_select;
static PyObject *__pyx_n_s_dlog;
static PyObject *__pyx_n_s_dob;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_downloadPDF;
static PyObject *__pyx_kp_u_download_default_directory;
static PyObject *__pyx_kp_u_download_directory_upgrade;
static PyObject *__pyx_kp_u_download_prompt_for_download;
static PyObject *__pyx_n_s_driver;
static PyObject *__pyx_n_s_drop;
static PyObject *__pyx_n_s_drop_in_place;
static PyObject *__pyx_n_s_drop_nulls;
static PyObject *__pyx_n_s_empty;
static PyObject *__pyx_n_s_empty_query;
static PyObject *__pyx_n_s_enter;
static PyObject *__pyx_n_s_enumerate;
static PyObject *__pyx_n_s_exceptions;
static PyObject *__pyx_n_s_existing_output;
static PyObject *__pyx_n_s_exit;
static PyObject *__pyx_n_s_explode;
static PyObject *__pyx_n_s_ext;
static PyObject *__pyx_n_s_extract;
static PyObject *__pyx_n_s_extract_all;
static PyObject *__pyx_n_s_fees;
static PyObject *__pyx_n_u_fees;
static PyObject *__pyx_n_s_fetch;
static PyObject *__pyx_n_s_filed_after;
static PyObject *__pyx_n_s_filed_after_box;
static PyObject *__pyx_n_s_filed_before;
static PyObject *__pyx_n_s_filed_before_box;
static PyObject *__pyx_n_s_fill_null;
static PyObject *__pyx_n_s_filterwarnings;
static PyObject *__pyx_n_s_find_element;
static PyObject *__pyx_n_s_find_elements;
static PyObject *__pyx_n_s_findall;
static PyObject *__pyx_n_s_fitz;
static PyObject *__pyx_n_s_float_precision;
static PyObject *__pyx_n_s_fname;
static PyObject *__pyx_n_s_force;
static PyObject *__pyx_n_s_found;
static PyObject *__pyx_n_s_frame;
static PyObject *__pyx_n_u_frmIndexSearchForm;
static PyObject *__pyx_n_s_fs;
static PyObject *__pyx_n_s_fshort_name;
static PyObject *__pyx_n_s_ft;
static PyObject *__pyx_n_s_genexpr;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_getAddress;
static PyObject *__pyx_n_s_getAddress1;
static PyObject *__pyx_n_s_getAddress2;
static PyObject *__pyx_n_s_getAdminUpdatedBy;
static PyObject *__pyx_n_s_getAgencyORI;
static PyObject *__pyx_n_s_getAlias;
static PyObject *__pyx_n_s_getAppealCourt;
static PyObject *__pyx_n_s_getAppealDate;
static PyObject *__pyx_n_s_getAppealStatus;
static PyObject *__pyx_n_s_getAppealTo;
static PyObject *__pyx_n_s_getAppealToDesc;
static PyObject *__pyx_n_s_getArrestDate;
static PyObject *__pyx_n_s_getArrestingAgencyType;
static PyObject *__pyx_n_s_getArrestingOfficer;
static PyObject *__pyx_n_s_getBondAmt;
static PyObject *__pyx_n_s_getBondReleaseDate;
static PyObject *__pyx_n_s_getBondType;
static PyObject *__pyx_n_s_getBondTypeDesc;
static PyObject *__pyx_n_s_getBondsmanProcessIssuance;
static PyObject *__pyx_n_s_getBondsmanProcessReturn;
static PyObject *__pyx_n_s_getCaseInitiationDate;
static PyObject *__pyx_n_s_getCaseInitiationType;
static PyObject *__pyx_n_s_getCaseNumber;
static PyObject *__pyx_n_s_getCaseYear;
static PyObject *__pyx_n_s_getChargesRows;
static PyObject *__pyx_n_s_getCity;
static PyObject *__pyx_n_s_getCountry;
static PyObject *__pyx_n_s_getCounty;
static PyObject *__pyx_n_s_getCourtAction;
static PyObject *__pyx_n_s_getCourtActionDate;
static PyObject *__pyx_n_s_getDOB;
static PyObject *__pyx_n_s_getDefendantStatus;
static PyObject *__pyx_n_s_getDescription;
static PyObject *__pyx_n_s_getDispositionDateOfAppeal;
static PyObject *__pyx_n_s_getDispositionTypeOfAppeal;
static PyObject *__pyx_n_s_getDomesticViolence;
static PyObject *__pyx_n_s_getDriverLicenseNo;
static PyObject *__pyx_n_s_getEyes;
static PyObject *__pyx_n_s_getFailedToAppearDate;
static PyObject *__pyx_n_s_getFeeSheetRows;
static PyObject *__pyx_n_s_getFilingDate;
static PyObject *__pyx_n_s_getFirstName;
static PyObject *__pyx_n_s_getHair;
static PyObject *__pyx_n_s_getHeight;
static PyObject *__pyx_n_s_getIndictmentDate;
static PyObject *__pyx_n_s_getInpatientTreatmentOrdered;
static PyObject *__pyx_n_s_getJailCreditPeriod;
static PyObject *__pyx_n_s_getJudge;
static PyObject *__pyx_n_s_getJuryDemand;
static PyObject *__pyx_n_s_getLastName;
static PyObject *__pyx_n_s_getLicenseSuspPeriod;
static PyObject *__pyx_n_s_getLowerCourtAppealDate;
static PyObject *__pyx_n_s_getMiddleName;
static PyObject *__pyx_n_s_getName;
static PyObject *__pyx_n_s_getNumberOfSubpoenas;
static PyObject *__pyx_n_s_getNumberOfWarrants;
static PyObject *__pyx_n_s_getOffenseDate;
static PyObject *__pyx_n_s_getOriginOfAppeal;
static PyObject *__pyx_n_s_getPDFText;
static PyObject *__pyx_n_s_getPDFText_locals_genexpr;
static PyObject *__pyx_n_s_getPaymentToRestore;
static PyObject *__pyx_n_s_getPhone;
static PyObject *__pyx_n_s_getPreviousDUIConvictions;
static PyObject *__pyx_n_s_getProbationBeginDate;
static PyObject *__pyx_n_s_getProbationOfficeName;
static PyObject *__pyx_n_s_getProbationOfficeNumber;
static PyObject *__pyx_n_s_getProbationPeriod;
static PyObject *__pyx_n_s_getProbationRevoke;
static PyObject *__pyx_n_s_getRace;
static PyObject *__pyx_n_s_getRelatedCases;
static PyObject *__pyx_n_s_getRetrieved;
static PyObject *__pyx_n_s_getSSN;
static PyObject *__pyx_n_s_getSentenceDate;
static PyObject *__pyx_n_s_getSentenceEndDate;
static PyObject *__pyx_n_s_getSentenceLastUpdate;
static PyObject *__pyx_n_s_getSentenceProvisions;
static PyObject *__pyx_n_s_getSentenceStartDate;
static PyObject *__pyx_n_s_getSentenceUpdatedBy;
static PyObject *__pyx_n_s_getSentencingRequirementsComplet;
static PyObject *__pyx_n_s_getSex;
static PyObject *__pyx_n_s_getShortCaseNumber;
static PyObject *__pyx_n_s_getState;
static PyObject *__pyx_n_s_getStateID;
static PyObject *__pyx_n_s_getSuretyCode;
static PyObject *__pyx_n_s_getTBNV1;
static PyObject *__pyx_n_s_getTBNV2;
static PyObject *__pyx_n_s_getTotalAmtDue;
static PyObject *__pyx_n_s_getTotalAmtHold;
static PyObject *__pyx_n_s_getTotalAmtPaid;
static PyObject *__pyx_n_s_getTotalBalance;
static PyObject *__pyx_n_s_getTotalRow;
static PyObject *__pyx_n_s_getTrafficCitationNumber;
static PyObject *__pyx_n_s_getTransferDesc;
static PyObject *__pyx_n_s_getTransferToAdminDocDate;
static PyObject *__pyx_n_s_getTrialType;
static PyObject *__pyx_n_s_getWarrantActionDate;
static PyObject *__pyx_n_s_getWarrantActionStatus;
static PyObject *__pyx_n_s_getWarrantIssuanceDate;
static PyObject *__pyx_n_s_getWarrantIssuanceStatus;
static PyObject *__pyx_n_s_getWarrantLocationStatus;
static PyObject *__pyx_n_s_getWeight;
static PyObject *__pyx_n_s_getYouthfulDate;
static PyObject *__pyx_n_s_getZipCode;
static PyObject *__pyx_n_s_get_attribute;
static PyObject *__pyx_n_s_get_text;
static PyObject *__pyx_n_s_glob;
static PyObject *__pyx_n_s_good;
static PyObject *__pyx_n_s_goodquery;
static PyObject *__pyx_n_s_group;
static PyObject *__pyx_n_s_group_index;
static PyObject *__pyx_n_s_groupby;
static PyObject *__pyx_kp_u_h;
static PyObject *__pyx_n_s_has_window;
static PyObject *__pyx_kp_u_help;
static PyObject *__pyx_n_s_help_option_names;
static PyObject *__pyx_n_s_hovers;
static PyObject *__pyx_n_s_how;
static PyObject *__pyx_n_u_href;
static PyObject *__pyx_kp_u_https_v2_alacourt_com_frmIndexSe;
static PyObject *__pyx_kp_u_https_v2_alacourt_com_frmIndexSe_2;
static PyObject *__pyx_kp_u_https_v2_alacourt_com_frmlogin_a;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_u_ignore;
static PyObject *__pyx_kp_u_image;
static PyObject *__pyx_n_s_implicitly_wait;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_inarc;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_inpath;
static PyObject *__pyx_n_s_inputs;
static PyObject *__pyx_n_s_inspect;
static PyObject *__pyx_n_s_is_full_text;
static PyObject *__pyx_n_s_is_not;
static PyObject *__pyx_n_s_isdir;
static PyObject *__pyx_n_s_isfile;
static PyObject *__pyx_n_s_itype;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_kp_u_json;
static PyObject *__pyx_n_u_left;
static PyObject *__pyx_n_s_lit;
static PyObject *__pyx_n_s_literal;
static PyObject *__pyx_n_s_login;
static PyObject *__pyx_n_s_login_button;
static PyObject *__pyx_n_s_login_screen;
static PyObject *__pyx_n_s_long_version;
static PyObject *__pyx_n_s_m;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_math;
static PyObject *__pyx_n_u_menuHover;
static PyObject *__pyx_n_s_mm;
static PyObject *__pyx_n_s_mmm;
static PyObject *__pyx_n_s_multi;
static PyObject *__pyx_n_u_multi;
static PyObject *__pyx_n_u_multitable;
static PyObject *__pyx_kp_u_n;
static PyObject *__pyx_kp_u_n_Requrements_Completed;
static PyObject *__pyx_n_s_n_chars;
static PyObject *__pyx_kp_u_n_s;
static PyObject *__pyx_kp_u_n_s_2;
static PyObject *__pyx_kp_u_n_s_d_Appeal_Court;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_named;
static PyObject *__pyx_n_s_next_button;
static PyObject *__pyx_n_s_next_pg;
static PyObject *__pyx_n_s_no_prompt;
static PyObject *__pyx_n_s_no_records_select;
static PyObject *__pyx_n_s_no_update;
static PyObject *__pyx_n_s_no_write;
static PyObject *__pyx_n_u_none;
static PyObject *__pyx_n_s_now;
static PyObject *__pyx_kp_u_null;
static PyObject *__pyx_n_u_object;
static PyObject *__pyx_n_s_old_archive;
static PyObject *__pyx_n_s_on;
static PyObject *__pyx_n_s_open;
static PyObject *__pyx_n_s_opt;
static PyObject *__pyx_n_s_option;
static PyObject *__pyx_n_s_options;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_otherwise;
static PyObject *__pyx_n_s_out;
static PyObject *__pyx_n_s_outarc;
static PyObject *__pyx_n_s_outpath;
static PyObject *__pyx_n_s_outputext;
static PyObject *__pyx_n_s_outputs;
static PyObject *__pyx_n_s_overwrite;
static PyObject *__pyx_n_s_page_counter;
static PyObject *__pyx_n_s_pager_select;
static PyObject *__pyx_n_s_pages;
static PyObject *__pyx_kp_u_parquet;
static PyObject *__pyx_n_s_party_name_box;
static PyObject *__pyx_n_s_party_search;
static PyObject *__pyx_n_s_party_type;
static PyObject *__pyx_n_s_party_type_select;
static PyObject *__pyx_n_u_partymountain;
static PyObject *__pyx_n_s_path;
static PyObject *__pyx_kp_u_pdf;
static PyObject *__pyx_n_s_pdflinks;
static PyObject *__pyx_n_s_pg;
static PyObject *__pyx_n_s_pl;
static PyObject *__pyx_n_u_plaintiffs;
static PyObject *__pyx_n_s_platform;
static PyObject *__pyx_kp_u_plugins_always_open_pdf_external;
static PyObject *__pyx_n_s_polars;
static PyObject *__pyx_n_s_pp;
static PyObject *__pyx_n_u_prefs;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_s_pscols;
static PyObject *__pyx_n_s_pts;
static PyObject *__pyx_n_s_pwd;
static PyObject *__pyx_n_s_pwd_box;
static PyObject *__pyx_n_s_qmax;
static PyObject *__pyx_n_s_qs;
static PyObject *__pyx_n_s_qskip;
static PyObject *__pyx_kp_u_queries_found_in_input_query_fi;
static PyObject *__pyx_n_s_query;
static PyObject *__pyx_n_u_query;
static PyObject *__pyx_n_s_querypath;
static PyObject *__pyx_n_s_queue;
static PyObject *__pyx_n_s_qwrite;
static PyObject *__pyx_n_s_r;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_re;
static PyObject *__pyx_n_s_read;
static PyObject *__pyx_n_s_read_csv;
static PyObject *__pyx_n_s_read_excel;
static PyObject *__pyx_n_s_read_json;
static PyObject *__pyx_n_s_read_parquet;
static PyObject *__pyx_n_s_read_query;
static PyObject *__pyx_kp_u_records_returned;
static PyObject *__pyx_kp_u_records_returned_2;
static PyObject *__pyx_n_s_recursive;
static PyObject *__pyx_n_s_replace;
static PyObject *__pyx_n_s_replace_all;
static PyObject *__pyx_n_s_results;
static PyObject *__pyx_n_s_results_count;
static PyObject *__pyx_kp_u_results_fetching_URLs_and_downl;
static PyObject *__pyx_n_s_results_indicator;
static PyObject *__pyx_n_s_rich;
static PyObject *__pyx_n_s_rows;
static PyObject *__pyx_n_s_rsplit;
static PyObject *__pyx_n_s_rstrip;
static PyObject *__pyx_kp_u_s;
static PyObject *__pyx_kp_u_s_d_d_2;
static PyObject *__pyx_n_s_scase_year;
static PyObject *__pyx_n_s_scounty;
static PyObject *__pyx_n_s_sdivision;
static PyObject *__pyx_n_s_search;
static PyObject *__pyx_n_u_searchButton;
static PyObject *__pyx_n_s_search_button;
static PyObject *__pyx_n_s_select;
static PyObject *__pyx_n_s_select_by_visible_text;
static PyObject *__pyx_n_s_selenium;
static PyObject *__pyx_n_s_selenium_webdriver_chrome_option;
static PyObject *__pyx_n_s_selenium_webdriver_common_by;
static PyObject *__pyx_n_s_selenium_webdriver_support_ui;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_send_keys;
static PyObject *__pyx_n_s_series;
static PyObject *__pyx_n_s_set;
static PyObject *__pyx_n_s_set_fmt_str_lengths;
static PyObject *__pyx_n_s_set_tbl_cols;
static PyObject *__pyx_n_s_set_tbl_formatting;
static PyObject *__pyx_n_s_set_tbl_rows;
static PyObject *__pyx_n_s_set_verbose;
static PyObject *__pyx_n_s_shape;
static PyObject *__pyx_n_s_sheet_names;
static PyObject *__pyx_n_s_sleep;
static PyObject *__pyx_n_s_slice;
static PyObject *__pyx_n_u_snappy;
static PyObject *__pyx_n_s_sno_records;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_split_cases;
static PyObject *__pyx_n_s_split_charges;
static PyObject *__pyx_n_s_split_charges_locals_lambda;
static PyObject *__pyx_n_s_split_fees;
static PyObject *__pyx_n_s_splitext;
static PyObject *__pyx_n_s_ssn;
static PyObject *__pyx_n_s_ssn_box;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_n_s_street1;
static PyObject *__pyx_n_s_street2;
static PyObject *__pyx_n_s_strict;
static PyObject *__pyx_n_s_strip;
static PyObject *__pyx_n_s_sub;
static PyObject *__pyx_n_s_success;
static PyObject *__pyx_n_s_support_archive;
static PyObject *__pyx_n_s_support_multitable;
static PyObject *__pyx_n_s_support_singletable;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_table;
static PyObject *__pyx_n_s_tables;
static PyObject *__pyx_n_s_tbal;
static PyObject *__pyx_n_s_tempcols;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_text;
static PyObject *__pyx_n_s_then;
static PyObject *__pyx_n_s_threading;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_time;
static PyObject *__pyx_n_s_tqdm;
static PyObject *__pyx_n_s_tracebacklimit;
static PyObject *__pyx_kp_u_txt;
static PyObject *__pyx_n_s_uID;
static PyObject *__pyx_n_s_upper;
static PyObject *__pyx_n_s_url;
static PyObject *__pyx_n_s_username_box;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_version;
static PyObject *__pyx_kp_u_w_2_d_12;
static PyObject *__pyx_kp_u_w_2_d_4_d_6_d_2;
static PyObject *__pyx_kp_u_w_2_d_4_d_6_d_2_2;
static PyObject *__pyx_kp_u_w_2_d_4_d_6_d_2_3;
static PyObject *__pyx_n_s_warnings;
static PyObject *__pyx_n_s_webdriver;
static PyObject *__pyx_n_s_when;
static PyObject *__pyx_n_s_window;
static PyObject *__pyx_n_s_with_columns;
static PyObject *__pyx_n_s_workbook;
static PyObject *__pyx_n_s_worksheet;
static PyObject *__pyx_n_s_write;
static PyObject *__pyx_n_s_write_csv;
static PyObject *__pyx_n_s_write_event_value;
static PyObject *__pyx_n_s_write_excel;
static PyObject *__pyx_n_s_write_json;
static PyObject *__pyx_n_s_write_parquet;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_kp_u_xls;
static PyObject *__pyx_kp_u_xlsx;
static PyObject *__pyx_n_s_xlsxwriter;
static PyObject *__pyx_kp_u_zip;
static PyObject *__pyx_n_s_zipcode;
static PyObject *__pyx_pf_9alacorder_3cal_multi(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_2cases(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_4charges(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_6fees(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_8tables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_10init(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_12archive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_14set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_inputs, PyObject *__pyx_v_outputs, PyObject *__pyx_v_count, PyObject *__pyx_v_table, PyObject *__pyx_v_archive, PyObject *__pyx_v_no_prompt, PyObject *__pyx_v_debug, PyObject *__pyx_v_overwrite, PyObject *__pyx_v_no_write, PyObject *__pyx_v_fetch, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_qmax, PyObject *__pyx_v_qskip, PyObject *__pyx_v_append, PyObject *__pyx_v_window, PyObject *__pyx_v_force, PyObject *__pyx_v_no_update, PyObject *__pyx_v_now); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_16dlog(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_18read(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_20write(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_outputs, PyObject *__pyx_v_sheet_names, PyObject *__pyx_v_cf, PyObject *__pyx_v_path, PyObject *__pyx_v_overwrite); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_22append_archive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_inpath, PyObject *__pyx_v_outpath, PyObject *__pyx_v_conf, PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_24split_cases(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_lambda_funcdef_lambda(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_26split_charges(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_28split_fees(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_30read_query(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path, PyObject *__pyx_v_qmax, PyObject *__pyx_v_qskip, CYTHON_UNUSED PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_32fetch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_querypath, PyObject *__pyx_v_dirpath, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_qmax, PyObject *__pyx_v_qskip, PyObject *__pyx_v_cf, PyObject *__pyx_v_no_update, CYTHON_UNUSED PyObject *__pyx_v_debug, PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_34party_search(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_driver, PyObject *__pyx_v_name, PyObject *__pyx_v_party_type, PyObject *__pyx_v_ssn, PyObject *__pyx_v_dob, PyObject *__pyx_v_county, PyObject *__pyx_v_division, PyObject *__pyx_v_case_year, PyObject *__pyx_v_filed_before, PyObject *__pyx_v_filed_after, PyObject *__pyx_v_debug, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_36downloadPDF(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_driver, PyObject *__pyx_v_url, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_38login(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_driver, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_path, CYTHON_UNUSED PyObject *__pyx_v_window); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_40empty_query(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_10getPDFText_genexpr(PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_42getPDFText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_44getName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_46getAlias(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_48getDOB(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_50getPhone(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_52getRace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_54getSex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_56getAddress1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_58getAddress2(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_60getCity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_62getState(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_64getCountry(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_66getZipCode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_68getAddress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_70getChargesRows(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_72getFeeSheetRows(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_74getTotalRow(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_76getTotalAmtDue(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_78getTotalAmtPaid(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_80getTotalBalance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_82getTotalAmtHold(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_84getPaymentToRestore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_86getShortCaseNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_88getCounty(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_90getCaseNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_92getCaseYear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_94getLastName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_96getFirstName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_98getMiddleName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_100getRelatedCases(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_102getFilingDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_104getCaseInitiationDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_106getArrestDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_108getOffenseDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_110getIndictmentDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_112getYouthfulDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_114getRetrieved(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_116getCourtAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_118getCourtActionDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_120getDescription(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_122getJuryDemand(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_124getInpatientTreatmentOrdered(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_126getTrialType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_128getJudge(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_130getProbationOfficeNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_132getDefendantStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_134getArrestingAgencyType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_136getArrestingOfficer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_138getProbationOfficeName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_140getTrafficCitationNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_142getPreviousDUIConvictions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_144getCaseInitiationType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_146getDomesticViolence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_148getAgencyORI(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_150getDriverLicenseNo(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_152getSSN(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_154getStateID(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_156getWeight(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_158getHeight(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_160getEyes(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_162getHair(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_164getCountry(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_166getWarrantIssuanceDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_168getWarrantActionDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_170getWarrantIssuanceStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_172getWarrantActionStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_174getWarrantLocationStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_176getNumberOfWarrants(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_178getBondType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_180getBondTypeDesc(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_182getBondAmt(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_184getSuretyCode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_186getBondReleaseDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_188getFailedToAppearDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_190getBondsmanProcessIssuance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_192getBondsmanProcessReturn(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_194getAppealDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_196getAppealCourt(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_198getOriginOfAppeal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_200getAppealToDesc(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_202getAppealStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_204getAppealTo(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_206getLowerCourtAppealDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_208getDispositionDateOfAppeal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_210getDispositionTypeOfAppeal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_212getNumberOfSubpoenas(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_214getAdminUpdatedBy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_216getTransferToAdminDocDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_218getTransferDesc(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_220getTBNV1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_222getTBNV2(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_224getSentencingRequirementsCompleted(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_226getSentenceDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_228getProbationPeriod(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_230getLicenseSuspPeriod(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_232getJailCreditPeriod(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_234getSentenceProvisions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_236getSentenceStartDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_238getSentenceEndDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_240getProbationBeginDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_242getSentenceUpdatedBy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_244getSentenceLastUpdate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_pf_9alacorder_3cal_246getProbationRevoke(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text); /* proto */
static PyObject *__pyx_tp_new_9alacorder_3cal___pyx_scope_struct__getPDFText(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9alacorder_3cal___pyx_scope_struct_1_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_float_0_0;
static PyObject *__pyx_float_0_5;
static PyObject *__pyx_float_0_00;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_6;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_9;
static PyObject *__pyx_int_10;
static PyObject *__pyx_int_19;
static PyObject *__pyx_int_100;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_int_neg_2;
static PyObject *__pyx_k__16;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__20;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__31;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__40;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__56;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__60;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__72;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__74;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__76;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__78;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__80;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__84;
static PyObject *__pyx_tuple__86;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__94;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__98;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_slice__112;
static PyObject *__pyx_slice__113;
static PyObject *__pyx_slice__114;
static PyObject *__pyx_tuple__100;
static PyObject *__pyx_tuple__101;
static PyObject *__pyx_tuple__102;
static PyObject *__pyx_tuple__103;
static PyObject *__pyx_tuple__104;
static PyObject *__pyx_tuple__105;
static PyObject *__pyx_tuple__106;
static PyObject *__pyx_tuple__107;
static PyObject *__pyx_tuple__108;
static PyObject *__pyx_tuple__110;
static PyObject *__pyx_tuple__116;
static PyObject *__pyx_tuple__117;
static PyObject *__pyx_tuple__118;
static PyObject *__pyx_tuple__119;
static PyObject *__pyx_tuple__120;
static PyObject *__pyx_tuple__121;
static PyObject *__pyx_tuple__123;
static PyObject *__pyx_tuple__125;
static PyObject *__pyx_tuple__127;
static PyObject *__pyx_tuple__129;
static PyObject *__pyx_tuple__131;
static PyObject *__pyx_tuple__133;
static PyObject *__pyx_tuple__135;
static PyObject *__pyx_tuple__137;
static PyObject *__pyx_tuple__139;
static PyObject *__pyx_tuple__141;
static PyObject *__pyx_tuple__143;
static PyObject *__pyx_tuple__145;
static PyObject *__pyx_tuple__147;
static PyObject *__pyx_tuple__149;
static PyObject *__pyx_tuple__151;
static PyObject *__pyx_tuple__153;
static PyObject *__pyx_tuple__155;
static PyObject *__pyx_tuple__157;
static PyObject *__pyx_tuple__159;
static PyObject *__pyx_tuple__161;
static PyObject *__pyx_tuple__163;
static PyObject *__pyx_tuple__165;
static PyObject *__pyx_tuple__167;
static PyObject *__pyx_tuple__169;
static PyObject *__pyx_tuple__171;
static PyObject *__pyx_tuple__173;
static PyObject *__pyx_tuple__175;
static PyObject *__pyx_tuple__177;
static PyObject *__pyx_tuple__179;
static PyObject *__pyx_tuple__181;
static PyObject *__pyx_tuple__183;
static PyObject *__pyx_tuple__185;
static PyObject *__pyx_tuple__187;
static PyObject *__pyx_tuple__189;
static PyObject *__pyx_tuple__191;
static PyObject *__pyx_tuple__193;
static PyObject *__pyx_tuple__195;
static PyObject *__pyx_tuple__197;
static PyObject *__pyx_tuple__199;
static PyObject *__pyx_tuple__201;
static PyObject *__pyx_tuple__203;
static PyObject *__pyx_tuple__205;
static PyObject *__pyx_tuple__207;
static PyObject *__pyx_tuple__209;
static PyObject *__pyx_tuple__211;
static PyObject *__pyx_tuple__213;
static PyObject *__pyx_tuple__215;
static PyObject *__pyx_tuple__217;
static PyObject *__pyx_tuple__219;
static PyObject *__pyx_tuple__221;
static PyObject *__pyx_tuple__223;
static PyObject *__pyx_tuple__225;
static PyObject *__pyx_tuple__227;
static PyObject *__pyx_tuple__229;
static PyObject *__pyx_tuple__231;
static PyObject *__pyx_tuple__233;
static PyObject *__pyx_tuple__235;
static PyObject *__pyx_tuple__237;
static PyObject *__pyx_tuple__239;
static PyObject *__pyx_tuple__241;
static PyObject *__pyx_tuple__243;
static PyObject *__pyx_tuple__245;
static PyObject *__pyx_tuple__247;
static PyObject *__pyx_tuple__249;
static PyObject *__pyx_tuple__251;
static PyObject *__pyx_tuple__253;
static PyObject *__pyx_tuple__255;
static PyObject *__pyx_tuple__257;
static PyObject *__pyx_tuple__259;
static PyObject *__pyx_tuple__261;
static PyObject *__pyx_tuple__263;
static PyObject *__pyx_tuple__265;
static PyObject *__pyx_tuple__267;
static PyObject *__pyx_tuple__269;
static PyObject *__pyx_tuple__271;
static PyObject *__pyx_tuple__273;
static PyObject *__pyx_tuple__275;
static PyObject *__pyx_tuple__277;
static PyObject *__pyx_tuple__279;
static PyObject *__pyx_tuple__281;
static PyObject *__pyx_tuple__283;
static PyObject *__pyx_tuple__285;
static PyObject *__pyx_tuple__287;
static PyObject *__pyx_tuple__289;
static PyObject *__pyx_tuple__291;
static PyObject *__pyx_tuple__293;
static PyObject *__pyx_tuple__295;
static PyObject *__pyx_tuple__297;
static PyObject *__pyx_tuple__299;
static PyObject *__pyx_tuple__301;
static PyObject *__pyx_tuple__303;
static PyObject *__pyx_tuple__305;
static PyObject *__pyx_tuple__307;
static PyObject *__pyx_tuple__309;
static PyObject *__pyx_tuple__311;
static PyObject *__pyx_tuple__313;
static PyObject *__pyx_tuple__315;
static PyObject *__pyx_tuple__317;
static PyObject *__pyx_tuple__319;
static PyObject *__pyx_tuple__321;
static PyObject *__pyx_tuple__323;
static PyObject *__pyx_tuple__325;
static PyObject *__pyx_tuple__327;
static PyObject *__pyx_tuple__329;
static PyObject *__pyx_tuple__331;
static PyObject *__pyx_tuple__333;
static PyObject *__pyx_tuple__335;
static PyObject *__pyx_tuple__337;
static PyObject *__pyx_tuple__339;
static PyObject *__pyx_tuple__341;
static PyObject *__pyx_tuple__343;
static PyObject *__pyx_tuple__345;
static PyObject *__pyx_tuple__347;
static PyObject *__pyx_tuple__349;
static PyObject *__pyx_tuple__351;
static PyObject *__pyx_tuple__353;
static PyObject *__pyx_tuple__355;
static PyObject *__pyx_tuple__357;
static PyObject *__pyx_tuple__359;
static PyObject *__pyx_tuple__361;
static PyObject *__pyx_tuple__363;
static PyObject *__pyx_tuple__365;
static PyObject *__pyx_tuple__367;
static PyObject *__pyx_codeobj__122;
static PyObject *__pyx_codeobj__124;
static PyObject *__pyx_codeobj__126;
static PyObject *__pyx_codeobj__128;
static PyObject *__pyx_codeobj__130;
static PyObject *__pyx_codeobj__132;
static PyObject *__pyx_codeobj__134;
static PyObject *__pyx_codeobj__136;
static PyObject *__pyx_codeobj__138;
static PyObject *__pyx_codeobj__140;
static PyObject *__pyx_codeobj__142;
static PyObject *__pyx_codeobj__144;
static PyObject *__pyx_codeobj__146;
static PyObject *__pyx_codeobj__148;
static PyObject *__pyx_codeobj__150;
static PyObject *__pyx_codeobj__152;
static PyObject *__pyx_codeobj__154;
static PyObject *__pyx_codeobj__156;
static PyObject *__pyx_codeobj__158;
static PyObject *__pyx_codeobj__160;
static PyObject *__pyx_codeobj__162;
static PyObject *__pyx_codeobj__164;
static PyObject *__pyx_codeobj__166;
static PyObject *__pyx_codeobj__168;
static PyObject *__pyx_codeobj__170;
static PyObject *__pyx_codeobj__172;
static PyObject *__pyx_codeobj__174;
static PyObject *__pyx_codeobj__176;
static PyObject *__pyx_codeobj__178;
static PyObject *__pyx_codeobj__180;
static PyObject *__pyx_codeobj__182;
static PyObject *__pyx_codeobj__184;
static PyObject *__pyx_codeobj__186;
static PyObject *__pyx_codeobj__188;
static PyObject *__pyx_codeobj__190;
static PyObject *__pyx_codeobj__192;
static PyObject *__pyx_codeobj__194;
static PyObject *__pyx_codeobj__196;
static PyObject *__pyx_codeobj__198;
static PyObject *__pyx_codeobj__200;
static PyObject *__pyx_codeobj__202;
static PyObject *__pyx_codeobj__204;
static PyObject *__pyx_codeobj__206;
static PyObject *__pyx_codeobj__208;
static PyObject *__pyx_codeobj__210;
static PyObject *__pyx_codeobj__212;
static PyObject *__pyx_codeobj__214;
static PyObject *__pyx_codeobj__216;
static PyObject *__pyx_codeobj__218;
static PyObject *__pyx_codeobj__220;
static PyObject *__pyx_codeobj__222;
static PyObject *__pyx_codeobj__224;
static PyObject *__pyx_codeobj__226;
static PyObject *__pyx_codeobj__228;
static PyObject *__pyx_codeobj__230;
static PyObject *__pyx_codeobj__232;
static PyObject *__pyx_codeobj__234;
static PyObject *__pyx_codeobj__236;
static PyObject *__pyx_codeobj__238;
static PyObject *__pyx_codeobj__240;
static PyObject *__pyx_codeobj__242;
static PyObject *__pyx_codeobj__244;
static PyObject *__pyx_codeobj__246;
static PyObject *__pyx_codeobj__248;
static PyObject *__pyx_codeobj__250;
static PyObject *__pyx_codeobj__252;
static PyObject *__pyx_codeobj__254;
static PyObject *__pyx_codeobj__256;
static PyObject *__pyx_codeobj__258;
static PyObject *__pyx_codeobj__260;
static PyObject *__pyx_codeobj__262;
static PyObject *__pyx_codeobj__264;
static PyObject *__pyx_codeobj__266;
static PyObject *__pyx_codeobj__268;
static PyObject *__pyx_codeobj__270;
static PyObject *__pyx_codeobj__272;
static PyObject *__pyx_codeobj__274;
static PyObject *__pyx_codeobj__276;
static PyObject *__pyx_codeobj__278;
static PyObject *__pyx_codeobj__280;
static PyObject *__pyx_codeobj__282;
static PyObject *__pyx_codeobj__284;
static PyObject *__pyx_codeobj__286;
static PyObject *__pyx_codeobj__288;
static PyObject *__pyx_codeobj__290;
static PyObject *__pyx_codeobj__292;
static PyObject *__pyx_codeobj__294;
static PyObject *__pyx_codeobj__296;
static PyObject *__pyx_codeobj__298;
static PyObject *__pyx_codeobj__300;
static PyObject *__pyx_codeobj__302;
static PyObject *__pyx_codeobj__304;
static PyObject *__pyx_codeobj__306;
static PyObject *__pyx_codeobj__308;
static PyObject *__pyx_codeobj__310;
static PyObject *__pyx_codeobj__312;
static PyObject *__pyx_codeobj__314;
static PyObject *__pyx_codeobj__316;
static PyObject *__pyx_codeobj__318;
static PyObject *__pyx_codeobj__320;
static PyObject *__pyx_codeobj__322;
static PyObject *__pyx_codeobj__324;
static PyObject *__pyx_codeobj__326;
static PyObject *__pyx_codeobj__328;
static PyObject *__pyx_codeobj__330;
static PyObject *__pyx_codeobj__332;
static PyObject *__pyx_codeobj__334;
static PyObject *__pyx_codeobj__336;
static PyObject *__pyx_codeobj__338;
static PyObject *__pyx_codeobj__340;
static PyObject *__pyx_codeobj__342;
static PyObject *__pyx_codeobj__344;
static PyObject *__pyx_codeobj__346;
static PyObject *__pyx_codeobj__348;
static PyObject *__pyx_codeobj__350;
static PyObject *__pyx_codeobj__352;
static PyObject *__pyx_codeobj__354;
static PyObject *__pyx_codeobj__356;
static PyObject *__pyx_codeobj__358;
static PyObject *__pyx_codeobj__360;
static PyObject *__pyx_codeobj__362;
static PyObject *__pyx_codeobj__364;
static PyObject *__pyx_codeobj__366;
static PyObject *__pyx_codeobj__368;
/* Late includes */

/* "alacorder/cal.pyx":31
 * #   #   #   #           TASK STARTERS           #   #   #   #
 * 
 * def multi(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start multitable collection using configuration object `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_1multi(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_multi[] = "\n     Start multitable collection using configuration object `cf`.\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_1multi = {"multi", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_1multi, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_multi};
static PyObject *__pyx_pw_9alacorder_3cal_1multi(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("multi (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "multi") < 0)) __PYX_ERR(0, 31, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("multi", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 31, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.multi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_multi(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_multi(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_df = NULL;
  PyObject *__pyx_v_ca = NULL;
  PyObject *__pyx_v_ac = NULL;
  PyObject *__pyx_v_af = NULL;
  PyObject *__pyx_v_ch = NULL;
  PyObject *__pyx_v_fs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("multi", 0);

  /* "alacorder/cal.pyx":35
 *      Start multitable collection using configuration object `cf`.
 *      """
 *      df = read(cf, window)             # <<<<<<<<<<<<<<
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cf);
    __Pyx_INCREF(__pyx_v_window);
    __Pyx_GIVEREF(__pyx_v_window);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_window);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":36
 *      """
 *      df = read(cf, window)
 *      print("Extracting case info...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])
 *      print("Parsing charges...")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":37
 *      df = read(cf, window)
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])             # <<<<<<<<<<<<<<
 *      print("Parsing charges...")
 *      ch = split_charges(ac, debug=cf['DEBUG'])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_split_cases); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_df);
  __Pyx_GIVEREF(__pyx_v_df);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_df);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_DEBUG); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_debug, __pyx_t_3) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_3))) || (PyList_CheckExact(__pyx_t_3))) {
    PyObject* sequence = __pyx_t_3;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 37, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_1 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_1);
    #else
    __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 1; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 2; __pyx_t_1 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 37, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_ca = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_ac = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_af = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":38
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])
 *      print("Parsing charges...")             # <<<<<<<<<<<<<<
 *      ch = split_charges(ac, debug=cf['DEBUG'])
 *      print("Parsing fees tables...")
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":39
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])
 *      print("Parsing charges...")
 *      ch = split_charges(ac, debug=cf['DEBUG'])             # <<<<<<<<<<<<<<
 *      print("Parsing fees tables...")
 *      fs = split_fees(af, debug=cf['DEBUG'])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_split_charges); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_ac);
  __Pyx_GIVEREF(__pyx_v_ac);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_ac);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_DEBUG); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_debug, __pyx_t_5) < 0) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ch = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":40
 *      print("Parsing charges...")
 *      ch = split_charges(ac, debug=cf['DEBUG'])
 *      print("Parsing fees tables...")             # <<<<<<<<<<<<<<
 *      fs = split_fees(af, debug=cf['DEBUG'])
 *      if not cf['NO_WRITE']:
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":41
 *      ch = split_charges(ac, debug=cf['DEBUG'])
 *      print("Parsing fees tables...")
 *      fs = split_fees(af, debug=cf['DEBUG'])             # <<<<<<<<<<<<<<
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_split_fees); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_af);
  __Pyx_GIVEREF(__pyx_v_af);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_af);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_DEBUG); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_debug, __pyx_t_3) < 0) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 41, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_fs = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":42
 *      print("Parsing fees tables...")
 *      fs = split_fees(af, debug=cf['DEBUG'])
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NO_WRITE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_9 = ((!__pyx_t_8) != 0);
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":43
 *      fs = split_fees(af, debug=cf['DEBUG'])
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")             # <<<<<<<<<<<<<<
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 *      if window:
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":42
 *      print("Parsing fees tables...")
 *      fs = split_fees(af, debug=cf['DEBUG'])
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 */
  }

  /* "alacorder/cal.pyx":44
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)             # <<<<<<<<<<<<<<
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_write); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_ca);
  __Pyx_GIVEREF(__pyx_v_ca);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_ca);
  __Pyx_INCREF(__pyx_v_ch);
  __Pyx_GIVEREF(__pyx_v_ch);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_v_ch);
  __Pyx_INCREF(__pyx_v_fs);
  __Pyx_GIVEREF(__pyx_v_fs);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_v_fs);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_n_u_cases);
  __Pyx_GIVEREF(__pyx_n_u_cases);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_n_u_cases);
  __Pyx_INCREF(__pyx_n_u_charges);
  __Pyx_GIVEREF(__pyx_n_u_charges);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_n_u_charges);
  __Pyx_INCREF(__pyx_n_u_fees);
  __Pyx_GIVEREF(__pyx_n_u_fees);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_n_u_fees);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_sheet_names, __pyx_t_5) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_cf, __pyx_v_cf) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_2, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":45
 *           print("Writing to export...")
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 45, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":46
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)             # <<<<<<<<<<<<<<
 *      return ca, ch, fs
 * def cases(cf, window=None, debug=False):
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":45
 *           print("Writing to export...")
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs
 */
  }

  /* "alacorder/cal.pyx":47
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs             # <<<<<<<<<<<<<<
 * def cases(cf, window=None, debug=False):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_ca);
  __Pyx_GIVEREF(__pyx_v_ca);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_ca);
  __Pyx_INCREF(__pyx_v_ch);
  __Pyx_GIVEREF(__pyx_v_ch);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_ch);
  __Pyx_INCREF(__pyx_v_fs);
  __Pyx_GIVEREF(__pyx_v_fs);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_fs);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":31
 * #   #   #   #           TASK STARTERS           #   #   #   #
 * 
 * def multi(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start multitable collection using configuration object `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.multi", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XDECREF(__pyx_v_ca);
  __Pyx_XDECREF(__pyx_v_ac);
  __Pyx_XDECREF(__pyx_v_af);
  __Pyx_XDECREF(__pyx_v_ch);
  __Pyx_XDECREF(__pyx_v_fs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":48
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs
 * def cases(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start cases table collection using configuration object `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_3cases(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_2cases[] = "\n     Start cases table collection using configuration object `cf`.\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_3cases = {"cases", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_3cases, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_2cases};
static PyObject *__pyx_pw_9alacorder_3cal_3cases(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cases (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "cases") < 0)) __PYX_ERR(0, 48, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cases", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 48, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.cases", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_2cases(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_2cases(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_df = NULL;
  PyObject *__pyx_v_ca = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ac = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_af = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cases", 0);

  /* "alacorder/cal.pyx":52
 *      Start cases table collection using configuration object `cf`.
 *      """
 *      df = read(cf, window)             # <<<<<<<<<<<<<<
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cf);
    __Pyx_INCREF(__pyx_v_window);
    __Pyx_GIVEREF(__pyx_v_window);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_window);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":53
 *      """
 *      df = read(cf, window)
 *      print("Extracting case info...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df)
 *      write(ca, cf=cf)
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":54
 *      df = read(cf, window)
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df)             # <<<<<<<<<<<<<<
 *      write(ca, cf=cf)
 *      if not cf['NO_WRITE']:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_split_cases); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_v_df) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_df);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 54, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 54, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 2; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(0, 54, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 54, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_ca = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_ac = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_af = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":55
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df)
 *      write(ca, cf=cf)             # <<<<<<<<<<<<<<
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_ca);
  __Pyx_GIVEREF(__pyx_v_ca);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ca);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cf, __pyx_v_cf) < 0) __PYX_ERR(0, 55, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":56
 *      ca, ac, af = split_cases(df)
 *      write(ca, cf=cf)
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      if window:
 */
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NO_WRITE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 56, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = ((!__pyx_t_8) != 0);
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":57
 *      write(ca, cf=cf)
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")             # <<<<<<<<<<<<<<
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":56
 *      ca, ac, af = split_cases(df)
 *      write(ca, cf=cf)
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      if window:
 */
  }

  /* "alacorder/cal.pyx":58
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 58, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":59
 *           print("Writing to export...")
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)             # <<<<<<<<<<<<<<
 *      return ca
 * def charges(cf, window=None, debug=False):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":58
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca
 */
  }

  /* "alacorder/cal.pyx":60
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca             # <<<<<<<<<<<<<<
 * def charges(cf, window=None, debug=False):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ca);
  __pyx_r = __pyx_v_ca;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":48
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs
 * def cases(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start cases table collection using configuration object `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.cases", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XDECREF(__pyx_v_ca);
  __Pyx_XDECREF(__pyx_v_ac);
  __Pyx_XDECREF(__pyx_v_af);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":61
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca
 * def charges(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start charges table collection using configuration object `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_5charges(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_4charges[] = "\n     Start charges table collection using configuration object `cf`.\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_5charges = {"charges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_5charges, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_4charges};
static PyObject *__pyx_pw_9alacorder_3cal_5charges(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("charges (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "charges") < 0)) __PYX_ERR(0, 61, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("charges", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 61, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.charges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_4charges(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_4charges(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_df = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ca = NULL;
  PyObject *__pyx_v_ac = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_af = NULL;
  PyObject *__pyx_v_ch = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("charges", 0);

  /* "alacorder/cal.pyx":65
 *      Start charges table collection using configuration object `cf`.
 *      """
 *      df = read(cf, window)             # <<<<<<<<<<<<<<
 *      print("Extracting charges...")
 *      ca, ac, af = split_cases(df)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cf);
    __Pyx_INCREF(__pyx_v_window);
    __Pyx_GIVEREF(__pyx_v_window);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_window);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":66
 *      """
 *      df = read(cf, window)
 *      print("Extracting charges...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df)
 *      print("Parsing charges...")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":67
 *      df = read(cf, window)
 *      print("Extracting charges...")
 *      ca, ac, af = split_cases(df)             # <<<<<<<<<<<<<<
 *      print("Parsing charges...")
 *      ch = split_charges(ac)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_split_cases); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_v_df) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_df);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 67, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 2; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(0, 67, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 67, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_ca = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_ac = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_af = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":68
 *      print("Extracting charges...")
 *      ca, ac, af = split_cases(df)
 *      print("Parsing charges...")             # <<<<<<<<<<<<<<
 *      ch = split_charges(ac)
 *      if not cf['NO_WRITE']:
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":69
 *      ca, ac, af = split_cases(df)
 *      print("Parsing charges...")
 *      ch = split_charges(ac)             # <<<<<<<<<<<<<<
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_split_charges); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_v_ac) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_ac);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 69, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_ch = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":70
 *      print("Parsing charges...")
 *      ch = split_charges(ac)
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      write(ch, cf=cf)
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NO_WRITE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 70, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_9 = ((!__pyx_t_8) != 0);
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":71
 *      ch = split_charges(ac)
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")             # <<<<<<<<<<<<<<
 *      write(ch, cf=cf)
 *      if window:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":70
 *      print("Parsing charges...")
 *      ch = split_charges(ac)
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      write(ch, cf=cf)
 */
  }

  /* "alacorder/cal.pyx":72
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 *      write(ch, cf=cf)             # <<<<<<<<<<<<<<
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_ch);
  __Pyx_GIVEREF(__pyx_v_ch);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_ch);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cf, __pyx_v_cf) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":73
 *           print("Writing to export...")
 *      write(ch, cf=cf)
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 73, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":74
 *      write(ch, cf=cf)
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)             # <<<<<<<<<<<<<<
 *      return ch
 * def fees(cf, window=None, debug=False):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":73
 *           print("Writing to export...")
 *      write(ch, cf=cf)
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch
 */
  }

  /* "alacorder/cal.pyx":75
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch             # <<<<<<<<<<<<<<
 * def fees(cf, window=None, debug=False):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_ch);
  __pyx_r = __pyx_v_ch;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":61
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca
 * def charges(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start charges table collection using configuration object `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.charges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XDECREF(__pyx_v_ca);
  __Pyx_XDECREF(__pyx_v_ac);
  __Pyx_XDECREF(__pyx_v_af);
  __Pyx_XDECREF(__pyx_v_ch);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":76
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch
 * def fees(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start fee sheet collection using configuration object `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_7fees(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_6fees[] = "\n     Start fee sheet collection using configuration object `cf`.\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_7fees = {"fees", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_7fees, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_6fees};
static PyObject *__pyx_pw_9alacorder_3cal_7fees(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fees (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "fees") < 0)) __PYX_ERR(0, 76, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("fees", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 76, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.fees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_6fees(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_6fees(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_df = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ca = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ac = NULL;
  PyObject *__pyx_v_af = NULL;
  PyObject *__pyx_v_fs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fees", 0);

  /* "alacorder/cal.pyx":80
 *      Start fee sheet collection using configuration object `cf`.
 *      """
 *      df = read(cf, window)             # <<<<<<<<<<<<<<
 *      print("Extracting fee sheets...")
 *      ca, ac, af = split_cases(df)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cf);
    __Pyx_INCREF(__pyx_v_window);
    __Pyx_GIVEREF(__pyx_v_window);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_window);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_df = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":81
 *      """
 *      df = read(cf, window)
 *      print("Extracting fee sheets...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df)
 *      print("Parsing fees tables...")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":82
 *      df = read(cf, window)
 *      print("Extracting fee sheets...")
 *      ca, ac, af = split_cases(df)             # <<<<<<<<<<<<<<
 *      print("Parsing fees tables...")
 *      fs = split_fees(af)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_split_cases); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_v_df) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_df);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 3)) {
      if (size > 3) __Pyx_RaiseTooManyValuesError(3);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(0, 82, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_6 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
    index = 0; __pyx_t_2 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 2; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) __PYX_ERR(0, 82, __pyx_L1_error)
    __pyx_t_7 = NULL;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(0, 82, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_ca = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_ac = __pyx_t_5;
  __pyx_t_5 = 0;
  __pyx_v_af = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":83
 *      print("Extracting fee sheets...")
 *      ca, ac, af = split_cases(df)
 *      print("Parsing fees tables...")             # <<<<<<<<<<<<<<
 *      fs = split_fees(af)
 *      write(fs, cf=cf)
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":84
 *      ca, ac, af = split_cases(df)
 *      print("Parsing fees tables...")
 *      fs = split_fees(af)             # <<<<<<<<<<<<<<
 *      write(fs, cf=cf)
 *      if not cf['NO_WRITE']:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_split_fees); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_v_af) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_af);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_fs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":85
 *      print("Parsing fees tables...")
 *      fs = split_fees(af)
 *      write(fs, cf=cf)             # <<<<<<<<<<<<<<
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_fs);
  __Pyx_GIVEREF(__pyx_v_fs);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_fs);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cf, __pyx_v_cf) < 0) __PYX_ERR(0, 85, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":86
 *      fs = split_fees(af)
 *      write(fs, cf=cf)
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      if window:
 */
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NO_WRITE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = ((!__pyx_t_8) != 0);
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":87
 *      write(fs, cf=cf)
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")             # <<<<<<<<<<<<<<
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":86
 *      fs = split_fees(af)
 *      write(fs, cf=cf)
 *      if not cf['NO_WRITE']:             # <<<<<<<<<<<<<<
 *           print("Writing to export...")
 *      if window:
 */
  }

  /* "alacorder/cal.pyx":88
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs
 */
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 88, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":89
 *           print("Writing to export...")
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)             # <<<<<<<<<<<<<<
 *      return fs
 * def tables(cf, window=None, debug=False):
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":88
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs
 */
  }

  /* "alacorder/cal.pyx":90
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs             # <<<<<<<<<<<<<<
 * def tables(cf, window=None, debug=False):
 *     """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fs);
  __pyx_r = __pyx_v_fs;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":76
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch
 * def fees(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start fee sheet collection using configuration object `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.fees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XDECREF(__pyx_v_ca);
  __Pyx_XDECREF(__pyx_v_ac);
  __Pyx_XDECREF(__pyx_v_af);
  __Pyx_XDECREF(__pyx_v_fs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":91
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs
 * def tables(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *     """
 *     Start Alacorder table export using configuration object `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_9tables(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_8tables[] = "\n    Start Alacorder table export using configuration object `cf`.\n    \n    Args:\n        cf (dict): Configuration object\n        debug (bool, optional): Print detailed logs\n    \n    Returns:\n        DataFrame returned from table parser\n    ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_9tables = {"tables", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_9tables, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_8tables};
static PyObject *__pyx_pw_9alacorder_3cal_9tables(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("tables (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "tables") < 0)) __PYX_ERR(0, 91, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("tables", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 91, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.tables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_8tables(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_8tables(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("tables", 0);

  /* "alacorder/cal.pyx":102
 *         DataFrame returned from table parser
 *     """
 *     return init(cf, window=window)             # <<<<<<<<<<<<<<
 * def init(cf, window=None, debug=False):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_init); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_cf);
  __Pyx_GIVEREF(__pyx_v_cf);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_cf);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":91
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs
 * def tables(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *     """
 *     Start Alacorder table export using configuration object `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("alacorder.cal.tables", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":103
 *     """
 *     return init(cf, window=window)
 * def init(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start Alacorder using configuration object `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_11init(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_10init[] = "\n     Start Alacorder using configuration object `cf`.\n     \n     Args:\n         cf (dict): Configuration dict object\n         debug (bool, optional): Print verbose logs\n     \n     Returns:\n         DataFrame: outputs from specified table parser\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_11init = {"init", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_11init, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_10init};
static PyObject *__pyx_pw_9alacorder_3cal_11init(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("init (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "init") < 0)) __PYX_ERR(0, 103, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("init", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 103, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_10init(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_10init(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_ft = NULL;
  PyObject *__pyx_v_ar = NULL;
  PyObject *__pyx_v_ch = NULL;
  PyObject *__pyx_v_ca = NULL;
  PyObject *__pyx_v_fs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("init", 0);

  /* "alacorder/cal.pyx":114
 *          DataFrame: outputs from specified table parser
 *      """
 *      if cf['FETCH'] == True:             # <<<<<<<<<<<<<<
 *           ft = fetch(cf=cf)
 *           return ft
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_FETCH); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":115
 *      """
 *      if cf['FETCH'] == True:
 *           ft = fetch(cf=cf)             # <<<<<<<<<<<<<<
 *           return ft
 *      elif cf['ARCHIVE'] == True:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_fetch); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_cf, __pyx_v_cf) < 0) __PYX_ERR(0, 115, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_ft = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":116
 *      if cf['FETCH'] == True:
 *           ft = fetch(cf=cf)
 *           return ft             # <<<<<<<<<<<<<<
 *      elif cf['ARCHIVE'] == True:
 *           ar = archive(cf, window=window)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ft);
    __pyx_r = __pyx_v_ft;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":114
 *          DataFrame: outputs from specified table parser
 *      """
 *      if cf['FETCH'] == True:             # <<<<<<<<<<<<<<
 *           ft = fetch(cf=cf)
 *           return ft
 */
  }

  /* "alacorder/cal.pyx":117
 *           ft = fetch(cf=cf)
 *           return ft
 *      elif cf['ARCHIVE'] == True:             # <<<<<<<<<<<<<<
 *           ar = archive(cf, window=window)
 *           return ar
 */
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_ARCHIVE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":118
 *           return ft
 *      elif cf['ARCHIVE'] == True:
 *           ar = archive(cf, window=window)             # <<<<<<<<<<<<<<
 *           return ar
 *      elif cf['TABLE'] == "charges" and cf['SUPPORT_SINGLETABLE']:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_archive); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_cf);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 118, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 118, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_ar = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":119
 *      elif cf['ARCHIVE'] == True:
 *           ar = archive(cf, window=window)
 *           return ar             # <<<<<<<<<<<<<<
 *      elif cf['TABLE'] == "charges" and cf['SUPPORT_SINGLETABLE']:
 *           ch = charges(cf, window=window)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ar);
    __pyx_r = __pyx_v_ar;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":117
 *           ft = fetch(cf=cf)
 *           return ft
 *      elif cf['ARCHIVE'] == True:             # <<<<<<<<<<<<<<
 *           ar = archive(cf, window=window)
 *           return ar
 */
  }

  /* "alacorder/cal.pyx":120
 *           ar = archive(cf, window=window)
 *           return ar
 *      elif cf['TABLE'] == "charges" and cf['SUPPORT_SINGLETABLE']:             # <<<<<<<<<<<<<<
 *           ch = charges(cf, window=window)
 *           return ch
 */
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_TABLE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_charges, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_3 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_SUPPORT_SINGLETABLE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __pyx_t_6;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":121
 *           return ar
 *      elif cf['TABLE'] == "charges" and cf['SUPPORT_SINGLETABLE']:
 *           ch = charges(cf, window=window)             # <<<<<<<<<<<<<<
 *           return ch
 *      elif cf['TABLE'] == "cases" and cf['SUPPORT_SINGLETABLE']:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_charges); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_cf);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 121, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 121, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_ch = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":122
 *      elif cf['TABLE'] == "charges" and cf['SUPPORT_SINGLETABLE']:
 *           ch = charges(cf, window=window)
 *           return ch             # <<<<<<<<<<<<<<
 *      elif cf['TABLE'] == "cases" and cf['SUPPORT_SINGLETABLE']:
 *           ca = cases(cf, window=window)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ch);
    __pyx_r = __pyx_v_ch;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":120
 *           ar = archive(cf, window=window)
 *           return ar
 *      elif cf['TABLE'] == "charges" and cf['SUPPORT_SINGLETABLE']:             # <<<<<<<<<<<<<<
 *           ch = charges(cf, window=window)
 *           return ch
 */
  }

  /* "alacorder/cal.pyx":123
 *           ch = charges(cf, window=window)
 *           return ch
 *      elif cf['TABLE'] == "cases" and cf['SUPPORT_SINGLETABLE']:             # <<<<<<<<<<<<<<
 *           ca = cases(cf, window=window)
 *           return ca
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_TABLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_cases, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_3 = __pyx_t_6;
    goto __pyx_L6_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_SUPPORT_SINGLETABLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_6;
  __pyx_L6_bool_binop_done:;
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":124
 *           return ch
 *      elif cf['TABLE'] == "cases" and cf['SUPPORT_SINGLETABLE']:
 *           ca = cases(cf, window=window)             # <<<<<<<<<<<<<<
 *           return ca
 *      elif cf['TABLE'] == "fees" and cf['SUPPORT_SINGLETABLE']:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_cases); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_cf);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 124, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_ca = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":125
 *      elif cf['TABLE'] == "cases" and cf['SUPPORT_SINGLETABLE']:
 *           ca = cases(cf, window=window)
 *           return ca             # <<<<<<<<<<<<<<
 *      elif cf['TABLE'] == "fees" and cf['SUPPORT_SINGLETABLE']:
 *           fs = fees(cf, window=window)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_ca);
    __pyx_r = __pyx_v_ca;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":123
 *           ch = charges(cf, window=window)
 *           return ch
 *      elif cf['TABLE'] == "cases" and cf['SUPPORT_SINGLETABLE']:             # <<<<<<<<<<<<<<
 *           ca = cases(cf, window=window)
 *           return ca
 */
  }

  /* "alacorder/cal.pyx":126
 *           ca = cases(cf, window=window)
 *           return ca
 *      elif cf['TABLE'] == "fees" and cf['SUPPORT_SINGLETABLE']:             # <<<<<<<<<<<<<<
 *           fs = fees(cf, window=window)
 *           return fs
 */
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_TABLE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_5, __pyx_n_u_fees, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_3 = __pyx_t_6;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_SUPPORT_SINGLETABLE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 126, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_3 = __pyx_t_6;
  __pyx_L8_bool_binop_done:;
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":127
 *           return ca
 *      elif cf['TABLE'] == "fees" and cf['SUPPORT_SINGLETABLE']:
 *           fs = fees(cf, window=window)             # <<<<<<<<<<<<<<
 *           return fs
 *      elif cf['TABLE'] in ("all","","multi","multitable") and cf['SUPPORT_MULTITABLE']:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_fees); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_cf);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 127, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_fs = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":128
 *      elif cf['TABLE'] == "fees" and cf['SUPPORT_SINGLETABLE']:
 *           fs = fees(cf, window=window)
 *           return fs             # <<<<<<<<<<<<<<
 *      elif cf['TABLE'] in ("all","","multi","multitable") and cf['SUPPORT_MULTITABLE']:
 *           ca, ch, fs = multi(cf, window=window)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_fs);
    __pyx_r = __pyx_v_fs;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":126
 *           ca = cases(cf, window=window)
 *           return ca
 *      elif cf['TABLE'] == "fees" and cf['SUPPORT_SINGLETABLE']:             # <<<<<<<<<<<<<<
 *           fs = fees(cf, window=window)
 *           return fs
 */
  }

  /* "alacorder/cal.pyx":129
 *           fs = fees(cf, window=window)
 *           return fs
 *      elif cf['TABLE'] in ("all","","multi","multitable") and cf['SUPPORT_MULTITABLE']:             # <<<<<<<<<<<<<<
 *           ca, ch, fs = multi(cf, window=window)
 *           return ca, ch, fs
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_TABLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_all, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 129, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u__8, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 129, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_multi, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 129, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_6 = __pyx_t_7;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_multitable, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 129, __pyx_L1_error)
  __pyx_t_6 = __pyx_t_7;
  __pyx_L12_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_6 != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_3 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_SUPPORT_MULTITABLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 129, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_t_7;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":130
 *           return fs
 *      elif cf['TABLE'] in ("all","","multi","multitable") and cf['SUPPORT_MULTITABLE']:
 *           ca, ch, fs = multi(cf, window=window)             # <<<<<<<<<<<<<<
 *           return ca, ch, fs
 *      else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_multi); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_cf);
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 130, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
      PyObject* sequence = __pyx_t_5;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(0, 130, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_1 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      #else
      __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      #endif
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_8 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
      index = 0; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L16_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_2);
      index = 1; __pyx_t_4 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_4)) goto __pyx_L16_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 2; __pyx_t_1 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_1)) goto __pyx_L16_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_1);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 3) < 0) __PYX_ERR(0, 130, __pyx_L1_error)
      __pyx_t_9 = NULL;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L17_unpacking_done;
      __pyx_L16_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      __PYX_ERR(0, 130, __pyx_L1_error)
      __pyx_L17_unpacking_done:;
    }
    __pyx_v_ca = __pyx_t_2;
    __pyx_t_2 = 0;
    __pyx_v_ch = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_fs = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":131
 *      elif cf['TABLE'] in ("all","","multi","multitable") and cf['SUPPORT_MULTITABLE']:
 *           ca, ch, fs = multi(cf, window=window)
 *           return ca, ch, fs             # <<<<<<<<<<<<<<
 *      else:
 *           print("Job not specified. Select a mode and reconfigure to start.")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_v_ca);
    __Pyx_GIVEREF(__pyx_v_ca);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_ca);
    __Pyx_INCREF(__pyx_v_ch);
    __Pyx_GIVEREF(__pyx_v_ch);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_ch);
    __Pyx_INCREF(__pyx_v_fs);
    __Pyx_GIVEREF(__pyx_v_fs);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_fs);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":129
 *           fs = fees(cf, window=window)
 *           return fs
 *      elif cf['TABLE'] in ("all","","multi","multitable") and cf['SUPPORT_MULTITABLE']:             # <<<<<<<<<<<<<<
 *           ca, ch, fs = multi(cf, window=window)
 *           return ca, ch, fs
 */
  }

  /* "alacorder/cal.pyx":133
 *           return ca, ch, fs
 *      else:
 *           print("Job not specified. Select a mode and reconfigure to start.")             # <<<<<<<<<<<<<<
 *           return None
 * def archive(cf, window=None, debug=False):
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":134
 *      else:
 *           print("Job not specified. Select a mode and reconfigure to start.")
 *           return None             # <<<<<<<<<<<<<<
 * def archive(cf, window=None, debug=False):
 *      """
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":103
 *     """
 *     return init(cf, window=window)
 * def init(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start Alacorder using configuration object `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ft);
  __Pyx_XDECREF(__pyx_v_ar);
  __Pyx_XDECREF(__pyx_v_ch);
  __Pyx_XDECREF(__pyx_v_ca);
  __Pyx_XDECREF(__pyx_v_fs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":135
 *           print("Job not specified. Select a mode and reconfigure to start.")
 *           return None
 * def archive(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Write a full text archive from inputs using configuration `cf`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_13archive(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_12archive[] = "\n     Write a full text archive from inputs using configuration `cf`.\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_13archive = {"archive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_13archive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_12archive};
static PyObject *__pyx_pw_9alacorder_3cal_13archive(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("archive (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "archive") < 0)) __PYX_ERR(0, 135, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("archive", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 135, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_12archive(__pyx_self, __pyx_v_cf, __pyx_v_window, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_12archive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window, CYTHON_UNUSED PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_a = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("archive", 0);

  /* "alacorder/cal.pyx":139
 *      Write a full text archive from inputs using configuration `cf`.
 *      """
 *      a = read(cf, window)             # <<<<<<<<<<<<<<
 *      write(a, cf=cf)
 *      if window:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_read); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_cf, __pyx_v_window};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 2+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(2+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(__pyx_v_cf);
    __Pyx_GIVEREF(__pyx_v_cf);
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, __pyx_v_cf);
    __Pyx_INCREF(__pyx_v_window);
    __Pyx_GIVEREF(__pyx_v_window);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_v_window);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_a = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":140
 *      """
 *      a = read(cf, window)
 *      write(a, cf=cf)             # <<<<<<<<<<<<<<
 *      if window:
 *           window.write_event_value("COMPLETE-MA",True)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_a);
  __Pyx_GIVEREF(__pyx_v_a);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_a);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cf, __pyx_v_cf) < 0) __PYX_ERR(0, 140, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 140, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":141
 *      a = read(cf, window)
 *      write(a, cf=cf)
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-MA",True)
 *      return a
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 141, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "alacorder/cal.pyx":142
 *      write(a, cf=cf)
 *      if window:
 *           window.write_event_value("COMPLETE-MA",True)             # <<<<<<<<<<<<<<
 *      return a
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 142, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":141
 *      a = read(cf, window)
 *      write(a, cf=cf)
 *      if window:             # <<<<<<<<<<<<<<
 *           window.write_event_value("COMPLETE-MA",True)
 *      return a
 */
  }

  /* "alacorder/cal.pyx":143
 *      if window:
 *           window.write_event_value("COMPLETE-MA",True)
 *      return a             # <<<<<<<<<<<<<<
 * 
 * #   #   #   #         CONFIGURATION & I/O        #   #   #   #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_a);
  __pyx_r = __pyx_v_a;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":135
 *           print("Job not specified. Select a mode and reconfigure to start.")
 *           return None
 * def archive(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Write a full text archive from inputs using configuration `cf`.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("alacorder.cal.archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_a);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":147
 * #   #   #   #         CONFIGURATION & I/O        #   #   #   #
 * 
 * def set(inputs, outputs=None, count=0, table='', archive=False, no_prompt=True, debug=False, overwrite=False, no_write=False, fetch=False, cID='', uID='', pwd='', qmax=0, qskip=0, append=False, window=None, force=False, no_update=False, now=False):             # <<<<<<<<<<<<<<
 *      """
 *      Check inputs and outputs and return a configuration object for Alacorder table parser functions to receive as parameter and complete task, or set `now = True` to run upon set() call.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_15set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_14set[] = "\n     Check inputs and outputs and return a configuration object for Alacorder table parser functions to receive as parameter and complete task, or set `now = True` to run upon set() call.\n\n     Args:\n         inputs (Path | DataFrame): PDF directory, query, archive path, or DataFrame input\n         outputs (Path | DataFrame, optional): Path to archive, directory, or file output\n         count (int, optional): Max cases to pull from input\n         table (str, optional): Table (all, cases, fees, charges)\n         archive (bool, optional): Write a full text archive from a directory of case detail PDFs\n         no_prompt (bool, optional): Skip user input / confirmation prompts\n         debug (bool, optional): Print verbose logs to console for developers\n         overwrite (bool, optional): Overwrite existing files at output path\n         no_write (bool, optional): Do not export to output path\n         no_update (bool, optional): Do not mark input query when fetching cases\n         fetch (bool, optional): Retrieve case detail PDFs from Alacourt.com\n         cID (str, optional): Customer ID on Alacourt.com\n         uID (str, optional): User ID on Alacourt.com\n         pwd (str, optional): Password on Alacourt.com\n         qmax (int, optional): Maximum queries to conduct on Alacourt.com\n         qskip (int, optional): Skip entries at top of query file\n         append (bool, optional): Append one archive to another\n         force (bool, optional): Do not raise exceptions\n         now (bool, optional): Start Alacorder upon successful configuration\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_15set = {"set", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_15set, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_14set};
static PyObject *__pyx_pw_9alacorder_3cal_15set(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_inputs = 0;
  PyObject *__pyx_v_outputs = 0;
  PyObject *__pyx_v_count = 0;
  PyObject *__pyx_v_table = 0;
  PyObject *__pyx_v_archive = 0;
  PyObject *__pyx_v_no_prompt = 0;
  PyObject *__pyx_v_debug = 0;
  PyObject *__pyx_v_overwrite = 0;
  PyObject *__pyx_v_no_write = 0;
  PyObject *__pyx_v_fetch = 0;
  PyObject *__pyx_v_cID = 0;
  PyObject *__pyx_v_uID = 0;
  PyObject *__pyx_v_pwd = 0;
  PyObject *__pyx_v_qmax = 0;
  PyObject *__pyx_v_qskip = 0;
  PyObject *__pyx_v_append = 0;
  PyObject *__pyx_v_window = 0;
  PyObject *__pyx_v_force = 0;
  PyObject *__pyx_v_no_update = 0;
  PyObject *__pyx_v_now = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_inputs,&__pyx_n_s_outputs,&__pyx_n_s_count,&__pyx_n_s_table,&__pyx_n_s_archive,&__pyx_n_s_no_prompt,&__pyx_n_s_debug,&__pyx_n_s_overwrite,&__pyx_n_s_no_write,&__pyx_n_s_fetch,&__pyx_n_s_cID,&__pyx_n_s_uID,&__pyx_n_s_pwd,&__pyx_n_s_qmax,&__pyx_n_s_qskip,&__pyx_n_s_append,&__pyx_n_s_window,&__pyx_n_s_force,&__pyx_n_s_no_update,&__pyx_n_s_now,0};
    PyObject* values[20] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)__pyx_int_0);
    values[3] = ((PyObject *)__pyx_kp_u__8);
    values[4] = ((PyObject *)Py_False);
    values[5] = ((PyObject *)Py_True);
    values[6] = ((PyObject *)Py_False);
    values[7] = ((PyObject *)Py_False);
    values[8] = ((PyObject *)Py_False);
    values[9] = ((PyObject *)Py_False);
    values[10] = ((PyObject *)__pyx_kp_u__8);
    values[11] = ((PyObject *)__pyx_kp_u__8);
    values[12] = ((PyObject *)__pyx_kp_u__8);
    values[13] = ((PyObject *)__pyx_int_0);
    values[14] = ((PyObject *)__pyx_int_0);
    values[15] = ((PyObject *)Py_False);
    values[16] = ((PyObject *)Py_None);
    values[17] = ((PyObject *)Py_False);
    values[18] = ((PyObject *)Py_False);
    values[19] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 20: values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_inputs)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_outputs);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_count);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_table);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_archive);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_no_prompt);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_overwrite);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_no_write);
          if (value) { values[8] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fetch);
          if (value) { values[9] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cID);
          if (value) { values[10] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_uID);
          if (value) { values[11] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pwd);
          if (value) { values[12] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_qmax);
          if (value) { values[13] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_qskip);
          if (value) { values[14] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 15:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_append);
          if (value) { values[15] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 16:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[16] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 17:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_force);
          if (value) { values[17] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 18:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_no_update);
          if (value) { values[18] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 19:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_now);
          if (value) { values[19] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "set") < 0)) __PYX_ERR(0, 147, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 20: values[19] = PyTuple_GET_ITEM(__pyx_args, 19);
        CYTHON_FALLTHROUGH;
        case 19: values[18] = PyTuple_GET_ITEM(__pyx_args, 18);
        CYTHON_FALLTHROUGH;
        case 18: values[17] = PyTuple_GET_ITEM(__pyx_args, 17);
        CYTHON_FALLTHROUGH;
        case 17: values[16] = PyTuple_GET_ITEM(__pyx_args, 16);
        CYTHON_FALLTHROUGH;
        case 16: values[15] = PyTuple_GET_ITEM(__pyx_args, 15);
        CYTHON_FALLTHROUGH;
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_inputs = values[0];
    __pyx_v_outputs = values[1];
    __pyx_v_count = values[2];
    __pyx_v_table = values[3];
    __pyx_v_archive = values[4];
    __pyx_v_no_prompt = values[5];
    __pyx_v_debug = values[6];
    __pyx_v_overwrite = values[7];
    __pyx_v_no_write = values[8];
    __pyx_v_fetch = values[9];
    __pyx_v_cID = values[10];
    __pyx_v_uID = values[11];
    __pyx_v_pwd = values[12];
    __pyx_v_qmax = values[13];
    __pyx_v_qskip = values[14];
    __pyx_v_append = values[15];
    __pyx_v_window = values[16];
    __pyx_v_force = values[17];
    __pyx_v_no_update = values[18];
    __pyx_v_now = values[19];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set", 0, 1, 20, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 147, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_14set(__pyx_self, __pyx_v_inputs, __pyx_v_outputs, __pyx_v_count, __pyx_v_table, __pyx_v_archive, __pyx_v_no_prompt, __pyx_v_debug, __pyx_v_overwrite, __pyx_v_no_write, __pyx_v_fetch, __pyx_v_cID, __pyx_v_uID, __pyx_v_pwd, __pyx_v_qmax, __pyx_v_qskip, __pyx_v_append, __pyx_v_window, __pyx_v_force, __pyx_v_no_update, __pyx_v_now);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_14set(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_inputs, PyObject *__pyx_v_outputs, PyObject *__pyx_v_count, PyObject *__pyx_v_table, PyObject *__pyx_v_archive, PyObject *__pyx_v_no_prompt, PyObject *__pyx_v_debug, PyObject *__pyx_v_overwrite, PyObject *__pyx_v_no_write, PyObject *__pyx_v_fetch, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_qmax, PyObject *__pyx_v_qskip, PyObject *__pyx_v_append, PyObject *__pyx_v_window, PyObject *__pyx_v_force, PyObject *__pyx_v_no_update, PyObject *__pyx_v_now) {
  CYTHON_UNUSED int __pyx_v_good;
  PyObject *__pyx_v_found = NULL;
  PyObject *__pyx_v_outputext = NULL;
  int __pyx_v_existing_output;
  int __pyx_v_support_multitable;
  int __pyx_v_support_singletable;
  int __pyx_v_support_archive;
  CYTHON_UNUSED PyObject *__pyx_v_old_archive = NULL;
  PyObject *__pyx_v_queue = NULL;
  int __pyx_v_is_full_text;
  PyObject *__pyx_v_itype = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set", 0);
  __Pyx_INCREF(__pyx_v_outputs);
  __Pyx_INCREF(__pyx_v_count);
  __Pyx_INCREF(__pyx_v_no_write);

  /* "alacorder/cal.pyx":173
 *      """
 *      # flag checks
 *      good = True             # <<<<<<<<<<<<<<
 *      outputs = None if no_write else outputs
 *      no_write = True if outputs == None else no_write
 */
  __pyx_v_good = 1;

  /* "alacorder/cal.pyx":174
 *      # flag checks
 *      good = True
 *      outputs = None if no_write else outputs             # <<<<<<<<<<<<<<
 *      no_write = True if outputs == None else no_write
 *      found = 0
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_no_write); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 174, __pyx_L1_error)
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  } else {
    __Pyx_INCREF(__pyx_v_outputs);
    __pyx_t_1 = __pyx_v_outputs;
  }
  __Pyx_DECREF_SET(__pyx_v_outputs, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":175
 *      good = True
 *      outputs = None if no_write else outputs
 *      no_write = True if outputs == None else no_write             # <<<<<<<<<<<<<<
 *      found = 0
 * 
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_outputs, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 175, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_True);
    __pyx_t_1 = Py_True;
  } else {
    __Pyx_INCREF(__pyx_v_no_write);
    __pyx_t_1 = __pyx_v_no_write;
  }
  __Pyx_DECREF_SET(__pyx_v_no_write, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":176
 *      outputs = None if no_write else outputs
 *      no_write = True if outputs == None else no_write
 *      found = 0             # <<<<<<<<<<<<<<
 * 
 *      if debug:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_found = __pyx_int_0;

  /* "alacorder/cal.pyx":178
 *      found = 0
 * 
 *      if debug:             # <<<<<<<<<<<<<<
 *          sys.tracebacklimit = 10
 *          pl.Config.set_verbose(True)
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_debug); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 178, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":179
 * 
 *      if debug:
 *          sys.tracebacklimit = 10             # <<<<<<<<<<<<<<
 *          pl.Config.set_verbose(True)
 *      else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_tracebacklimit, __pyx_int_10) < 0) __PYX_ERR(0, 179, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":180
 *      if debug:
 *          sys.tracebacklimit = 10
 *          pl.Config.set_verbose(True)             # <<<<<<<<<<<<<<
 *      else:
 *          sys.tracebacklimit = 1
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Config); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_verbose); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_3, Py_True);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":178
 *      found = 0
 * 
 *      if debug:             # <<<<<<<<<<<<<<
 *          sys.tracebacklimit = 10
 *          pl.Config.set_verbose(True)
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":182
 *          pl.Config.set_verbose(True)
 *      else:
 *          sys.tracebacklimit = 1             # <<<<<<<<<<<<<<
 *          pl.Config.set_verbose(False)
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (__Pyx_PyObject_SetAttrStr(__pyx_t_1, __pyx_n_s_tracebacklimit, __pyx_int_1) < 0) __PYX_ERR(0, 182, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":183
 *      else:
 *          sys.tracebacklimit = 1
 *          pl.Config.set_verbose(False)             # <<<<<<<<<<<<<<
 * 
 *      # check output
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Config); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_set_verbose); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_3, Py_False);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 183, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "alacorder/cal.pyx":186
 * 
 *      # check output
 *      if no_write:             # <<<<<<<<<<<<<<
 *           outputext = "none"
 *           existing_output = False
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_no_write); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 186, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":187
 *      # check output
 *      if no_write:
 *           outputext = "none"             # <<<<<<<<<<<<<<
 *           existing_output = False
 *      elif os.path.isdir(outputs):
 */
    __Pyx_INCREF(__pyx_n_u_none);
    __pyx_v_outputext = __pyx_n_u_none;

    /* "alacorder/cal.pyx":188
 *      if no_write:
 *           outputext = "none"
 *           existing_output = False             # <<<<<<<<<<<<<<
 *      elif os.path.isdir(outputs):
 *           outputext = "directory"
 */
    __pyx_v_existing_output = 0;

    /* "alacorder/cal.pyx":186
 * 
 *      # check output
 *      if no_write:             # <<<<<<<<<<<<<<
 *           outputext = "none"
 *           existing_output = False
 */
    goto __pyx_L4;
  }

  /* "alacorder/cal.pyx":189
 *           outputext = "none"
 *           existing_output = False
 *      elif os.path.isdir(outputs):             # <<<<<<<<<<<<<<
 *           outputext = "directory"
 *           existing_output = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_isdir); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_outputs) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_outputs);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":190
 *           existing_output = False
 *      elif os.path.isdir(outputs):
 *           outputext = "directory"             # <<<<<<<<<<<<<<
 *           existing_output = False
 *      elif os.path.isfile(outputs):
 */
    __Pyx_INCREF(__pyx_n_u_directory);
    __pyx_v_outputext = __pyx_n_u_directory;

    /* "alacorder/cal.pyx":191
 *      elif os.path.isdir(outputs):
 *           outputext = "directory"
 *           existing_output = False             # <<<<<<<<<<<<<<
 *      elif os.path.isfile(outputs):
 *           assert overwrite or append # Existing file at output path!
 */
    __pyx_v_existing_output = 0;

    /* "alacorder/cal.pyx":189
 *           outputext = "none"
 *           existing_output = False
 *      elif os.path.isdir(outputs):             # <<<<<<<<<<<<<<
 *           outputext = "directory"
 *           existing_output = False
 */
    goto __pyx_L4;
  }

  /* "alacorder/cal.pyx":192
 *           outputext = "directory"
 *           existing_output = False
 *      elif os.path.isfile(outputs):             # <<<<<<<<<<<<<<
 *           assert overwrite or append # Existing file at output path!
 *           outputext = os.path.splitext(outputs)[1]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_isfile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_outputs) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_outputs);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":193
 *           existing_output = False
 *      elif os.path.isfile(outputs):
 *           assert overwrite or append # Existing file at output path!             # <<<<<<<<<<<<<<
 *           outputext = os.path.splitext(outputs)[1]
 *           existing_output = True
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_overwrite); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 193, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L5_bool_binop_done;
      }
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_append); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 193, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_5;
      __pyx_L5_bool_binop_done:;
      if (unlikely(!__pyx_t_2)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 193, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":194
 *      elif os.path.isfile(outputs):
 *           assert overwrite or append # Existing file at output path!
 *           outputext = os.path.splitext(outputs)[1]             # <<<<<<<<<<<<<<
 *           existing_output = True
 *      else:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_splitext); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_outputs) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_outputs);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_outputext = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":195
 *           assert overwrite or append # Existing file at output path!
 *           outputext = os.path.splitext(outputs)[1]
 *           existing_output = True             # <<<<<<<<<<<<<<
 *      else:
 *           outputext = os.path.splitext(str(outputs))[1]
 */
    __pyx_v_existing_output = 1;

    /* "alacorder/cal.pyx":192
 *           outputext = "directory"
 *           existing_output = False
 *      elif os.path.isfile(outputs):             # <<<<<<<<<<<<<<
 *           assert overwrite or append # Existing file at output path!
 *           outputext = os.path.splitext(outputs)[1]
 */
    goto __pyx_L4;
  }

  /* "alacorder/cal.pyx":197
 *           existing_output = True
 *      else:
 *           outputext = os.path.splitext(str(outputs))[1]             # <<<<<<<<<<<<<<
 *           existing_output = False
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_splitext); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_outputs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_outputext = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":198
 *      else:
 *           outputext = os.path.splitext(str(outputs))[1]
 *           existing_output = False             # <<<<<<<<<<<<<<
 * 
 *      #flag checks - output extension
 */
    __pyx_v_existing_output = 0;
  }
  __pyx_L4:;

  /* "alacorder/cal.pyx":201
 * 
 *      #flag checks - output extension
 *      support_multitable = True if outputext in (".xls",".xlsx","none") else False             # <<<<<<<<<<<<<<
 *      support_singletable = True if outputext in (".xls",".xlsx","none",".json",".parquet", ".csv") else False
 *      support_archive = True if outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none") else False
 */
  __Pyx_INCREF(__pyx_v_outputext);
  __pyx_t_1 = __pyx_v_outputext;
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 201, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 201, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_none, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 201, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_7;
  __pyx_L7_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((__pyx_t_5 != 0)) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_support_multitable = __pyx_t_2;

  /* "alacorder/cal.pyx":202
 *      #flag checks - output extension
 *      support_multitable = True if outputext in (".xls",".xlsx","none") else False
 *      support_singletable = True if outputext in (".xls",".xlsx","none",".json",".parquet", ".csv") else False             # <<<<<<<<<<<<<<
 *      support_archive = True if outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none") else False
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")
 */
  __Pyx_INCREF(__pyx_v_outputext);
  __pyx_t_1 = __pyx_v_outputext;
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_none, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 202, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 202, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_7;
  __pyx_L10_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((__pyx_t_5 != 0)) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_support_singletable = __pyx_t_2;

  /* "alacorder/cal.pyx":203
 *      support_multitable = True if outputext in (".xls",".xlsx","none") else False
 *      support_singletable = True if outputext in (".xls",".xlsx","none",".json",".parquet", ".csv") else False
 *      support_archive = True if outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none") else False             # <<<<<<<<<<<<<<
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):
 */
  __Pyx_INCREF(__pyx_v_outputext);
  __pyx_t_1 = __pyx_v_outputext;
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_zip, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  if (!__pyx_t_7) {
  } else {
    __pyx_t_5 = __pyx_t_7;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_none, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 203, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_7;
  __pyx_L16_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((__pyx_t_5 != 0)) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_support_archive = __pyx_t_2;

  /* "alacorder/cal.pyx":204
 *      support_singletable = True if outputext in (".xls",".xlsx","none",".json",".parquet", ".csv") else False
 *      support_archive = True if outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none") else False
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")             # <<<<<<<<<<<<<<
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_force); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L23_bool_binop_done;
    }
    __Pyx_INCREF(__pyx_v_outputext);
    __pyx_t_1 = __pyx_v_outputext;
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_zip, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_none, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L25_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_directory, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 204, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_7;
    __pyx_L25_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_7 = (__pyx_t_5 != 0);
    __pyx_t_2 = __pyx_t_7;
    __pyx_L23_bool_binop_done:;
    if (unlikely(!__pyx_t_2)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 204, __pyx_L1_error)
    }
  }
  #endif

  /* "alacorder/cal.pyx":205
 *      support_archive = True if outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none") else False
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):             # <<<<<<<<<<<<<<
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:
 */
  __pyx_t_7 = ((__pyx_v_support_multitable == 0) != 0);
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L34_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_archive, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L34_bool_binop_done;
  }
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_fetch, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_7) {
  } else {
    __pyx_t_2 = __pyx_t_7;
    goto __pyx_L34_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_v_table);
  __pyx_t_1 = __pyx_v_table;
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_cases, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_7 = __pyx_t_5;
    goto __pyx_L38_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_charges, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 205, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_7 = __pyx_t_5;
    goto __pyx_L38_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_n_u_fees, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 205, __pyx_L1_error)
  __pyx_t_7 = __pyx_t_5;
  __pyx_L38_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__pyx_t_7 != 0);
  __pyx_t_2 = __pyx_t_5;
  __pyx_L34_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "alacorder/cal.pyx":206
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):
 *           raise Exception("Single table export choice required! (cases, charges, fees)")             # <<<<<<<<<<<<<<
 *      if archive and append and existing_output and not no_write:
 *           try:
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 206, __pyx_L1_error)

    /* "alacorder/cal.pyx":205
 *      support_archive = True if outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none") else False
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):             # <<<<<<<<<<<<<<
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:
 */
  }

  /* "alacorder/cal.pyx":207
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:             # <<<<<<<<<<<<<<
 *           try:
 *                old_archive = read(outputs)
 */
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_archive); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 207, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L42_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_append); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 207, __pyx_L1_error)
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L42_bool_binop_done;
  }
  __pyx_t_5 = (__pyx_v_existing_output != 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_2 = __pyx_t_5;
    goto __pyx_L42_bool_binop_done;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_no_write); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 207, __pyx_L1_error)
  __pyx_t_7 = ((!__pyx_t_5) != 0);
  __pyx_t_2 = __pyx_t_7;
  __pyx_L42_bool_binop_done:;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":208
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:
 *           try:             # <<<<<<<<<<<<<<
 *                old_archive = read(outputs)
 *           except:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {

        /* "alacorder/cal.pyx":209
 *      if archive and append and existing_output and not no_write:
 *           try:
 *                old_archive = read(outputs)             # <<<<<<<<<<<<<<
 *           except:
 *                print("Append failed! Archive at output path could not be read.")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_read); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 209, __pyx_L46_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_outputs) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_outputs);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 209, __pyx_L46_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_old_archive = __pyx_t_1;
        __pyx_t_1 = 0;

        /* "alacorder/cal.pyx":208
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:
 *           try:             # <<<<<<<<<<<<<<
 *                old_archive = read(outputs)
 *           except:
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L51_try_end;
      __pyx_L46_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "alacorder/cal.pyx":210
 *           try:
 *                old_archive = read(outputs)
 *           except:             # <<<<<<<<<<<<<<
 *                print("Append failed! Archive at output path could not be read.")
 * 
 */
      /*except:*/ {
        __Pyx_AddTraceback("alacorder.cal.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(0, 210, __pyx_L48_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_4);

        /* "alacorder/cal.pyx":211
 *                old_archive = read(outputs)
 *           except:
 *                print("Append failed! Archive at output path could not be read.")             # <<<<<<<<<<<<<<
 * 
 *      ## DIRECTORY INPUTS
 */
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 211, __pyx_L48_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L47_exception_handled;
      }
      __pyx_L48_except_error:;

      /* "alacorder/cal.pyx":208
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:
 *           try:             # <<<<<<<<<<<<<<
 *                old_archive = read(outputs)
 *           except:
 */
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L47_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L51_try_end:;
    }

    /* "alacorder/cal.pyx":207
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):
 *           raise Exception("Single table export choice required! (cases, charges, fees)")
 *      if archive and append and existing_output and not no_write:             # <<<<<<<<<<<<<<
 *           try:
 *                old_archive = read(outputs)
 */
  }

  /* "alacorder/cal.pyx":214
 * 
 *      ## DIRECTORY INPUTS
 *      if os.path.isdir(inputs):             # <<<<<<<<<<<<<<
 *           queue = glob.glob(inputs + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           found = len(queue)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_isdir); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_v_inputs) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_inputs);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":215
 *      ## DIRECTORY INPUTS
 *      if os.path.isdir(inputs):
 *           queue = glob.glob(inputs + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)             # <<<<<<<<<<<<<<
 *           found = len(queue)
 *           assert force or found > 0
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_glob); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_glob); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyNumber_Add(__pyx_v_inputs, __pyx_kp_u_pdf); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_recursive, Py_True) < 0) __PYX_ERR(0, 215, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_queue = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":216
 *      if os.path.isdir(inputs):
 *           queue = glob.glob(inputs + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           found = len(queue)             # <<<<<<<<<<<<<<
 *           assert force or found > 0
 *           is_full_text = False
 */
    __pyx_t_11 = PyObject_Length(__pyx_v_queue); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 216, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 216, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF_SET(__pyx_v_found, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":217
 *           queue = glob.glob(inputs + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           found = len(queue)
 *           assert force or found > 0             # <<<<<<<<<<<<<<
 *           is_full_text = False
 *           itype = "directory"
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_force); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 217, __pyx_L1_error)
      if (!__pyx_t_7) {
      } else {
        __pyx_t_2 = __pyx_t_7;
        goto __pyx_L55_bool_binop_done;
      }
      __pyx_t_6 = PyObject_RichCompare(__pyx_v_found, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 217, __pyx_L1_error)
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_2 = __pyx_t_7;
      __pyx_L55_bool_binop_done:;
      if (unlikely(!__pyx_t_2)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 217, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":218
 *           found = len(queue)
 *           assert force or found > 0
 *           is_full_text = False             # <<<<<<<<<<<<<<
 *           itype = "directory"
 * 
 */
    __pyx_v_is_full_text = 0;

    /* "alacorder/cal.pyx":219
 *           assert force or found > 0
 *           is_full_text = False
 *           itype = "directory"             # <<<<<<<<<<<<<<
 * 
 *      ## FILE INPUTS
 */
    __Pyx_INCREF(__pyx_n_u_directory);
    __pyx_v_itype = __pyx_n_u_directory;

    /* "alacorder/cal.pyx":214
 * 
 *      ## DIRECTORY INPUTS
 *      if os.path.isdir(inputs):             # <<<<<<<<<<<<<<
 *           queue = glob.glob(inputs + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           found = len(queue)
 */
    goto __pyx_L54;
  }

  /* "alacorder/cal.pyx":222
 * 
 *      ## FILE INPUTS
 *      elif os.path.isfile(inputs):             # <<<<<<<<<<<<<<
 *           queue = read(inputs)
 *           found = queue.shape[0]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_isfile); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_6 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_inputs) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_inputs);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":223
 *      ## FILE INPUTS
 *      elif os.path.isfile(inputs):
 *           queue = read(inputs)             # <<<<<<<<<<<<<<
 *           found = queue.shape[0]
 *           is_full_text = True
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_read); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_6 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_inputs) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_inputs);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_queue = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":224
 *      elif os.path.isfile(inputs):
 *           queue = read(inputs)
 *           found = queue.shape[0]             # <<<<<<<<<<<<<<
 *           is_full_text = True
 *           itype = "query" if os.path.splitext(inputs)[1] in (".xls",".xlsx") else "archive"
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_queue, __pyx_n_s_shape); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_6, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 224, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF_SET(__pyx_v_found, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":225
 *           queue = read(inputs)
 *           found = queue.shape[0]
 *           is_full_text = True             # <<<<<<<<<<<<<<
 *           itype = "query" if os.path.splitext(inputs)[1] in (".xls",".xlsx") else "archive"
 * 
 */
    __pyx_v_is_full_text = 1;

    /* "alacorder/cal.pyx":226
 *           found = queue.shape[0]
 *           is_full_text = True
 *           itype = "query" if os.path.splitext(inputs)[1] in (".xls",".xlsx") else "archive"             # <<<<<<<<<<<<<<
 * 
 *      ## OBJECT INPUTS
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_splitext); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_6 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_v_inputs) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_inputs);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_6, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 226, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_2 = __pyx_t_7;
      goto __pyx_L57_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 226, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_7;
    __pyx_L57_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if ((__pyx_t_2 != 0)) {
      __Pyx_INCREF(__pyx_n_u_query);
      __pyx_t_4 = __pyx_n_u_query;
    } else {
      __Pyx_INCREF(__pyx_n_u_archive);
      __pyx_t_4 = __pyx_n_u_archive;
    }
    __pyx_v_itype = ((PyObject*)__pyx_t_4);
    __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":222
 * 
 *      ## FILE INPUTS
 *      elif os.path.isfile(inputs):             # <<<<<<<<<<<<<<
 *           queue = read(inputs)
 *           found = queue.shape[0]
 */
    goto __pyx_L54;
  }

  /* "alacorder/cal.pyx":229
 * 
 *      ## OBJECT INPUTS
 *      elif isinstance(inputs, pl.dataframe.frame.DataFrame):             # <<<<<<<<<<<<<<
 *           assert force or "AllPagesText" in inputs.columns # AllPagesText not found in archive columns! Archive appears to be corrupted.
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0] # Case text could not be found in archive! Archive may be empty or corrupted.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dataframe); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_frame); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = PyObject_IsInstance(__pyx_v_inputs, __pyx_t_1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(0, 229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = (__pyx_t_2 != 0);
  if (__pyx_t_7) {

    /* "alacorder/cal.pyx":230
 *      ## OBJECT INPUTS
 *      elif isinstance(inputs, pl.dataframe.frame.DataFrame):
 *           assert force or "AllPagesText" in inputs.columns # AllPagesText not found in archive columns! Archive appears to be corrupted.             # <<<<<<<<<<<<<<
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0] # Case text could not be found in archive! Archive may be empty or corrupted.
 *           queue = inputs
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_force); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 230, __pyx_L1_error)
      if (!__pyx_t_2) {
      } else {
        __pyx_t_7 = __pyx_t_2;
        goto __pyx_L59_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_inputs, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_AllPagesText, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 230, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = (__pyx_t_2 != 0);
      __pyx_t_7 = __pyx_t_5;
      __pyx_L59_bool_binop_done:;
      if (unlikely(!__pyx_t_7)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 230, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":231
 *      elif isinstance(inputs, pl.dataframe.frame.DataFrame):
 *           assert force or "AllPagesText" in inputs.columns # AllPagesText not found in archive columns! Archive appears to be corrupted.
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0] # Case text could not be found in archive! Archive may be empty or corrupted.             # <<<<<<<<<<<<<<
 *           queue = inputs
 *           found = queue.shape[0]
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_force); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 231, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L61_bool_binop_done;
      }
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_inputs, __pyx_n_u_AllPagesText); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_ALABAMA, __pyx_t_4, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = (__pyx_t_5 != 0);
      __pyx_t_7 = __pyx_t_2;
      __pyx_L61_bool_binop_done:;
      if (unlikely(!__pyx_t_7)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 231, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":232
 *           assert force or "AllPagesText" in inputs.columns # AllPagesText not found in archive columns! Archive appears to be corrupted.
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0] # Case text could not be found in archive! Archive may be empty or corrupted.
 *           queue = inputs             # <<<<<<<<<<<<<<
 *           found = queue.shape[0]
 *           is_full_text = True
 */
    __Pyx_INCREF(__pyx_v_inputs);
    __pyx_v_queue = __pyx_v_inputs;

    /* "alacorder/cal.pyx":233
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0] # Case text could not be found in archive! Archive may be empty or corrupted.
 *           queue = inputs
 *           found = queue.shape[0]             # <<<<<<<<<<<<<<
 *           is_full_text = True
 *           itype = "object"
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_queue, __pyx_n_s_shape); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF_SET(__pyx_v_found, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":234
 *           queue = inputs
 *           found = queue.shape[0]
 *           is_full_text = True             # <<<<<<<<<<<<<<
 *           itype = "object"
 *      elif isinstance(inputs, pl.series.series.Series):
 */
    __pyx_v_is_full_text = 1;

    /* "alacorder/cal.pyx":235
 *           found = queue.shape[0]
 *           is_full_text = True
 *           itype = "object"             # <<<<<<<<<<<<<<
 *      elif isinstance(inputs, pl.series.series.Series):
 *           assert force or "AllPagesText" in inputs.columns
 */
    __Pyx_INCREF(__pyx_n_u_object);
    __pyx_v_itype = __pyx_n_u_object;

    /* "alacorder/cal.pyx":229
 * 
 *      ## OBJECT INPUTS
 *      elif isinstance(inputs, pl.dataframe.frame.DataFrame):             # <<<<<<<<<<<<<<
 *           assert force or "AllPagesText" in inputs.columns # AllPagesText not found in archive columns! Archive appears to be corrupted.
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0] # Case text could not be found in archive! Archive may be empty or corrupted.
 */
    goto __pyx_L54;
  }

  /* "alacorder/cal.pyx":236
 *           is_full_text = True
 *           itype = "object"
 *      elif isinstance(inputs, pl.series.series.Series):             # <<<<<<<<<<<<<<
 *           assert force or "AllPagesText" in inputs.columns
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_series); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_series); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Series); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = PyObject_IsInstance(__pyx_v_inputs, __pyx_t_4); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = (__pyx_t_7 != 0);
  if (likely(__pyx_t_2)) {

    /* "alacorder/cal.pyx":237
 *           itype = "object"
 *      elif isinstance(inputs, pl.series.series.Series):
 *           assert force or "AllPagesText" in inputs.columns             # <<<<<<<<<<<<<<
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0]
 *           queue = inputs
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_force); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 237, __pyx_L1_error)
      if (!__pyx_t_7) {
      } else {
        __pyx_t_2 = __pyx_t_7;
        goto __pyx_L63_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_inputs, __pyx_n_s_columns); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 237, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_AllPagesText, __pyx_t_4, Py_EQ)); if (unlikely(__pyx_t_7 < 0)) __PYX_ERR(0, 237, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = (__pyx_t_7 != 0);
      __pyx_t_2 = __pyx_t_5;
      __pyx_L63_bool_binop_done:;
      if (unlikely(!__pyx_t_2)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 237, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":238
 *      elif isinstance(inputs, pl.series.series.Series):
 *           assert force or "AllPagesText" in inputs.columns
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0]             # <<<<<<<<<<<<<<
 *           queue = inputs
 *           found = queue.shape[0]
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_force); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 238, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L65_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_inputs, __pyx_n_u_AllPagesText); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 238, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_ALABAMA, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 238, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = (__pyx_t_5 != 0);
      __pyx_t_2 = __pyx_t_7;
      __pyx_L65_bool_binop_done:;
      if (unlikely(!__pyx_t_2)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 238, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":239
 *           assert force or "AllPagesText" in inputs.columns
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0]
 *           queue = inputs             # <<<<<<<<<<<<<<
 *           found = queue.shape[0]
 *           is_full_text = True
 */
    __Pyx_INCREF(__pyx_v_inputs);
    __pyx_v_queue = __pyx_v_inputs;

    /* "alacorder/cal.pyx":240
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0]
 *           queue = inputs
 *           found = queue.shape[0]             # <<<<<<<<<<<<<<
 *           is_full_text = True
 *           itype = "object"
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_queue, __pyx_n_s_shape); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 240, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_found, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":241
 *           queue = inputs
 *           found = queue.shape[0]
 *           is_full_text = True             # <<<<<<<<<<<<<<
 *           itype = "object"
 *      else:
 */
    __pyx_v_is_full_text = 1;

    /* "alacorder/cal.pyx":242
 *           found = queue.shape[0]
 *           is_full_text = True
 *           itype = "object"             # <<<<<<<<<<<<<<
 *      else:
 *           raise Exception("Failed to determine input type.")
 */
    __Pyx_INCREF(__pyx_n_u_object);
    __pyx_v_itype = __pyx_n_u_object;

    /* "alacorder/cal.pyx":236
 *           is_full_text = True
 *           itype = "object"
 *      elif isinstance(inputs, pl.series.series.Series):             # <<<<<<<<<<<<<<
 *           assert force or "AllPagesText" in inputs.columns
 *           assert force or "ALABAMA" in inputs['AllPagesText'][0]
 */
    goto __pyx_L54;
  }

  /* "alacorder/cal.pyx":244
 *           itype = "object"
 *      else:
 *           raise Exception("Failed to determine input type.")             # <<<<<<<<<<<<<<
 * 
 *      if count == 0:
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 244, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 244, __pyx_L1_error)
  }
  __pyx_L54:;

  /* "alacorder/cal.pyx":246
 *           raise Exception("Failed to determine input type.")
 * 
 *      if count == 0:             # <<<<<<<<<<<<<<
 *           count = found
 *      if count > found:
 */
  __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_count, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":247
 * 
 *      if count == 0:
 *           count = found             # <<<<<<<<<<<<<<
 *      if count > found:
 *           count = found
 */
    __Pyx_INCREF(__pyx_v_found);
    __Pyx_DECREF_SET(__pyx_v_count, __pyx_v_found);

    /* "alacorder/cal.pyx":246
 *           raise Exception("Failed to determine input type.")
 * 
 *      if count == 0:             # <<<<<<<<<<<<<<
 *           count = found
 *      if count > found:
 */
  }

  /* "alacorder/cal.pyx":248
 *      if count == 0:
 *           count = found
 *      if count > found:             # <<<<<<<<<<<<<<
 *           count = found
 *      if found > count:
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_count, __pyx_v_found, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 248, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":249
 *           count = found
 *      if count > found:
 *           count = found             # <<<<<<<<<<<<<<
 *      if found > count:
 *           queue = queue[0:count]
 */
    __Pyx_INCREF(__pyx_v_found);
    __Pyx_DECREF_SET(__pyx_v_count, __pyx_v_found);

    /* "alacorder/cal.pyx":248
 *      if count == 0:
 *           count = found
 *      if count > found:             # <<<<<<<<<<<<<<
 *           count = found
 *      if found > count:
 */
  }

  /* "alacorder/cal.pyx":250
 *      if count > found:
 *           count = found
 *      if found > count:             # <<<<<<<<<<<<<<
 *           queue = queue[0:count]
 * 
 */
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_found, __pyx_v_count, Py_GT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 250, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 250, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":251
 *           count = found
 *      if found > count:
 *           queue = queue[0:count]             # <<<<<<<<<<<<<<
 * 
 *      out = {
 */
    __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_queue, 0, 0, NULL, &__pyx_v_count, NULL, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_queue, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":250
 *      if count > found:
 *           count = found
 *      if found > count:             # <<<<<<<<<<<<<<
 *           queue = queue[0:count]
 * 
 */
  }

  /* "alacorder/cal.pyx":254
 * 
 *      out = {
 *           'QUEUE': queue,             # <<<<<<<<<<<<<<
 *           'INPUTS': inputs,
 *           'NEEDTEXT': bool(not is_full_text),
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(27); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_QUEUE, __pyx_v_queue) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":255
 *      out = {
 *           'QUEUE': queue,
 *           'INPUTS': inputs,             # <<<<<<<<<<<<<<
 *           'NEEDTEXT': bool(not is_full_text),
 *           'INPUT_TYPE': itype,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_INPUTS, __pyx_v_inputs) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":256
 *           'QUEUE': queue,
 *           'INPUTS': inputs,
 *           'NEEDTEXT': bool(not is_full_text),             # <<<<<<<<<<<<<<
 *           'INPUT_TYPE': itype,
 *           'FOUND': found,
 */
  __pyx_t_2 = (!(__pyx_v_is_full_text != 0));
  __pyx_t_1 = __Pyx_PyBool_FromLong((!(!__pyx_t_2))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_NEEDTEXT, __pyx_t_1) < 0) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":257
 *           'INPUTS': inputs,
 *           'NEEDTEXT': bool(not is_full_text),
 *           'INPUT_TYPE': itype,             # <<<<<<<<<<<<<<
 *           'FOUND': found,
 *           'COUNT': count,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_INPUT_TYPE, __pyx_v_itype) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":258
 *           'NEEDTEXT': bool(not is_full_text),
 *           'INPUT_TYPE': itype,
 *           'FOUND': found,             # <<<<<<<<<<<<<<
 *           'COUNT': count,
 *           'OUTPUT_PATH': outputs,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_FOUND, __pyx_v_found) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":259
 *           'INPUT_TYPE': itype,
 *           'FOUND': found,
 *           'COUNT': count,             # <<<<<<<<<<<<<<
 *           'OUTPUT_PATH': outputs,
 *           'OUTPUT_EXT': outputext,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_COUNT, __pyx_v_count) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":260
 *           'FOUND': found,
 *           'COUNT': count,
 *           'OUTPUT_PATH': outputs,             # <<<<<<<<<<<<<<
 *           'OUTPUT_EXT': outputext,
 * 
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_OUTPUT_PATH, __pyx_v_outputs) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":261
 *           'COUNT': count,
 *           'OUTPUT_PATH': outputs,
 *           'OUTPUT_EXT': outputext,             # <<<<<<<<<<<<<<
 * 
 *           'SUPPORT_MULTITABLE': support_multitable,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_OUTPUT_EXT, __pyx_v_outputext) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":263
 *           'OUTPUT_EXT': outputext,
 * 
 *           'SUPPORT_MULTITABLE': support_multitable,             # <<<<<<<<<<<<<<
 *           'SUPPORT_SINGLETABLE': support_singletable,
 *           'SUPPORT_ARCHIVE': support_archive,
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_support_multitable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 263, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_SUPPORT_MULTITABLE, __pyx_t_1) < 0) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":264
 * 
 *           'SUPPORT_MULTITABLE': support_multitable,
 *           'SUPPORT_SINGLETABLE': support_singletable,             # <<<<<<<<<<<<<<
 *           'SUPPORT_ARCHIVE': support_archive,
 * 
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_support_singletable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_SUPPORT_SINGLETABLE, __pyx_t_1) < 0) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":265
 *           'SUPPORT_MULTITABLE': support_multitable,
 *           'SUPPORT_SINGLETABLE': support_singletable,
 *           'SUPPORT_ARCHIVE': support_archive,             # <<<<<<<<<<<<<<
 * 
 *           'TABLE': table,
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_support_archive); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_SUPPORT_ARCHIVE, __pyx_t_1) < 0) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":267
 *           'SUPPORT_ARCHIVE': support_archive,
 * 
 *           'TABLE': table,             # <<<<<<<<<<<<<<
 *           'ARCHIVE': archive,
 *           'APPEND': append,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_TABLE, __pyx_v_table) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":268
 * 
 *           'TABLE': table,
 *           'ARCHIVE': archive,             # <<<<<<<<<<<<<<
 *           'APPEND': append,
 *           'NO_UPDATE': no_update,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_ARCHIVE, __pyx_v_archive) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":269
 *           'TABLE': table,
 *           'ARCHIVE': archive,
 *           'APPEND': append,             # <<<<<<<<<<<<<<
 *           'NO_UPDATE': no_update,
 * 
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_APPEND, __pyx_v_append) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":270
 *           'ARCHIVE': archive,
 *           'APPEND': append,
 *           'NO_UPDATE': no_update,             # <<<<<<<<<<<<<<
 * 
 *           'FETCH': fetch,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_NO_UPDATE, __pyx_v_no_update) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":272
 *           'NO_UPDATE': no_update,
 * 
 *           'FETCH': fetch,             # <<<<<<<<<<<<<<
 *           'ALA_CUSTOMER_ID': cID,
 *           'ALA_USER_ID': uID,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_FETCH, __pyx_v_fetch) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":273
 * 
 *           'FETCH': fetch,
 *           'ALA_CUSTOMER_ID': cID,             # <<<<<<<<<<<<<<
 *           'ALA_USER_ID': uID,
 *           'ALA_PASSWORD': pwd,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_ALA_CUSTOMER_ID, __pyx_v_cID) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":274
 *           'FETCH': fetch,
 *           'ALA_CUSTOMER_ID': cID,
 *           'ALA_USER_ID': uID,             # <<<<<<<<<<<<<<
 *           'ALA_PASSWORD': pwd,
 *           'FETCH_SKIP': qskip,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_ALA_USER_ID, __pyx_v_uID) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":275
 *           'ALA_CUSTOMER_ID': cID,
 *           'ALA_USER_ID': uID,
 *           'ALA_PASSWORD': pwd,             # <<<<<<<<<<<<<<
 *           'FETCH_SKIP': qskip,
 *           'FETCH_MAX': qmax,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_ALA_PASSWORD, __pyx_v_pwd) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":276
 *           'ALA_USER_ID': uID,
 *           'ALA_PASSWORD': pwd,
 *           'FETCH_SKIP': qskip,             # <<<<<<<<<<<<<<
 *           'FETCH_MAX': qmax,
 * 
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_FETCH_SKIP, __pyx_v_qskip) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":277
 *           'ALA_PASSWORD': pwd,
 *           'FETCH_SKIP': qskip,
 *           'FETCH_MAX': qmax,             # <<<<<<<<<<<<<<
 * 
 *           'NO_WRITE': no_write,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_FETCH_MAX, __pyx_v_qmax) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":279
 *           'FETCH_MAX': qmax,
 * 
 *           'NO_WRITE': no_write,             # <<<<<<<<<<<<<<
 *           'NO_PROMPT': no_prompt,
 *           'OVERWRITE': overwrite,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_NO_WRITE, __pyx_v_no_write) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":280
 * 
 *           'NO_WRITE': no_write,
 *           'NO_PROMPT': no_prompt,             # <<<<<<<<<<<<<<
 *           'OVERWRITE': overwrite,
 *           'EXISTING_OUTPUT': existing_output,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_NO_PROMPT, __pyx_v_no_prompt) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":281
 *           'NO_WRITE': no_write,
 *           'NO_PROMPT': no_prompt,
 *           'OVERWRITE': overwrite,             # <<<<<<<<<<<<<<
 *           'EXISTING_OUTPUT': existing_output,
 *           'DEBUG': debug,
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_OVERWRITE, __pyx_v_overwrite) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":282
 *           'NO_PROMPT': no_prompt,
 *           'OVERWRITE': overwrite,
 *           'EXISTING_OUTPUT': existing_output,             # <<<<<<<<<<<<<<
 *           'DEBUG': debug,
 *           'WINDOW': window
 */
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_v_existing_output); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_EXISTING_OUTPUT, __pyx_t_1) < 0) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":283
 *           'OVERWRITE': overwrite,
 *           'EXISTING_OUTPUT': existing_output,
 *           'DEBUG': debug,             # <<<<<<<<<<<<<<
 *           'WINDOW': window
 *      }
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_DEBUG, __pyx_v_debug) < 0) __PYX_ERR(0, 254, __pyx_L1_error)

  /* "alacorder/cal.pyx":284
 *           'EXISTING_OUTPUT': existing_output,
 *           'DEBUG': debug,
 *           'WINDOW': window             # <<<<<<<<<<<<<<
 *      }
 *      dlog(debug, out)
 */
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_WINDOW, __pyx_v_window) < 0) __PYX_ERR(0, 254, __pyx_L1_error)
  __pyx_v_out = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":286
 *           'WINDOW': window
 *      }
 *      dlog(debug, out)             # <<<<<<<<<<<<<<
 *      print("Successfully configured.")
 *      if now:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_dlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = NULL;
  __pyx_t_12 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_12 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_debug, __pyx_v_out};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_debug, __pyx_v_out};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_12, __pyx_v_debug);
    __Pyx_INCREF(__pyx_v_out);
    __Pyx_GIVEREF(__pyx_v_out);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_12, __pyx_v_out);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":287
 *      }
 *      dlog(debug, out)
 *      print("Successfully configured.")             # <<<<<<<<<<<<<<
 *      if now:
 *           return init(out, window=window, debug=debug)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":288
 *      dlog(debug, out)
 *      print("Successfully configured.")
 *      if now:             # <<<<<<<<<<<<<<
 *           return init(out, window=window, debug=debug)
 *      return out
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_now); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 288, __pyx_L1_error)
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":289
 *      print("Successfully configured.")
 *      if now:
 *           return init(out, window=window, debug=debug)             # <<<<<<<<<<<<<<
 *      return out
 * def dlog(cf=None, text=""):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_init); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_out);
    __Pyx_GIVEREF(__pyx_v_out);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_out);
    __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 289, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_debug, __pyx_v_debug) < 0) __PYX_ERR(0, 289, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":288
 *      dlog(debug, out)
 *      print("Successfully configured.")
 *      if now:             # <<<<<<<<<<<<<<
 *           return init(out, window=window, debug=debug)
 *      return out
 */
  }

  /* "alacorder/cal.pyx":290
 *      if now:
 *           return init(out, window=window, debug=debug)
 *      return out             # <<<<<<<<<<<<<<
 * def dlog(cf=None, text=""):
 *      if cf == None or cf == False:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":147
 * #   #   #   #         CONFIGURATION & I/O        #   #   #   #
 * 
 * def set(inputs, outputs=None, count=0, table='', archive=False, no_prompt=True, debug=False, overwrite=False, no_write=False, fetch=False, cID='', uID='', pwd='', qmax=0, qskip=0, append=False, window=None, force=False, no_update=False, now=False):             # <<<<<<<<<<<<<<
 *      """
 *      Check inputs and outputs and return a configuration object for Alacorder table parser functions to receive as parameter and complete task, or set `now = True` to run upon set() call.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.set", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_found);
  __Pyx_XDECREF(__pyx_v_outputext);
  __Pyx_XDECREF(__pyx_v_old_archive);
  __Pyx_XDECREF(__pyx_v_queue);
  __Pyx_XDECREF(__pyx_v_itype);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_outputs);
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XDECREF(__pyx_v_no_write);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":291
 *           return init(out, window=window, debug=debug)
 *      return out
 * def dlog(cf=None, text=""):             # <<<<<<<<<<<<<<
 *      if cf == None or cf == False:
 *           return None
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_17dlog(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_17dlog = {"dlog", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_17dlog, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9alacorder_3cal_17dlog(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_text = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dlog (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_text,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)Py_None);
    values[1] = ((PyObject *)__pyx_kp_u__8);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_text);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "dlog") < 0)) __PYX_ERR(0, 291, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_text = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dlog", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 291, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.dlog", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_16dlog(__pyx_self, __pyx_v_cf, __pyx_v_text);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_16dlog(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dlog", 0);

  /* "alacorder/cal.pyx":292
 *      return out
 * def dlog(cf=None, text=""):
 *      if cf == None or cf == False:             # <<<<<<<<<<<<<<
 *           return None
 *      if cf == True:
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_cf, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_cf, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 292, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "alacorder/cal.pyx":293
 * def dlog(cf=None, text=""):
 *      if cf == None or cf == False:
 *           return None             # <<<<<<<<<<<<<<
 *      if cf == True:
 *           print(text)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "alacorder/cal.pyx":292
 *      return out
 * def dlog(cf=None, text=""):
 *      if cf == None or cf == False:             # <<<<<<<<<<<<<<
 *           return None
 *      if cf == True:
 */
  }

  /* "alacorder/cal.pyx":294
 *      if cf == None or cf == False:
 *           return None
 *      if cf == True:             # <<<<<<<<<<<<<<
 *           print(text)
 *      else:
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_cf, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 294, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "alacorder/cal.pyx":295
 *           return None
 *      if cf == True:
 *           print(text)             # <<<<<<<<<<<<<<
 *      else:
 *           if cf['DEBUG'] == True:
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 295, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":294
 *      if cf == None or cf == False:
 *           return None
 *      if cf == True:             # <<<<<<<<<<<<<<
 *           print(text)
 *      else:
 */
    goto __pyx_L6;
  }

  /* "alacorder/cal.pyx":297
 *           print(text)
 *      else:
 *           if cf['DEBUG'] == True:             # <<<<<<<<<<<<<<
 *                print(text)
 *                return text
 */
  /*else*/ {
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_DEBUG); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 297, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 297, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_1) {

      /* "alacorder/cal.pyx":298
 *      else:
 *           if cf['DEBUG'] == True:
 *                print(text)             # <<<<<<<<<<<<<<
 *                return text
 *           else:
 */
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 298, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":299
 *           if cf['DEBUG'] == True:
 *                print(text)
 *                return text             # <<<<<<<<<<<<<<
 *           else:
 *                return None
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_text);
      __pyx_r = __pyx_v_text;
      goto __pyx_L0;

      /* "alacorder/cal.pyx":297
 *           print(text)
 *      else:
 *           if cf['DEBUG'] == True:             # <<<<<<<<<<<<<<
 *                print(text)
 *                return text
 */
    }

    /* "alacorder/cal.pyx":301
 *                return text
 *           else:
 *                return None             # <<<<<<<<<<<<<<
 * def read(cf='', window=None):
 *      """
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;
    }
  }
  __pyx_L6:;

  /* "alacorder/cal.pyx":291
 *           return init(out, window=window, debug=debug)
 *      return out
 * def dlog(cf=None, text=""):             # <<<<<<<<<<<<<<
 *      if cf == None or cf == False:
 *           return None
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("alacorder.cal.dlog", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":302
 *           else:
 *                return None
 * def read(cf='', window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Read `cf` input PDF directory or case text archive into memory.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_19read(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_18read[] = "\n     Read `cf` input PDF directory or case text archive into memory.\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_19read = {"read", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_19read, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_18read};
static PyObject *__pyx_pw_9alacorder_3cal_19read(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_cf,&__pyx_n_s_window,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)__pyx_kp_u__8);
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "read") < 0)) __PYX_ERR(0, 302, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_cf = values[0];
    __pyx_v_window = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("read", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 302, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_18read(__pyx_self, __pyx_v_cf, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_18read(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_cf, PyObject *__pyx_v_window) {
  PyObject *__pyx_v_queue = NULL;
  PyObject *__pyx_v_aptxt = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_pp = NULL;
  PyObject *__pyx_v_archive = NULL;
  PyObject *__pyx_v_ext = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read", 0);

  /* "alacorder/cal.pyx":306
 *      Read `cf` input PDF directory or case text archive into memory.
 *      """
 *      if isinstance(cf, dict):             # <<<<<<<<<<<<<<
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:
 *                return cf['QUEUE']
 */
  __pyx_t_1 = PyDict_Check(__pyx_v_cf); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":307
 *      """
 *      if isinstance(cf, dict):
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:             # <<<<<<<<<<<<<<
 *                return cf['QUEUE']
 *           if cf['NEEDTEXT'] == True:
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NEEDTEXT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, Py_False, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (!__pyx_t_1) {
    } else {
      __pyx_t_2 = __pyx_t_1;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_QUEUE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_ALABAMA, __pyx_t_3, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 307, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = (__pyx_t_1 != 0);
    __pyx_t_2 = __pyx_t_5;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":308
 *      if isinstance(cf, dict):
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:
 *                return cf['QUEUE']             # <<<<<<<<<<<<<<
 *           if cf['NEEDTEXT'] == True:
 *                queue = cf['QUEUE']
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_QUEUE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 308, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "alacorder/cal.pyx":307
 *      """
 *      if isinstance(cf, dict):
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:             # <<<<<<<<<<<<<<
 *                return cf['QUEUE']
 *           if cf['NEEDTEXT'] == True:
 */
    }

    /* "alacorder/cal.pyx":309
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:
 *                return cf['QUEUE']
 *           if cf['NEEDTEXT'] == True:             # <<<<<<<<<<<<<<
 *                queue = cf['QUEUE']
 *                aptxt = []
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NEEDTEXT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":310
 *                return cf['QUEUE']
 *           if cf['NEEDTEXT'] == True:
 *                queue = cf['QUEUE']             # <<<<<<<<<<<<<<
 *                aptxt = []
 *                print("Extracting text...")
 */
      __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_QUEUE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_queue = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":311
 *           if cf['NEEDTEXT'] == True:
 *                queue = cf['QUEUE']
 *                aptxt = []             # <<<<<<<<<<<<<<
 *                print("Extracting text...")
 *                if window:
 */
      __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_aptxt = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":312
 *                queue = cf['QUEUE']
 *                aptxt = []
 *                print("Extracting text...")             # <<<<<<<<<<<<<<
 *                if window:
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 312, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":313
 *                aptxt = []
 *                print("Extracting text...")
 *                if window:             # <<<<<<<<<<<<<<
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                     for i, pp in enumerate(queue):
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 313, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "alacorder/cal.pyx":314
 *                print("Extracting text...")
 *                if window:
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))             # <<<<<<<<<<<<<<
 *                     for i, pp in enumerate(queue):
 *                          aptxt += [getPDFText(pp)]
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_6 = PyObject_Length(__pyx_v_queue); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 314, __pyx_L1_error)
        __pyx_t_7 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 314, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_8)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_8);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_9 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_n_u_PROGRESS_TOTAL, __pyx_t_7};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 314, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
          PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_n_u_PROGRESS_TOTAL, __pyx_t_7};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 314, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        } else
        #endif
        {
          __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (__pyx_t_8) {
            __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
          }
          __Pyx_INCREF(__pyx_n_u_PROGRESS_TOTAL);
          __Pyx_GIVEREF(__pyx_n_u_PROGRESS_TOTAL);
          PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_n_u_PROGRESS_TOTAL);
          __Pyx_GIVEREF(__pyx_t_7);
          PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_7);
          __pyx_t_7 = 0;
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "alacorder/cal.pyx":315
 *                if window:
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                     for i, pp in enumerate(queue):             # <<<<<<<<<<<<<<
 *                          aptxt += [getPDFText(pp)]
 *                          window.write_event_value("PROGRESS",i+1)
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_4 = __pyx_int_0;
        if (likely(PyList_CheckExact(__pyx_v_queue)) || PyTuple_CheckExact(__pyx_v_queue)) {
          __pyx_t_3 = __pyx_v_queue; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
          __pyx_t_11 = NULL;
        } else {
          __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_queue); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_11 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 315, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_11)) {
            if (likely(PyList_CheckExact(__pyx_t_3))) {
              if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_10 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_10); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 315, __pyx_L1_error)
              #else
              __pyx_t_10 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              #endif
            } else {
              if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_10); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 315, __pyx_L1_error)
              #else
              __pyx_t_10 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              #endif
            }
          } else {
            __pyx_t_10 = __pyx_t_11(__pyx_t_3);
            if (unlikely(!__pyx_t_10)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 315, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_10);
          }
          __Pyx_XDECREF_SET(__pyx_v_pp, __pyx_t_10);
          __pyx_t_10 = 0;
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
          __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_4);
          __pyx_t_4 = __pyx_t_10;
          __pyx_t_10 = 0;

          /* "alacorder/cal.pyx":316
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                     for i, pp in enumerate(queue):
 *                          aptxt += [getPDFText(pp)]             # <<<<<<<<<<<<<<
 *                          window.write_event_value("PROGRESS",i+1)
 *                else:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getPDFText); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 316, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_8)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_8);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
            }
          }
          __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_pp) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_pp);
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 316, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = PyList_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 316, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_GIVEREF(__pyx_t_10);
          PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_10);
          __pyx_t_10 = 0;
          __pyx_t_10 = PyNumber_InPlaceAdd(__pyx_v_aptxt, __pyx_t_7); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 316, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF_SET(__pyx_v_aptxt, ((PyObject*)__pyx_t_10));
          __pyx_t_10 = 0;

          /* "alacorder/cal.pyx":317
 *                     for i, pp in enumerate(queue):
 *                          aptxt += [getPDFText(pp)]
 *                          window.write_event_value("PROGRESS",i+1)             # <<<<<<<<<<<<<<
 *                else:
 *                     for pp in tqdm.tqdm(queue):
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 317, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 317, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_12 = NULL;
          __pyx_t_9 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_9 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_n_u_PROGRESS, __pyx_t_8};
            __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 317, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
            PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_n_u_PROGRESS, __pyx_t_8};
            __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 317, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          } else
          #endif
          {
            __pyx_t_13 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 317, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            if (__pyx_t_12) {
              __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_12); __pyx_t_12 = NULL;
            }
            __Pyx_INCREF(__pyx_n_u_PROGRESS);
            __Pyx_GIVEREF(__pyx_n_u_PROGRESS);
            PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_9, __pyx_n_u_PROGRESS);
            __Pyx_GIVEREF(__pyx_t_8);
            PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_9, __pyx_t_8);
            __pyx_t_8 = 0;
            __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_13, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 317, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

          /* "alacorder/cal.pyx":315
 *                if window:
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                     for i, pp in enumerate(queue):             # <<<<<<<<<<<<<<
 *                          aptxt += [getPDFText(pp)]
 *                          window.write_event_value("PROGRESS",i+1)
 */
        }
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "alacorder/cal.pyx":313
 *                aptxt = []
 *                print("Extracting text...")
 *                if window:             # <<<<<<<<<<<<<<
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                     for i, pp in enumerate(queue):
 */
        goto __pyx_L8;
      }

      /* "alacorder/cal.pyx":319
 *                          window.write_event_value("PROGRESS",i+1)
 *                else:
 *                     for pp in tqdm.tqdm(queue):             # <<<<<<<<<<<<<<
 *                          aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 319, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_3, __pyx_v_queue) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_queue);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
          __pyx_t_10 = __pyx_t_4; __Pyx_INCREF(__pyx_t_10); __pyx_t_6 = 0;
          __pyx_t_11 = NULL;
        } else {
          __pyx_t_6 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 319, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_11 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 319, __pyx_L1_error)
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        for (;;) {
          if (likely(!__pyx_t_11)) {
            if (likely(PyList_CheckExact(__pyx_t_10))) {
              if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_10)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 319, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_10, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            } else {
              if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 319, __pyx_L1_error)
              #else
              __pyx_t_4 = PySequence_ITEM(__pyx_t_10, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              #endif
            }
          } else {
            __pyx_t_4 = __pyx_t_11(__pyx_t_10);
            if (unlikely(!__pyx_t_4)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 319, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_4);
          }
          __Pyx_XDECREF_SET(__pyx_v_pp, __pyx_t_4);
          __pyx_t_4 = 0;

          /* "alacorder/cal.pyx":320
 *                else:
 *                     for pp in tqdm.tqdm(queue):
 *                          aptxt += [getPDFText(pp)]             # <<<<<<<<<<<<<<
 *           archive = pl.DataFrame({
 *                'Timestamp': time.time(),
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_getPDFText); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_7 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_3, function);
            }
          }
          __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_v_pp) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_pp);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GIVEREF(__pyx_t_4);
          PyList_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
          __pyx_t_4 = 0;
          __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_aptxt, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF_SET(__pyx_v_aptxt, ((PyObject*)__pyx_t_4));
          __pyx_t_4 = 0;

          /* "alacorder/cal.pyx":319
 *                          window.write_event_value("PROGRESS",i+1)
 *                else:
 *                     for pp in tqdm.tqdm(queue):             # <<<<<<<<<<<<<<
 *                          aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({
 */
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __pyx_L8:;

      /* "alacorder/cal.pyx":309
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:
 *                return cf['QUEUE']
 *           if cf['NEEDTEXT'] == True:             # <<<<<<<<<<<<<<
 *                queue = cf['QUEUE']
 *                aptxt = []
 */
    }

    /* "alacorder/cal.pyx":321
 *                     for pp in tqdm.tqdm(queue):
 *                          aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({             # <<<<<<<<<<<<<<
 *                'Timestamp': time.time(),
 *                'AllPagesText': aptxt,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":322
 *                          aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({
 *                'Timestamp': time.time(),             # <<<<<<<<<<<<<<
 *                'AllPagesText': aptxt,
 *                'Path': queue
 */
    __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_time); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_time); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_7 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_Timestamp, __pyx_t_7) < 0) __PYX_ERR(0, 322, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":323
 *           archive = pl.DataFrame({
 *                'Timestamp': time.time(),
 *                'AllPagesText': aptxt,             # <<<<<<<<<<<<<<
 *                'Path': queue
 *                })
 */
    if (unlikely(!__pyx_v_aptxt)) { __Pyx_RaiseUnboundLocalError("aptxt"); __PYX_ERR(0, 323, __pyx_L1_error) }
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_AllPagesText, __pyx_v_aptxt) < 0) __PYX_ERR(0, 322, __pyx_L1_error)

    /* "alacorder/cal.pyx":324
 *                'Timestamp': time.time(),
 *                'AllPagesText': aptxt,
 *                'Path': queue             # <<<<<<<<<<<<<<
 *                })
 *           return archive
 */
    if (unlikely(!__pyx_v_queue)) { __Pyx_RaiseUnboundLocalError("queue"); __PYX_ERR(0, 324, __pyx_L1_error) }
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_u_Path, __pyx_v_queue) < 0) __PYX_ERR(0, 322, __pyx_L1_error)
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_10 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_archive = __pyx_t_10;
    __pyx_t_10 = 0;

    /* "alacorder/cal.pyx":326
 *                'Path': queue
 *                })
 *           return archive             # <<<<<<<<<<<<<<
 *      elif os.path.isdir(cf):
 *           queue = glob.glob(cf + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_archive);
    __pyx_r = __pyx_v_archive;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":306
 *      Read `cf` input PDF directory or case text archive into memory.
 *      """
 *      if isinstance(cf, dict):             # <<<<<<<<<<<<<<
 *           if cf['NEEDTEXT'] == False or "ALABAMA" in cf['QUEUE'][0]:
 *                return cf['QUEUE']
 */
  }

  /* "alacorder/cal.pyx":327
 *                })
 *           return archive
 *      elif os.path.isdir(cf):             # <<<<<<<<<<<<<<
 *           queue = glob.glob(cf + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           aptxt = []
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_isdir); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_10 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_cf);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":328
 *           return archive
 *      elif os.path.isdir(cf):
 *           queue = glob.glob(cf + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)             # <<<<<<<<<<<<<<
 *           aptxt = []
 *           print("Extracting text...")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_glob); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_glob); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyNumber_Add(__pyx_v_cf, __pyx_kp_u_pdf); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_10);
    __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_recursive, Py_True) < 0) __PYX_ERR(0, 328, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_v_queue = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":329
 *      elif os.path.isdir(cf):
 *           queue = glob.glob(cf + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           aptxt = []             # <<<<<<<<<<<<<<
 *           print("Extracting text...")
 *           if window:
 */
    __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_v_aptxt = ((PyObject*)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":330
 *           queue = glob.glob(cf + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           aptxt = []
 *           print("Extracting text...")             # <<<<<<<<<<<<<<
 *           if window:
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))
 */
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 330, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":331
 *           aptxt = []
 *           print("Extracting text...")
 *           if window:             # <<<<<<<<<<<<<<
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                for i, pp in enumerate(queue):
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 331, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":332
 *           print("Extracting text...")
 *           if window:
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))             # <<<<<<<<<<<<<<
 *                for i, pp in enumerate(queue):
 *                     aptxt += [getPDFText(pp)]
 */
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 332, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_6 = PyObject_Length(__pyx_v_queue); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 332, __pyx_L1_error)
      __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 332, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_n_u_PROGRESS_TOTAL, __pyx_t_4};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 332, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_n_u_PROGRESS_TOTAL, __pyx_t_4};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 332, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 332, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_3) {
          __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3); __pyx_t_3 = NULL;
        }
        __Pyx_INCREF(__pyx_n_u_PROGRESS_TOTAL);
        __Pyx_GIVEREF(__pyx_n_u_PROGRESS_TOTAL);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_9, __pyx_n_u_PROGRESS_TOTAL);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_9, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 332, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "alacorder/cal.pyx":333
 *           if window:
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                for i, pp in enumerate(queue):             # <<<<<<<<<<<<<<
 *                     aptxt += [getPDFText(pp)]
 *                     window.write_event_value("PROGRESS",i+1)
 */
      __Pyx_INCREF(__pyx_int_0);
      __pyx_t_7 = __pyx_int_0;
      if (likely(PyList_CheckExact(__pyx_v_queue)) || PyTuple_CheckExact(__pyx_v_queue)) {
        __pyx_t_10 = __pyx_v_queue; __Pyx_INCREF(__pyx_t_10); __pyx_t_6 = 0;
        __pyx_t_11 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_v_queue); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 333, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_11 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 333, __pyx_L1_error)
      }
      for (;;) {
        if (likely(!__pyx_t_11)) {
          if (likely(PyList_CheckExact(__pyx_t_10))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_10)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_8 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 333, __pyx_L1_error)
            #else
            __pyx_t_8 = PySequence_ITEM(__pyx_t_10, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 333, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 333, __pyx_L1_error)
            #else
            __pyx_t_8 = PySequence_ITEM(__pyx_t_10, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 333, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_8);
            #endif
          }
        } else {
          __pyx_t_8 = __pyx_t_11(__pyx_t_10);
          if (unlikely(!__pyx_t_8)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 333, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_8);
        }
        __Pyx_XDECREF_SET(__pyx_v_pp, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_7);
        __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_t_7, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 333, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7);
        __pyx_t_7 = __pyx_t_8;
        __pyx_t_8 = 0;

        /* "alacorder/cal.pyx":334
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                for i, pp in enumerate(queue):
 *                     aptxt += [getPDFText(pp)]             # <<<<<<<<<<<<<<
 *                     window.write_event_value("PROGRESS",i+1)
 *           else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_getPDFText); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_8 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, __pyx_v_pp) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_pp);
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_8);
        PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_8 = PyNumber_InPlaceAdd(__pyx_v_aptxt, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 334, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_aptxt, ((PyObject*)__pyx_t_8));
        __pyx_t_8 = 0;

        /* "alacorder/cal.pyx":335
 *                for i, pp in enumerate(queue):
 *                     aptxt += [getPDFText(pp)]
 *                     window.write_event_value("PROGRESS",i+1)             # <<<<<<<<<<<<<<
 *           else:
 *                for pp in tqdm.tqdm(queue):
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 335, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_13 = NULL;
        __pyx_t_9 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_9 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_n_u_PROGRESS, __pyx_t_3};
          __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
          PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_n_u_PROGRESS, __pyx_t_3};
          __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        } else
        #endif
        {
          __pyx_t_12 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_12);
          if (__pyx_t_13) {
            __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_13); __pyx_t_13 = NULL;
          }
          __Pyx_INCREF(__pyx_n_u_PROGRESS);
          __Pyx_GIVEREF(__pyx_n_u_PROGRESS);
          PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_9, __pyx_n_u_PROGRESS);
          __Pyx_GIVEREF(__pyx_t_3);
          PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_9, __pyx_t_3);
          __pyx_t_3 = 0;
          __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_12, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 335, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "alacorder/cal.pyx":333
 *           if window:
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                for i, pp in enumerate(queue):             # <<<<<<<<<<<<<<
 *                     aptxt += [getPDFText(pp)]
 *                     window.write_event_value("PROGRESS",i+1)
 */
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "alacorder/cal.pyx":331
 *           aptxt = []
 *           print("Extracting text...")
 *           if window:             # <<<<<<<<<<<<<<
 *                window.write_event_value("PROGRESS_TOTAL",len(queue))
 *                for i, pp in enumerate(queue):
 */
      goto __pyx_L13;
    }

    /* "alacorder/cal.pyx":337
 *                     window.write_event_value("PROGRESS",i+1)
 *           else:
 *                for pp in tqdm.tqdm(queue):             # <<<<<<<<<<<<<<
 *                     aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({
 */
    /*else*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_7 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_10, __pyx_v_queue) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_queue);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 337, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
        __pyx_t_8 = __pyx_t_7; __Pyx_INCREF(__pyx_t_8); __pyx_t_6 = 0;
        __pyx_t_11 = NULL;
      } else {
        __pyx_t_6 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 337, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = Py_TYPE(__pyx_t_8)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 337, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      for (;;) {
        if (likely(!__pyx_t_11)) {
          if (likely(PyList_CheckExact(__pyx_t_8))) {
            if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_8)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_6); __Pyx_INCREF(__pyx_t_7); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 337, __pyx_L1_error)
            #else
            __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 337, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          } else {
            if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_6); __Pyx_INCREF(__pyx_t_7); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 337, __pyx_L1_error)
            #else
            __pyx_t_7 = PySequence_ITEM(__pyx_t_8, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 337, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            #endif
          }
        } else {
          __pyx_t_7 = __pyx_t_11(__pyx_t_8);
          if (unlikely(!__pyx_t_7)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 337, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_7);
        }
        __Pyx_XDECREF_SET(__pyx_v_pp, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "alacorder/cal.pyx":338
 *           else:
 *                for pp in tqdm.tqdm(queue):
 *                     aptxt += [getPDFText(pp)]             # <<<<<<<<<<<<<<
 *           archive = pl.DataFrame({
 *           'Timestamp': time.time(),
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_getPDFText); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 338, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_v_pp) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_pp);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 338, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = PyList_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 338, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_7);
        PyList_SET_ITEM(__pyx_t_10, 0, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_aptxt, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 338, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF_SET(__pyx_v_aptxt, ((PyObject*)__pyx_t_7));
        __pyx_t_7 = 0;

        /* "alacorder/cal.pyx":337
 *                     window.write_event_value("PROGRESS",i+1)
 *           else:
 *                for pp in tqdm.tqdm(queue):             # <<<<<<<<<<<<<<
 *                     aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({
 */
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __pyx_L13:;

    /* "alacorder/cal.pyx":339
 *                for pp in tqdm.tqdm(queue):
 *                     aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({             # <<<<<<<<<<<<<<
 *           'Timestamp': time.time(),
 *           'AllPagesText': aptxt,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":340
 *                     aptxt += [getPDFText(pp)]
 *           archive = pl.DataFrame({
 *           'Timestamp': time.time(),             # <<<<<<<<<<<<<<
 *           'AllPagesText': aptxt,
 *           'Path': queue
 */
    __pyx_t_7 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_time); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_time); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_t_12 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_12)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_Timestamp, __pyx_t_4) < 0) __PYX_ERR(0, 340, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":341
 *           archive = pl.DataFrame({
 *           'Timestamp': time.time(),
 *           'AllPagesText': aptxt,             # <<<<<<<<<<<<<<
 *           'Path': queue
 *           })
 */
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_AllPagesText, __pyx_v_aptxt) < 0) __PYX_ERR(0, 340, __pyx_L1_error)

    /* "alacorder/cal.pyx":342
 *           'Timestamp': time.time(),
 *           'AllPagesText': aptxt,
 *           'Path': queue             # <<<<<<<<<<<<<<
 *           })
 *           return archive
 */
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_u_Path, __pyx_v_queue) < 0) __PYX_ERR(0, 340, __pyx_L1_error)
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_8 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_v_archive = __pyx_t_8;
    __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":344
 *           'Path': queue
 *           })
 *           return archive             # <<<<<<<<<<<<<<
 * 
 *      elif os.path.isfile(cf):
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_archive);
    __pyx_r = __pyx_v_archive;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":327
 *                })
 *           return archive
 *      elif os.path.isdir(cf):             # <<<<<<<<<<<<<<
 *           queue = glob.glob(cf + '**[inserted by cython to avoid comment closer]/[inserted by cython to avoid comment start]*.pdf', recursive=True)
 *           aptxt = []
 */
  }

  /* "alacorder/cal.pyx":346
 *           return archive
 * 
 *      elif os.path.isfile(cf):             # <<<<<<<<<<<<<<
 *           ext = os.path.splitext(cf)[1]
 *           if ext in (".xls",".xlsx"):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_os); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_isfile); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_7, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_cf);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":347
 * 
 *      elif os.path.isfile(cf):
 *           ext = os.path.splitext(cf)[1]             # <<<<<<<<<<<<<<
 *           if ext in (".xls",".xlsx"):
 *                archive = pl.read_excel(cf)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_os); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_path); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_splitext); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_7, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_cf);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_GetItemInt(__pyx_t_8, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_ext = __pyx_t_10;
    __pyx_t_10 = 0;

    /* "alacorder/cal.pyx":348
 *      elif os.path.isfile(cf):
 *           ext = os.path.splitext(cf)[1]
 *           if ext in (".xls",".xlsx"):             # <<<<<<<<<<<<<<
 *                archive = pl.read_excel(cf)
 *                return archive
 */
    __Pyx_INCREF(__pyx_v_ext);
    __pyx_t_10 = __pyx_v_ext;
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_10, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 348, __pyx_L1_error)
    if (!__pyx_t_5) {
    } else {
      __pyx_t_2 = __pyx_t_5;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_10, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 348, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_5;
    __pyx_L19_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_5 = (__pyx_t_2 != 0);
    if (__pyx_t_5) {

      /* "alacorder/cal.pyx":349
 *           ext = os.path.splitext(cf)[1]
 *           if ext in (".xls",".xlsx"):
 *                archive = pl.read_excel(cf)             # <<<<<<<<<<<<<<
 *                return archive
 *           elif ext == ".json":
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_read_excel); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_cf);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 349, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_archive = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":350
 *           if ext in (".xls",".xlsx"):
 *                archive = pl.read_excel(cf)
 *                return archive             # <<<<<<<<<<<<<<
 *           elif ext == ".json":
 *                archive = pl.read_json(cf)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_archive);
      __pyx_r = __pyx_v_archive;
      goto __pyx_L0;

      /* "alacorder/cal.pyx":348
 *      elif os.path.isfile(cf):
 *           ext = os.path.splitext(cf)[1]
 *           if ext in (".xls",".xlsx"):             # <<<<<<<<<<<<<<
 *                archive = pl.read_excel(cf)
 *                return archive
 */
    }

    /* "alacorder/cal.pyx":351
 *                archive = pl.read_excel(cf)
 *                return archive
 *           elif ext == ".json":             # <<<<<<<<<<<<<<
 *                archive = pl.read_json(cf)
 *                return archive
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_ext, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 351, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "alacorder/cal.pyx":352
 *                return archive
 *           elif ext == ".json":
 *                archive = pl.read_json(cf)             # <<<<<<<<<<<<<<
 *                return archive
 *           elif ext == ".csv":
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_read_json); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_10 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_cf);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 352, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_archive = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":353
 *           elif ext == ".json":
 *                archive = pl.read_json(cf)
 *                return archive             # <<<<<<<<<<<<<<
 *           elif ext == ".csv":
 *                archive = pl.read_csv(cf)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_archive);
      __pyx_r = __pyx_v_archive;
      goto __pyx_L0;

      /* "alacorder/cal.pyx":351
 *                archive = pl.read_excel(cf)
 *                return archive
 *           elif ext == ".json":             # <<<<<<<<<<<<<<
 *                archive = pl.read_json(cf)
 *                return archive
 */
    }

    /* "alacorder/cal.pyx":354
 *                archive = pl.read_json(cf)
 *                return archive
 *           elif ext == ".csv":             # <<<<<<<<<<<<<<
 *                archive = pl.read_csv(cf)
 *                return archive
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_ext, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 354, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "alacorder/cal.pyx":355
 *                return archive
 *           elif ext == ".csv":
 *                archive = pl.read_csv(cf)             # <<<<<<<<<<<<<<
 *                return archive
 *           elif ext == ".parquet":
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_cf);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_archive = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":356
 *           elif ext == ".csv":
 *                archive = pl.read_csv(cf)
 *                return archive             # <<<<<<<<<<<<<<
 *           elif ext == ".parquet":
 *                archive = pl.read_parquet(cf)
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_archive);
      __pyx_r = __pyx_v_archive;
      goto __pyx_L0;

      /* "alacorder/cal.pyx":354
 *                archive = pl.read_json(cf)
 *                return archive
 *           elif ext == ".csv":             # <<<<<<<<<<<<<<
 *                archive = pl.read_csv(cf)
 *                return archive
 */
    }

    /* "alacorder/cal.pyx":357
 *                archive = pl.read_csv(cf)
 *                return archive
 *           elif ext == ".parquet":             # <<<<<<<<<<<<<<
 *                archive = pl.read_parquet(cf)
 *                return archive
 */
    __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_v_ext, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 357, __pyx_L1_error)
    if (__pyx_t_5) {

      /* "alacorder/cal.pyx":358
 *                return archive
 *           elif ext == ".parquet":
 *                archive = pl.read_parquet(cf)             # <<<<<<<<<<<<<<
 *                return archive
 *      else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_read_parquet); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_10 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, __pyx_v_cf) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_v_cf);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 358, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_archive = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":359
 *           elif ext == ".parquet":
 *                archive = pl.read_parquet(cf)
 *                return archive             # <<<<<<<<<<<<<<
 *      else:
 *           return None
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_archive);
      __pyx_r = __pyx_v_archive;
      goto __pyx_L0;

      /* "alacorder/cal.pyx":357
 *                archive = pl.read_csv(cf)
 *                return archive
 *           elif ext == ".parquet":             # <<<<<<<<<<<<<<
 *                archive = pl.read_parquet(cf)
 *                return archive
 */
    }

    /* "alacorder/cal.pyx":346
 *           return archive
 * 
 *      elif os.path.isfile(cf):             # <<<<<<<<<<<<<<
 *           ext = os.path.splitext(cf)[1]
 *           if ext in (".xls",".xlsx"):
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":361
 *                return archive
 *      else:
 *           return None             # <<<<<<<<<<<<<<
 * 
 * def write(outputs, sheet_names=[], cf=None, path=None, overwrite=False):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "alacorder/cal.pyx":302
 *           else:
 *                return None
 * def read(cf='', window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Read `cf` input PDF directory or case text archive into memory.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.read", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_queue);
  __Pyx_XDECREF(__pyx_v_aptxt);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_pp);
  __Pyx_XDECREF(__pyx_v_archive);
  __Pyx_XDECREF(__pyx_v_ext);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":363
 *           return None
 * 
 * def write(outputs, sheet_names=[], cf=None, path=None, overwrite=False):             # <<<<<<<<<<<<<<
 *      """Write `outputs` to output path at `cf` in accordance with configuration settings.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_21write(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_20write[] = "Write `outputs` to output path at `cf` in accordance with configuration settings.\n     \n     Args:\n         cf (dict): Configuration object\n         outputs ([DataFrame]): DataFrame(s) to write to output\n         sheet_names (List[str], optional): Output Excel worksheet names\n     \n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_21write = {"write", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_21write, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_20write};
static PyObject *__pyx_pw_9alacorder_3cal_21write(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_outputs = 0;
  PyObject *__pyx_v_sheet_names = 0;
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_overwrite = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("write (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_outputs,&__pyx_n_s_sheet_names,&__pyx_n_s_cf,&__pyx_n_s_path,&__pyx_n_s_overwrite,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[1] = __pyx_k__16;
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_outputs)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_sheet_names);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_path);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_overwrite);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "write") < 0)) __PYX_ERR(0, 363, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_outputs = values[0];
    __pyx_v_sheet_names = values[1];
    __pyx_v_cf = values[2];
    __pyx_v_path = values[3];
    __pyx_v_overwrite = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("write", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 363, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_20write(__pyx_self, __pyx_v_outputs, __pyx_v_sheet_names, __pyx_v_cf, __pyx_v_path, __pyx_v_overwrite);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_20write(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_outputs, PyObject *__pyx_v_sheet_names, PyObject *__pyx_v_cf, PyObject *__pyx_v_path, PyObject *__pyx_v_overwrite) {
  PyObject *__pyx_v_workbook = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("write", 0);
  __Pyx_INCREF(__pyx_v_outputs);
  __Pyx_INCREF(__pyx_v_cf);
  __Pyx_INCREF(__pyx_v_path);
  __Pyx_INCREF(__pyx_v_overwrite);

  /* "alacorder/cal.pyx":372
 * 
 *      """
 *      if cf == None:             # <<<<<<<<<<<<<<
 *         assert os.path.splitext(path)[1] in (".xlsx",".xls",".csv",".json",".parquet",".txt") # Invalid file extension!
 *         if os.path.isfile(path):
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cf, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 372, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 372, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":373
 *      """
 *      if cf == None:
 *         assert os.path.splitext(path)[1] in (".xlsx",".xls",".csv",".json",".parquet",".txt") # Invalid file extension!             # <<<<<<<<<<<<<<
 *         if os.path.isfile(path):
 *             assert overwrite
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_splitext); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_path);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 373, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L4_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L4_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L4_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L4_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_2 = __pyx_t_5;
        goto __pyx_L4_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_txt, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 373, __pyx_L1_error)
      __pyx_t_2 = __pyx_t_5;
      __pyx_L4_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!(__pyx_t_2 != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 373, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":374
 *      if cf == None:
 *         assert os.path.splitext(path)[1] in (".xlsx",".xls",".csv",".json",".parquet",".txt") # Invalid file extension!
 *         if os.path.isfile(path):             # <<<<<<<<<<<<<<
 *             assert overwrite
 *         # assert overwrite or not os.path.isfile(path) # Existing file at output path!
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_isfile); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 374, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 374, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":375
 *         assert os.path.splitext(path)[1] in (".xlsx",".xls",".csv",".json",".parquet",".txt") # Invalid file extension!
 *         if os.path.isfile(path):
 *             assert overwrite             # <<<<<<<<<<<<<<
 *         # assert overwrite or not os.path.isfile(path) # Existing file at output path!
 *         cf = {
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_overwrite); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 375, __pyx_L1_error)
        if (unlikely(!__pyx_t_2)) {
          PyErr_SetNone(PyExc_AssertionError);
          __PYX_ERR(0, 375, __pyx_L1_error)
        }
      }
      #endif

      /* "alacorder/cal.pyx":374
 *      if cf == None:
 *         assert os.path.splitext(path)[1] in (".xlsx",".xls",".csv",".json",".parquet",".txt") # Invalid file extension!
 *         if os.path.isfile(path):             # <<<<<<<<<<<<<<
 *             assert overwrite
 *         # assert overwrite or not os.path.isfile(path) # Existing file at output path!
 */
    }

    /* "alacorder/cal.pyx":378
 *         # assert overwrite or not os.path.isfile(path) # Existing file at output path!
 *         cf = {
 *         'OUTPUT_PATH': path,             # <<<<<<<<<<<<<<
 *         'OUTPUT_EXT': os.path.splitext(path)[1],
 *         'NO_WRITE': False,
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_OUTPUT_PATH, __pyx_v_path) < 0) __PYX_ERR(0, 378, __pyx_L1_error)

    /* "alacorder/cal.pyx":379
 *         cf = {
 *         'OUTPUT_PATH': path,
 *         'OUTPUT_EXT': os.path.splitext(path)[1],             # <<<<<<<<<<<<<<
 *         'NO_WRITE': False,
 *         'OVERWRITE': overwrite,
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_splitext); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_6, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 379, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_OUTPUT_EXT, __pyx_t_4) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":380
 *         'OUTPUT_PATH': path,
 *         'OUTPUT_EXT': os.path.splitext(path)[1],
 *         'NO_WRITE': False,             # <<<<<<<<<<<<<<
 *         'OVERWRITE': overwrite,
 *         }
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_NO_WRITE, Py_False) < 0) __PYX_ERR(0, 378, __pyx_L1_error)

    /* "alacorder/cal.pyx":381
 *         'OUTPUT_EXT': os.path.splitext(path)[1],
 *         'NO_WRITE': False,
 *         'OVERWRITE': overwrite,             # <<<<<<<<<<<<<<
 *         }
 *      else: # cf trumps params if both given
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_u_OVERWRITE, __pyx_v_overwrite) < 0) __PYX_ERR(0, 378, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_cf, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":372
 * 
 *      """
 *      if cf == None:             # <<<<<<<<<<<<<<
 *         assert os.path.splitext(path)[1] in (".xlsx",".xls",".csv",".json",".parquet",".txt") # Invalid file extension!
 *         if os.path.isfile(path):
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":384
 *         }
 *      else: # cf trumps params if both given
 *         path = cf['OUTPUT_PATH']             # <<<<<<<<<<<<<<
 *         overwrite = cf['OVERWRITE']
 *      if isinstance(outputs, list):
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_path, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":385
 *      else: # cf trumps params if both given
 *         path = cf['OUTPUT_PATH']
 *         overwrite = cf['OVERWRITE']             # <<<<<<<<<<<<<<
 *      if isinstance(outputs, list):
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OVERWRITE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 385, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_overwrite, __pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "alacorder/cal.pyx":386
 *         path = cf['OUTPUT_PATH']
 *         overwrite = cf['OVERWRITE']
 *      if isinstance(outputs, list):             # <<<<<<<<<<<<<<
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1
 *      if cf['NO_WRITE']==True:
 */
  __pyx_t_2 = PyList_Check(__pyx_v_outputs); 
  __pyx_t_5 = (__pyx_t_2 != 0);
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":387
 *         overwrite = cf['OVERWRITE']
 *      if isinstance(outputs, list):
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1             # <<<<<<<<<<<<<<
 *      if cf['NO_WRITE']==True:
 *           return outputs
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      __pyx_t_7 = PyObject_Length(__pyx_v_outputs); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 387, __pyx_L1_error)
      __pyx_t_8 = PyObject_Length(__pyx_v_sheet_names); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 387, __pyx_L1_error)
      __pyx_t_2 = ((__pyx_t_7 == __pyx_t_8) != 0);
      if (!__pyx_t_2) {
      } else {
        __pyx_t_5 = __pyx_t_2;
        goto __pyx_L12_bool_binop_done;
      }
      __pyx_t_8 = PyObject_Length(__pyx_v_outputs); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 387, __pyx_L1_error)
      __pyx_t_2 = ((__pyx_t_8 == 1) != 0);
      __pyx_t_5 = __pyx_t_2;
      __pyx_L12_bool_binop_done:;
      if (unlikely(!__pyx_t_5)) {
        PyErr_SetNone(PyExc_AssertionError);
        __PYX_ERR(0, 387, __pyx_L1_error)
      }
    }
    #endif

    /* "alacorder/cal.pyx":386
 *         path = cf['OUTPUT_PATH']
 *         overwrite = cf['OVERWRITE']
 *      if isinstance(outputs, list):             # <<<<<<<<<<<<<<
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1
 *      if cf['NO_WRITE']==True:
 */
  }

  /* "alacorder/cal.pyx":388
 *      if isinstance(outputs, list):
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1
 *      if cf['NO_WRITE']==True:             # <<<<<<<<<<<<<<
 *           return outputs
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_NO_WRITE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, Py_True, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 388, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":389
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1
 *      if cf['NO_WRITE']==True:
 *           return outputs             # <<<<<<<<<<<<<<
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_outputs);
    __pyx_r = __pyx_v_outputs;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":388
 *      if isinstance(outputs, list):
 *           assert len(outputs) == len(sheet_names) or len(outputs) == 1
 *      if cf['NO_WRITE']==True:             # <<<<<<<<<<<<<<
 *           return outputs
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 */
  }

  /* "alacorder/cal.pyx":390
 *      if cf['NO_WRITE']==True:
 *           return outputs
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):             # <<<<<<<<<<<<<<
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 */
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OVERWRITE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = ((!__pyx_t_2) != 0);
  if (__pyx_t_9) {
  } else {
    __pyx_t_5 = __pyx_t_9;
    goto __pyx_L15_bool_binop_done;
  }
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_isfile); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_t_1) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 390, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __pyx_t_9;
  __pyx_L15_bool_binop_done:;
  if (unlikely(__pyx_t_5)) {

    /* "alacorder/cal.pyx":391
 *           return outputs
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")             # <<<<<<<<<<<<<<
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 */
    __pyx_t_4 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 391, __pyx_L1_error)

    /* "alacorder/cal.pyx":390
 *      if cf['NO_WRITE']==True:
 *           return outputs
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):             # <<<<<<<<<<<<<<
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 */
  }

  /* "alacorder/cal.pyx":392
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):             # <<<<<<<<<<<<<<
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 *                  if not isinstance(outputs, list):
 */
  __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_EXT); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 392, __pyx_L1_error)
  if (!__pyx_t_9) {
  } else {
    __pyx_t_5 = __pyx_t_9;
    goto __pyx_L17_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 392, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_9;
  __pyx_L17_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_9 = (__pyx_t_5 != 0);
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":393
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:             # <<<<<<<<<<<<<<
 *                  if not isinstance(outputs, list):
 *                     outputs = [outputs]
 */
    /*with:*/ {
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_xlsxwriter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_Workbook); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_6, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_n_s_exit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_3 = __Pyx_PyObject_LookupSpecial(__pyx_t_4, __pyx_n_s_enter); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 393, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_1 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 393, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __pyx_t_1;
      __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      /*try:*/ {
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          /*try:*/ {
            __pyx_v_workbook = __pyx_t_3;
            __pyx_t_3 = 0;

            /* "alacorder/cal.pyx":394
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 *                  if not isinstance(outputs, list):             # <<<<<<<<<<<<<<
 *                     outputs = [outputs]
 *                  if len(sheet_names) > 0:
 */
            __pyx_t_9 = PyList_Check(__pyx_v_outputs); 
            __pyx_t_5 = ((!(__pyx_t_9 != 0)) != 0);
            if (__pyx_t_5) {

              /* "alacorder/cal.pyx":395
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 *                  if not isinstance(outputs, list):
 *                     outputs = [outputs]             # <<<<<<<<<<<<<<
 *                  if len(sheet_names) > 0:
 *                      for i, x in enumerate(outputs):
 */
              __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 395, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_INCREF(__pyx_v_outputs);
              __Pyx_GIVEREF(__pyx_v_outputs);
              PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_outputs);
              __Pyx_DECREF_SET(__pyx_v_outputs, __pyx_t_3);
              __pyx_t_3 = 0;

              /* "alacorder/cal.pyx":394
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 *                  if not isinstance(outputs, list):             # <<<<<<<<<<<<<<
 *                     outputs = [outputs]
 *                  if len(sheet_names) > 0:
 */
            }

            /* "alacorder/cal.pyx":396
 *                  if not isinstance(outputs, list):
 *                     outputs = [outputs]
 *                  if len(sheet_names) > 0:             # <<<<<<<<<<<<<<
 *                      for i, x in enumerate(outputs):
 *                           x.write_excel(workbook=workbook,worksheet=sheet_names[i], autofit=True, float_precision=2)
 */
            __pyx_t_8 = PyObject_Length(__pyx_v_sheet_names); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 396, __pyx_L23_error)
            __pyx_t_5 = ((__pyx_t_8 > 0) != 0);
            if (__pyx_t_5) {

              /* "alacorder/cal.pyx":397
 *                     outputs = [outputs]
 *                  if len(sheet_names) > 0:
 *                      for i, x in enumerate(outputs):             # <<<<<<<<<<<<<<
 *                           x.write_excel(workbook=workbook,worksheet=sheet_names[i], autofit=True, float_precision=2)
 *                  else:
 */
              __Pyx_INCREF(__pyx_int_0);
              __pyx_t_3 = __pyx_int_0;
              if (likely(PyList_CheckExact(__pyx_v_outputs)) || PyTuple_CheckExact(__pyx_v_outputs)) {
                __pyx_t_4 = __pyx_v_outputs; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
                __pyx_t_14 = NULL;
              } else {
                __pyx_t_8 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_outputs); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 397, __pyx_L23_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_14 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 397, __pyx_L23_error)
              }
              for (;;) {
                if (likely(!__pyx_t_14)) {
                  if (likely(PyList_CheckExact(__pyx_t_4))) {
                    if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
                    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 397, __pyx_L23_error)
                    #else
                    __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L23_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    #endif
                  } else {
                    if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
                    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                    __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_1); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 397, __pyx_L23_error)
                    #else
                    __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L23_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    #endif
                  }
                } else {
                  __pyx_t_1 = __pyx_t_14(__pyx_t_4);
                  if (unlikely(!__pyx_t_1)) {
                    PyObject* exc_type = PyErr_Occurred();
                    if (exc_type) {
                      if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                      else __PYX_ERR(0, 397, __pyx_L23_error)
                    }
                    break;
                  }
                  __Pyx_GOTREF(__pyx_t_1);
                }
                __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_1);
                __pyx_t_1 = 0;
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
                __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L23_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_3);
                __pyx_t_3 = __pyx_t_1;
                __pyx_t_1 = 0;

                /* "alacorder/cal.pyx":398
 *                  if len(sheet_names) > 0:
 *                      for i, x in enumerate(outputs):
 *                           x.write_excel(workbook=workbook,worksheet=sheet_names[i], autofit=True, float_precision=2)             # <<<<<<<<<<<<<<
 *                  else:
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)
 */
                __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_n_s_write_excel); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 398, __pyx_L23_error)
                __Pyx_GOTREF(__pyx_t_1);
                __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 398, __pyx_L23_error)
                __Pyx_GOTREF(__pyx_t_6);
                if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_workbook, __pyx_v_workbook) < 0) __PYX_ERR(0, 398, __pyx_L23_error)
                __pyx_t_15 = __Pyx_PyObject_GetItem(__pyx_v_sheet_names, __pyx_v_i); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 398, __pyx_L23_error)
                __Pyx_GOTREF(__pyx_t_15);
                if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_worksheet, __pyx_t_15) < 0) __PYX_ERR(0, 398, __pyx_L23_error)
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_autofit, Py_True) < 0) __PYX_ERR(0, 398, __pyx_L23_error)
                if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_float_precision, __pyx_int_2) < 0) __PYX_ERR(0, 398, __pyx_L23_error)
                __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 398, __pyx_L23_error)
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

                /* "alacorder/cal.pyx":397
 *                     outputs = [outputs]
 *                  if len(sheet_names) > 0:
 *                      for i, x in enumerate(outputs):             # <<<<<<<<<<<<<<
 *                           x.write_excel(workbook=workbook,worksheet=sheet_names[i], autofit=True, float_precision=2)
 *                  else:
 */
              }
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

              /* "alacorder/cal.pyx":396
 *                  if not isinstance(outputs, list):
 *                     outputs = [outputs]
 *                  if len(sheet_names) > 0:             # <<<<<<<<<<<<<<
 *                      for i, x in enumerate(outputs):
 *                           x.write_excel(workbook=workbook,worksheet=sheet_names[i], autofit=True, float_precision=2)
 */
              goto __pyx_L30;
            }

            /* "alacorder/cal.pyx":400
 *                           x.write_excel(workbook=workbook,worksheet=sheet_names[i], autofit=True, float_precision=2)
 *                  else:
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)             # <<<<<<<<<<<<<<
 *      elif cf['OUTPUT_EXT'] == ".parquet":
 *           try:
 */
            /*else*/ {
              __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_outputs, __pyx_n_s_write_excel); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 400, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_3);
              __pyx_t_4 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 400, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_4);
              if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_workbook, __pyx_v_workbook) < 0) __PYX_ERR(0, 400, __pyx_L23_error)
              if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_autofit, Py_True) < 0) __PYX_ERR(0, 400, __pyx_L23_error)
              if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_float_precision, __pyx_int_2) < 0) __PYX_ERR(0, 400, __pyx_L23_error)
              __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 400, __pyx_L23_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
            }
            __pyx_L30:;

            /* "alacorder/cal.pyx":393
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:             # <<<<<<<<<<<<<<
 *                  if not isinstance(outputs, list):
 *                     outputs = [outputs]
 */
          }
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          goto __pyx_L28_try_end;
          __pyx_L23_error:;
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          /*except:*/ {
            __Pyx_AddTraceback("alacorder.cal.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_15, &__pyx_t_4, &__pyx_t_3) < 0) __PYX_ERR(0, 393, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_6 = PyTuple_Pack(3, __pyx_t_15, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 393, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_6, NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 393, __pyx_L25_except_error)
            __Pyx_GOTREF(__pyx_t_16);
            __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_16);
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            if (__pyx_t_5 < 0) __PYX_ERR(0, 393, __pyx_L25_except_error)
            __pyx_t_9 = ((!(__pyx_t_5 != 0)) != 0);
            if (__pyx_t_9) {
              __Pyx_GIVEREF(__pyx_t_15);
              __Pyx_GIVEREF(__pyx_t_4);
              __Pyx_XGIVEREF(__pyx_t_3);
              __Pyx_ErrRestoreWithState(__pyx_t_15, __pyx_t_4, __pyx_t_3);
              __pyx_t_15 = 0; __pyx_t_4 = 0; __pyx_t_3 = 0; 
              __PYX_ERR(0, 393, __pyx_L25_except_error)
            }
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            goto __pyx_L24_exception_handled;
          }
          __pyx_L25_except_error:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          goto __pyx_L1_error;
          __pyx_L24_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
          __pyx_L28_try_end:;
        }
      }
      /*finally:*/ {
        /*normal exit:*/{
          if (__pyx_t_10) {
            __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__18, NULL);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 393, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          }
          goto __pyx_L22;
        }
        __pyx_L22:;
      }
      goto __pyx_L36;
      __pyx_L19_error:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L1_error;
      __pyx_L36:;
    }

    /* "alacorder/cal.pyx":392
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):             # <<<<<<<<<<<<<<
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 *                  if not isinstance(outputs, list):
 */
    goto __pyx_L14;
  }

  /* "alacorder/cal.pyx":401
 *                  else:
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)
 *      elif cf['OUTPUT_EXT'] == ".parquet":             # <<<<<<<<<<<<<<
 *           try:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_EXT); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 401, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":402
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)
 *      elif cf['OUTPUT_EXT'] == ".parquet":
 *           try:             # <<<<<<<<<<<<<<
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 *           except:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_13, &__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_12);
      /*try:*/ {

        /* "alacorder/cal.pyx":403
 *      elif cf['OUTPUT_EXT'] == ".parquet":
 *           try:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')             # <<<<<<<<<<<<<<
 *           except:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='snappy')
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_outputs, __pyx_n_s_write_parquet); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 403, __pyx_L37_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 403, __pyx_L37_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_15 = PyTuple_New(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 403, __pyx_L37_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 403, __pyx_L37_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_compression, __pyx_n_u_brotli) < 0) __PYX_ERR(0, 403, __pyx_L37_error)
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_15, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 403, __pyx_L37_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "alacorder/cal.pyx":402
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)
 *      elif cf['OUTPUT_EXT'] == ".parquet":
 *           try:             # <<<<<<<<<<<<<<
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 *           except:
 */
      }
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      goto __pyx_L42_try_end;
      __pyx_L37_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "alacorder/cal.pyx":404
 *           try:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 *           except:             # <<<<<<<<<<<<<<
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='snappy')
 *      elif cf['OUTPUT_EXT'] == ".json":
 */
      /*except:*/ {
        __Pyx_AddTraceback("alacorder.cal.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_15) < 0) __PYX_ERR(0, 404, __pyx_L39_except_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_15);

        /* "alacorder/cal.pyx":405
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 *           except:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='snappy')             # <<<<<<<<<<<<<<
 *      elif cf['OUTPUT_EXT'] == ".json":
 *           outputs.write_json(cf['OUTPUT_PATH'])
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_outputs, __pyx_n_s_write_parquet); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 405, __pyx_L39_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L39_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_17 = PyTuple_New(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 405, __pyx_L39_except_error)
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 405, __pyx_L39_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_compression, __pyx_n_u_snappy) < 0) __PYX_ERR(0, 405, __pyx_L39_except_error)
        __pyx_t_18 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_17, __pyx_t_1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 405, __pyx_L39_except_error)
        __Pyx_GOTREF(__pyx_t_18);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        goto __pyx_L38_exception_handled;
      }
      __pyx_L39_except_error:;

      /* "alacorder/cal.pyx":402
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)
 *      elif cf['OUTPUT_EXT'] == ".parquet":
 *           try:             # <<<<<<<<<<<<<<
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 *           except:
 */
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_13, __pyx_t_12);
      goto __pyx_L1_error;
      __pyx_L38_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_13, __pyx_t_12);
      __pyx_L42_try_end:;
    }

    /* "alacorder/cal.pyx":401
 *                  else:
 *                      outputs.write_excel(workbook=workbook, autofit=True, float_precision=2)
 *      elif cf['OUTPUT_EXT'] == ".parquet":             # <<<<<<<<<<<<<<
 *           try:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='brotli')
 */
    goto __pyx_L14;
  }

  /* "alacorder/cal.pyx":406
 *           except:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='snappy')
 *      elif cf['OUTPUT_EXT'] == ".json":             # <<<<<<<<<<<<<<
 *           outputs.write_json(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):
 */
  __pyx_t_15 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_EXT); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":407
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='snappy')
 *      elif cf['OUTPUT_EXT'] == ".json":
 *           outputs.write_json(cf['OUTPUT_PATH'])             # <<<<<<<<<<<<<<
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_outputs, __pyx_n_s_write_json); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_18 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_18)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_18);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_15 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_18, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 407, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "alacorder/cal.pyx":406
 *           except:
 *                outputs.write_parquet(cf['OUTPUT_PATH'], compression='snappy')
 *      elif cf['OUTPUT_EXT'] == ".json":             # <<<<<<<<<<<<<<
 *           outputs.write_json(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):
 */
    goto __pyx_L14;
  }

  /* "alacorder/cal.pyx":408
 *      elif cf['OUTPUT_EXT'] == ".json":
 *           outputs.write_json(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):             # <<<<<<<<<<<<<<
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] not in ("none","","directory",None):
 */
  __pyx_t_15 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_EXT); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 408, __pyx_L1_error)
  if (!__pyx_t_5) {
  } else {
    __pyx_t_9 = __pyx_t_5;
    goto __pyx_L45_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_kp_u_txt, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 408, __pyx_L1_error)
  __pyx_t_9 = __pyx_t_5;
  __pyx_L45_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_5 = (__pyx_t_9 != 0);
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":409
 *           outputs.write_json(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):
 *           outputs.write_csv(cf['OUTPUT_PATH'])             # <<<<<<<<<<<<<<
 *      elif cf['OUTPUT_EXT'] not in ("none","","directory",None):
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_outputs, __pyx_n_s_write_csv); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_18 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_18)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_18);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_15 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_18, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "alacorder/cal.pyx":408
 *      elif cf['OUTPUT_EXT'] == ".json":
 *           outputs.write_json(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):             # <<<<<<<<<<<<<<
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] not in ("none","","directory",None):
 */
    goto __pyx_L14;
  }

  /* "alacorder/cal.pyx":410
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] not in ("none","","directory",None):             # <<<<<<<<<<<<<<
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      else:
 */
  __pyx_t_15 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_EXT); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_n_u_none, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_5 = __pyx_t_9;
    goto __pyx_L47_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_5 = __pyx_t_9;
    goto __pyx_L47_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_15, __pyx_n_u_directory, Py_NE)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_5 = __pyx_t_9;
    goto __pyx_L47_bool_binop_done;
  }
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_15, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 410, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = __pyx_t_9;
  __pyx_L47_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_9 = (__pyx_t_5 != 0);
  if (__pyx_t_9) {

    /* "alacorder/cal.pyx":411
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] not in ("none","","directory",None):
 *           outputs.write_csv(cf['OUTPUT_PATH'])             # <<<<<<<<<<<<<<
 *      else:
 *           pass
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_outputs, __pyx_n_s_write_csv); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_18 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_18)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_18);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_15 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_18, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

    /* "alacorder/cal.pyx":410
 *      elif cf['OUTPUT_EXT'] in (".csv",".txt"):
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      elif cf['OUTPUT_EXT'] not in ("none","","directory",None):             # <<<<<<<<<<<<<<
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      else:
 */
    goto __pyx_L14;
  }

  /* "alacorder/cal.pyx":413
 *           outputs.write_csv(cf['OUTPUT_PATH'])
 *      else:
 *           pass             # <<<<<<<<<<<<<<
 *      return outputs
 * def append_archive(inpath='', outpath='', conf=None, window=None):
 */
  /*else*/ {
  }
  __pyx_L14:;

  /* "alacorder/cal.pyx":414
 *      else:
 *           pass
 *      return outputs             # <<<<<<<<<<<<<<
 * def append_archive(inpath='', outpath='', conf=None, window=None):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_outputs);
  __pyx_r = __pyx_v_outputs;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":363
 *           return None
 * 
 * def write(outputs, sheet_names=[], cf=None, path=None, overwrite=False):             # <<<<<<<<<<<<<<
 *      """Write `outputs` to output path at `cf` in accordance with configuration settings.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("alacorder.cal.write", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_workbook);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_outputs);
  __Pyx_XDECREF(__pyx_v_cf);
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_overwrite);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":415
 *           pass
 *      return outputs
 * def append_archive(inpath='', outpath='', conf=None, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Append the contents of one archive to another.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_23append_archive(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_22append_archive[] = "\n     Append the contents of one archive to another.\n     \n     Args:\n         inpath (str): Input archive \n         outpath (str): Output archive\n         conf (dict): Configuration object\n     \n     Returns:\n         DataFrame: Appended archive object\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_23append_archive = {"append_archive", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_23append_archive, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_22append_archive};
static PyObject *__pyx_pw_9alacorder_3cal_23append_archive(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_inpath = 0;
  PyObject *__pyx_v_outpath = 0;
  PyObject *__pyx_v_conf = 0;
  PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("append_archive (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_inpath,&__pyx_n_s_outpath,&__pyx_n_s_conf,&__pyx_n_s_window,0};
    PyObject* values[4] = {0,0,0,0};
    values[0] = ((PyObject *)__pyx_kp_u__8);
    values[1] = ((PyObject *)__pyx_kp_u__8);
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_inpath);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_outpath);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_conf);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "append_archive") < 0)) __PYX_ERR(0, 415, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_inpath = values[0];
    __pyx_v_outpath = values[1];
    __pyx_v_conf = values[2];
    __pyx_v_window = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("append_archive", 0, 0, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 415, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.append_archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_22append_archive(__pyx_self, __pyx_v_inpath, __pyx_v_outpath, __pyx_v_conf, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_22append_archive(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_inpath, PyObject *__pyx_v_outpath, PyObject *__pyx_v_conf, PyObject *__pyx_v_window) {
  PyObject *__pyx_v_inarc = NULL;
  PyObject *__pyx_v_outarc = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append_archive", 0);
  __Pyx_INCREF(__pyx_v_inpath);
  __Pyx_INCREF(__pyx_v_outpath);

  /* "alacorder/cal.pyx":427
 *          DataFrame: Appended archive object
 *      """
 *      if conf and inpath == '':             # <<<<<<<<<<<<<<
 *           inpath = conf['INPUTS']
 *      if conf and outpath == '':
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_conf); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 427, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_inpath, __pyx_kp_u__8, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 427, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "alacorder/cal.pyx":428
 *      """
 *      if conf and inpath == '':
 *           inpath = conf['INPUTS']             # <<<<<<<<<<<<<<
 *      if conf and outpath == '':
 *           outpath = conf['OUTPUT_PATH']
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_conf, __pyx_n_u_INPUTS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 428, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_inpath, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":427
 *          DataFrame: Appended archive object
 *      """
 *      if conf and inpath == '':             # <<<<<<<<<<<<<<
 *           inpath = conf['INPUTS']
 *      if conf and outpath == '':
 */
  }

  /* "alacorder/cal.pyx":429
 *      if conf and inpath == '':
 *           inpath = conf['INPUTS']
 *      if conf and outpath == '':             # <<<<<<<<<<<<<<
 *           outpath = conf['OUTPUT_PATH']
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_conf); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_outpath, __pyx_kp_u__8, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "alacorder/cal.pyx":430
 *           inpath = conf['INPUTS']
 *      if conf and outpath == '':
 *           outpath = conf['OUTPUT_PATH']             # <<<<<<<<<<<<<<
 * 
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_conf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_outpath, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":429
 *      if conf and inpath == '':
 *           inpath = conf['INPUTS']
 *      if conf and outpath == '':             # <<<<<<<<<<<<<<
 *           outpath = conf['OUTPUT_PATH']
 * 
 */
  }

  /* "alacorder/cal.pyx":432
 *           outpath = conf['OUTPUT_PATH']
 * 
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)             # <<<<<<<<<<<<<<
 *      try:
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_isfile); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_inpath) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_inpath);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L9_bool_binop_done;
    }
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_os); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_path); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_isfile); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_outpath) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_outpath);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 432, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_1 = __pyx_t_2;
    __pyx_L9_bool_binop_done:;
    if (unlikely(!__pyx_t_1)) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 432, __pyx_L1_error)
    }
  }
  #endif

  /* "alacorder/cal.pyx":433
 * 
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)
 *      try:             # <<<<<<<<<<<<<<
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "alacorder/cal.pyx":434
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)
 *      try:
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")             # <<<<<<<<<<<<<<
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 *      except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_read); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 434, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_inpath) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_inpath);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 434, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 434, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 434, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_inarc = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "alacorder/cal.pyx":435
 *      try:
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")             # <<<<<<<<<<<<<<
 *      except:
 *           try:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_read); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 435, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_v_outpath) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_outpath);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 435, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 435, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 435, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_outarc = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "alacorder/cal.pyx":433
 * 
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)
 *      try:             # <<<<<<<<<<<<<<
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "alacorder/cal.pyx":436
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 *      except:             # <<<<<<<<<<<<<<
 *           try:
 *                print("Could not find column Timestamp in archive.")
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.append_archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 436, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":437
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 *      except:
 *           try:             # <<<<<<<<<<<<<<
 *                print("Could not find column Timestamp in archive.")
 *                inarc = read(inpath).select("AllPagesText","Path")
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        /*try:*/ {

          /* "alacorder/cal.pyx":438
 *      except:
 *           try:
 *                print("Could not find column Timestamp in archive.")             # <<<<<<<<<<<<<<
 *                inarc = read(inpath).select("AllPagesText","Path")
 *                outarc = read(outpath).select("AllPagesText","Path")
 */
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__20, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 438, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "alacorder/cal.pyx":439
 *           try:
 *                print("Could not find column Timestamp in archive.")
 *                inarc = read(inpath).select("AllPagesText","Path")             # <<<<<<<<<<<<<<
 *                outarc = read(outpath).select("AllPagesText","Path")
 *           except:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_read); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 439, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          __pyx_t_12 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, __pyx_v_inpath) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_v_inpath);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 439, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_select); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 439, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 439, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF_SET(__pyx_v_inarc, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "alacorder/cal.pyx":440
 *                print("Could not find column Timestamp in archive.")
 *                inarc = read(inpath).select("AllPagesText","Path")
 *                outarc = read(outpath).select("AllPagesText","Path")             # <<<<<<<<<<<<<<
 *           except:
 *                print("Could not find column Path in archive.")
 */
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_read); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 440, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_13, function);
            }
          }
          __pyx_t_12 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, __pyx_v_outpath) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_v_outpath);
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 440, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_select); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 440, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 440, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF_SET(__pyx_v_outarc, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "alacorder/cal.pyx":437
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 *      except:
 *           try:             # <<<<<<<<<<<<<<
 *                print("Could not find column Timestamp in archive.")
 *                inarc = read(inpath).select("AllPagesText","Path")
 */
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L26_try_end;
        __pyx_L19_error:;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;

        /* "alacorder/cal.pyx":441
 *                inarc = read(inpath).select("AllPagesText","Path")
 *                outarc = read(outpath).select("AllPagesText","Path")
 *           except:             # <<<<<<<<<<<<<<
 *                print("Could not find column Path in archive.")
 *                inarc = read(inpath).select("AllPagesText")
 */
        /*except:*/ {
          __Pyx_AddTraceback("alacorder.cal.append_archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14) < 0) __PYX_ERR(0, 441, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_GOTREF(__pyx_t_14);

          /* "alacorder/cal.pyx":442
 *                outarc = read(outpath).select("AllPagesText","Path")
 *           except:
 *                print("Could not find column Path in archive.")             # <<<<<<<<<<<<<<
 *                inarc = read(inpath).select("AllPagesText")
 *                outarc = read(outpath).select("AllPagesText")
 */
          __pyx_t_15 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 442, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

          /* "alacorder/cal.pyx":443
 *           except:
 *                print("Could not find column Path in archive.")
 *                inarc = read(inpath).select("AllPagesText")             # <<<<<<<<<<<<<<
 *                outarc = read(outpath).select("AllPagesText")
 * 
 */
          __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_read); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 443, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_18 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_18)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_18);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          __pyx_t_16 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_18, __pyx_v_inpath) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_v_inpath);
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 443, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_select); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 443, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_17, function);
            }
          }
          __pyx_t_15 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_16, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_AllPagesText);
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 443, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF_SET(__pyx_v_inarc, __pyx_t_15);
          __pyx_t_15 = 0;

          /* "alacorder/cal.pyx":444
 *                print("Could not find column Path in archive.")
 *                inarc = read(inpath).select("AllPagesText")
 *                outarc = read(outpath).select("AllPagesText")             # <<<<<<<<<<<<<<
 * 
 *      out = pl.concat([inarc, outarc])
 */
          __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_read); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 444, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __pyx_t_18 = NULL;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_16);
            if (likely(__pyx_t_18)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_18);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_16, function);
            }
          }
          __pyx_t_17 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_18, __pyx_v_outpath) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_v_outpath);
          __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 444, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_select); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 444, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __pyx_t_17 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_16, function);
            }
          }
          __pyx_t_15 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_17, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_AllPagesText);
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 444, __pyx_L21_except_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF_SET(__pyx_v_outarc, __pyx_t_15);
          __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          goto __pyx_L20_exception_handled;
        }
        __pyx_L21_except_error:;

        /* "alacorder/cal.pyx":437
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 *      except:
 *           try:             # <<<<<<<<<<<<<<
 *                print("Could not find column Timestamp in archive.")
 *                inarc = read(inpath).select("AllPagesText","Path")
 */
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L13_except_error;
        __pyx_L20_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __pyx_L26_try_end:;
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L12_exception_handled;
    }
    __pyx_L13_except_error:;

    /* "alacorder/cal.pyx":433
 * 
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)
 *      try:             # <<<<<<<<<<<<<<
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L16_try_end:;
  }

  /* "alacorder/cal.pyx":446
 *                outarc = read(outpath).select("AllPagesText")
 * 
 *      out = pl.concat([inarc, outarc])             # <<<<<<<<<<<<<<
 *      if window:
 *                window.write_event_value("COMPLETE-AA",True)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_concat); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyList_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_inarc);
  __Pyx_GIVEREF(__pyx_v_inarc);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_v_inarc);
  __Pyx_INCREF(__pyx_v_outarc);
  __Pyx_GIVEREF(__pyx_v_outarc);
  PyList_SET_ITEM(__pyx_t_4, 1, __pyx_v_outarc);
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_14, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_out = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":447
 * 
 *      out = pl.concat([inarc, outarc])
 *      if window:             # <<<<<<<<<<<<<<
 *                window.write_event_value("COMPLETE-AA",True)
 *      write(conf, out)
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_window); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 447, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "alacorder/cal.pyx":448
 *      out = pl.concat([inarc, outarc])
 *      if window:
 *                window.write_event_value("COMPLETE-AA",True)             # <<<<<<<<<<<<<<
 *      write(conf, out)
 *      return out
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":447
 * 
 *      out = pl.concat([inarc, outarc])
 *      if window:             # <<<<<<<<<<<<<<
 *                window.write_event_value("COMPLETE-AA",True)
 *      write(conf, out)
 */
  }

  /* "alacorder/cal.pyx":449
 *      if window:
 *                window.write_event_value("COMPLETE-AA",True)
 *      write(conf, out)             # <<<<<<<<<<<<<<
 *      return out
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_write); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  __pyx_t_19 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_19 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_conf, __pyx_v_out};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_19, 2+__pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_conf, __pyx_v_out};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_19, 2+__pyx_t_19); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  {
    __pyx_t_14 = PyTuple_New(2+__pyx_t_19); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_conf);
    __Pyx_GIVEREF(__pyx_v_conf);
    PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_19, __pyx_v_conf);
    __Pyx_INCREF(__pyx_v_out);
    __Pyx_GIVEREF(__pyx_v_out);
    PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_19, __pyx_v_out);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_14, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":450
 *                window.write_event_value("COMPLETE-AA",True)
 *      write(conf, out)
 *      return out             # <<<<<<<<<<<<<<
 * 
 * #   #   #   #           TABLE PARSERS           #   #   #   #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":415
 *           pass
 *      return outputs
 * def append_archive(inpath='', outpath='', conf=None, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Append the contents of one archive to another.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("alacorder.cal.append_archive", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_inarc);
  __Pyx_XDECREF(__pyx_v_outarc);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_inpath);
  __Pyx_XDECREF(__pyx_v_outpath);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":454
 * #   #   #   #           TABLE PARSERS           #   #   #   #
 * 
 * def split_cases(df, debug=False):             # <<<<<<<<<<<<<<
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_25split_cases(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_25split_cases = {"split_cases", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_25split_cases, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9alacorder_3cal_25split_cases(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_df = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split_cases (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_df,&__pyx_n_s_debug,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_df)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "split_cases") < 0)) __PYX_ERR(0, 454, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_df = values[0];
    __pyx_v_debug = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("split_cases", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 454, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.split_cases", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_24split_cases(__pyx_self, __pyx_v_df, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_24split_cases(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_cases = NULL;
  PyObject *__pyx_v_all_charges = NULL;
  PyObject *__pyx_v_all_fees = NULL;
  PyObject *__pyx_v_clean_ch_list = NULL;
  PyObject *__pyx_v_clean_fs_list = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  PyObject *__pyx_t_26 = NULL;
  PyObject *__pyx_t_27 = NULL;
  PyObject *__pyx_t_28 = NULL;
  PyObject *__pyx_t_29 = NULL;
  PyObject *__pyx_t_30 = NULL;
  PyObject *__pyx_t_31 = NULL;
  PyObject *__pyx_t_32 = NULL;
  PyObject *__pyx_t_33 = NULL;
  PyObject *__pyx_t_34 = NULL;
  PyObject *__pyx_t_35 = NULL;
  PyObject *__pyx_t_36 = NULL;
  PyObject *__pyx_t_37 = NULL;
  PyObject *__pyx_t_38 = NULL;
  PyObject *__pyx_t_39 = NULL;
  PyObject *__pyx_t_40 = NULL;
  PyObject *__pyx_t_41 = NULL;
  PyObject *__pyx_t_42 = NULL;
  PyObject *__pyx_t_43 = NULL;
  PyObject *__pyx_t_44 = NULL;
  PyObject *__pyx_t_45 = NULL;
  PyObject *__pyx_t_46 = NULL;
  PyObject *__pyx_t_47 = NULL;
  PyObject *__pyx_t_48 = NULL;
  PyObject *__pyx_t_49 = NULL;
  PyObject *__pyx_t_50 = NULL;
  PyObject *__pyx_t_51 = NULL;
  PyObject *__pyx_t_52 = NULL;
  PyObject *__pyx_t_53 = NULL;
  PyObject *__pyx_t_54 = NULL;
  PyObject *__pyx_t_55 = NULL;
  PyObject *__pyx_t_56 = NULL;
  PyObject *__pyx_t_57 = NULL;
  PyObject *__pyx_t_58 = NULL;
  PyObject *__pyx_t_59 = NULL;
  PyObject *__pyx_t_60 = NULL;
  PyObject *__pyx_t_61 = NULL;
  PyObject *__pyx_t_62 = NULL;
  PyObject *__pyx_t_63 = NULL;
  PyObject *__pyx_t_64 = NULL;
  PyObject *__pyx_t_65 = NULL;
  PyObject *__pyx_t_66 = NULL;
  PyObject *__pyx_t_67 = NULL;
  PyObject *__pyx_t_68 = NULL;
  PyObject *__pyx_t_69 = NULL;
  PyObject *__pyx_t_70 = NULL;
  PyObject *__pyx_t_71 = NULL;
  PyObject *__pyx_t_72 = NULL;
  PyObject *__pyx_t_73 = NULL;
  PyObject *__pyx_t_74 = NULL;
  PyObject *__pyx_t_75 = NULL;
  PyObject *__pyx_t_76 = NULL;
  PyObject *__pyx_t_77 = NULL;
  PyObject *__pyx_t_78 = NULL;
  PyObject *__pyx_t_79 = NULL;
  PyObject *__pyx_t_80 = NULL;
  PyObject *__pyx_t_81 = NULL;
  PyObject *__pyx_t_82 = NULL;
  PyObject *__pyx_t_83 = NULL;
  PyObject *__pyx_t_84 = NULL;
  PyObject *__pyx_t_85 = NULL;
  PyObject *__pyx_t_86 = NULL;
  PyObject *__pyx_t_87 = NULL;
  PyObject *__pyx_t_88 = NULL;
  PyObject *__pyx_t_89 = NULL;
  int __pyx_t_90;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("split_cases", 0);

  /* "alacorder/cal.pyx":455
 * 
 * def split_cases(df, debug=False):
 *      cases = df.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":456
 * def split_cases(df, debug=False):
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_6, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_extract); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 456, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__24, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_literal, Py_True) < 0) __PYX_ERR(0, 456, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__25, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, __pyx_n_u_Name) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_Name);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":457
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_extract); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 457, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__27, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_literal, Py_True) < 0) __PYX_ERR(0, 457, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__29, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_strip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_4 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_n_u_Alias) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_Alias);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":458
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_8 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_extract); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  if (PyDict_SetItem(__pyx_t_9, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 458, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__30, __pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__31, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_4, __pyx_n_u_DOB) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_DOB);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":459
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),
 *           pl.col("AllPagesText").str.extract(r'(Phone: )(.+)', group_index=2).str.replace_all(r'[^0-9]','').str.slice(0,10).alias("RE_Phone"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_extract); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_10, __pyx_kp_u_w_2_d_4_d_6_d_2) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_kp_u_w_2_d_4_d_6_d_2);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_9 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_4, __pyx_n_u_SHORTCASENO) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_n_u_SHORTCASENO);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 459, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "alacorder/cal.pyx":460
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(Phone: )(.+)', group_index=2).str.replace_all(r'[^0-9]','').str.slice(0,10).alias("RE_Phone"),
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_8, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_extract); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_4 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_11, __pyx_kp_u_County_d_2) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_kp_u_County_d_2);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_n_u_SHORTCOUNTY) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_SHORTCOUNTY);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 460, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":461
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),
 *           pl.col("AllPagesText").str.extract(r'(Phone: )(.+)', group_index=2).str.replace_all(r'[^0-9]','').str.slice(0,10).alias("RE_Phone"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_pl); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_4 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_11, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_extract); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (PyDict_SetItem(__pyx_t_8, __pyx_n_s_group_index, __pyx_int_2) < 0) __PYX_ERR(0, 461, __pyx_L1_error)
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__32, __pyx_t_8); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_slice); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_10 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_11, __pyx_n_u_RE_Phone) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_RE_Phone);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":462
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),
 *           pl.col("AllPagesText").str.extract(r'(Phone: )(.+)', group_index=2).str.replace_all(r'[^0-9]','').str.slice(0,10).alias("RE_Phone"),
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_4 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_12, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_extract); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_11 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_kp_u_B_W_H_A_F_M) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_u_B_W_H_A_F_M);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_11, __pyx_n_u_Race) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_Race);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":463
 *           pl.col("AllPagesText").str.extract(r'(Phone: )(.+)', group_index=2).str.replace_all(r'[^0-9]','').str.slice(0,10).alias("RE_Phone"),
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_13 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_12, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_str); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_extract); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_11 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, __pyx_kp_u_B_W_H_A_F_M_2) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_kp_u_B_W_H_A_F_M_2);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_4 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_11, __pyx_n_u_Sex) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_Sex);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 463, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":464
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_col); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_14 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_12, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_str); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_extract); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  if (PyDict_SetItem(__pyx_t_15, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 464, __pyx_L1_error)
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__35, __pyx_t_15); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_str); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_replace); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_str); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_strip); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_11 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_13 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_11, __pyx_n_u_Address1) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_Address1);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "alacorder/cal.pyx":465
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_14 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_16, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_str); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_extract); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_12 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_17, __pyx_kp_u_Address_2) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_u_Address_2);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_str); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_strip); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_11 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_15 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_11, __pyx_n_u_Address2) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_Address2);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "alacorder/cal.pyx":466
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_11 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_14, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_extract); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 466, __pyx_L1_error)
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__37, __pyx_t_17); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_str); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_alias); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_12 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_17, __pyx_n_u_ZipCode) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_ZipCode);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "alacorder/cal.pyx":467
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_pl); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_17 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_11, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_str); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_extract); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  if (PyDict_SetItem(__pyx_t_16, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 467, __pyx_L1_error)
  __pyx_t_11 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__39, __pyx_t_16); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_14 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_11, __pyx_n_u_City) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_City);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

  /* "alacorder/cal.pyx":468
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_pl); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_col); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_18))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_18);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_18, function);
    }
  }
  __pyx_t_11 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_18, __pyx_t_17, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_extract); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_group_index, __pyx_int_2) < 0) __PYX_ERR(0, 468, __pyx_L1_error)
  __pyx_t_17 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_tuple__39, __pyx_t_18); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_alias); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_18))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_18);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_18, function);
    }
  }
  __pyx_t_16 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_18, __pyx_t_17, __pyx_n_u_State) : __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_n_u_State);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

  /* "alacorder/cal.pyx":469
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_pl); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_col); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_20))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_20);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_20, function);
    }
  }
  __pyx_t_11 = (__pyx_t_19) ? __Pyx_PyObject_Call2Args(__pyx_t_20, __pyx_t_19, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_20, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_20, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __pyx_t_20 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_20 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_20)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_20);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_17 = (__pyx_t_20) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_20, __pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10);
  __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_alias); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_18 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_17, __pyx_n_u_RE_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_RE_Charges);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "alacorder/cal.pyx":470
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_19, __pyx_n_s_pl); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_col); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_19)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_19);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  __pyx_t_20 = (__pyx_t_19) ? __Pyx_PyObject_Call2Args(__pyx_t_21, __pyx_t_19, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
  if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_20, __pyx_n_s_str); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_20);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_20, function);
    }
  }
  __pyx_t_17 = (__pyx_t_21) ? __Pyx_PyObject_Call2Args(__pyx_t_20, __pyx_t_21, __pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_n) : __Pyx_PyObject_CallOneArg(__pyx_t_20, __pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_n);
  __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
  __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_alias); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_20))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_20);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_20, function);
    }
  }
  __pyx_t_11 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_20, __pyx_t_17, __pyx_n_u_RE_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_20, __pyx_n_u_RE_Fees);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;

  /* "alacorder/cal.pyx":471
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_pl); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_col); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_23))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_23);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_23, function);
    }
  }
  __pyx_t_19 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_23, __pyx_t_22, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_23, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_str); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_23, __pyx_n_s_extract); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_23)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_23);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
    }
  }
  __pyx_t_21 = (__pyx_t_23) ? __Pyx_PyObject_Call2Args(__pyx_t_19, __pyx_t_23, __pyx_kp_u_Total_n) : __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_kp_u_Total_n);
  __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_str); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_Call(__pyx_t_21, __pyx_tuple__40, NULL); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_19, __pyx_n_s_str); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_21 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_21)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_21);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
    }
  }
  __pyx_t_17 = (__pyx_t_21) ? __Pyx_PyObject_Call2Args(__pyx_t_19, __pyx_t_21, __pyx_kp_u_s_d_d_2) : __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_kp_u_s_d_d_2);
  __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
  __pyx_t_19 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_alias); if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_19))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_19);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_19);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_19, function);
    }
  }
  __pyx_t_20 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_19, __pyx_t_17, __pyx_n_u_TOTALS) : __Pyx_PyObject_CallOneArg(__pyx_t_19, __pyx_n_u_TOTALS);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_20);
  __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;

  /* "alacorder/cal.pyx":472
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),
 *           pl.col("AllPagesText").str.extract(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)').alias("FilingDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_25))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_25);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_25, function);
    }
  }
  __pyx_t_22 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_25, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_25, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_str); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = __Pyx_PyObject_GetAttrStr(__pyx_t_25, __pyx_n_s_extract); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_25)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_25);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
    }
  }
  __pyx_t_23 = (__pyx_t_25) ? __Pyx_PyObject_Call2Args(__pyx_t_22, __pyx_t_25, __pyx_kp_u_ACTIVE_n_D999_n) : __Pyx_PyObject_CallOneArg(__pyx_t_22, __pyx_kp_u_ACTIVE_n_D999_n);
  __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
  if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = __Pyx_PyObject_GetAttrStr(__pyx_t_23, __pyx_n_s_str); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_23))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_23);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_23, function);
    }
  }
  __pyx_t_21 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_23, __pyx_t_22, __pyx_kp_u_d_d_2) : __Pyx_PyObject_CallOneArg(__pyx_t_23, __pyx_kp_u_d_d_2);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_arr); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_23, __pyx_n_s_get); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_23 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_23)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_23);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  __pyx_t_17 = (__pyx_t_23) ? __Pyx_PyObject_Call2Args(__pyx_t_21, __pyx_t_23, __pyx_int_neg_1) : __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_int_neg_1);
  __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_str); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_replace); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_cast); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_21, __pyx_n_s_pl); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_Float64); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = PyTuple_New(1); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_GIVEREF(__pyx_t_23);
  PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_23);
  __pyx_t_23 = 0;
  __pyx_t_23 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  if (PyDict_SetItem(__pyx_t_23, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 472, __pyx_L1_error)
  __pyx_t_22 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_21, __pyx_t_23); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
  __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_23))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_23);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_23);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_23, function);
    }
  }
  __pyx_t_19 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_23, __pyx_t_22, __pyx_n_u_D999) : __Pyx_PyObject_CallOneArg(__pyx_t_23, __pyx_n_u_D999);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_19)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_19);
  __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;

  /* "alacorder/cal.pyx":473
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)').alias("FilingDate"),
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CaseInitiationDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_25, __pyx_n_s_pl); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_t_25, __pyx_n_s_col); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_24))) {
    __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_24);
    if (likely(__pyx_t_25)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
      __Pyx_INCREF(__pyx_t_25);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_24, function);
    }
  }
  __pyx_t_17 = (__pyx_t_25) ? __Pyx_PyObject_Call2Args(__pyx_t_24, __pyx_t_25, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_24, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_str); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_21 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_24, __pyx_kp_u_w_2_d_12) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_kp_u_w_2_d_12);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_21, __pyx_n_s_arr); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_join); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  __pyx_t_22 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_21, __pyx_t_17, __pyx_kp_u__42) : __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_kp_u__42);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
  __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_21))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_21);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_21);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_21, function);
    }
  }
  __pyx_t_23 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_21, __pyx_t_22, __pyx_n_u_RelatedCases) : __Pyx_PyObject_CallOneArg(__pyx_t_21, __pyx_n_u_RelatedCases);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_23);
  __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;

  /* "alacorder/cal.pyx":474
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),
 *           pl.col("AllPagesText").str.extract(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)').alias("FilingDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CaseInitiationDate"),
 *           pl.col("AllPagesText").str.extract(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)').alias("ArrestDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_25))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_25);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_25, function);
    }
  }
  __pyx_t_17 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_25, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_25, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_str); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_25, __pyx_n_s_extract); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_25 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_25)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_25);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_22 = (__pyx_t_25) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_25, __pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_25); __pyx_t_25 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_21 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_22, __pyx_n_u_FilingDate) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_FilingDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_21);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "alacorder/cal.pyx":475
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),
 *           pl.col("AllPagesText").str.extract(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)').alias("FilingDate"),
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CaseInitiationDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)').alias("ArrestDate"),
 *           pl.col("AllPagesText").str.extract(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)').alias("OffenseDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_26 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_26))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_26);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_26);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_26, function);
    }
  }
  __pyx_t_25 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_26, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_26, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
  __pyx_t_26 = __Pyx_PyObject_GetAttrStr(__pyx_t_25, __pyx_n_s_str); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_26, __pyx_n_s_extract); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
  __pyx_t_26 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_25))) {
    __pyx_t_26 = PyMethod_GET_SELF(__pyx_t_25);
    if (likely(__pyx_t_26)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
      __Pyx_INCREF(__pyx_t_26);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_25, function);
    }
  }
  __pyx_t_22 = (__pyx_t_26) ? __Pyx_PyObject_Call2Args(__pyx_t_25, __pyx_t_26, __pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_25, __pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_26); __pyx_t_26 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;
  __pyx_t_25 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_25))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_25);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_25);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_25, function);
    }
  }
  __pyx_t_17 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_25, __pyx_t_22, __pyx_n_u_CaseInitiationDate) : __Pyx_PyObject_CallOneArg(__pyx_t_25, __pyx_n_u_CaseInitiationDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_25); __pyx_t_25 = 0;

  /* "alacorder/cal.pyx":476
 *           pl.col("AllPagesText").str.extract(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)').alias("FilingDate"),
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CaseInitiationDate"),
 *           pl.col("AllPagesText").str.extract(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)').alias("ArrestDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)').alias("OffenseDate"),
 *           pl.col("AllPagesText").str.extract(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)').alias("IndictmentDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_27 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_27))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_27);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_27);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_27, function);
    }
  }
  __pyx_t_26 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_27, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_27, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
  __pyx_t_27 = __Pyx_PyObject_GetAttrStr(__pyx_t_26, __pyx_n_s_str); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
  __pyx_t_26 = __Pyx_PyObject_GetAttrStr(__pyx_t_27, __pyx_n_s_extract); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
  __pyx_t_27 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_26))) {
    __pyx_t_27 = PyMethod_GET_SELF(__pyx_t_26);
    if (likely(__pyx_t_27)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_26);
      __Pyx_INCREF(__pyx_t_27);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_26, function);
    }
  }
  __pyx_t_22 = (__pyx_t_27) ? __Pyx_PyObject_Call2Args(__pyx_t_26, __pyx_t_27, __pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_26, __pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_27); __pyx_t_27 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;
  __pyx_t_26 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_26))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_26);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_26);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_26, function);
    }
  }
  __pyx_t_25 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_26, __pyx_t_22, __pyx_n_u_ArrestDate) : __Pyx_PyObject_CallOneArg(__pyx_t_26, __pyx_n_u_ArrestDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_25)) __PYX_ERR(0, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_25);
  __Pyx_DECREF(__pyx_t_26); __pyx_t_26 = 0;

  /* "alacorder/cal.pyx":477
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CaseInitiationDate"),
 *           pl.col("AllPagesText").str.extract(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)').alias("ArrestDate"),
 *           pl.col("AllPagesText").str.extract(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)').alias("OffenseDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)').alias("IndictmentDate"),
 *           pl.col("AllPagesText").str.extract(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)').alias("YouthfulDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_28 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_28))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_28);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_28);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_28, function);
    }
  }
  __pyx_t_27 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_28, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_28, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
  __pyx_t_28 = __Pyx_PyObject_GetAttrStr(__pyx_t_27, __pyx_n_s_str); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
  __pyx_t_27 = __Pyx_PyObject_GetAttrStr(__pyx_t_28, __pyx_n_s_extract); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
  __pyx_t_28 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_27))) {
    __pyx_t_28 = PyMethod_GET_SELF(__pyx_t_27);
    if (likely(__pyx_t_28)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_27);
      __Pyx_INCREF(__pyx_t_28);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_27, function);
    }
  }
  __pyx_t_22 = (__pyx_t_28) ? __Pyx_PyObject_Call2Args(__pyx_t_27, __pyx_t_28, __pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_27, __pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_28); __pyx_t_28 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;
  __pyx_t_27 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_27))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_27);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_27);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_27, function);
    }
  }
  __pyx_t_26 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_27, __pyx_t_22, __pyx_n_u_OffenseDate) : __Pyx_PyObject_CallOneArg(__pyx_t_27, __pyx_n_u_OffenseDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_26)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_26);
  __Pyx_DECREF(__pyx_t_27); __pyx_t_27 = 0;

  /* "alacorder/cal.pyx":478
 *           pl.col("AllPagesText").str.extract(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)').alias("ArrestDate"),
 *           pl.col("AllPagesText").str.extract(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)').alias("OffenseDate"),
 *           pl.col("AllPagesText").str.extract(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)').alias("IndictmentDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)').alias("YouthfulDate"),
 *           pl.col("AllPagesText").str.extract(r'AL Institutional Service Num: ([^\na-z])').str.strip().alias("ALInstitutionalServiceNum"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_29 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_29))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_29);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_29);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_29, function);
    }
  }
  __pyx_t_28 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_29, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_29, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
  __pyx_t_29 = __Pyx_PyObject_GetAttrStr(__pyx_t_28, __pyx_n_s_str); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
  __pyx_t_28 = __Pyx_PyObject_GetAttrStr(__pyx_t_29, __pyx_n_s_extract); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
  __pyx_t_29 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_28))) {
    __pyx_t_29 = PyMethod_GET_SELF(__pyx_t_28);
    if (likely(__pyx_t_29)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_28);
      __Pyx_INCREF(__pyx_t_29);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_28, function);
    }
  }
  __pyx_t_22 = (__pyx_t_29) ? __Pyx_PyObject_Call2Args(__pyx_t_28, __pyx_t_29, __pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_28, __pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_29); __pyx_t_29 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;
  __pyx_t_28 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_28))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_28);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_28);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_28, function);
    }
  }
  __pyx_t_27 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_28, __pyx_t_22, __pyx_n_u_IndictmentDate) : __Pyx_PyObject_CallOneArg(__pyx_t_28, __pyx_n_u_IndictmentDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_27)) __PYX_ERR(0, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_27);
  __Pyx_DECREF(__pyx_t_28); __pyx_t_28 = 0;

  /* "alacorder/cal.pyx":479
 *           pl.col("AllPagesText").str.extract(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)').alias("OffenseDate"),
 *           pl.col("AllPagesText").str.extract(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)').alias("IndictmentDate"),
 *           pl.col("AllPagesText").str.extract(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)').alias("YouthfulDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'AL Institutional Service Num: ([^\na-z])').str.strip().alias("ALInstitutionalServiceNum"),
 *           pl.col("AllPagesText").str.extract(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)').alias("Retrieved"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_24, __pyx_n_s_pl); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __pyx_t_30 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_col); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_30))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_30);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_30);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_30, function);
    }
  }
  __pyx_t_29 = (__pyx_t_24) ? __Pyx_PyObject_Call2Args(__pyx_t_30, __pyx_t_24, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_30, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_30); __pyx_t_30 = 0;
  __pyx_t_30 = __Pyx_PyObject_GetAttrStr(__pyx_t_29, __pyx_n_s_str); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
  __pyx_t_29 = __Pyx_PyObject_GetAttrStr(__pyx_t_30, __pyx_n_s_extract); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_30); __pyx_t_30 = 0;
  __pyx_t_30 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_29))) {
    __pyx_t_30 = PyMethod_GET_SELF(__pyx_t_29);
    if (likely(__pyx_t_30)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_29);
      __Pyx_INCREF(__pyx_t_30);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_29, function);
    }
  }
  __pyx_t_22 = (__pyx_t_30) ? __Pyx_PyObject_Call2Args(__pyx_t_29, __pyx_t_30, __pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_29, __pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_30); __pyx_t_30 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;
  __pyx_t_29 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_29))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_29);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_29);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_29, function);
    }
  }
  __pyx_t_28 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_29, __pyx_t_22, __pyx_n_u_YouthfulDate) : __Pyx_PyObject_CallOneArg(__pyx_t_29, __pyx_n_u_YouthfulDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_28)) __PYX_ERR(0, 479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_28);
  __Pyx_DECREF(__pyx_t_29); __pyx_t_29 = 0;

  /* "alacorder/cal.pyx":480
 *           pl.col("AllPagesText").str.extract(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)').alias("IndictmentDate"),
 *           pl.col("AllPagesText").str.extract(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)').alias("YouthfulDate"),
 *           pl.col("AllPagesText").str.extract(r'AL Institutional Service Num: ([^\na-z])').str.strip().alias("ALInstitutionalServiceNum"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)').alias("Retrieved"),
 *           pl.col("AllPagesText").str.extract(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)').alias("CourtAction"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_31, __pyx_n_s_pl); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __pyx_t_32 = __Pyx_PyObject_GetAttrStr(__pyx_t_31, __pyx_n_s_col); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;
  __pyx_t_31 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_32))) {
    __pyx_t_31 = PyMethod_GET_SELF(__pyx_t_32);
    if (likely(__pyx_t_31)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_32);
      __Pyx_INCREF(__pyx_t_31);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_32, function);
    }
  }
  __pyx_t_24 = (__pyx_t_31) ? __Pyx_PyObject_Call2Args(__pyx_t_32, __pyx_t_31, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_32, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_31); __pyx_t_31 = 0;
  if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_str); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_extract); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_24))) {
    __pyx_t_32 = PyMethod_GET_SELF(__pyx_t_24);
    if (likely(__pyx_t_32)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
      __Pyx_INCREF(__pyx_t_32);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_24, function);
    }
  }
  __pyx_t_30 = (__pyx_t_32) ? __Pyx_PyObject_Call2Args(__pyx_t_24, __pyx_t_32, __pyx_kp_u_AL_Institutional_Service_Num_na) : __Pyx_PyObject_CallOneArg(__pyx_t_24, __pyx_kp_u_AL_Institutional_Service_Num_na);
  __Pyx_XDECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_t_30, __pyx_n_s_str); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_30); __pyx_t_30 = 0;
  __pyx_t_30 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_strip); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_30))) {
    __pyx_t_24 = PyMethod_GET_SELF(__pyx_t_30);
    if (likely(__pyx_t_24)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_30);
      __Pyx_INCREF(__pyx_t_24);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_30, function);
    }
  }
  __pyx_t_22 = (__pyx_t_24) ? __Pyx_PyObject_CallOneArg(__pyx_t_30, __pyx_t_24) : __Pyx_PyObject_CallNoArg(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_24); __pyx_t_24 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_30); __pyx_t_30 = 0;
  __pyx_t_30 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_30))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_30);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_30);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_30, function);
    }
  }
  __pyx_t_29 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_30, __pyx_t_22, __pyx_n_u_ALInstitutionalServiceNum) : __Pyx_PyObject_CallOneArg(__pyx_t_30, __pyx_n_u_ALInstitutionalServiceNum);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_29)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_29);
  __Pyx_DECREF(__pyx_t_30); __pyx_t_30 = 0;

  /* "alacorder/cal.pyx":481
 *           pl.col("AllPagesText").str.extract(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)').alias("YouthfulDate"),
 *           pl.col("AllPagesText").str.extract(r'AL Institutional Service Num: ([^\na-z])').str.strip().alias("ALInstitutionalServiceNum"),
 *           pl.col("AllPagesText").str.extract(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)').alias("Retrieved"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)').alias("CourtAction"),
 *           pl.col("AllPagesText").str.extract(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CourtActionDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_32, __pyx_n_s_pl); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __pyx_t_31 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_col); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_31))) {
    __pyx_t_32 = PyMethod_GET_SELF(__pyx_t_31);
    if (likely(__pyx_t_32)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_31);
      __Pyx_INCREF(__pyx_t_32);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_31, function);
    }
  }
  __pyx_t_24 = (__pyx_t_32) ? __Pyx_PyObject_Call2Args(__pyx_t_31, __pyx_t_32, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_31, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;
  __pyx_t_31 = __Pyx_PyObject_GetAttrStr(__pyx_t_24, __pyx_n_s_str); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_t_31, __pyx_n_s_extract); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;
  __pyx_t_31 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_24))) {
    __pyx_t_31 = PyMethod_GET_SELF(__pyx_t_24);
    if (likely(__pyx_t_31)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
      __Pyx_INCREF(__pyx_t_31);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_24, function);
    }
  }
  __pyx_t_22 = (__pyx_t_31) ? __Pyx_PyObject_Call2Args(__pyx_t_24, __pyx_t_31, __pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_24, __pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_31); __pyx_t_31 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;
  __pyx_t_24 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_24))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_24);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_24);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_24, function);
    }
  }
  __pyx_t_30 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_24, __pyx_t_22, __pyx_n_u_Retrieved) : __Pyx_PyObject_CallOneArg(__pyx_t_24, __pyx_n_u_Retrieved);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_30)) __PYX_ERR(0, 481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_30);
  __Pyx_DECREF(__pyx_t_24); __pyx_t_24 = 0;

  /* "alacorder/cal.pyx":482
 *           pl.col("AllPagesText").str.extract(r'AL Institutional Service Num: ([^\na-z])').str.strip().alias("ALInstitutionalServiceNum"),
 *           pl.col("AllPagesText").str.extract(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)').alias("Retrieved"),
 *           pl.col("AllPagesText").str.extract(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)').alias("CourtAction"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CourtActionDate"),
 *           pl.col("AllPagesText").str.extract(r'Charge: ([A-Z\.0-9\-\s]+)').str.rstrip("C").str.strip().alias("Description"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_32, __pyx_n_s_pl); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __pyx_t_33 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_col); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_33))) {
    __pyx_t_32 = PyMethod_GET_SELF(__pyx_t_33);
    if (likely(__pyx_t_32)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_33);
      __Pyx_INCREF(__pyx_t_32);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_33, function);
    }
  }
  __pyx_t_31 = (__pyx_t_32) ? __Pyx_PyObject_Call2Args(__pyx_t_33, __pyx_t_32, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_33, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_33); __pyx_t_33 = 0;
  __pyx_t_33 = __Pyx_PyObject_GetAttrStr(__pyx_t_31, __pyx_n_s_str); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;
  __pyx_t_31 = __Pyx_PyObject_GetAttrStr(__pyx_t_33, __pyx_n_s_extract); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_33); __pyx_t_33 = 0;
  __pyx_t_33 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_31))) {
    __pyx_t_33 = PyMethod_GET_SELF(__pyx_t_31);
    if (likely(__pyx_t_33)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_31);
      __Pyx_INCREF(__pyx_t_33);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_31, function);
    }
  }
  __pyx_t_22 = (__pyx_t_33) ? __Pyx_PyObject_Call2Args(__pyx_t_31, __pyx_t_33, __pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W) : __Pyx_PyObject_CallOneArg(__pyx_t_31, __pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W);
  __Pyx_XDECREF(__pyx_t_33); __pyx_t_33 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;
  __pyx_t_31 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_31))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_31);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_31);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_31, function);
    }
  }
  __pyx_t_24 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_31, __pyx_t_22, __pyx_n_u_CourtAction) : __Pyx_PyObject_CallOneArg(__pyx_t_31, __pyx_n_u_CourtAction);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_24)) __PYX_ERR(0, 482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_24);
  __Pyx_DECREF(__pyx_t_31); __pyx_t_31 = 0;

  /* "alacorder/cal.pyx":483
 *           pl.col("AllPagesText").str.extract(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)').alias("Retrieved"),
 *           pl.col("AllPagesText").str.extract(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)').alias("CourtAction"),
 *           pl.col("AllPagesText").str.extract(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CourtActionDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Charge: ([A-Z\.0-9\-\s]+)').str.rstrip("C").str.strip().alias("Description"),
 *           pl.col("AllPagesText").str.extract(r'Jury Demand: ([A-Z]+)').str.strip().alias("JuryDemand"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_32, __pyx_n_s_pl); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __pyx_t_34 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_col); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_34))) {
    __pyx_t_32 = PyMethod_GET_SELF(__pyx_t_34);
    if (likely(__pyx_t_32)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_34);
      __Pyx_INCREF(__pyx_t_32);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_34, function);
    }
  }
  __pyx_t_33 = (__pyx_t_32) ? __Pyx_PyObject_Call2Args(__pyx_t_34, __pyx_t_32, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_34, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_DECREF(__pyx_t_34); __pyx_t_34 = 0;
  __pyx_t_34 = __Pyx_PyObject_GetAttrStr(__pyx_t_33, __pyx_n_s_str); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_DECREF(__pyx_t_33); __pyx_t_33 = 0;
  __pyx_t_33 = __Pyx_PyObject_GetAttrStr(__pyx_t_34, __pyx_n_s_extract); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_DECREF(__pyx_t_34); __pyx_t_34 = 0;
  __pyx_t_34 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_33))) {
    __pyx_t_34 = PyMethod_GET_SELF(__pyx_t_33);
    if (likely(__pyx_t_34)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_33);
      __Pyx_INCREF(__pyx_t_34);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_33, function);
    }
  }
  __pyx_t_22 = (__pyx_t_34) ? __Pyx_PyObject_Call2Args(__pyx_t_33, __pyx_t_34, __pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_33, __pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_34); __pyx_t_34 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_33); __pyx_t_33 = 0;
  __pyx_t_33 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_33))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_33);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_33);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_33, function);
    }
  }
  __pyx_t_31 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_33, __pyx_t_22, __pyx_n_u_CourtActionDate) : __Pyx_PyObject_CallOneArg(__pyx_t_33, __pyx_n_u_CourtActionDate);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_31)) __PYX_ERR(0, 483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_31);
  __Pyx_DECREF(__pyx_t_33); __pyx_t_33 = 0;

  /* "alacorder/cal.pyx":484
 *           pl.col("AllPagesText").str.extract(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)').alias("CourtAction"),
 *           pl.col("AllPagesText").str.extract(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CourtActionDate"),
 *           pl.col("AllPagesText").str.extract(r'Charge: ([A-Z\.0-9\-\s]+)').str.rstrip("C").str.strip().alias("Description"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Jury Demand: ([A-Z]+)').str.strip().alias("JuryDemand"),
 *           pl.col("AllPagesText").str.extract(r'Inpatient Treatment Ordered: ([YES|NO]?)').str.strip().alias("InpatientTreatmentOrdered"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_36, __pyx_n_s_pl); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_col); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_37))) {
    __pyx_t_36 = PyMethod_GET_SELF(__pyx_t_37);
    if (likely(__pyx_t_36)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_37);
      __Pyx_INCREF(__pyx_t_36);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_37, function);
    }
  }
  __pyx_t_35 = (__pyx_t_36) ? __Pyx_PyObject_Call2Args(__pyx_t_37, __pyx_t_36, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_37, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_36); __pyx_t_36 = 0;
  if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_35, __pyx_n_s_str); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_extract); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_35))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_35);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_35);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_35, function);
    }
  }
  __pyx_t_32 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_35, __pyx_t_37, __pyx_kp_u_Charge_A_Z_0_9_s) : __Pyx_PyObject_CallOneArg(__pyx_t_35, __pyx_kp_u_Charge_A_Z_0_9_s);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_str); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = __Pyx_PyObject_GetAttrStr(__pyx_t_35, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_32))) {
    __pyx_t_35 = PyMethod_GET_SELF(__pyx_t_32);
    if (likely(__pyx_t_35)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_32);
      __Pyx_INCREF(__pyx_t_35);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_32, function);
    }
  }
  __pyx_t_34 = (__pyx_t_35) ? __Pyx_PyObject_Call2Args(__pyx_t_32, __pyx_t_35, __pyx_n_u_C_2) : __Pyx_PyObject_CallOneArg(__pyx_t_32, __pyx_n_u_C_2);
  __Pyx_XDECREF(__pyx_t_35); __pyx_t_35 = 0;
  if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = __Pyx_PyObject_GetAttrStr(__pyx_t_34, __pyx_n_s_str); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_34); __pyx_t_34 = 0;
  __pyx_t_34 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_strip); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_34))) {
    __pyx_t_32 = PyMethod_GET_SELF(__pyx_t_34);
    if (likely(__pyx_t_32)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_34);
      __Pyx_INCREF(__pyx_t_32);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_34, function);
    }
  }
  __pyx_t_22 = (__pyx_t_32) ? __Pyx_PyObject_CallOneArg(__pyx_t_34, __pyx_t_32) : __Pyx_PyObject_CallNoArg(__pyx_t_34);
  __Pyx_XDECREF(__pyx_t_32); __pyx_t_32 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_34); __pyx_t_34 = 0;
  __pyx_t_34 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_34))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_34);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_34);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_34, function);
    }
  }
  __pyx_t_33 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_34, __pyx_t_22, __pyx_n_u_Description) : __Pyx_PyObject_CallOneArg(__pyx_t_34, __pyx_n_u_Description);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_33)) __PYX_ERR(0, 484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_33);
  __Pyx_DECREF(__pyx_t_34); __pyx_t_34 = 0;

  /* "alacorder/cal.pyx":485
 *           pl.col("AllPagesText").str.extract(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)').alias("CourtActionDate"),
 *           pl.col("AllPagesText").str.extract(r'Charge: ([A-Z\.0-9\-\s]+)').str.rstrip("C").str.strip().alias("Description"),
 *           pl.col("AllPagesText").str.extract(r'Jury Demand: ([A-Z]+)').str.strip().alias("JuryDemand"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Inpatient Treatment Ordered: ([YES|NO]?)').str.strip().alias("InpatientTreatmentOrdered"),
 *           pl.col("AllPagesText").str.extract(r'Trial Type: ([A-Z]+)').str.replace(r'[S|N]$','').str.strip().alias("TrialType"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_37, __pyx_n_s_pl); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_col); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_36))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_36);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_36);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_36, function);
    }
  }
  __pyx_t_35 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_36, __pyx_t_37, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_36, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_35, __pyx_n_s_str); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_extract); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_35))) {
    __pyx_t_36 = PyMethod_GET_SELF(__pyx_t_35);
    if (likely(__pyx_t_36)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_35);
      __Pyx_INCREF(__pyx_t_36);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_35, function);
    }
  }
  __pyx_t_32 = (__pyx_t_36) ? __Pyx_PyObject_Call2Args(__pyx_t_35, __pyx_t_36, __pyx_kp_u_Jury_Demand_A_Z) : __Pyx_PyObject_CallOneArg(__pyx_t_35, __pyx_kp_u_Jury_Demand_A_Z);
  __Pyx_XDECREF(__pyx_t_36); __pyx_t_36 = 0;
  if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = __Pyx_PyObject_GetAttrStr(__pyx_t_32, __pyx_n_s_str); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = __Pyx_PyObject_GetAttrStr(__pyx_t_35, __pyx_n_s_strip); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_32))) {
    __pyx_t_35 = PyMethod_GET_SELF(__pyx_t_32);
    if (likely(__pyx_t_35)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_32);
      __Pyx_INCREF(__pyx_t_35);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_32, function);
    }
  }
  __pyx_t_22 = (__pyx_t_35) ? __Pyx_PyObject_CallOneArg(__pyx_t_32, __pyx_t_35) : __Pyx_PyObject_CallNoArg(__pyx_t_32);
  __Pyx_XDECREF(__pyx_t_35); __pyx_t_35 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;
  __pyx_t_32 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_32))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_32);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_32);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_32, function);
    }
  }
  __pyx_t_34 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_32, __pyx_t_22, __pyx_n_u_JuryDemand) : __Pyx_PyObject_CallOneArg(__pyx_t_32, __pyx_n_u_JuryDemand);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_34)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_34);
  __Pyx_DECREF(__pyx_t_32); __pyx_t_32 = 0;

  /* "alacorder/cal.pyx":486
 *           pl.col("AllPagesText").str.extract(r'Charge: ([A-Z\.0-9\-\s]+)').str.rstrip("C").str.strip().alias("Description"),
 *           pl.col("AllPagesText").str.extract(r'Jury Demand: ([A-Z]+)').str.strip().alias("JuryDemand"),
 *           pl.col("AllPagesText").str.extract(r'Inpatient Treatment Ordered: ([YES|NO]?)').str.strip().alias("InpatientTreatmentOrdered"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Trial Type: ([A-Z]+)').str.replace(r'[S|N]$','').str.strip().alias("TrialType"),
 *           pl.col("AllPagesText").str.extract(r'Case Number: (\d\d-\w+) County:').str.strip().alias("County"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_37, __pyx_n_s_pl); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __pyx_t_38 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_col); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_38))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_38);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_38);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_38, function);
    }
  }
  __pyx_t_36 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_38, __pyx_t_37, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_38, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_str); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_38, __pyx_n_s_extract); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_36))) {
    __pyx_t_38 = PyMethod_GET_SELF(__pyx_t_36);
    if (likely(__pyx_t_38)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_36);
      __Pyx_INCREF(__pyx_t_38);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_36, function);
    }
  }
  __pyx_t_35 = (__pyx_t_38) ? __Pyx_PyObject_Call2Args(__pyx_t_36, __pyx_t_38, __pyx_kp_u_Inpatient_Treatment_Ordered_YES) : __Pyx_PyObject_CallOneArg(__pyx_t_36, __pyx_kp_u_Inpatient_Treatment_Ordered_YES);
  __Pyx_XDECREF(__pyx_t_38); __pyx_t_38 = 0;
  if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_35, __pyx_n_s_str); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_strip); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_35))) {
    __pyx_t_36 = PyMethod_GET_SELF(__pyx_t_35);
    if (likely(__pyx_t_36)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_35);
      __Pyx_INCREF(__pyx_t_36);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_35, function);
    }
  }
  __pyx_t_22 = (__pyx_t_36) ? __Pyx_PyObject_CallOneArg(__pyx_t_35, __pyx_t_36) : __Pyx_PyObject_CallNoArg(__pyx_t_35);
  __Pyx_XDECREF(__pyx_t_36); __pyx_t_36 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;
  __pyx_t_35 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_35))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_35);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_35);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_35, function);
    }
  }
  __pyx_t_32 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_35, __pyx_t_22, __pyx_n_u_InpatientTreatmentOrdered) : __Pyx_PyObject_CallOneArg(__pyx_t_35, __pyx_n_u_InpatientTreatmentOrdered);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_32)) __PYX_ERR(0, 486, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_32);
  __Pyx_DECREF(__pyx_t_35); __pyx_t_35 = 0;

  /* "alacorder/cal.pyx":487
 *           pl.col("AllPagesText").str.extract(r'Jury Demand: ([A-Z]+)').str.strip().alias("JuryDemand"),
 *           pl.col("AllPagesText").str.extract(r'Inpatient Treatment Ordered: ([YES|NO]?)').str.strip().alias("InpatientTreatmentOrdered"),
 *           pl.col("AllPagesText").str.extract(r'Trial Type: ([A-Z]+)').str.replace(r'[S|N]$','').str.strip().alias("TrialType"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Case Number: (\d\d-\w+) County:').str.strip().alias("County"),
 *           pl.col("AllPagesText").str.extract(r'Judge: ([A-Z\-\.\s]+)').str.rstrip("T").str.strip().alias("Judge"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_37, __pyx_n_s_pl); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __pyx_t_39 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_col); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_39))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_39);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_39);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_39, function);
    }
  }
  __pyx_t_38 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_39, __pyx_t_37, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_39, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = __Pyx_PyObject_GetAttrStr(__pyx_t_38, __pyx_n_s_str); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = __Pyx_PyObject_GetAttrStr(__pyx_t_39, __pyx_n_s_extract); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_38))) {
    __pyx_t_39 = PyMethod_GET_SELF(__pyx_t_38);
    if (likely(__pyx_t_39)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_38);
      __Pyx_INCREF(__pyx_t_39);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_38, function);
    }
  }
  __pyx_t_36 = (__pyx_t_39) ? __Pyx_PyObject_Call2Args(__pyx_t_38, __pyx_t_39, __pyx_kp_u_Trial_Type_A_Z) : __Pyx_PyObject_CallOneArg(__pyx_t_38, __pyx_kp_u_Trial_Type_A_Z);
  __Pyx_XDECREF(__pyx_t_39); __pyx_t_39 = 0;
  if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_str); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_38, __pyx_n_s_replace); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = __Pyx_PyObject_Call(__pyx_t_36, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_38, __pyx_n_s_str); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_strip); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_38))) {
    __pyx_t_36 = PyMethod_GET_SELF(__pyx_t_38);
    if (likely(__pyx_t_36)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_38);
      __Pyx_INCREF(__pyx_t_36);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_38, function);
    }
  }
  __pyx_t_22 = (__pyx_t_36) ? __Pyx_PyObject_CallOneArg(__pyx_t_38, __pyx_t_36) : __Pyx_PyObject_CallNoArg(__pyx_t_38);
  __Pyx_XDECREF(__pyx_t_36); __pyx_t_36 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;
  __pyx_t_38 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_38))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_38);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_38);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_38, function);
    }
  }
  __pyx_t_35 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_38, __pyx_t_22, __pyx_n_u_TrialType) : __Pyx_PyObject_CallOneArg(__pyx_t_38, __pyx_n_u_TrialType);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_35)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_35);
  __Pyx_DECREF(__pyx_t_38); __pyx_t_38 = 0;

  /* "alacorder/cal.pyx":488
 *           pl.col("AllPagesText").str.extract(r'Inpatient Treatment Ordered: ([YES|NO]?)').str.strip().alias("InpatientTreatmentOrdered"),
 *           pl.col("AllPagesText").str.extract(r'Trial Type: ([A-Z]+)').str.replace(r'[S|N]$','').str.strip().alias("TrialType"),
 *           pl.col("AllPagesText").str.extract(r'Case Number: (\d\d-\w+) County:').str.strip().alias("County"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Judge: ([A-Z\-\.\s]+)').str.rstrip("T").str.strip().alias("Judge"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office \#: ([0-9\-]+)').alias("PROBATIONOFFICENUMBERRAW"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_37, __pyx_n_s_pl); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __pyx_t_40 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_col); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_40))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_40);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_40);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_40, function);
    }
  }
  __pyx_t_39 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_40, __pyx_t_37, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_40, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = __Pyx_PyObject_GetAttrStr(__pyx_t_39, __pyx_n_s_str); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = __Pyx_PyObject_GetAttrStr(__pyx_t_40, __pyx_n_s_extract); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_39))) {
    __pyx_t_40 = PyMethod_GET_SELF(__pyx_t_39);
    if (likely(__pyx_t_40)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_39);
      __Pyx_INCREF(__pyx_t_40);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_39, function);
    }
  }
  __pyx_t_36 = (__pyx_t_40) ? __Pyx_PyObject_Call2Args(__pyx_t_39, __pyx_t_40, __pyx_kp_u_Case_Number_d_d_w_County) : __Pyx_PyObject_CallOneArg(__pyx_t_39, __pyx_kp_u_Case_Number_d_d_w_County);
  __Pyx_XDECREF(__pyx_t_40); __pyx_t_40 = 0;
  if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = __Pyx_PyObject_GetAttrStr(__pyx_t_36, __pyx_n_s_str); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_39, __pyx_n_s_strip); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_36))) {
    __pyx_t_39 = PyMethod_GET_SELF(__pyx_t_36);
    if (likely(__pyx_t_39)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_36);
      __Pyx_INCREF(__pyx_t_39);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_36, function);
    }
  }
  __pyx_t_22 = (__pyx_t_39) ? __Pyx_PyObject_CallOneArg(__pyx_t_36, __pyx_t_39) : __Pyx_PyObject_CallNoArg(__pyx_t_36);
  __Pyx_XDECREF(__pyx_t_39); __pyx_t_39 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;
  __pyx_t_36 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_36))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_36);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_36);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_36, function);
    }
  }
  __pyx_t_38 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_36, __pyx_t_22, __pyx_n_u_County) : __Pyx_PyObject_CallOneArg(__pyx_t_36, __pyx_n_u_County);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_38)) __PYX_ERR(0, 488, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_38);
  __Pyx_DECREF(__pyx_t_36); __pyx_t_36 = 0;

  /* "alacorder/cal.pyx":489
 *           pl.col("AllPagesText").str.extract(r'Trial Type: ([A-Z]+)').str.replace(r'[S|N]$','').str.strip().alias("TrialType"),
 *           pl.col("AllPagesText").str.extract(r'Case Number: (\d\d-\w+) County:').str.strip().alias("County"),
 *           pl.col("AllPagesText").str.extract(r'Judge: ([A-Z\-\.\s]+)').str.rstrip("T").str.strip().alias("Judge"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Probation Office \#: ([0-9\-]+)').alias("PROBATIONOFFICENUMBERRAW"),
 *           pl.col("AllPagesText").str.extract(r'Defendant Status: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("DefendantStatus"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_41, __pyx_n_s_pl); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __pyx_t_42 = __Pyx_PyObject_GetAttrStr(__pyx_t_41, __pyx_n_s_col); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_42))) {
    __pyx_t_41 = PyMethod_GET_SELF(__pyx_t_42);
    if (likely(__pyx_t_41)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_42);
      __Pyx_INCREF(__pyx_t_41);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_42, function);
    }
  }
  __pyx_t_37 = (__pyx_t_41) ? __Pyx_PyObject_Call2Args(__pyx_t_42, __pyx_t_41, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_42, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_41); __pyx_t_41 = 0;
  if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;
  __pyx_t_42 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_str); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_42, __pyx_n_s_extract); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;
  __pyx_t_42 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_37))) {
    __pyx_t_42 = PyMethod_GET_SELF(__pyx_t_37);
    if (likely(__pyx_t_42)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_37);
      __Pyx_INCREF(__pyx_t_42);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_37, function);
    }
  }
  __pyx_t_40 = (__pyx_t_42) ? __Pyx_PyObject_Call2Args(__pyx_t_37, __pyx_t_42, __pyx_kp_u_Judge_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_37, __pyx_kp_u_Judge_A_Z_s);
  __Pyx_XDECREF(__pyx_t_42); __pyx_t_42 = 0;
  if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_40, __pyx_n_s_str); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_40))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_40);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_40);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_40, function);
    }
  }
  __pyx_t_39 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_40, __pyx_t_37, __pyx_n_u_T) : __Pyx_PyObject_CallOneArg(__pyx_t_40, __pyx_n_u_T);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = __Pyx_PyObject_GetAttrStr(__pyx_t_39, __pyx_n_s_str); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = __Pyx_PyObject_GetAttrStr(__pyx_t_40, __pyx_n_s_strip); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_39))) {
    __pyx_t_40 = PyMethod_GET_SELF(__pyx_t_39);
    if (likely(__pyx_t_40)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_39);
      __Pyx_INCREF(__pyx_t_40);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_39, function);
    }
  }
  __pyx_t_22 = (__pyx_t_40) ? __Pyx_PyObject_CallOneArg(__pyx_t_39, __pyx_t_40) : __Pyx_PyObject_CallNoArg(__pyx_t_39);
  __Pyx_XDECREF(__pyx_t_40); __pyx_t_40 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;
  __pyx_t_39 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_39))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_39);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_39);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_39, function);
    }
  }
  __pyx_t_36 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_39, __pyx_t_22, __pyx_n_u_Judge) : __Pyx_PyObject_CallOneArg(__pyx_t_39, __pyx_n_u_Judge);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_36)) __PYX_ERR(0, 489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_36);
  __Pyx_DECREF(__pyx_t_39); __pyx_t_39 = 0;

  /* "alacorder/cal.pyx":490
 *           pl.col("AllPagesText").str.extract(r'Case Number: (\d\d-\w+) County:').str.strip().alias("County"),
 *           pl.col("AllPagesText").str.extract(r'Judge: ([A-Z\-\.\s]+)').str.rstrip("T").str.strip().alias("Judge"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office \#: ([0-9\-]+)').alias("PROBATIONOFFICENUMBERRAW"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Defendant Status: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("DefendantStatus"),
 *           pl.col("AllPagesText").str.extract(r'([^0-9]+) Arresting Agency Type:').str.replace(r'\n','').str.strip().alias("ArrestingAgencyType"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_37, __pyx_n_s_pl); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __pyx_t_42 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_col); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_42))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_42);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_42);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_42, function);
    }
  }
  __pyx_t_40 = (__pyx_t_37) ? __Pyx_PyObject_Call2Args(__pyx_t_42, __pyx_t_37, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_42, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;
  __pyx_t_42 = __Pyx_PyObject_GetAttrStr(__pyx_t_40, __pyx_n_s_str); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = __Pyx_PyObject_GetAttrStr(__pyx_t_42, __pyx_n_s_extract); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;
  __pyx_t_42 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_40))) {
    __pyx_t_42 = PyMethod_GET_SELF(__pyx_t_40);
    if (likely(__pyx_t_42)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_40);
      __Pyx_INCREF(__pyx_t_42);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_40, function);
    }
  }
  __pyx_t_22 = (__pyx_t_42) ? __Pyx_PyObject_Call2Args(__pyx_t_40, __pyx_t_42, __pyx_kp_u_Probation_Office_0_9) : __Pyx_PyObject_CallOneArg(__pyx_t_40, __pyx_kp_u_Probation_Office_0_9);
  __Pyx_XDECREF(__pyx_t_42); __pyx_t_42 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;
  __pyx_t_40 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_40))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_40);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_40);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_40, function);
    }
  }
  __pyx_t_39 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_40, __pyx_t_22, __pyx_n_u_PROBATIONOFFICENUMBERRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_40, __pyx_n_u_PROBATIONOFFICENUMBERRAW);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_39)) __PYX_ERR(0, 490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_39);
  __Pyx_DECREF(__pyx_t_40); __pyx_t_40 = 0;

  /* "alacorder/cal.pyx":491
 *           pl.col("AllPagesText").str.extract(r'Judge: ([A-Z\-\.\s]+)').str.rstrip("T").str.strip().alias("Judge"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office \#: ([0-9\-]+)').alias("PROBATIONOFFICENUMBERRAW"),
 *           pl.col("AllPagesText").str.extract(r'Defendant Status: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("DefendantStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'([^0-9]+) Arresting Agency Type:').str.replace(r'\n','').str.strip().alias("ArrestingAgencyType"),
 *           pl.col("AllPagesText").str.extract(r'Arresting Officer: ([A-Z\s]+)').str.rstrip("S").str.rstrip("P").str.strip().alias("ArrestingOfficer"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_43, __pyx_n_s_pl); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_43, __pyx_n_s_col); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_44))) {
    __pyx_t_43 = PyMethod_GET_SELF(__pyx_t_44);
    if (likely(__pyx_t_43)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_44);
      __Pyx_INCREF(__pyx_t_43);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_44, function);
    }
  }
  __pyx_t_41 = (__pyx_t_43) ? __Pyx_PyObject_Call2Args(__pyx_t_44, __pyx_t_43, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_44, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_43); __pyx_t_43 = 0;
  if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_41, __pyx_n_s_str); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_extract); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_41))) {
    __pyx_t_44 = PyMethod_GET_SELF(__pyx_t_41);
    if (likely(__pyx_t_44)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_41);
      __Pyx_INCREF(__pyx_t_44);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_41, function);
    }
  }
  __pyx_t_37 = (__pyx_t_44) ? __Pyx_PyObject_Call2Args(__pyx_t_41, __pyx_t_44, __pyx_kp_u_Defendant_Status_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_41, __pyx_kp_u_Defendant_Status_A_Z_s);
  __Pyx_XDECREF(__pyx_t_44); __pyx_t_44 = 0;
  if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_str); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_41, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_37))) {
    __pyx_t_41 = PyMethod_GET_SELF(__pyx_t_37);
    if (likely(__pyx_t_41)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_37);
      __Pyx_INCREF(__pyx_t_41);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_37, function);
    }
  }
  __pyx_t_42 = (__pyx_t_41) ? __Pyx_PyObject_Call2Args(__pyx_t_37, __pyx_t_41, __pyx_n_u_J) : __Pyx_PyObject_CallOneArg(__pyx_t_37, __pyx_n_u_J);
  __Pyx_XDECREF(__pyx_t_41); __pyx_t_41 = 0;
  if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_42, __pyx_n_s_str); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;
  __pyx_t_42 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_strip); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_42))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_42);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_42);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_42, function);
    }
  }
  __pyx_t_22 = (__pyx_t_37) ? __Pyx_PyObject_CallOneArg(__pyx_t_42, __pyx_t_37) : __Pyx_PyObject_CallNoArg(__pyx_t_42);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;
  __pyx_t_42 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_42))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_42);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_42);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_42, function);
    }
  }
  __pyx_t_40 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_42, __pyx_t_22, __pyx_n_u_DefendantStatus) : __Pyx_PyObject_CallOneArg(__pyx_t_42, __pyx_n_u_DefendantStatus);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_40)) __PYX_ERR(0, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_40);
  __Pyx_DECREF(__pyx_t_42); __pyx_t_42 = 0;

  /* "alacorder/cal.pyx":492
 *           pl.col("AllPagesText").str.extract(r'Probation Office \#: ([0-9\-]+)').alias("PROBATIONOFFICENUMBERRAW"),
 *           pl.col("AllPagesText").str.extract(r'Defendant Status: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("DefendantStatus"),
 *           pl.col("AllPagesText").str.extract(r'([^0-9]+) Arresting Agency Type:').str.replace(r'\n','').str.strip().alias("ArrestingAgencyType"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Arresting Officer: ([A-Z\s]+)').str.rstrip("S").str.rstrip("P").str.strip().alias("ArrestingOfficer"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office Name: ([A-Z0-9]+)').alias("ProbationOfficeName"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_44, __pyx_n_s_pl); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __pyx_t_43 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_col); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_43))) {
    __pyx_t_44 = PyMethod_GET_SELF(__pyx_t_43);
    if (likely(__pyx_t_44)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_43);
      __Pyx_INCREF(__pyx_t_44);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_43, function);
    }
  }
  __pyx_t_41 = (__pyx_t_44) ? __Pyx_PyObject_Call2Args(__pyx_t_43, __pyx_t_44, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_43, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_44); __pyx_t_44 = 0;
  if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = __Pyx_PyObject_GetAttrStr(__pyx_t_41, __pyx_n_s_str); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_GetAttrStr(__pyx_t_43, __pyx_n_s_extract); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_41))) {
    __pyx_t_43 = PyMethod_GET_SELF(__pyx_t_41);
    if (likely(__pyx_t_43)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_41);
      __Pyx_INCREF(__pyx_t_43);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_41, function);
    }
  }
  __pyx_t_37 = (__pyx_t_43) ? __Pyx_PyObject_Call2Args(__pyx_t_41, __pyx_t_43, __pyx_kp_u_0_9_Arresting_Agency_Type) : __Pyx_PyObject_CallOneArg(__pyx_t_41, __pyx_kp_u_0_9_Arresting_Agency_Type);
  __Pyx_XDECREF(__pyx_t_43); __pyx_t_43 = 0;
  if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_str); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_41, __pyx_n_s_replace); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_Call(__pyx_t_37, __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_41, __pyx_n_s_str); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_strip); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_41))) {
    __pyx_t_37 = PyMethod_GET_SELF(__pyx_t_41);
    if (likely(__pyx_t_37)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_41);
      __Pyx_INCREF(__pyx_t_37);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_41, function);
    }
  }
  __pyx_t_22 = (__pyx_t_37) ? __Pyx_PyObject_CallOneArg(__pyx_t_41, __pyx_t_37) : __Pyx_PyObject_CallNoArg(__pyx_t_41);
  __Pyx_XDECREF(__pyx_t_37); __pyx_t_37 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;
  __pyx_t_41 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_41))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_41);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_41);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_41, function);
    }
  }
  __pyx_t_42 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_41, __pyx_t_22, __pyx_n_u_ArrestingAgencyType) : __Pyx_PyObject_CallOneArg(__pyx_t_41, __pyx_n_u_ArrestingAgencyType);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_42)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_42);
  __Pyx_DECREF(__pyx_t_41); __pyx_t_41 = 0;

  /* "alacorder/cal.pyx":493
 *           pl.col("AllPagesText").str.extract(r'Defendant Status: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("DefendantStatus"),
 *           pl.col("AllPagesText").str.extract(r'([^0-9]+) Arresting Agency Type:').str.replace(r'\n','').str.strip().alias("ArrestingAgencyType"),
 *           pl.col("AllPagesText").str.extract(r'Arresting Officer: ([A-Z\s]+)').str.rstrip("S").str.rstrip("P").str.strip().alias("ArrestingOfficer"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Probation Office Name: ([A-Z0-9]+)').alias("ProbationOfficeName"),
 *           pl.col("AllPagesText").str.extract(r'Traffic Citation \#: ([A-Z0-9]+)').alias("TrafficCitationNumber"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_46, __pyx_n_s_pl); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_col); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_47))) {
    __pyx_t_46 = PyMethod_GET_SELF(__pyx_t_47);
    if (likely(__pyx_t_46)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_47);
      __Pyx_INCREF(__pyx_t_46);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_47, function);
    }
  }
  __pyx_t_45 = (__pyx_t_46) ? __Pyx_PyObject_Call2Args(__pyx_t_47, __pyx_t_46, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_47, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_46); __pyx_t_46 = 0;
  if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_45, __pyx_n_s_str); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = __Pyx_PyObject_GetAttrStr(__pyx_t_47, __pyx_n_s_extract); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_45))) {
    __pyx_t_47 = PyMethod_GET_SELF(__pyx_t_45);
    if (likely(__pyx_t_47)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_45);
      __Pyx_INCREF(__pyx_t_47);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_45, function);
    }
  }
  __pyx_t_44 = (__pyx_t_47) ? __Pyx_PyObject_Call2Args(__pyx_t_45, __pyx_t_47, __pyx_kp_u_Arresting_Officer_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_45, __pyx_kp_u_Arresting_Officer_A_Z_s);
  __Pyx_XDECREF(__pyx_t_47); __pyx_t_47 = 0;
  if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_str); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_45, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_44))) {
    __pyx_t_45 = PyMethod_GET_SELF(__pyx_t_44);
    if (likely(__pyx_t_45)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_44);
      __Pyx_INCREF(__pyx_t_45);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_44, function);
    }
  }
  __pyx_t_43 = (__pyx_t_45) ? __Pyx_PyObject_Call2Args(__pyx_t_44, __pyx_t_45, __pyx_n_u_S) : __Pyx_PyObject_CallOneArg(__pyx_t_44, __pyx_n_u_S);
  __Pyx_XDECREF(__pyx_t_45); __pyx_t_45 = 0;
  if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_43, __pyx_n_s_str); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_43))) {
    __pyx_t_44 = PyMethod_GET_SELF(__pyx_t_43);
    if (likely(__pyx_t_44)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_43);
      __Pyx_INCREF(__pyx_t_44);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_43, function);
    }
  }
  __pyx_t_37 = (__pyx_t_44) ? __Pyx_PyObject_Call2Args(__pyx_t_43, __pyx_t_44, __pyx_n_u_P) : __Pyx_PyObject_CallOneArg(__pyx_t_43, __pyx_n_u_P);
  __Pyx_XDECREF(__pyx_t_44); __pyx_t_44 = 0;
  if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = __Pyx_PyObject_GetAttrStr(__pyx_t_37, __pyx_n_s_str); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_43, __pyx_n_s_strip); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_37))) {
    __pyx_t_43 = PyMethod_GET_SELF(__pyx_t_37);
    if (likely(__pyx_t_43)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_37);
      __Pyx_INCREF(__pyx_t_43);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_37, function);
    }
  }
  __pyx_t_22 = (__pyx_t_43) ? __Pyx_PyObject_CallOneArg(__pyx_t_37, __pyx_t_43) : __Pyx_PyObject_CallNoArg(__pyx_t_37);
  __Pyx_XDECREF(__pyx_t_43); __pyx_t_43 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;
  __pyx_t_37 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_37))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_37);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_37);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_37, function);
    }
  }
  __pyx_t_41 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_37, __pyx_t_22, __pyx_n_u_ArrestingOfficer) : __Pyx_PyObject_CallOneArg(__pyx_t_37, __pyx_n_u_ArrestingOfficer);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_41)) __PYX_ERR(0, 493, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_41);
  __Pyx_DECREF(__pyx_t_37); __pyx_t_37 = 0;

  /* "alacorder/cal.pyx":494
 *           pl.col("AllPagesText").str.extract(r'([^0-9]+) Arresting Agency Type:').str.replace(r'\n','').str.strip().alias("ArrestingAgencyType"),
 *           pl.col("AllPagesText").str.extract(r'Arresting Officer: ([A-Z\s]+)').str.rstrip("S").str.rstrip("P").str.strip().alias("ArrestingOfficer"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office Name: ([A-Z0-9]+)').alias("ProbationOfficeName"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Traffic Citation \#: ([A-Z0-9]+)').alias("TrafficCitationNumber"),
 *           pl.col("AllPagesText").str.extract(r'Previous DUI Convictions: (\d{3})').str.strip().cast(pl.Int64, strict=False).alias("PreviousDUIConvictions"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_44, __pyx_n_s_pl); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __pyx_t_45 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_col); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_45))) {
    __pyx_t_44 = PyMethod_GET_SELF(__pyx_t_45);
    if (likely(__pyx_t_44)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_45);
      __Pyx_INCREF(__pyx_t_44);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_45, function);
    }
  }
  __pyx_t_43 = (__pyx_t_44) ? __Pyx_PyObject_Call2Args(__pyx_t_45, __pyx_t_44, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_45, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_44); __pyx_t_44 = 0;
  if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = __Pyx_PyObject_GetAttrStr(__pyx_t_43, __pyx_n_s_str); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = __Pyx_PyObject_GetAttrStr(__pyx_t_45, __pyx_n_s_extract); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_43))) {
    __pyx_t_45 = PyMethod_GET_SELF(__pyx_t_43);
    if (likely(__pyx_t_45)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_43);
      __Pyx_INCREF(__pyx_t_45);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_43, function);
    }
  }
  __pyx_t_22 = (__pyx_t_45) ? __Pyx_PyObject_Call2Args(__pyx_t_43, __pyx_t_45, __pyx_kp_u_Probation_Office_Name_A_Z0_9) : __Pyx_PyObject_CallOneArg(__pyx_t_43, __pyx_kp_u_Probation_Office_Name_A_Z0_9);
  __Pyx_XDECREF(__pyx_t_45); __pyx_t_45 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;
  __pyx_t_43 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_43))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_43);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_43);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_43, function);
    }
  }
  __pyx_t_37 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_43, __pyx_t_22, __pyx_n_u_ProbationOfficeName) : __Pyx_PyObject_CallOneArg(__pyx_t_43, __pyx_n_u_ProbationOfficeName);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_37)) __PYX_ERR(0, 494, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_37);
  __Pyx_DECREF(__pyx_t_43); __pyx_t_43 = 0;

  /* "alacorder/cal.pyx":495
 *           pl.col("AllPagesText").str.extract(r'Arresting Officer: ([A-Z\s]+)').str.rstrip("S").str.rstrip("P").str.strip().alias("ArrestingOfficer"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office Name: ([A-Z0-9]+)').alias("ProbationOfficeName"),
 *           pl.col("AllPagesText").str.extract(r'Traffic Citation \#: ([A-Z0-9]+)').alias("TrafficCitationNumber"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Previous DUI Convictions: (\d{3})').str.strip().cast(pl.Int64, strict=False).alias("PreviousDUIConvictions"),
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Type: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("CaseInitiationType"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_44, __pyx_n_s_pl); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_col); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_47))) {
    __pyx_t_44 = PyMethod_GET_SELF(__pyx_t_47);
    if (likely(__pyx_t_44)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_47);
      __Pyx_INCREF(__pyx_t_44);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_47, function);
    }
  }
  __pyx_t_45 = (__pyx_t_44) ? __Pyx_PyObject_Call2Args(__pyx_t_47, __pyx_t_44, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_47, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_44); __pyx_t_44 = 0;
  if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_45, __pyx_n_s_str); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = __Pyx_PyObject_GetAttrStr(__pyx_t_47, __pyx_n_s_extract); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_45))) {
    __pyx_t_47 = PyMethod_GET_SELF(__pyx_t_45);
    if (likely(__pyx_t_47)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_45);
      __Pyx_INCREF(__pyx_t_47);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_45, function);
    }
  }
  __pyx_t_22 = (__pyx_t_47) ? __Pyx_PyObject_Call2Args(__pyx_t_45, __pyx_t_47, __pyx_kp_u_Traffic_Citation_A_Z0_9) : __Pyx_PyObject_CallOneArg(__pyx_t_45, __pyx_kp_u_Traffic_Citation_A_Z0_9);
  __Pyx_XDECREF(__pyx_t_47); __pyx_t_47 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;
  __pyx_t_45 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_alias); if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_45))) {
    __pyx_t_22 = PyMethod_GET_SELF(__pyx_t_45);
    if (likely(__pyx_t_22)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_45);
      __Pyx_INCREF(__pyx_t_22);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_45, function);
    }
  }
  __pyx_t_43 = (__pyx_t_22) ? __Pyx_PyObject_Call2Args(__pyx_t_45, __pyx_t_22, __pyx_n_u_TrafficCitationNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_45, __pyx_n_u_TrafficCitationNumber);
  __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
  if (unlikely(!__pyx_t_43)) __PYX_ERR(0, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_43);
  __Pyx_DECREF(__pyx_t_45); __pyx_t_45 = 0;

  /* "alacorder/cal.pyx":496
 *           pl.col("AllPagesText").str.extract(r'Probation Office Name: ([A-Z0-9]+)').alias("ProbationOfficeName"),
 *           pl.col("AllPagesText").str.extract(r'Traffic Citation \#: ([A-Z0-9]+)').alias("TrafficCitationNumber"),
 *           pl.col("AllPagesText").str.extract(r'Previous DUI Convictions: (\d{3})').str.strip().cast(pl.Int64, strict=False).alias("PreviousDUIConvictions"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Type: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("CaseInitiationType"),
 *           pl.col("AllPagesText").str.extract(r'Domestic Violence: ([YES|NO])').str.strip().alias("DomesticViolence"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_46, __pyx_n_s_pl); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __pyx_t_48 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_col); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_48))) {
    __pyx_t_46 = PyMethod_GET_SELF(__pyx_t_48);
    if (likely(__pyx_t_46)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_48);
      __Pyx_INCREF(__pyx_t_46);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_48, function);
    }
  }
  __pyx_t_44 = (__pyx_t_46) ? __Pyx_PyObject_Call2Args(__pyx_t_48, __pyx_t_46, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_48, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_46); __pyx_t_46 = 0;
  if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_str); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_extract); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_44))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_44);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_44);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_44, function);
    }
  }
  __pyx_t_47 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_44, __pyx_t_48, __pyx_kp_u_Previous_DUI_Convictions_d_3) : __Pyx_PyObject_CallOneArg(__pyx_t_44, __pyx_kp_u_Previous_DUI_Convictions_d_3);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_47, __pyx_n_s_str); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_44, __pyx_n_s_strip); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_47))) {
    __pyx_t_44 = PyMethod_GET_SELF(__pyx_t_47);
    if (likely(__pyx_t_44)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_47);
      __Pyx_INCREF(__pyx_t_44);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_47, function);
    }
  }
  __pyx_t_22 = (__pyx_t_44) ? __Pyx_PyObject_CallOneArg(__pyx_t_47, __pyx_t_44) : __Pyx_PyObject_CallNoArg(__pyx_t_47);
  __Pyx_XDECREF(__pyx_t_44); __pyx_t_44 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_cast); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_22, __pyx_n_s_pl); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_Int64); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = PyTuple_New(1); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_44);
  PyTuple_SET_ITEM(__pyx_t_22, 0, __pyx_t_44);
  __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  if (PyDict_SetItem(__pyx_t_44, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 496, __pyx_L1_error)
  __pyx_t_48 = __Pyx_PyObject_Call(__pyx_t_47, __pyx_t_22, __pyx_t_44); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;
  __pyx_t_44 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_44))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_44);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_44);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_44, function);
    }
  }
  __pyx_t_45 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_44, __pyx_t_48, __pyx_n_u_PreviousDUIConvictions) : __Pyx_PyObject_CallOneArg(__pyx_t_44, __pyx_n_u_PreviousDUIConvictions);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_45)) __PYX_ERR(0, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_45);
  __Pyx_DECREF(__pyx_t_44); __pyx_t_44 = 0;

  /* "alacorder/cal.pyx":497
 *           pl.col("AllPagesText").str.extract(r'Traffic Citation \#: ([A-Z0-9]+)').alias("TrafficCitationNumber"),
 *           pl.col("AllPagesText").str.extract(r'Previous DUI Convictions: (\d{3})').str.strip().cast(pl.Int64, strict=False).alias("PreviousDUIConvictions"),
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Type: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("CaseInitiationType"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Domestic Violence: ([YES|NO])').str.strip().alias("DomesticViolence"),
 *           pl.col("AllPagesText").str.extract(r'Agency ORI: ([A-Z\s]+)').str.rstrip("C").str.strip().alias("AgencyORI"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_49, __pyx_n_s_pl); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_49, __pyx_n_s_col); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_50))) {
    __pyx_t_49 = PyMethod_GET_SELF(__pyx_t_50);
    if (likely(__pyx_t_49)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_50);
      __Pyx_INCREF(__pyx_t_49);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_50, function);
    }
  }
  __pyx_t_46 = (__pyx_t_49) ? __Pyx_PyObject_Call2Args(__pyx_t_50, __pyx_t_49, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_50, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_49); __pyx_t_49 = 0;
  if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_str); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_extract); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_46))) {
    __pyx_t_50 = PyMethod_GET_SELF(__pyx_t_46);
    if (likely(__pyx_t_50)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_46);
      __Pyx_INCREF(__pyx_t_50);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_46, function);
    }
  }
  __pyx_t_47 = (__pyx_t_50) ? __Pyx_PyObject_Call2Args(__pyx_t_46, __pyx_t_50, __pyx_kp_u_Case_Initiation_Type_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_46, __pyx_kp_u_Case_Initiation_Type_A_Z_s);
  __Pyx_XDECREF(__pyx_t_50); __pyx_t_50 = 0;
  if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = __Pyx_PyObject_GetAttrStr(__pyx_t_47, __pyx_n_s_str); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_47))) {
    __pyx_t_46 = PyMethod_GET_SELF(__pyx_t_47);
    if (likely(__pyx_t_46)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_47);
      __Pyx_INCREF(__pyx_t_46);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_47, function);
    }
  }
  __pyx_t_22 = (__pyx_t_46) ? __Pyx_PyObject_Call2Args(__pyx_t_47, __pyx_t_46, __pyx_n_u_J) : __Pyx_PyObject_CallOneArg(__pyx_t_47, __pyx_n_u_J);
  __Pyx_XDECREF(__pyx_t_46); __pyx_t_46 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_22, __pyx_n_s_str); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = __Pyx_PyObject_GetAttrStr(__pyx_t_47, __pyx_n_s_strip); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_47 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_47)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_47);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
    }
  }
  __pyx_t_48 = (__pyx_t_47) ? __Pyx_PyObject_CallOneArg(__pyx_t_22, __pyx_t_47) : __Pyx_PyObject_CallNoArg(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_47); __pyx_t_47 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
  __pyx_t_22 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_22))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_22);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_22);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_22, function);
    }
  }
  __pyx_t_44 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_22, __pyx_t_48, __pyx_n_u_CaseInitiationType) : __Pyx_PyObject_CallOneArg(__pyx_t_22, __pyx_n_u_CaseInitiationType);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_44)) __PYX_ERR(0, 497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_44);
  __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;

  /* "alacorder/cal.pyx":498
 *           pl.col("AllPagesText").str.extract(r'Previous DUI Convictions: (\d{3})').str.strip().cast(pl.Int64, strict=False).alias("PreviousDUIConvictions"),
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Type: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("CaseInitiationType"),
 *           pl.col("AllPagesText").str.extract(r'Domestic Violence: ([YES|NO])').str.strip().alias("DomesticViolence"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Agency ORI: ([A-Z\s]+)').str.rstrip("C").str.strip().alias("AgencyORI"),
 *           pl.col("AllPagesText").str.extract(r'Driver License N: ([A-Z0-9]+)').str.strip().alias("DLRAW"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_50, __pyx_n_s_pl); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __pyx_t_49 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_col); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_49))) {
    __pyx_t_50 = PyMethod_GET_SELF(__pyx_t_49);
    if (likely(__pyx_t_50)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_49);
      __Pyx_INCREF(__pyx_t_50);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_49, function);
    }
  }
  __pyx_t_46 = (__pyx_t_50) ? __Pyx_PyObject_Call2Args(__pyx_t_49, __pyx_t_50, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_49, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_50); __pyx_t_50 = 0;
  if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_str); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = __Pyx_PyObject_GetAttrStr(__pyx_t_49, __pyx_n_s_extract); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_46))) {
    __pyx_t_49 = PyMethod_GET_SELF(__pyx_t_46);
    if (likely(__pyx_t_49)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_46);
      __Pyx_INCREF(__pyx_t_49);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_46, function);
    }
  }
  __pyx_t_47 = (__pyx_t_49) ? __Pyx_PyObject_Call2Args(__pyx_t_46, __pyx_t_49, __pyx_kp_u_Domestic_Violence_YES_NO) : __Pyx_PyObject_CallOneArg(__pyx_t_46, __pyx_kp_u_Domestic_Violence_YES_NO);
  __Pyx_XDECREF(__pyx_t_49); __pyx_t_49 = 0;
  if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = __Pyx_PyObject_GetAttrStr(__pyx_t_47, __pyx_n_s_str); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_strip); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_47))) {
    __pyx_t_46 = PyMethod_GET_SELF(__pyx_t_47);
    if (likely(__pyx_t_46)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_47);
      __Pyx_INCREF(__pyx_t_46);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_47, function);
    }
  }
  __pyx_t_48 = (__pyx_t_46) ? __Pyx_PyObject_CallOneArg(__pyx_t_47, __pyx_t_46) : __Pyx_PyObject_CallNoArg(__pyx_t_47);
  __Pyx_XDECREF(__pyx_t_46); __pyx_t_46 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;
  __pyx_t_47 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_47))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_47);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_47);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_47, function);
    }
  }
  __pyx_t_22 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_47, __pyx_t_48, __pyx_n_u_DomesticViolence) : __Pyx_PyObject_CallOneArg(__pyx_t_47, __pyx_n_u_DomesticViolence);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_22);
  __Pyx_DECREF(__pyx_t_47); __pyx_t_47 = 0;

  /* "alacorder/cal.pyx":499
 *           pl.col("AllPagesText").str.extract(r'Case Initiation Type: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("CaseInitiationType"),
 *           pl.col("AllPagesText").str.extract(r'Domestic Violence: ([YES|NO])').str.strip().alias("DomesticViolence"),
 *           pl.col("AllPagesText").str.extract(r'Agency ORI: ([A-Z\s]+)').str.rstrip("C").str.strip().alias("AgencyORI"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Driver License N: ([A-Z0-9]+)').str.strip().alias("DLRAW"),
 *           pl.col("AllPagesText").str.extract(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})').alias("SSN"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_51, __pyx_n_s_pl); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __pyx_t_52 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_col); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_52))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_52);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_52);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_52, function);
    }
  }
  __pyx_t_50 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_52, __pyx_t_51, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_52, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_str); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_52, __pyx_n_s_extract); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_50))) {
    __pyx_t_52 = PyMethod_GET_SELF(__pyx_t_50);
    if (likely(__pyx_t_52)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_50);
      __Pyx_INCREF(__pyx_t_52);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_50, function);
    }
  }
  __pyx_t_49 = (__pyx_t_52) ? __Pyx_PyObject_Call2Args(__pyx_t_50, __pyx_t_52, __pyx_kp_u_Agency_ORI_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_50, __pyx_kp_u_Agency_ORI_A_Z_s);
  __Pyx_XDECREF(__pyx_t_52); __pyx_t_52 = 0;
  if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_49, __pyx_n_s_str); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_49))) {
    __pyx_t_50 = PyMethod_GET_SELF(__pyx_t_49);
    if (likely(__pyx_t_50)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_49);
      __Pyx_INCREF(__pyx_t_50);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_49, function);
    }
  }
  __pyx_t_46 = (__pyx_t_50) ? __Pyx_PyObject_Call2Args(__pyx_t_49, __pyx_t_50, __pyx_n_u_C_2) : __Pyx_PyObject_CallOneArg(__pyx_t_49, __pyx_n_u_C_2);
  __Pyx_XDECREF(__pyx_t_50); __pyx_t_50 = 0;
  if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = __Pyx_PyObject_GetAttrStr(__pyx_t_46, __pyx_n_s_str); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = __Pyx_PyObject_GetAttrStr(__pyx_t_49, __pyx_n_s_strip); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_46))) {
    __pyx_t_49 = PyMethod_GET_SELF(__pyx_t_46);
    if (likely(__pyx_t_49)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_46);
      __Pyx_INCREF(__pyx_t_49);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_46, function);
    }
  }
  __pyx_t_48 = (__pyx_t_49) ? __Pyx_PyObject_CallOneArg(__pyx_t_46, __pyx_t_49) : __Pyx_PyObject_CallNoArg(__pyx_t_46);
  __Pyx_XDECREF(__pyx_t_49); __pyx_t_49 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;
  __pyx_t_46 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_46))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_46);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_46);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_46, function);
    }
  }
  __pyx_t_47 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_46, __pyx_t_48, __pyx_n_u_AgencyORI) : __Pyx_PyObject_CallOneArg(__pyx_t_46, __pyx_n_u_AgencyORI);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_47)) __PYX_ERR(0, 499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_47);
  __Pyx_DECREF(__pyx_t_46); __pyx_t_46 = 0;

  /* "alacorder/cal.pyx":500
 *           pl.col("AllPagesText").str.extract(r'Domestic Violence: ([YES|NO])').str.strip().alias("DomesticViolence"),
 *           pl.col("AllPagesText").str.extract(r'Agency ORI: ([A-Z\s]+)').str.rstrip("C").str.strip().alias("AgencyORI"),
 *           pl.col("AllPagesText").str.extract(r'Driver License N: ([A-Z0-9]+)').str.strip().alias("DLRAW"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})').alias("SSN"),
 *           pl.col("AllPagesText").str.extract(r'([A-Z0-9]{11}?) State ID:').alias("SIDRAW"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_52, __pyx_n_s_pl); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_52, __pyx_n_s_col); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_51))) {
    __pyx_t_52 = PyMethod_GET_SELF(__pyx_t_51);
    if (likely(__pyx_t_52)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_51);
      __Pyx_INCREF(__pyx_t_52);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_51, function);
    }
  }
  __pyx_t_50 = (__pyx_t_52) ? __Pyx_PyObject_Call2Args(__pyx_t_51, __pyx_t_52, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_51, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_52); __pyx_t_52 = 0;
  if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_str); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_extract); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_50))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_50);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_50);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_50, function);
    }
  }
  __pyx_t_49 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_50, __pyx_t_51, __pyx_kp_u_Driver_License_N_A_Z0_9) : __Pyx_PyObject_CallOneArg(__pyx_t_50, __pyx_kp_u_Driver_License_N_A_Z0_9);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_49, __pyx_n_s_str); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_strip); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_49))) {
    __pyx_t_50 = PyMethod_GET_SELF(__pyx_t_49);
    if (likely(__pyx_t_50)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_49);
      __Pyx_INCREF(__pyx_t_50);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_49, function);
    }
  }
  __pyx_t_48 = (__pyx_t_50) ? __Pyx_PyObject_CallOneArg(__pyx_t_49, __pyx_t_50) : __Pyx_PyObject_CallNoArg(__pyx_t_49);
  __Pyx_XDECREF(__pyx_t_50); __pyx_t_50 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;
  __pyx_t_49 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_49))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_49);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_49);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_49, function);
    }
  }
  __pyx_t_46 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_49, __pyx_t_48, __pyx_n_u_DLRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_49, __pyx_n_u_DLRAW);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_46)) __PYX_ERR(0, 500, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_46);
  __Pyx_DECREF(__pyx_t_49); __pyx_t_49 = 0;

  /* "alacorder/cal.pyx":501
 *           pl.col("AllPagesText").str.extract(r'Agency ORI: ([A-Z\s]+)').str.rstrip("C").str.strip().alias("AgencyORI"),
 *           pl.col("AllPagesText").str.extract(r'Driver License N: ([A-Z0-9]+)').str.strip().alias("DLRAW"),
 *           pl.col("AllPagesText").str.extract(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})').alias("SSN"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'([A-Z0-9]{11}?) State ID:').alias("SIDRAW"),
 *           pl.col("AllPagesText").str.extract(r'Weight: (\d+)').cast(pl.Int64, strict=False).alias("Weight"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_51, __pyx_n_s_pl); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __pyx_t_52 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_col); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_52))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_52);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_52);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_52, function);
    }
  }
  __pyx_t_50 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_52, __pyx_t_51, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_52, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = __Pyx_PyObject_GetAttrStr(__pyx_t_50, __pyx_n_s_str); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_52, __pyx_n_s_extract); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_50))) {
    __pyx_t_52 = PyMethod_GET_SELF(__pyx_t_50);
    if (likely(__pyx_t_52)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_50);
      __Pyx_INCREF(__pyx_t_52);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_50, function);
    }
  }
  __pyx_t_48 = (__pyx_t_52) ? __Pyx_PyObject_Call2Args(__pyx_t_50, __pyx_t_52, __pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4) : __Pyx_PyObject_CallOneArg(__pyx_t_50, __pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4);
  __Pyx_XDECREF(__pyx_t_52); __pyx_t_52 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;
  __pyx_t_50 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_50))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_50);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_50);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_50, function);
    }
  }
  __pyx_t_49 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_50, __pyx_t_48, __pyx_n_u_SSN) : __Pyx_PyObject_CallOneArg(__pyx_t_50, __pyx_n_u_SSN);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_49)) __PYX_ERR(0, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_49);
  __Pyx_DECREF(__pyx_t_50); __pyx_t_50 = 0;

  /* "alacorder/cal.pyx":502
 *           pl.col("AllPagesText").str.extract(r'Driver License N: ([A-Z0-9]+)').str.strip().alias("DLRAW"),
 *           pl.col("AllPagesText").str.extract(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})').alias("SSN"),
 *           pl.col("AllPagesText").str.extract(r'([A-Z0-9]{11}?) State ID:').alias("SIDRAW"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Weight: (\d+)').cast(pl.Int64, strict=False).alias("Weight"),
 *           pl.col("AllPagesText").str.extract(r"Height : (\d'\d{2})").alias("RAWHEIGHT"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_51, __pyx_n_s_pl); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_col); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_53))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_53);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_53);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_53, function);
    }
  }
  __pyx_t_52 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_53, __pyx_t_51, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_53, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_52, __pyx_n_s_str); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = __Pyx_PyObject_GetAttrStr(__pyx_t_53, __pyx_n_s_extract); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_52))) {
    __pyx_t_53 = PyMethod_GET_SELF(__pyx_t_52);
    if (likely(__pyx_t_53)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_52);
      __Pyx_INCREF(__pyx_t_53);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_52, function);
    }
  }
  __pyx_t_48 = (__pyx_t_53) ? __Pyx_PyObject_Call2Args(__pyx_t_52, __pyx_t_53, __pyx_kp_u_A_Z0_9_11_State_ID) : __Pyx_PyObject_CallOneArg(__pyx_t_52, __pyx_kp_u_A_Z0_9_11_State_ID);
  __Pyx_XDECREF(__pyx_t_53); __pyx_t_53 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;
  __pyx_t_52 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_alias); if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_52))) {
    __pyx_t_48 = PyMethod_GET_SELF(__pyx_t_52);
    if (likely(__pyx_t_48)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_52);
      __Pyx_INCREF(__pyx_t_48);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_52, function);
    }
  }
  __pyx_t_50 = (__pyx_t_48) ? __Pyx_PyObject_Call2Args(__pyx_t_52, __pyx_t_48, __pyx_n_u_SIDRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_52, __pyx_n_u_SIDRAW);
  __Pyx_XDECREF(__pyx_t_48); __pyx_t_48 = 0;
  if (unlikely(!__pyx_t_50)) __PYX_ERR(0, 502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_50);
  __Pyx_DECREF(__pyx_t_52); __pyx_t_52 = 0;

  /* "alacorder/cal.pyx":503
 *           pl.col("AllPagesText").str.extract(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})').alias("SSN"),
 *           pl.col("AllPagesText").str.extract(r'([A-Z0-9]{11}?) State ID:').alias("SIDRAW"),
 *           pl.col("AllPagesText").str.extract(r'Weight: (\d+)').cast(pl.Int64, strict=False).alias("Weight"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r"Height : (\d'\d{2})").alias("RAWHEIGHT"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_51, __pyx_n_s_pl); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __pyx_t_54 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_col); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_54))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_54);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_54);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_54, function);
    }
  }
  __pyx_t_53 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_54, __pyx_t_51, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_54, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_54); __pyx_t_54 = 0;
  __pyx_t_54 = __Pyx_PyObject_GetAttrStr(__pyx_t_53, __pyx_n_s_str); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_54, __pyx_n_s_extract); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_54); __pyx_t_54 = 0;
  __pyx_t_54 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_53))) {
    __pyx_t_54 = PyMethod_GET_SELF(__pyx_t_53);
    if (likely(__pyx_t_54)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_53);
      __Pyx_INCREF(__pyx_t_54);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_53, function);
    }
  }
  __pyx_t_48 = (__pyx_t_54) ? __Pyx_PyObject_Call2Args(__pyx_t_53, __pyx_t_54, __pyx_kp_u_Weight_d) : __Pyx_PyObject_CallOneArg(__pyx_t_53, __pyx_kp_u_Weight_d);
  __Pyx_XDECREF(__pyx_t_54); __pyx_t_54 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_cast); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_48, __pyx_n_s_pl); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __pyx_t_54 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_Int64); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = PyTuple_New(1); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_GIVEREF(__pyx_t_54);
  PyTuple_SET_ITEM(__pyx_t_48, 0, __pyx_t_54);
  __pyx_t_54 = 0;
  __pyx_t_54 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  if (PyDict_SetItem(__pyx_t_54, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
  __pyx_t_51 = __Pyx_PyObject_Call(__pyx_t_53, __pyx_t_48, __pyx_t_54); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __Pyx_DECREF(__pyx_t_54); __pyx_t_54 = 0;
  __pyx_t_54 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_54))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_54);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_54);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_54, function);
    }
  }
  __pyx_t_52 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_54, __pyx_t_51, __pyx_n_u_Weight) : __Pyx_PyObject_CallOneArg(__pyx_t_54, __pyx_n_u_Weight);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_52)) __PYX_ERR(0, 503, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_52);
  __Pyx_DECREF(__pyx_t_54); __pyx_t_54 = 0;

  /* "alacorder/cal.pyx":504
 *           pl.col("AllPagesText").str.extract(r'([A-Z0-9]{11}?) State ID:').alias("SIDRAW"),
 *           pl.col("AllPagesText").str.extract(r'Weight: (\d+)').cast(pl.Int64, strict=False).alias("Weight"),
 *           pl.col("AllPagesText").str.extract(r"Height : (\d'\d{2})").alias("RAWHEIGHT"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_53, __pyx_n_s_pl); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_53, __pyx_n_s_col); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_55))) {
    __pyx_t_53 = PyMethod_GET_SELF(__pyx_t_55);
    if (likely(__pyx_t_53)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_55);
      __Pyx_INCREF(__pyx_t_53);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_55, function);
    }
  }
  __pyx_t_48 = (__pyx_t_53) ? __Pyx_PyObject_Call2Args(__pyx_t_55, __pyx_t_53, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_55, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_53); __pyx_t_53 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_48, __pyx_n_s_str); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_extract); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_48))) {
    __pyx_t_55 = PyMethod_GET_SELF(__pyx_t_48);
    if (likely(__pyx_t_55)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_48);
      __Pyx_INCREF(__pyx_t_55);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_48, function);
    }
  }
  __pyx_t_51 = (__pyx_t_55) ? __Pyx_PyObject_Call2Args(__pyx_t_48, __pyx_t_55, __pyx_kp_u_Height_d_d_2) : __Pyx_PyObject_CallOneArg(__pyx_t_48, __pyx_kp_u_Height_d_d_2);
  __Pyx_XDECREF(__pyx_t_55); __pyx_t_55 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;
  __pyx_t_48 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_48))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_48);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_48);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_48, function);
    }
  }
  __pyx_t_54 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_48, __pyx_t_51, __pyx_n_u_RAWHEIGHT) : __Pyx_PyObject_CallOneArg(__pyx_t_48, __pyx_n_u_RAWHEIGHT);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_54)) __PYX_ERR(0, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_54);
  __Pyx_DECREF(__pyx_t_48); __pyx_t_48 = 0;

  /* "alacorder/cal.pyx":505
 *           pl.col("AllPagesText").str.extract(r'Weight: (\d+)').cast(pl.Int64, strict=False).alias("Weight"),
 *           pl.col("AllPagesText").str.extract(r"Height : (\d'\d{2})").alias("RAWHEIGHT"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_55, __pyx_n_s_pl); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_col); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_53))) {
    __pyx_t_55 = PyMethod_GET_SELF(__pyx_t_53);
    if (likely(__pyx_t_55)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_53);
      __Pyx_INCREF(__pyx_t_55);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_53, function);
    }
  }
  __pyx_t_51 = (__pyx_t_55) ? __Pyx_PyObject_Call2Args(__pyx_t_53, __pyx_t_55, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_53, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_55); __pyx_t_55 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_str); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_53, __pyx_n_s_extract); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  if (PyDict_SetItem(__pyx_t_53, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 505, __pyx_L1_error)
  __pyx_t_55 = __Pyx_PyObject_Call(__pyx_t_51, __pyx_tuple__45, __pyx_t_53); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;
  __pyx_t_53 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_alias); if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_53))) {
    __pyx_t_55 = PyMethod_GET_SELF(__pyx_t_53);
    if (likely(__pyx_t_55)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_53);
      __Pyx_INCREF(__pyx_t_55);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_53, function);
    }
  }
  __pyx_t_48 = (__pyx_t_55) ? __Pyx_PyObject_Call2Args(__pyx_t_53, __pyx_t_55, __pyx_n_u_Eyes) : __Pyx_PyObject_CallOneArg(__pyx_t_53, __pyx_n_u_Eyes);
  __Pyx_XDECREF(__pyx_t_55); __pyx_t_55 = 0;
  if (unlikely(!__pyx_t_48)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_48);
  __Pyx_DECREF(__pyx_t_53); __pyx_t_53 = 0;

  /* "alacorder/cal.pyx":506
 *           pl.col("AllPagesText").str.extract(r"Height : (\d'\d{2})").alias("RAWHEIGHT"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),
 *           pl.col("AllPagesText").str.extract(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:').str.strip().alias("WarrantIssuanceDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_51, __pyx_n_s_pl); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __pyx_t_56 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_col); if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_56);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_56))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_56);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_56);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_56, function);
    }
  }
  __pyx_t_55 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_56, __pyx_t_51, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_56, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_56); __pyx_t_56 = 0;
  __pyx_t_56 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_str); if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_56);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_56, __pyx_n_s_extract); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_56); __pyx_t_56 = 0;
  __pyx_t_56 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_56);
  if (PyDict_SetItem(__pyx_t_56, __pyx_n_s_group_index, __pyx_int_2) < 0) __PYX_ERR(0, 506, __pyx_L1_error)
  __pyx_t_51 = __Pyx_PyObject_Call(__pyx_t_55, __pyx_tuple__45, __pyx_t_56); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __Pyx_DECREF(__pyx_t_56); __pyx_t_56 = 0;
  __pyx_t_56 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_56);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_56))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_56);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_56);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_56, function);
    }
  }
  __pyx_t_53 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_56, __pyx_t_51, __pyx_n_u_Hair) : __Pyx_PyObject_CallOneArg(__pyx_t_56, __pyx_n_u_Hair);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_53)) __PYX_ERR(0, 506, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_53);
  __Pyx_DECREF(__pyx_t_56); __pyx_t_56 = 0;

  /* "alacorder/cal.pyx":507
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:').str.strip().alias("WarrantIssuanceDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("WarrantActionDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_59 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_59))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_59);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_59);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_59, function);
    }
  }
  __pyx_t_57 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_59, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_59, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = __Pyx_PyObject_GetAttrStr(__pyx_t_57, __pyx_n_s_str); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_57); __pyx_t_57 = 0;
  __pyx_t_57 = __Pyx_PyObject_GetAttrStr(__pyx_t_59, __pyx_n_s_extract); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_57))) {
    __pyx_t_59 = PyMethod_GET_SELF(__pyx_t_57);
    if (likely(__pyx_t_59)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_57);
      __Pyx_INCREF(__pyx_t_59);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_57, function);
    }
  }
  __pyx_t_55 = (__pyx_t_59) ? __Pyx_PyObject_Call2Args(__pyx_t_57, __pyx_t_59, __pyx_kp_u_Country_w) : __Pyx_PyObject_CallOneArg(__pyx_t_57, __pyx_kp_u_Country_w);
  __Pyx_XDECREF(__pyx_t_59); __pyx_t_59 = 0;
  if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_57); __pyx_t_57 = 0;
  __pyx_t_57 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_str); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_57, __pyx_n_s_replace); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_57); __pyx_t_57 = 0;
  __pyx_t_57 = __Pyx_PyObject_Call(__pyx_t_55, __pyx_tuple__46, NULL); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_57, __pyx_n_s_str); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_57); __pyx_t_57 = 0;
  __pyx_t_57 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_strip); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_57))) {
    __pyx_t_55 = PyMethod_GET_SELF(__pyx_t_57);
    if (likely(__pyx_t_55)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_57);
      __Pyx_INCREF(__pyx_t_55);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_57, function);
    }
  }
  __pyx_t_51 = (__pyx_t_55) ? __Pyx_PyObject_CallOneArg(__pyx_t_57, __pyx_t_55) : __Pyx_PyObject_CallNoArg(__pyx_t_57);
  __Pyx_XDECREF(__pyx_t_55); __pyx_t_55 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_57); __pyx_t_57 = 0;
  __pyx_t_57 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_57))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_57);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_57);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_57, function);
    }
  }
  __pyx_t_56 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_57, __pyx_t_51, __pyx_n_u_Country) : __Pyx_PyObject_CallOneArg(__pyx_t_57, __pyx_n_u_Country);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_56)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_56);
  __Pyx_DECREF(__pyx_t_57); __pyx_t_57 = 0;

  /* "alacorder/cal.pyx":508
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),
 *           pl.col("AllPagesText").str.extract(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:').str.strip().alias("WarrantIssuanceDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("WarrantActionDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Issuance Status: (\w)').str.strip().alias("WarrantIssuanceStatus"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_60 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_60))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_60);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_60);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_60, function);
    }
  }
  __pyx_t_59 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_60, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_60, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = __Pyx_PyObject_GetAttrStr(__pyx_t_59, __pyx_n_s_str); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = __Pyx_PyObject_GetAttrStr(__pyx_t_60, __pyx_n_s_extract); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_59))) {
    __pyx_t_60 = PyMethod_GET_SELF(__pyx_t_59);
    if (likely(__pyx_t_60)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_59);
      __Pyx_INCREF(__pyx_t_60);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_59, function);
    }
  }
  __pyx_t_55 = (__pyx_t_60) ? __Pyx_PyObject_Call2Args(__pyx_t_59, __pyx_t_60, __pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc) : __Pyx_PyObject_CallOneArg(__pyx_t_59, __pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc);
  __Pyx_XDECREF(__pyx_t_60); __pyx_t_60 = 0;
  if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = __Pyx_PyObject_GetAttrStr(__pyx_t_55, __pyx_n_s_str); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_59, __pyx_n_s_strip); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_55))) {
    __pyx_t_59 = PyMethod_GET_SELF(__pyx_t_55);
    if (likely(__pyx_t_59)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_55);
      __Pyx_INCREF(__pyx_t_59);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_55, function);
    }
  }
  __pyx_t_51 = (__pyx_t_59) ? __Pyx_PyObject_CallOneArg(__pyx_t_55, __pyx_t_59) : __Pyx_PyObject_CallNoArg(__pyx_t_55);
  __Pyx_XDECREF(__pyx_t_59); __pyx_t_59 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;
  __pyx_t_55 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_55))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_55);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_55);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_55, function);
    }
  }
  __pyx_t_57 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_55, __pyx_t_51, __pyx_n_u_WarrantIssuanceDate) : __Pyx_PyObject_CallOneArg(__pyx_t_55, __pyx_n_u_WarrantIssuanceDate);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_57)) __PYX_ERR(0, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_57);
  __Pyx_DECREF(__pyx_t_55); __pyx_t_55 = 0;

  /* "alacorder/cal.pyx":509
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),
 *           pl.col("AllPagesText").str.extract(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:').str.strip().alias("WarrantIssuanceDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("WarrantActionDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Warrant Issuance Status: (\w)').str.strip().alias("WarrantIssuanceStatus"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Status: (\w)').str.strip().alias("WarrantActionStatus"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_61 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_61))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_61);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_61);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_61, function);
    }
  }
  __pyx_t_60 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_61, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_61, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = __Pyx_PyObject_GetAttrStr(__pyx_t_60, __pyx_n_s_str); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = __Pyx_PyObject_GetAttrStr(__pyx_t_61, __pyx_n_s_extract); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_60))) {
    __pyx_t_61 = PyMethod_GET_SELF(__pyx_t_60);
    if (likely(__pyx_t_61)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_60);
      __Pyx_INCREF(__pyx_t_61);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_60, function);
    }
  }
  __pyx_t_59 = (__pyx_t_61) ? __Pyx_PyObject_Call2Args(__pyx_t_60, __pyx_t_61, __pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_60, __pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_61); __pyx_t_61 = 0;
  if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = __Pyx_PyObject_GetAttrStr(__pyx_t_59, __pyx_n_s_str); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = __Pyx_PyObject_GetAttrStr(__pyx_t_60, __pyx_n_s_strip); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_59))) {
    __pyx_t_60 = PyMethod_GET_SELF(__pyx_t_59);
    if (likely(__pyx_t_60)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_59);
      __Pyx_INCREF(__pyx_t_60);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_59, function);
    }
  }
  __pyx_t_51 = (__pyx_t_60) ? __Pyx_PyObject_CallOneArg(__pyx_t_59, __pyx_t_60) : __Pyx_PyObject_CallNoArg(__pyx_t_59);
  __Pyx_XDECREF(__pyx_t_60); __pyx_t_60 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;
  __pyx_t_59 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_59))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_59);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_59);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_59, function);
    }
  }
  __pyx_t_55 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_59, __pyx_t_51, __pyx_n_u_WarrantActionDate) : __Pyx_PyObject_CallOneArg(__pyx_t_59, __pyx_n_u_WarrantActionDate);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_55)) __PYX_ERR(0, 509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_55);
  __Pyx_DECREF(__pyx_t_59); __pyx_t_59 = 0;

  /* "alacorder/cal.pyx":510
 *           pl.col("AllPagesText").str.extract(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:').str.strip().alias("WarrantIssuanceDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("WarrantActionDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Issuance Status: (\w)').str.strip().alias("WarrantIssuanceStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Status: (\w)').str.strip().alias("WarrantActionStatus"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Location Status: (\w)').str.strip().alias("WarrantLocationStatus"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_62 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_62))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_62);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_62);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_62, function);
    }
  }
  __pyx_t_61 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_62, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_62, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = __Pyx_PyObject_GetAttrStr(__pyx_t_61, __pyx_n_s_str); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = __Pyx_PyObject_GetAttrStr(__pyx_t_62, __pyx_n_s_extract); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_61))) {
    __pyx_t_62 = PyMethod_GET_SELF(__pyx_t_61);
    if (likely(__pyx_t_62)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_61);
      __Pyx_INCREF(__pyx_t_62);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_61, function);
    }
  }
  __pyx_t_60 = (__pyx_t_62) ? __Pyx_PyObject_Call2Args(__pyx_t_61, __pyx_t_62, __pyx_kp_u_Warrant_Issuance_Status_w) : __Pyx_PyObject_CallOneArg(__pyx_t_61, __pyx_kp_u_Warrant_Issuance_Status_w);
  __Pyx_XDECREF(__pyx_t_62); __pyx_t_62 = 0;
  if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = __Pyx_PyObject_GetAttrStr(__pyx_t_60, __pyx_n_s_str); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = __Pyx_PyObject_GetAttrStr(__pyx_t_61, __pyx_n_s_strip); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_60))) {
    __pyx_t_61 = PyMethod_GET_SELF(__pyx_t_60);
    if (likely(__pyx_t_61)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_60);
      __Pyx_INCREF(__pyx_t_61);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_60, function);
    }
  }
  __pyx_t_51 = (__pyx_t_61) ? __Pyx_PyObject_CallOneArg(__pyx_t_60, __pyx_t_61) : __Pyx_PyObject_CallNoArg(__pyx_t_60);
  __Pyx_XDECREF(__pyx_t_61); __pyx_t_61 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;
  __pyx_t_60 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_60))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_60);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_60);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_60, function);
    }
  }
  __pyx_t_59 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_60, __pyx_t_51, __pyx_n_u_WarrantIssuanceStatus) : __Pyx_PyObject_CallOneArg(__pyx_t_60, __pyx_n_u_WarrantIssuanceStatus);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_59)) __PYX_ERR(0, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_59);
  __Pyx_DECREF(__pyx_t_60); __pyx_t_60 = 0;

  /* "alacorder/cal.pyx":511
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("WarrantActionDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Issuance Status: (\w)').str.strip().alias("WarrantIssuanceStatus"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Status: (\w)').str.strip().alias("WarrantActionStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Warrant Location Status: (\w)').str.strip().alias("WarrantLocationStatus"),
 *           pl.col("AllPagesText").str.extract(r'Number Of Warrants: (\d{3}\s\d{3})').str.strip().alias("NumberOfWarrants"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_63 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_63))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_63);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_63);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_63, function);
    }
  }
  __pyx_t_62 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_63, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_63, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = __Pyx_PyObject_GetAttrStr(__pyx_t_62, __pyx_n_s_str); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = __Pyx_PyObject_GetAttrStr(__pyx_t_63, __pyx_n_s_extract); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_62))) {
    __pyx_t_63 = PyMethod_GET_SELF(__pyx_t_62);
    if (likely(__pyx_t_63)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_62);
      __Pyx_INCREF(__pyx_t_63);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_62, function);
    }
  }
  __pyx_t_61 = (__pyx_t_63) ? __Pyx_PyObject_Call2Args(__pyx_t_62, __pyx_t_63, __pyx_kp_u_Warrant_Action_Status_w) : __Pyx_PyObject_CallOneArg(__pyx_t_62, __pyx_kp_u_Warrant_Action_Status_w);
  __Pyx_XDECREF(__pyx_t_63); __pyx_t_63 = 0;
  if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = __Pyx_PyObject_GetAttrStr(__pyx_t_61, __pyx_n_s_str); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = __Pyx_PyObject_GetAttrStr(__pyx_t_62, __pyx_n_s_strip); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_61))) {
    __pyx_t_62 = PyMethod_GET_SELF(__pyx_t_61);
    if (likely(__pyx_t_62)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_61);
      __Pyx_INCREF(__pyx_t_62);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_61, function);
    }
  }
  __pyx_t_51 = (__pyx_t_62) ? __Pyx_PyObject_CallOneArg(__pyx_t_61, __pyx_t_62) : __Pyx_PyObject_CallNoArg(__pyx_t_61);
  __Pyx_XDECREF(__pyx_t_62); __pyx_t_62 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;
  __pyx_t_61 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_61))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_61);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_61);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_61, function);
    }
  }
  __pyx_t_60 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_61, __pyx_t_51, __pyx_n_u_WarrantActionStatus) : __Pyx_PyObject_CallOneArg(__pyx_t_61, __pyx_n_u_WarrantActionStatus);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_60)) __PYX_ERR(0, 511, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_60);
  __Pyx_DECREF(__pyx_t_61); __pyx_t_61 = 0;

  /* "alacorder/cal.pyx":512
 *           pl.col("AllPagesText").str.extract(r'Warrant Issuance Status: (\w)').str.strip().alias("WarrantIssuanceStatus"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Status: (\w)').str.strip().alias("WarrantActionStatus"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Location Status: (\w)').str.strip().alias("WarrantLocationStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Number Of Warrants: (\d{3}\s\d{3})').str.strip().alias("NumberOfWarrants"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type: (\w)').str.strip().alias("BondType"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_64))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_64);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_64);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_64, function);
    }
  }
  __pyx_t_63 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_64, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_64, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_63, __pyx_n_s_str); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = __Pyx_PyObject_GetAttrStr(__pyx_t_64, __pyx_n_s_extract); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_63))) {
    __pyx_t_64 = PyMethod_GET_SELF(__pyx_t_63);
    if (likely(__pyx_t_64)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_63);
      __Pyx_INCREF(__pyx_t_64);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_63, function);
    }
  }
  __pyx_t_62 = (__pyx_t_64) ? __Pyx_PyObject_Call2Args(__pyx_t_63, __pyx_t_64, __pyx_kp_u_Warrant_Location_Status_w) : __Pyx_PyObject_CallOneArg(__pyx_t_63, __pyx_kp_u_Warrant_Location_Status_w);
  __Pyx_XDECREF(__pyx_t_64); __pyx_t_64 = 0;
  if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = __Pyx_PyObject_GetAttrStr(__pyx_t_62, __pyx_n_s_str); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = __Pyx_PyObject_GetAttrStr(__pyx_t_63, __pyx_n_s_strip); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_62))) {
    __pyx_t_63 = PyMethod_GET_SELF(__pyx_t_62);
    if (likely(__pyx_t_63)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_62);
      __Pyx_INCREF(__pyx_t_63);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_62, function);
    }
  }
  __pyx_t_51 = (__pyx_t_63) ? __Pyx_PyObject_CallOneArg(__pyx_t_62, __pyx_t_63) : __Pyx_PyObject_CallNoArg(__pyx_t_62);
  __Pyx_XDECREF(__pyx_t_63); __pyx_t_63 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;
  __pyx_t_62 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_62))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_62);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_62);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_62, function);
    }
  }
  __pyx_t_61 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_62, __pyx_t_51, __pyx_n_u_WarrantLocationStatus) : __Pyx_PyObject_CallOneArg(__pyx_t_62, __pyx_n_u_WarrantLocationStatus);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_61)) __PYX_ERR(0, 512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_61);
  __Pyx_DECREF(__pyx_t_62); __pyx_t_62 = 0;

  /* "alacorder/cal.pyx":513
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Status: (\w)').str.strip().alias("WarrantActionStatus"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Location Status: (\w)').str.strip().alias("WarrantLocationStatus"),
 *           pl.col("AllPagesText").str.extract(r'Number Of Warrants: (\d{3}\s\d{3})').str.strip().alias("NumberOfWarrants"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Bond Type: (\w)').str.strip().alias("BondType"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type Desc: ([A-Z\s]+)').str.strip().alias("BondTypeDesc"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_65 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_65))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_65);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_65);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_65, function);
    }
  }
  __pyx_t_64 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_65, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_65, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = __Pyx_PyObject_GetAttrStr(__pyx_t_64, __pyx_n_s_str); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_65, __pyx_n_s_extract); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_64))) {
    __pyx_t_65 = PyMethod_GET_SELF(__pyx_t_64);
    if (likely(__pyx_t_65)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_64);
      __Pyx_INCREF(__pyx_t_65);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_64, function);
    }
  }
  __pyx_t_63 = (__pyx_t_65) ? __Pyx_PyObject_Call2Args(__pyx_t_64, __pyx_t_65, __pyx_kp_u_Number_Of_Warrants_d_3_s_d_3) : __Pyx_PyObject_CallOneArg(__pyx_t_64, __pyx_kp_u_Number_Of_Warrants_d_3_s_d_3);
  __Pyx_XDECREF(__pyx_t_65); __pyx_t_65 = 0;
  if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_63, __pyx_n_s_str); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = __Pyx_PyObject_GetAttrStr(__pyx_t_64, __pyx_n_s_strip); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_63))) {
    __pyx_t_64 = PyMethod_GET_SELF(__pyx_t_63);
    if (likely(__pyx_t_64)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_63);
      __Pyx_INCREF(__pyx_t_64);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_63, function);
    }
  }
  __pyx_t_51 = (__pyx_t_64) ? __Pyx_PyObject_CallOneArg(__pyx_t_63, __pyx_t_64) : __Pyx_PyObject_CallNoArg(__pyx_t_63);
  __Pyx_XDECREF(__pyx_t_64); __pyx_t_64 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;
  __pyx_t_63 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_63))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_63);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_63);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_63, function);
    }
  }
  __pyx_t_62 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_63, __pyx_t_51, __pyx_n_u_NumberOfWarrants) : __Pyx_PyObject_CallOneArg(__pyx_t_63, __pyx_n_u_NumberOfWarrants);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_62)) __PYX_ERR(0, 513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_62);
  __Pyx_DECREF(__pyx_t_63); __pyx_t_63 = 0;

  /* "alacorder/cal.pyx":514
 *           pl.col("AllPagesText").str.extract(r'Warrant Location Status: (\w)').str.strip().alias("WarrantLocationStatus"),
 *           pl.col("AllPagesText").str.extract(r'Number Of Warrants: (\d{3}\s\d{3})').str.strip().alias("NumberOfWarrants"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type: (\w)').str.strip().alias("BondType"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Bond Type Desc: ([A-Z\s]+)').str.strip().alias("BondTypeDesc"),
 *           pl.col("AllPagesText").str.extract(r'([\d\.]+) Bond Amount:').str.replace_all(r'[^0-9\.\s]','').cast(pl.Float64,strict=False).alias("BondAmt"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_66))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_66);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_66);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_66, function);
    }
  }
  __pyx_t_65 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_66, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_66, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_65, __pyx_n_s_str); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_extract); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_65))) {
    __pyx_t_66 = PyMethod_GET_SELF(__pyx_t_65);
    if (likely(__pyx_t_66)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_65);
      __Pyx_INCREF(__pyx_t_66);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_65, function);
    }
  }
  __pyx_t_64 = (__pyx_t_66) ? __Pyx_PyObject_Call2Args(__pyx_t_65, __pyx_t_66, __pyx_kp_u_Bond_Type_w) : __Pyx_PyObject_CallOneArg(__pyx_t_65, __pyx_kp_u_Bond_Type_w);
  __Pyx_XDECREF(__pyx_t_66); __pyx_t_66 = 0;
  if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = __Pyx_PyObject_GetAttrStr(__pyx_t_64, __pyx_n_s_str); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_65, __pyx_n_s_strip); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_64))) {
    __pyx_t_65 = PyMethod_GET_SELF(__pyx_t_64);
    if (likely(__pyx_t_65)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_64);
      __Pyx_INCREF(__pyx_t_65);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_64, function);
    }
  }
  __pyx_t_51 = (__pyx_t_65) ? __Pyx_PyObject_CallOneArg(__pyx_t_64, __pyx_t_65) : __Pyx_PyObject_CallNoArg(__pyx_t_64);
  __Pyx_XDECREF(__pyx_t_65); __pyx_t_65 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_64))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_64);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_64);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_64, function);
    }
  }
  __pyx_t_63 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_64, __pyx_t_51, __pyx_n_u_BondType) : __Pyx_PyObject_CallOneArg(__pyx_t_64, __pyx_n_u_BondType);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_63)) __PYX_ERR(0, 514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_63);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;

  /* "alacorder/cal.pyx":515
 *           pl.col("AllPagesText").str.extract(r'Number Of Warrants: (\d{3}\s\d{3})').str.strip().alias("NumberOfWarrants"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type: (\w)').str.strip().alias("BondType"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type Desc: ([A-Z\s]+)').str.strip().alias("BondTypeDesc"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'([\d\.]+) Bond Amount:').str.replace_all(r'[^0-9\.\s]','').cast(pl.Float64,strict=False).alias("BondAmt"),
 *           pl.col("AllPagesText").str.extract(r'Bond Company: ([A-Z0-9]+)').str.rstrip("S").str.strip().alias("BondCompany"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_58, __pyx_n_s_pl); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __pyx_t_67 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_col); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_67))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_67);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_67);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_67, function);
    }
  }
  __pyx_t_66 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_67, __pyx_t_58, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_67, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_str); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_extract); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_66))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_66);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_66);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_66, function);
    }
  }
  __pyx_t_65 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_66, __pyx_t_67, __pyx_kp_u_Bond_Type_Desc_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_66, __pyx_kp_u_Bond_Type_Desc_A_Z_s);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_65, __pyx_n_s_str); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_strip); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_65))) {
    __pyx_t_66 = PyMethod_GET_SELF(__pyx_t_65);
    if (likely(__pyx_t_66)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_65);
      __Pyx_INCREF(__pyx_t_66);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_65, function);
    }
  }
  __pyx_t_51 = (__pyx_t_66) ? __Pyx_PyObject_CallOneArg(__pyx_t_65, __pyx_t_66) : __Pyx_PyObject_CallNoArg(__pyx_t_65);
  __Pyx_XDECREF(__pyx_t_66); __pyx_t_66 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;
  __pyx_t_65 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_alias); if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_65))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_65);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_65);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_65, function);
    }
  }
  __pyx_t_64 = (__pyx_t_51) ? __Pyx_PyObject_Call2Args(__pyx_t_65, __pyx_t_51, __pyx_n_u_BondTypeDesc) : __Pyx_PyObject_CallOneArg(__pyx_t_65, __pyx_n_u_BondTypeDesc);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 515, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_65); __pyx_t_65 = 0;

  /* "alacorder/cal.pyx":516
 *           pl.col("AllPagesText").str.extract(r'Bond Type: (\w)').str.strip().alias("BondType"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type Desc: ([A-Z\s]+)').str.strip().alias("BondTypeDesc"),
 *           pl.col("AllPagesText").str.extract(r'([\d\.]+) Bond Amount:').str.replace_all(r'[^0-9\.\s]','').cast(pl.Float64,strict=False).alias("BondAmt"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Bond Company: ([A-Z0-9]+)').str.rstrip("S").str.strip().alias("BondCompany"),
 *           pl.col("AllPagesText").str.extract(r'Surety Code: ([A-Z0-9]{4})').str.strip().alias("SuretyCode"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_58 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_58))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_58);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_58);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_58, function);
    }
  }
  __pyx_t_66 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_58, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_58, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_str); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_58, __pyx_n_s_extract); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_66))) {
    __pyx_t_58 = PyMethod_GET_SELF(__pyx_t_66);
    if (likely(__pyx_t_58)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_66);
      __Pyx_INCREF(__pyx_t_58);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_66, function);
    }
  }
  __pyx_t_51 = (__pyx_t_58) ? __Pyx_PyObject_Call2Args(__pyx_t_66, __pyx_t_58, __pyx_kp_u_d_Bond_Amount) : __Pyx_PyObject_CallOneArg(__pyx_t_66, __pyx_kp_u_d_Bond_Amount);
  __Pyx_XDECREF(__pyx_t_58); __pyx_t_58 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_str); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_Call(__pyx_t_51, __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_cast); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_66, __pyx_n_s_pl); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __pyx_t_58 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_Float64); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = PyTuple_New(1); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_GIVEREF(__pyx_t_58);
  PyTuple_SET_ITEM(__pyx_t_66, 0, __pyx_t_58);
  __pyx_t_58 = 0;
  __pyx_t_58 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  if (PyDict_SetItem(__pyx_t_58, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 516, __pyx_L1_error)
  __pyx_t_67 = __Pyx_PyObject_Call(__pyx_t_51, __pyx_t_66, __pyx_t_58); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;
  __pyx_t_58 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_58))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_58);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_58);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_58, function);
    }
  }
  __pyx_t_65 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_58, __pyx_t_67, __pyx_n_u_BondAmt) : __Pyx_PyObject_CallOneArg(__pyx_t_58, __pyx_n_u_BondAmt);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_65)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_65);
  __Pyx_DECREF(__pyx_t_58); __pyx_t_58 = 0;

  /* "alacorder/cal.pyx":517
 *           pl.col("AllPagesText").str.extract(r'Bond Type Desc: ([A-Z\s]+)').str.strip().alias("BondTypeDesc"),
 *           pl.col("AllPagesText").str.extract(r'([\d\.]+) Bond Amount:').str.replace_all(r'[^0-9\.\s]','').cast(pl.Float64,strict=False).alias("BondAmt"),
 *           pl.col("AllPagesText").str.extract(r'Bond Company: ([A-Z0-9]+)').str.rstrip("S").str.strip().alias("BondCompany"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Surety Code: ([A-Z0-9]{4})').str.strip().alias("SuretyCode"),
 *           pl.col("AllPagesText").str.extract(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("BondReleaseDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_69, __pyx_n_s_pl); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_col); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_69 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_69)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_69);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_68 = (__pyx_t_69) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_69, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_69); __pyx_t_69 = 0;
  if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_68, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_extract); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_68))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_68);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_68);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_68, function);
    }
  }
  __pyx_t_51 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_68, __pyx_t_70, __pyx_kp_u_Bond_Company_A_Z0_9) : __Pyx_PyObject_CallOneArg(__pyx_t_68, __pyx_kp_u_Bond_Company_A_Z0_9);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_str); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_68, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_51))) {
    __pyx_t_68 = PyMethod_GET_SELF(__pyx_t_51);
    if (likely(__pyx_t_68)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_51);
      __Pyx_INCREF(__pyx_t_68);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_51, function);
    }
  }
  __pyx_t_66 = (__pyx_t_68) ? __Pyx_PyObject_Call2Args(__pyx_t_51, __pyx_t_68, __pyx_n_u_S) : __Pyx_PyObject_CallOneArg(__pyx_t_51, __pyx_n_u_S);
  __Pyx_XDECREF(__pyx_t_68); __pyx_t_68 = 0;
  if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_66, __pyx_n_s_str); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_strip); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_66))) {
    __pyx_t_51 = PyMethod_GET_SELF(__pyx_t_66);
    if (likely(__pyx_t_51)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_66);
      __Pyx_INCREF(__pyx_t_51);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_66, function);
    }
  }
  __pyx_t_67 = (__pyx_t_51) ? __Pyx_PyObject_CallOneArg(__pyx_t_66, __pyx_t_51) : __Pyx_PyObject_CallNoArg(__pyx_t_66);
  __Pyx_XDECREF(__pyx_t_51); __pyx_t_51 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;
  __pyx_t_66 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_66))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_66);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_66);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_66, function);
    }
  }
  __pyx_t_58 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_66, __pyx_t_67, __pyx_n_u_BondCompany) : __Pyx_PyObject_CallOneArg(__pyx_t_66, __pyx_n_u_BondCompany);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_58)) __PYX_ERR(0, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_58);
  __Pyx_DECREF(__pyx_t_66); __pyx_t_66 = 0;

  /* "alacorder/cal.pyx":518
 *           pl.col("AllPagesText").str.extract(r'([\d\.]+) Bond Amount:').str.replace_all(r'[^0-9\.\s]','').cast(pl.Float64,strict=False).alias("BondAmt"),
 *           pl.col("AllPagesText").str.extract(r'Bond Company: ([A-Z0-9]+)').str.rstrip("S").str.strip().alias("BondCompany"),
 *           pl.col("AllPagesText").str.extract(r'Surety Code: ([A-Z0-9]{4})').str.strip().alias("SuretyCode"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("BondReleaseDate"),
 *           pl.col("AllPagesText").str.extract(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("FailedToAppearDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_69))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_69);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_69);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_69, function);
    }
  }
  __pyx_t_68 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_69, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_69, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_68, __pyx_n_s_str); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_extract); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_68))) {
    __pyx_t_69 = PyMethod_GET_SELF(__pyx_t_68);
    if (likely(__pyx_t_69)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_68);
      __Pyx_INCREF(__pyx_t_69);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_68, function);
    }
  }
  __pyx_t_51 = (__pyx_t_69) ? __Pyx_PyObject_Call2Args(__pyx_t_68, __pyx_t_69, __pyx_kp_u_Surety_Code_A_Z0_9_4) : __Pyx_PyObject_CallOneArg(__pyx_t_68, __pyx_kp_u_Surety_Code_A_Z0_9_4);
  __Pyx_XDECREF(__pyx_t_69); __pyx_t_69 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_51, __pyx_n_s_str); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_68, __pyx_n_s_strip); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_51))) {
    __pyx_t_68 = PyMethod_GET_SELF(__pyx_t_51);
    if (likely(__pyx_t_68)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_51);
      __Pyx_INCREF(__pyx_t_68);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_51, function);
    }
  }
  __pyx_t_67 = (__pyx_t_68) ? __Pyx_PyObject_CallOneArg(__pyx_t_51, __pyx_t_68) : __Pyx_PyObject_CallNoArg(__pyx_t_51);
  __Pyx_XDECREF(__pyx_t_68); __pyx_t_68 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;
  __pyx_t_51 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_51))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_51);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_51);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_51, function);
    }
  }
  __pyx_t_66 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_51, __pyx_t_67, __pyx_n_u_SuretyCode) : __Pyx_PyObject_CallOneArg(__pyx_t_51, __pyx_n_u_SuretyCode);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_66)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_66);
  __Pyx_DECREF(__pyx_t_51); __pyx_t_51 = 0;

  /* "alacorder/cal.pyx":519
 *           pl.col("AllPagesText").str.extract(r'Bond Company: ([A-Z0-9]+)').str.rstrip("S").str.strip().alias("BondCompany"),
 *           pl.col("AllPagesText").str.extract(r'Surety Code: ([A-Z0-9]{4})').str.strip().alias("SuretyCode"),
 *           pl.col("AllPagesText").str.extract(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("BondReleaseDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("FailedToAppearDate"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:').str.strip().alias("BondsmanProcessIssuance"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_69 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_str); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_extract); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_69))) {
    __pyx_t_71 = PyMethod_GET_SELF(__pyx_t_69);
    if (likely(__pyx_t_71)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_69);
      __Pyx_INCREF(__pyx_t_71);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_69, function);
    }
  }
  __pyx_t_68 = (__pyx_t_71) ? __Pyx_PyObject_Call2Args(__pyx_t_69, __pyx_t_71, __pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_69, __pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_71); __pyx_t_71 = 0;
  if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_68, __pyx_n_s_str); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_strip); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_68))) {
    __pyx_t_69 = PyMethod_GET_SELF(__pyx_t_68);
    if (likely(__pyx_t_69)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_68);
      __Pyx_INCREF(__pyx_t_69);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_68, function);
    }
  }
  __pyx_t_67 = (__pyx_t_69) ? __Pyx_PyObject_CallOneArg(__pyx_t_68, __pyx_t_69) : __Pyx_PyObject_CallNoArg(__pyx_t_68);
  __Pyx_XDECREF(__pyx_t_69); __pyx_t_69 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_68))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_68);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_68);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_68, function);
    }
  }
  __pyx_t_51 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_68, __pyx_t_67, __pyx_n_u_BondReleaseDate) : __Pyx_PyObject_CallOneArg(__pyx_t_68, __pyx_n_u_BondReleaseDate);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_51)) __PYX_ERR(0, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_51);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;

  /* "alacorder/cal.pyx":520
 *           pl.col("AllPagesText").str.extract(r'Surety Code: ([A-Z0-9]{4})').str.strip().alias("SuretyCode"),
 *           pl.col("AllPagesText").str.extract(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("BondReleaseDate"),
 *           pl.col("AllPagesText").str.extract(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("FailedToAppearDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:').str.strip().alias("BondsmanProcessIssuance"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Return: (.*?) Number of Subponeas').str.strip().alias("BondsmanProcessReturn"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_71 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_72, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_str); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_extract); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_72 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_72)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_72);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_69 = (__pyx_t_72) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_72, __pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_72); __pyx_t_72 = 0;
  if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_str); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_strip); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_69))) {
    __pyx_t_71 = PyMethod_GET_SELF(__pyx_t_69);
    if (likely(__pyx_t_71)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_69);
      __Pyx_INCREF(__pyx_t_71);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_69, function);
    }
  }
  __pyx_t_67 = (__pyx_t_71) ? __Pyx_PyObject_CallOneArg(__pyx_t_69, __pyx_t_71) : __Pyx_PyObject_CallNoArg(__pyx_t_69);
  __Pyx_XDECREF(__pyx_t_71); __pyx_t_71 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_69))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_69);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_69);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_69, function);
    }
  }
  __pyx_t_68 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_69, __pyx_t_67, __pyx_n_u_FailedToAppearDate) : __Pyx_PyObject_CallOneArg(__pyx_t_69, __pyx_n_u_FailedToAppearDate);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;

  /* "alacorder/cal.pyx":521
 *           pl.col("AllPagesText").str.extract(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("BondReleaseDate"),
 *           pl.col("AllPagesText").str.extract(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("FailedToAppearDate"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:').str.strip().alias("BondsmanProcessIssuance"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Return: (.*?) Number of Subponeas').str.strip().alias("BondsmanProcessReturn"),
 *           pl.col("AllPagesText").str.extract(r'([\n\s/\d]*?) Appeal Court:').str.replace_all(r'[\n\s]','').str.strip().alias("AppealDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_72 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_str); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_extract); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_71 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_72, __pyx_t_73, __pyx_kp_u_Bondsman_Process_Issuance_n_Bond) : __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_kp_u_Bondsman_Process_Issuance_n_Bond);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_str); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_strip); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_72 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_72)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_72);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_67 = (__pyx_t_72) ? __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_t_72) : __Pyx_PyObject_CallNoArg(__pyx_t_71);
  __Pyx_XDECREF(__pyx_t_72); __pyx_t_72 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_69 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_67, __pyx_n_u_BondsmanProcessIssuance) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_n_u_BondsmanProcessIssuance);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;

  /* "alacorder/cal.pyx":522
 *           pl.col("AllPagesText").str.extract(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("FailedToAppearDate"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:').str.strip().alias("BondsmanProcessIssuance"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Return: (.*?) Number of Subponeas').str.strip().alias("BondsmanProcessReturn"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'([\n\s/\d]*?) Appeal Court:').str.replace_all(r'[\n\s]','').str.strip().alias("AppealDate"),
 *           pl.col("AllPagesText").str.extract(r'([A-Z\-\s]+) Appeal Case Number').str.strip().alias("AppealCourt"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_73 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_extract); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_74 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_74)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_74);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_72 = (__pyx_t_74) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_74, __pyx_kp_u_Bondsman_Process_Return_Number_o) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_kp_u_Bondsman_Process_Return_Number_o);
  __Pyx_XDECREF(__pyx_t_74); __pyx_t_74 = 0;
  if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_str); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_strip); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_67 = (__pyx_t_73) ? __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_t_73) : __Pyx_PyObject_CallNoArg(__pyx_t_72);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_71 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_72, __pyx_t_67, __pyx_n_u_BondsmanProcessReturn) : __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_n_u_BondsmanProcessReturn);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;

  /* "alacorder/cal.pyx":523
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:').str.strip().alias("BondsmanProcessIssuance"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Return: (.*?) Number of Subponeas').str.strip().alias("BondsmanProcessReturn"),
 *           pl.col("AllPagesText").str.extract(r'([\n\s/\d]*?) Appeal Court:').str.replace_all(r'[\n\s]','').str.strip().alias("AppealDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'([A-Z\-\s]+) Appeal Case Number').str.strip().alias("AppealCourt"),
 *           pl.col("AllPagesText").str.extract(r'Orgin Of Appeal: ([A-Z\-\s]+)').str.rstrip("L").str.strip().alias("OriginOfAppeal"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_74 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_str); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_extract); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_75 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_75)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_75);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_73 = (__pyx_t_75) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_75, __pyx_kp_u_n_s_d_Appeal_Court) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_kp_u_n_s_d_Appeal_Court);
  __Pyx_XDECREF(__pyx_t_75); __pyx_t_75 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_Call(__pyx_t_73, __pyx_tuple__48, NULL); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_str); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_strip); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_67 = (__pyx_t_73) ? __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_t_73) : __Pyx_PyObject_CallNoArg(__pyx_t_74);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_72 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_67, __pyx_n_u_AppealDate) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_n_u_AppealDate);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;

  /* "alacorder/cal.pyx":524
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Return: (.*?) Number of Subponeas').str.strip().alias("BondsmanProcessReturn"),
 *           pl.col("AllPagesText").str.extract(r'([\n\s/\d]*?) Appeal Court:').str.replace_all(r'[\n\s]','').str.strip().alias("AppealDate"),
 *           pl.col("AllPagesText").str.extract(r'([A-Z\-\s]+) Appeal Case Number').str.strip().alias("AppealCourt"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Orgin Of Appeal: ([A-Z\-\s]+)').str.rstrip("L").str.strip().alias("OriginOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To Desc: ([A-Z\-\s]+)').str.rstrip("D").str.rstrip("T").str.strip().alias("AppealToDesc"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_70, __pyx_n_s_pl); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_col); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_75 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_70, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_str); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_extract); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_73 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_76, __pyx_kp_u_A_Z_s_Appeal_Case_Number) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_kp_u_A_Z_s_Appeal_Case_Number);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_strip); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_75 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_75)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_75);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_67 = (__pyx_t_75) ? __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_t_75) : __Pyx_PyObject_CallNoArg(__pyx_t_73);
  __Pyx_XDECREF(__pyx_t_75); __pyx_t_75 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_74 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_67, __pyx_n_u_AppealCourt) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_AppealCourt);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 524, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;

  /* "alacorder/cal.pyx":525
 *           pl.col("AllPagesText").str.extract(r'([\n\s/\d]*?) Appeal Court:').str.replace_all(r'[\n\s]','').str.strip().alias("AppealDate"),
 *           pl.col("AllPagesText").str.extract(r'([A-Z\-\s]+) Appeal Case Number').str.strip().alias("AppealCourt"),
 *           pl.col("AllPagesText").str.extract(r'Orgin Of Appeal: ([A-Z\-\s]+)').str.rstrip("L").str.strip().alias("OriginOfAppeal"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Appeal To Desc: ([A-Z\-\s]+)').str.rstrip("D").str.rstrip("T").str.strip().alias("AppealToDesc"),
 *           pl.col("AllPagesText").str.extract(r'Appeal Status: ([A-Z\-\s]+)').str.rstrip("A").str.strip().alias("AppealStatus"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_77, __pyx_n_s_pl); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_col); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_70 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_77, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_str); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_extract); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_76 = (__pyx_t_78) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_78, __pyx_kp_u_Orgin_Of_Appeal_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_kp_u_Orgin_Of_Appeal_A_Z_s);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_75 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_70, __pyx_n_u_L) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_L);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_str); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_strip); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_67 = (__pyx_t_76) ? __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_t_76) : __Pyx_PyObject_CallNoArg(__pyx_t_75);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_73 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_67, __pyx_n_u_OriginOfAppeal) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_n_u_OriginOfAppeal);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;

  /* "alacorder/cal.pyx":526
 *           pl.col("AllPagesText").str.extract(r'([A-Z\-\s]+) Appeal Case Number').str.strip().alias("AppealCourt"),
 *           pl.col("AllPagesText").str.extract(r'Orgin Of Appeal: ([A-Z\-\s]+)').str.rstrip("L").str.strip().alias("OriginOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To Desc: ([A-Z\-\s]+)').str.rstrip("D").str.rstrip("T").str.strip().alias("AppealToDesc"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Appeal Status: ([A-Z\-\s]+)').str.rstrip("A").str.strip().alias("AppealStatus"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To: (\w?) Appeal').str.strip().alias("AppealTo"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_77 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_extract); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_78 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_80, __pyx_kp_u_Appeal_To_Desc_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_kp_u_Appeal_To_Desc_A_Z_s);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_70 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_77, __pyx_n_u_D) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_D);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_str); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_76 = (__pyx_t_78) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_78, __pyx_n_u_T) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_T);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_strip); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_67 = (__pyx_t_70) ? __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_t_70) : __Pyx_PyObject_CallNoArg(__pyx_t_76);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_75 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_67, __pyx_n_u_AppealToDesc) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_AppealToDesc);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;

  /* "alacorder/cal.pyx":527
 *           pl.col("AllPagesText").str.extract(r'Orgin Of Appeal: ([A-Z\-\s]+)').str.rstrip("L").str.strip().alias("OriginOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To Desc: ([A-Z\-\s]+)').str.rstrip("D").str.rstrip("T").str.strip().alias("AppealToDesc"),
 *           pl.col("AllPagesText").str.extract(r'Appeal Status: ([A-Z\-\s]+)').str.rstrip("A").str.strip().alias("AppealStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Appeal To: (\w?) Appeal').str.strip().alias("AppealTo"),
 *           pl.col("AllPagesText").str.extract(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("LowerCourtAppealDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_80, __pyx_n_s_pl); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_79 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_col); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_79))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_79);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_79);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_79, function);
    }
  }
  __pyx_t_77 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_79, __pyx_t_80, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_79, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_extract); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_78 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_79, __pyx_kp_u_Appeal_Status_A_Z_s) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_kp_u_Appeal_Status_A_Z_s);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_70 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_77, __pyx_n_u_A) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_A);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_str); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_strip); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_67 = (__pyx_t_78) ? __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_t_78) : __Pyx_PyObject_CallNoArg(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_76 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_67, __pyx_n_u_AppealStatus) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_AppealStatus);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;

  /* "alacorder/cal.pyx":528
 *           pl.col("AllPagesText").str.extract(r'Appeal To Desc: ([A-Z\-\s]+)').str.rstrip("D").str.rstrip("T").str.strip().alias("AppealToDesc"),
 *           pl.col("AllPagesText").str.extract(r'Appeal Status: ([A-Z\-\s]+)').str.rstrip("A").str.strip().alias("AppealStatus"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To: (\w?) Appeal').str.strip().alias("AppealTo"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("LowerCourtAppealDate"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionDateOfAppeal"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_77 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_extract); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_78 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_80, __pyx_kp_u_Appeal_To_w_Appeal) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_kp_u_Appeal_To_w_Appeal);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_strip); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_67 = (__pyx_t_77) ? __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_t_77) : __Pyx_PyObject_CallNoArg(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_70 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_67, __pyx_n_u_AppealTo) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_AppealTo);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;

  /* "alacorder/cal.pyx":529
 *           pl.col("AllPagesText").str.extract(r'Appeal Status: ([A-Z\-\s]+)').str.rstrip("A").str.strip().alias("AppealStatus"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To: (\w?) Appeal').str.strip().alias("AppealTo"),
 *           pl.col("AllPagesText").str.extract(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("LowerCourtAppealDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionDateOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Type Of Appeal: [^A-Za-z]+').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionTypeOfAppeal"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_80 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_extract); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_77 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_81, __pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_Call(__pyx_t_77, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_strip); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_67 = (__pyx_t_77) ? __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_77) : __Pyx_PyObject_CallNoArg(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_78 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_67, __pyx_n_u_LowerCourtAppealDate) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_LowerCourtAppealDate);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;

  /* "alacorder/cal.pyx":530
 *           pl.col("AllPagesText").str.extract(r'Appeal To: (\w?) Appeal').str.strip().alias("AppealTo"),
 *           pl.col("AllPagesText").str.extract(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("LowerCourtAppealDate"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionDateOfAppeal"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Disposition Type Of Appeal: [^A-Za-z]+').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionTypeOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Number of Subponeas: (\d{3})').str.replace_all(r'[^0-9]','').str.strip().cast(pl.Int64, strict=False).alias("NumberOfSubpoenas"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_81 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_extract); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_77 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_82, __pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_Call(__pyx_t_77, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_strip); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_67 = (__pyx_t_77) ? __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_t_77) : __Pyx_PyObject_CallNoArg(__pyx_t_81);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_80 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_67, __pyx_n_u_DispositionDateOfAppeal) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_DispositionDateOfAppeal);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 530, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;

  /* "alacorder/cal.pyx":531
 *           pl.col("AllPagesText").str.extract(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("LowerCourtAppealDate"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionDateOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Type Of Appeal: [^A-Za-z]+').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionTypeOfAppeal"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Number of Subponeas: (\d{3})').str.replace_all(r'[^0-9]','').str.strip().cast(pl.Int64, strict=False).alias("NumberOfSubpoenas"),
 *           pl.col("AllPagesText").str.extract(r'Updated By: (\w{3})').str.strip().alias("AdminUpdatedBy"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_82 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_str); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_extract); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_77 = (__pyx_t_83) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_83, __pyx_kp_u_Disposition_Type_Of_Appeal_A_Za) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_kp_u_Disposition_Type_Of_Appeal_A_Za);
  __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_Call(__pyx_t_77, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_strip); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_67 = (__pyx_t_77) ? __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_t_77) : __Pyx_PyObject_CallNoArg(__pyx_t_82);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_alias); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_81 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_67, __pyx_n_u_DispositionTypeOfAppeal) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_n_u_DispositionTypeOfAppeal);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;

  /* "alacorder/cal.pyx":532
 *           pl.col("AllPagesText").str.extract(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionDateOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Type Of Appeal: [^A-Za-z]+').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionTypeOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Number of Subponeas: (\d{3})').str.replace_all(r'[^0-9]','').str.strip().cast(pl.Int64, strict=False).alias("NumberOfSubpoenas"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Updated By: (\w{3})').str.strip().alias("AdminUpdatedBy"),
 *           pl.col("AllPagesText").str.extract(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("TransferToAdminDocDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_84 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_84))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_84);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_84);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_84, function);
    }
  }
  __pyx_t_83 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_84, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_84, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_str); if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_extract); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_77 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_84, __pyx_kp_u_Number_of_Subponeas_d_3) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_kp_u_Number_of_Subponeas_d_3);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_Call(__pyx_t_77, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_strip); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_67 = (__pyx_t_77) ? __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_77) : __Pyx_PyObject_CallNoArg(__pyx_t_83);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_cast); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_Int64); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = PyTuple_New(1); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_GIVEREF(__pyx_t_77);
  PyTuple_SET_ITEM(__pyx_t_67, 0, __pyx_t_77);
  __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  if (PyDict_SetItem(__pyx_t_77, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 532, __pyx_L1_error)
  __pyx_t_84 = __Pyx_PyObject_Call(__pyx_t_83, __pyx_t_67, __pyx_t_77); if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_alias); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_82 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_84, __pyx_n_u_NumberOfSubpoenas) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_n_u_NumberOfSubpoenas);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;

  /* "alacorder/cal.pyx":533
 *           pl.col("AllPagesText").str.extract(r'Disposition Type Of Appeal: [^A-Za-z]+').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionTypeOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Number of Subponeas: (\d{3})').str.replace_all(r'[^0-9]','').str.strip().cast(pl.Int64, strict=False).alias("NumberOfSubpoenas"),
 *           pl.col("AllPagesText").str.extract(r'Updated By: (\w{3})').str.strip().alias("AdminUpdatedBy"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("TransferToAdminDocDate"),
 *           pl.col("AllPagesText").str.extract(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'(Transfer Desc:)','').str.strip().alias("TransferDesc"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_85))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_85);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_85);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_85, function);
    }
  }
  __pyx_t_83 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_85, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_85, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_str); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_extract); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_67 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_85, __pyx_kp_u_Updated_By_w_3) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_kp_u_Updated_By_w_3);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_str); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_strip); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_67))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_67);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_67);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_67, function);
    }
  }
  __pyx_t_84 = (__pyx_t_83) ? __Pyx_PyObject_CallOneArg(__pyx_t_67, __pyx_t_83) : __Pyx_PyObject_CallNoArg(__pyx_t_67);
  __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
  if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_alias); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_67))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_67);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_67);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_67, function);
    }
  }
  __pyx_t_77 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_67, __pyx_t_84, __pyx_n_u_AdminUpdatedBy) : __Pyx_PyObject_CallOneArg(__pyx_t_67, __pyx_n_u_AdminUpdatedBy);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;

  /* "alacorder/cal.pyx":534
 *           pl.col("AllPagesText").str.extract(r'Number of Subponeas: (\d{3})').str.replace_all(r'[^0-9]','').str.strip().cast(pl.Int64, strict=False).alias("NumberOfSubpoenas"),
 *           pl.col("AllPagesText").str.extract(r'Updated By: (\w{3})').str.strip().alias("AdminUpdatedBy"),
 *           pl.col("AllPagesText").str.extract(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("TransferToAdminDocDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'(Transfer Desc:)','').str.strip().alias("TransferDesc"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_85 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_extract); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_85))) {
    __pyx_t_86 = PyMethod_GET_SELF(__pyx_t_85);
    if (likely(__pyx_t_86)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_85);
      __Pyx_INCREF(__pyx_t_86);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_85, function);
    }
  }
  __pyx_t_83 = (__pyx_t_86) ? __Pyx_PyObject_Call2Args(__pyx_t_85, __pyx_t_86, __pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_85, __pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d);
  __Pyx_XDECREF(__pyx_t_86); __pyx_t_86 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_str); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_strip); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_84 = (__pyx_t_85) ? __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_85) : __Pyx_PyObject_CallNoArg(__pyx_t_83);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_alias); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_67 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_84, __pyx_n_u_TransferToAdminDocDate) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_n_u_TransferToAdminDocDate);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;

  /* "alacorder/cal.pyx":535
 *           pl.col("AllPagesText").str.extract(r'Updated By: (\w{3})').str.strip().alias("AdminUpdatedBy"),
 *           pl.col("AllPagesText").str.extract(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("TransferToAdminDocDate"),
 *           pl.col("AllPagesText").str.extract(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'(Transfer Desc:)','').str.strip().alias("TransferDesc"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_86 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_str); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_extract); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_85 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_87, __pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_Call(__pyx_t_85, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_str); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_strip); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_84 = (__pyx_t_85) ? __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_t_85) : __Pyx_PyObject_CallNoArg(__pyx_t_86);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_alias); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_83 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_84, __pyx_n_u_TransferDesc) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_n_u_TransferDesc);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;

  /* "alacorder/cal.pyx":536
 *           pl.col("AllPagesText").str.extract(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("TransferToAdminDocDate"),
 *           pl.col("AllPagesText").str.extract(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'(Transfer Desc:)','').str.strip().alias("TransferDesc"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])
 *      cases.with_columns([
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_88 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_88);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_88))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_88);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_88);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_88, function);
    }
  }
  __pyx_t_87 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_88, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_88, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_88); __pyx_t_88 = 0;
  __pyx_t_88 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_str); if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_88);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_88, __pyx_n_s_extract); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_88); __pyx_t_88 = 0;
  __pyx_t_88 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_88 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_88)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_88);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_85 = (__pyx_t_88) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_88, __pyx_kp_u_Date_Trial_Began_but_No_Verdict) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_kp_u_Date_Trial_Began_but_No_Verdict);
  __Pyx_XDECREF(__pyx_t_88); __pyx_t_88 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_str); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_strip); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_85))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_85);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_85);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_85, function);
    }
  }
  __pyx_t_84 = (__pyx_t_87) ? __Pyx_PyObject_CallOneArg(__pyx_t_85, __pyx_t_87) : __Pyx_PyObject_CallNoArg(__pyx_t_85);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_alias); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_85))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_85);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_85);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_85, function);
    }
  }
  __pyx_t_86 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_85, __pyx_t_84, __pyx_n_u_TBNV1) : __Pyx_PyObject_CallOneArg(__pyx_t_85, __pyx_n_u_TBNV1);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;

  /* "alacorder/cal.pyx":537
 *           pl.col("AllPagesText").str.extract(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'(Transfer Desc:)','').str.strip().alias("TransferDesc"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])             # <<<<<<<<<<<<<<
 *      cases.with_columns([
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_79, __pyx_n_s_pl); if (unlikely(!__pyx_t_79)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_79);
  __pyx_t_89 = __Pyx_PyObject_GetAttrStr(__pyx_t_79, __pyx_n_s_col); if (unlikely(!__pyx_t_89)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_89);
  __Pyx_DECREF(__pyx_t_79); __pyx_t_79 = 0;
  __pyx_t_79 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_89))) {
    __pyx_t_79 = PyMethod_GET_SELF(__pyx_t_89);
    if (likely(__pyx_t_79)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_89);
      __Pyx_INCREF(__pyx_t_79);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_89, function);
    }
  }
  __pyx_t_88 = (__pyx_t_79) ? __Pyx_PyObject_Call2Args(__pyx_t_89, __pyx_t_79, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_89, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_79); __pyx_t_79 = 0;
  if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_88);
  __Pyx_DECREF(__pyx_t_89); __pyx_t_89 = 0;
  __pyx_t_89 = __Pyx_PyObject_GetAttrStr(__pyx_t_88, __pyx_n_s_str); if (unlikely(!__pyx_t_89)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_89);
  __Pyx_DECREF(__pyx_t_88); __pyx_t_88 = 0;
  __pyx_t_88 = __Pyx_PyObject_GetAttrStr(__pyx_t_89, __pyx_n_s_extract); if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_88);
  __Pyx_DECREF(__pyx_t_89); __pyx_t_89 = 0;
  __pyx_t_89 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_88))) {
    __pyx_t_89 = PyMethod_GET_SELF(__pyx_t_88);
    if (likely(__pyx_t_89)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_88);
      __Pyx_INCREF(__pyx_t_89);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_88, function);
    }
  }
  __pyx_t_87 = (__pyx_t_89) ? __Pyx_PyObject_Call2Args(__pyx_t_88, __pyx_t_89, __pyx_kp_u_Date_Trial_Began_but_No_Verdict_2) : __Pyx_PyObject_CallOneArg(__pyx_t_88, __pyx_kp_u_Date_Trial_Began_but_No_Verdict_2);
  __Pyx_XDECREF(__pyx_t_89); __pyx_t_89 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_88); __pyx_t_88 = 0;
  __pyx_t_88 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_str); if (unlikely(!__pyx_t_88)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_88);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_88, __pyx_n_s_strip); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_88); __pyx_t_88 = 0;
  __pyx_t_88 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_88 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_88)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_88);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_84 = (__pyx_t_88) ? __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_t_88) : __Pyx_PyObject_CallNoArg(__pyx_t_87);
  __Pyx_XDECREF(__pyx_t_88); __pyx_t_88 = 0;
  if (unlikely(!__pyx_t_84)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_84);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_84, __pyx_n_s_alias); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_84); __pyx_t_84 = 0;
  __pyx_t_84 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_84 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_84)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_84);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_85 = (__pyx_t_84) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_84, __pyx_n_u_TBNV2) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_TBNV2);
  __Pyx_XDECREF(__pyx_t_84); __pyx_t_84 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;

  /* "alacorder/cal.pyx":455
 * 
 * def split_cases(df, debug=False):
 *      cases = df.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 */
  __pyx_t_87 = PyList_New(82); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_87, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_87, 1, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_87, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_87, 3, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_87, 4, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_87, 5, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_87, 6, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_87, 7, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_87, 8, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_15);
  PyList_SET_ITEM(__pyx_t_87, 9, __pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_87, 10, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_87, 11, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_16);
  PyList_SET_ITEM(__pyx_t_87, 12, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_18);
  PyList_SET_ITEM(__pyx_t_87, 13, __pyx_t_18);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_87, 14, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_20);
  PyList_SET_ITEM(__pyx_t_87, 15, __pyx_t_20);
  __Pyx_GIVEREF(__pyx_t_19);
  PyList_SET_ITEM(__pyx_t_87, 16, __pyx_t_19);
  __Pyx_GIVEREF(__pyx_t_23);
  PyList_SET_ITEM(__pyx_t_87, 17, __pyx_t_23);
  __Pyx_GIVEREF(__pyx_t_21);
  PyList_SET_ITEM(__pyx_t_87, 18, __pyx_t_21);
  __Pyx_GIVEREF(__pyx_t_17);
  PyList_SET_ITEM(__pyx_t_87, 19, __pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_25);
  PyList_SET_ITEM(__pyx_t_87, 20, __pyx_t_25);
  __Pyx_GIVEREF(__pyx_t_26);
  PyList_SET_ITEM(__pyx_t_87, 21, __pyx_t_26);
  __Pyx_GIVEREF(__pyx_t_27);
  PyList_SET_ITEM(__pyx_t_87, 22, __pyx_t_27);
  __Pyx_GIVEREF(__pyx_t_28);
  PyList_SET_ITEM(__pyx_t_87, 23, __pyx_t_28);
  __Pyx_GIVEREF(__pyx_t_29);
  PyList_SET_ITEM(__pyx_t_87, 24, __pyx_t_29);
  __Pyx_GIVEREF(__pyx_t_30);
  PyList_SET_ITEM(__pyx_t_87, 25, __pyx_t_30);
  __Pyx_GIVEREF(__pyx_t_24);
  PyList_SET_ITEM(__pyx_t_87, 26, __pyx_t_24);
  __Pyx_GIVEREF(__pyx_t_31);
  PyList_SET_ITEM(__pyx_t_87, 27, __pyx_t_31);
  __Pyx_GIVEREF(__pyx_t_33);
  PyList_SET_ITEM(__pyx_t_87, 28, __pyx_t_33);
  __Pyx_GIVEREF(__pyx_t_34);
  PyList_SET_ITEM(__pyx_t_87, 29, __pyx_t_34);
  __Pyx_GIVEREF(__pyx_t_32);
  PyList_SET_ITEM(__pyx_t_87, 30, __pyx_t_32);
  __Pyx_GIVEREF(__pyx_t_35);
  PyList_SET_ITEM(__pyx_t_87, 31, __pyx_t_35);
  __Pyx_GIVEREF(__pyx_t_38);
  PyList_SET_ITEM(__pyx_t_87, 32, __pyx_t_38);
  __Pyx_GIVEREF(__pyx_t_36);
  PyList_SET_ITEM(__pyx_t_87, 33, __pyx_t_36);
  __Pyx_GIVEREF(__pyx_t_39);
  PyList_SET_ITEM(__pyx_t_87, 34, __pyx_t_39);
  __Pyx_GIVEREF(__pyx_t_40);
  PyList_SET_ITEM(__pyx_t_87, 35, __pyx_t_40);
  __Pyx_GIVEREF(__pyx_t_42);
  PyList_SET_ITEM(__pyx_t_87, 36, __pyx_t_42);
  __Pyx_GIVEREF(__pyx_t_41);
  PyList_SET_ITEM(__pyx_t_87, 37, __pyx_t_41);
  __Pyx_GIVEREF(__pyx_t_37);
  PyList_SET_ITEM(__pyx_t_87, 38, __pyx_t_37);
  __Pyx_GIVEREF(__pyx_t_43);
  PyList_SET_ITEM(__pyx_t_87, 39, __pyx_t_43);
  __Pyx_GIVEREF(__pyx_t_45);
  PyList_SET_ITEM(__pyx_t_87, 40, __pyx_t_45);
  __Pyx_GIVEREF(__pyx_t_44);
  PyList_SET_ITEM(__pyx_t_87, 41, __pyx_t_44);
  __Pyx_GIVEREF(__pyx_t_22);
  PyList_SET_ITEM(__pyx_t_87, 42, __pyx_t_22);
  __Pyx_GIVEREF(__pyx_t_47);
  PyList_SET_ITEM(__pyx_t_87, 43, __pyx_t_47);
  __Pyx_GIVEREF(__pyx_t_46);
  PyList_SET_ITEM(__pyx_t_87, 44, __pyx_t_46);
  __Pyx_GIVEREF(__pyx_t_49);
  PyList_SET_ITEM(__pyx_t_87, 45, __pyx_t_49);
  __Pyx_GIVEREF(__pyx_t_50);
  PyList_SET_ITEM(__pyx_t_87, 46, __pyx_t_50);
  __Pyx_GIVEREF(__pyx_t_52);
  PyList_SET_ITEM(__pyx_t_87, 47, __pyx_t_52);
  __Pyx_GIVEREF(__pyx_t_54);
  PyList_SET_ITEM(__pyx_t_87, 48, __pyx_t_54);
  __Pyx_GIVEREF(__pyx_t_48);
  PyList_SET_ITEM(__pyx_t_87, 49, __pyx_t_48);
  __Pyx_GIVEREF(__pyx_t_53);
  PyList_SET_ITEM(__pyx_t_87, 50, __pyx_t_53);
  __Pyx_GIVEREF(__pyx_t_56);
  PyList_SET_ITEM(__pyx_t_87, 51, __pyx_t_56);
  __Pyx_GIVEREF(__pyx_t_57);
  PyList_SET_ITEM(__pyx_t_87, 52, __pyx_t_57);
  __Pyx_GIVEREF(__pyx_t_55);
  PyList_SET_ITEM(__pyx_t_87, 53, __pyx_t_55);
  __Pyx_GIVEREF(__pyx_t_59);
  PyList_SET_ITEM(__pyx_t_87, 54, __pyx_t_59);
  __Pyx_GIVEREF(__pyx_t_60);
  PyList_SET_ITEM(__pyx_t_87, 55, __pyx_t_60);
  __Pyx_GIVEREF(__pyx_t_61);
  PyList_SET_ITEM(__pyx_t_87, 56, __pyx_t_61);
  __Pyx_GIVEREF(__pyx_t_62);
  PyList_SET_ITEM(__pyx_t_87, 57, __pyx_t_62);
  __Pyx_GIVEREF(__pyx_t_63);
  PyList_SET_ITEM(__pyx_t_87, 58, __pyx_t_63);
  __Pyx_GIVEREF(__pyx_t_64);
  PyList_SET_ITEM(__pyx_t_87, 59, __pyx_t_64);
  __Pyx_GIVEREF(__pyx_t_65);
  PyList_SET_ITEM(__pyx_t_87, 60, __pyx_t_65);
  __Pyx_GIVEREF(__pyx_t_58);
  PyList_SET_ITEM(__pyx_t_87, 61, __pyx_t_58);
  __Pyx_GIVEREF(__pyx_t_66);
  PyList_SET_ITEM(__pyx_t_87, 62, __pyx_t_66);
  __Pyx_GIVEREF(__pyx_t_51);
  PyList_SET_ITEM(__pyx_t_87, 63, __pyx_t_51);
  __Pyx_GIVEREF(__pyx_t_68);
  PyList_SET_ITEM(__pyx_t_87, 64, __pyx_t_68);
  __Pyx_GIVEREF(__pyx_t_69);
  PyList_SET_ITEM(__pyx_t_87, 65, __pyx_t_69);
  __Pyx_GIVEREF(__pyx_t_71);
  PyList_SET_ITEM(__pyx_t_87, 66, __pyx_t_71);
  __Pyx_GIVEREF(__pyx_t_72);
  PyList_SET_ITEM(__pyx_t_87, 67, __pyx_t_72);
  __Pyx_GIVEREF(__pyx_t_74);
  PyList_SET_ITEM(__pyx_t_87, 68, __pyx_t_74);
  __Pyx_GIVEREF(__pyx_t_73);
  PyList_SET_ITEM(__pyx_t_87, 69, __pyx_t_73);
  __Pyx_GIVEREF(__pyx_t_75);
  PyList_SET_ITEM(__pyx_t_87, 70, __pyx_t_75);
  __Pyx_GIVEREF(__pyx_t_76);
  PyList_SET_ITEM(__pyx_t_87, 71, __pyx_t_76);
  __Pyx_GIVEREF(__pyx_t_70);
  PyList_SET_ITEM(__pyx_t_87, 72, __pyx_t_70);
  __Pyx_GIVEREF(__pyx_t_78);
  PyList_SET_ITEM(__pyx_t_87, 73, __pyx_t_78);
  __Pyx_GIVEREF(__pyx_t_80);
  PyList_SET_ITEM(__pyx_t_87, 74, __pyx_t_80);
  __Pyx_GIVEREF(__pyx_t_81);
  PyList_SET_ITEM(__pyx_t_87, 75, __pyx_t_81);
  __Pyx_GIVEREF(__pyx_t_82);
  PyList_SET_ITEM(__pyx_t_87, 76, __pyx_t_82);
  __Pyx_GIVEREF(__pyx_t_77);
  PyList_SET_ITEM(__pyx_t_87, 77, __pyx_t_77);
  __Pyx_GIVEREF(__pyx_t_67);
  PyList_SET_ITEM(__pyx_t_87, 78, __pyx_t_67);
  __Pyx_GIVEREF(__pyx_t_83);
  PyList_SET_ITEM(__pyx_t_87, 79, __pyx_t_83);
  __Pyx_GIVEREF(__pyx_t_86);
  PyList_SET_ITEM(__pyx_t_87, 80, __pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_85);
  PyList_SET_ITEM(__pyx_t_87, 81, __pyx_t_85);
  __pyx_t_3 = 0;
  __pyx_t_7 = 0;
  __pyx_t_5 = 0;
  __pyx_t_9 = 0;
  __pyx_t_6 = 0;
  __pyx_t_10 = 0;
  __pyx_t_8 = 0;
  __pyx_t_4 = 0;
  __pyx_t_13 = 0;
  __pyx_t_15 = 0;
  __pyx_t_12 = 0;
  __pyx_t_14 = 0;
  __pyx_t_16 = 0;
  __pyx_t_18 = 0;
  __pyx_t_11 = 0;
  __pyx_t_20 = 0;
  __pyx_t_19 = 0;
  __pyx_t_23 = 0;
  __pyx_t_21 = 0;
  __pyx_t_17 = 0;
  __pyx_t_25 = 0;
  __pyx_t_26 = 0;
  __pyx_t_27 = 0;
  __pyx_t_28 = 0;
  __pyx_t_29 = 0;
  __pyx_t_30 = 0;
  __pyx_t_24 = 0;
  __pyx_t_31 = 0;
  __pyx_t_33 = 0;
  __pyx_t_34 = 0;
  __pyx_t_32 = 0;
  __pyx_t_35 = 0;
  __pyx_t_38 = 0;
  __pyx_t_36 = 0;
  __pyx_t_39 = 0;
  __pyx_t_40 = 0;
  __pyx_t_42 = 0;
  __pyx_t_41 = 0;
  __pyx_t_37 = 0;
  __pyx_t_43 = 0;
  __pyx_t_45 = 0;
  __pyx_t_44 = 0;
  __pyx_t_22 = 0;
  __pyx_t_47 = 0;
  __pyx_t_46 = 0;
  __pyx_t_49 = 0;
  __pyx_t_50 = 0;
  __pyx_t_52 = 0;
  __pyx_t_54 = 0;
  __pyx_t_48 = 0;
  __pyx_t_53 = 0;
  __pyx_t_56 = 0;
  __pyx_t_57 = 0;
  __pyx_t_55 = 0;
  __pyx_t_59 = 0;
  __pyx_t_60 = 0;
  __pyx_t_61 = 0;
  __pyx_t_62 = 0;
  __pyx_t_63 = 0;
  __pyx_t_64 = 0;
  __pyx_t_65 = 0;
  __pyx_t_58 = 0;
  __pyx_t_66 = 0;
  __pyx_t_51 = 0;
  __pyx_t_68 = 0;
  __pyx_t_69 = 0;
  __pyx_t_71 = 0;
  __pyx_t_72 = 0;
  __pyx_t_74 = 0;
  __pyx_t_73 = 0;
  __pyx_t_75 = 0;
  __pyx_t_76 = 0;
  __pyx_t_70 = 0;
  __pyx_t_78 = 0;
  __pyx_t_80 = 0;
  __pyx_t_81 = 0;
  __pyx_t_82 = 0;
  __pyx_t_77 = 0;
  __pyx_t_67 = 0;
  __pyx_t_83 = 0;
  __pyx_t_86 = 0;
  __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_85, __pyx_t_87) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_87);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_cases = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":538
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])
 *      cases.with_columns([             # <<<<<<<<<<<<<<
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":539
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])
 *      cases.with_columns([
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_86, __pyx_n_s_pl); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_concat_str); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_86 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_67, __pyx_n_u_RAWHEIGHT) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_n_u_RAWHEIGHT);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_lit); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_77 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_67, __pyx_kp_u__51) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_kp_u__51);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = PyList_New(2); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_GIVEREF(__pyx_t_86);
  PyList_SET_ITEM(__pyx_t_82, 0, __pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_77);
  PyList_SET_ITEM(__pyx_t_82, 1, __pyx_t_77);
  __pyx_t_86 = 0;
  __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_85 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_77, __pyx_t_82) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_82);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_87 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_85, __pyx_n_u_Height) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_n_u_Height);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;

  /* "alacorder/cal.pyx":540
 *      cases.with_columns([
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_86 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_77 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_81, __pyx_kp_u_Requrements_Completed_YES_NO) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_kp_u_Requrements_Completed_YES_NO);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_arr); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_join); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_86 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_86)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_86);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_82 = (__pyx_t_86) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_86, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_86); __pyx_t_86 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_Call(__pyx_t_82, __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_strip); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_85 = (__pyx_t_82) ? __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_t_82) : __Pyx_PyObject_CallNoArg(__pyx_t_77);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_83 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_85, __pyx_n_u_SentencingRequirementsCompleted) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_n_u_SentencingRequirementsCompleted);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;

  /* "alacorder/cal.pyx":541
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_81 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_86 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_80, __pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_arr); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_join); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_82 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_81, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_Call(__pyx_t_82, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_str); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_strip); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_85 = (__pyx_t_82) ? __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_t_82) : __Pyx_PyObject_CallNoArg(__pyx_t_86);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_77 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_85, __pyx_n_u_SentenceDate) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_n_u_SentenceDate);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;

  /* "alacorder/cal.pyx":542
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_80 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_str); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_81 = (__pyx_t_78) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_78, __pyx_kp_u_Probation_Period) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_kp_u_Probation_Period);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_arr); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_join); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_82 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_80, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_82);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_86 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_85, __pyx_n_u_ProbationPeriod) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_n_u_ProbationPeriod);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;

  /* "alacorder/cal.pyx":543
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_78 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_80 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_70, __pyx_kp_u_License_Susp_Period) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_kp_u_License_Susp_Period);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_arr); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_join); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_81 = (__pyx_t_78) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_78, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__55, NULL); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_82 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_85, __pyx_n_u_LicenseSuspPeriod) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_LicenseSuspPeriod);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;

  /* "alacorder/cal.pyx":544
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_70 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_str); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_78 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_76, __pyx_kp_u_Jail_Credit_Period) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_kp_u_Jail_Credit_Period);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_arr); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_join); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_81 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_70, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__56, NULL); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_80 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_85, __pyx_n_u_JailCreditPeriod) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_JailCreditPeriod);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;

  /* "alacorder/cal.pyx":545
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_76 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_str); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_75 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_75)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_75);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_70 = (__pyx_t_75) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_75, __pyx_kp_u_Sentence_Provisions_Y_N) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_kp_u_Sentence_Provisions_Y_N);
  __Pyx_XDECREF(__pyx_t_75); __pyx_t_75 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_arr); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_join); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_81 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_76, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_78 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_85, __pyx_n_u_SentenceProvisions) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_SentenceProvisions);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;

  /* "alacorder/cal.pyx":546
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_75 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_str); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_76 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_73, __pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_arr); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_join); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_75 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_75)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_75);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_81 = (__pyx_t_75) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_75, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_75); __pyx_t_75 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_76);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_70 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_85, __pyx_n_u_SentenceStartDate) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_SentenceStartDate);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;

  /* "alacorder/cal.pyx":547
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_73 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_74 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_74)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_74);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_75 = (__pyx_t_74) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_74, __pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_74); __pyx_t_74 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_arr); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_join); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_81 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_73, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_75, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_75);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_76 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_85, __pyx_n_u_SentenceEndDate) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_n_u_SentenceEndDate);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;

  /* "alacorder/cal.pyx":548
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_74 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_72, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_str); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_72 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_72)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_72);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_73 = (__pyx_t_72) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_72, __pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_72); __pyx_t_72 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_arr); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_join); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_74 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_74)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_74);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_81 = (__pyx_t_74) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_74, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_74); __pyx_t_74 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__60, NULL); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_73);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_75 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_85, __pyx_n_u_ProbationBeginDate) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_ProbationBeginDate);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;

  /* "alacorder/cal.pyx":549
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'Probation Revoke: ','').str.strip().alias("ProbationRevoke")])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_72 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_str); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_71 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_71)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_71);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_74 = (__pyx_t_71) ? __Pyx_PyObject_Call2Args(__pyx_t_72, __pyx_t_71, __pyx_kp_u_Updated_By_w_3_2) : __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_kp_u_Updated_By_w_3_2);
  __Pyx_XDECREF(__pyx_t_71); __pyx_t_71 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_arr); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_join); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_72 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_72)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_72);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_81 = (__pyx_t_72) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_72, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_72); __pyx_t_72 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_strip); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_85 = (__pyx_t_81) ? __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_t_81) : __Pyx_PyObject_CallNoArg(__pyx_t_74);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_73 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_85, __pyx_n_u_SentenceUpdatedBy) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_n_u_SentenceUpdatedBy);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;

  /* "alacorder/cal.pyx":550
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'Probation Revoke: ','').str.strip().alias("ProbationRevoke")])
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_69))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_69);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_69);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_69, function);
    }
  }
  __pyx_t_71 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_69, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_69, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_str); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_69 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_69)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_69);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_72 = (__pyx_t_69) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_69, __pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_69); __pyx_t_69 = 0;
  if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_arr); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_join); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_72))) {
    __pyx_t_71 = PyMethod_GET_SELF(__pyx_t_72);
    if (likely(__pyx_t_71)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_72);
      __Pyx_INCREF(__pyx_t_71);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_72, function);
    }
  }
  __pyx_t_81 = (__pyx_t_71) ? __Pyx_PyObject_Call2Args(__pyx_t_72, __pyx_t_71, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_72, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_71); __pyx_t_71 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_strip); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_72 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_72)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_72);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_85 = (__pyx_t_72) ? __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_t_72) : __Pyx_PyObject_CallNoArg(__pyx_t_81);
  __Pyx_XDECREF(__pyx_t_72); __pyx_t_72 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_74 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_85, __pyx_n_u_SentenceLastUpdate) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_SentenceLastUpdate);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;

  /* "alacorder/cal.pyx":551
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'Probation Revoke: ','').str.strip().alias("ProbationRevoke")])             # <<<<<<<<<<<<<<
 * 
 *      dlog(debug, [cases.columns, cases.shape, "alac 899"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_67, __pyx_n_s_pl); if (unlikely(!__pyx_t_67)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_67);
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_67, __pyx_n_s_col); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_67); __pyx_t_67 = 0;
  __pyx_t_67 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_68))) {
    __pyx_t_67 = PyMethod_GET_SELF(__pyx_t_68);
    if (likely(__pyx_t_67)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_68);
      __Pyx_INCREF(__pyx_t_67);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_68, function);
    }
  }
  __pyx_t_69 = (__pyx_t_67) ? __Pyx_PyObject_Call2Args(__pyx_t_68, __pyx_t_67, __pyx_n_u_AllPagesText) : __Pyx_PyObject_CallOneArg(__pyx_t_68, __pyx_n_u_AllPagesText);
  __Pyx_XDECREF(__pyx_t_67); __pyx_t_67 = 0;
  if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_str); if (unlikely(!__pyx_t_68)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_68);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_68, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_68); __pyx_t_68 = 0;
  __pyx_t_68 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_69))) {
    __pyx_t_68 = PyMethod_GET_SELF(__pyx_t_69);
    if (likely(__pyx_t_68)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_69);
      __Pyx_INCREF(__pyx_t_68);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_69, function);
    }
  }
  __pyx_t_71 = (__pyx_t_68) ? __Pyx_PyObject_Call2Args(__pyx_t_69, __pyx_t_68, __pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d) : __Pyx_PyObject_CallOneArg(__pyx_t_69, __pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d);
  __Pyx_XDECREF(__pyx_t_68); __pyx_t_68 = 0;
  if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_arr); if (unlikely(!__pyx_t_69)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_69);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_69, __pyx_n_s_join); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_69); __pyx_t_69 = 0;
  __pyx_t_69 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_69 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_69)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_69);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_72 = (__pyx_t_69) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_69, __pyx_kp_u__52) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_kp_u__52);
  __Pyx_XDECREF(__pyx_t_69); __pyx_t_69 = 0;
  if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_str); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_Call(__pyx_t_72, __pyx_tuple__62, NULL); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = __Pyx_PyObject_GetAttrStr(__pyx_t_71, __pyx_n_s_str); if (unlikely(!__pyx_t_72)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_72);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_72, __pyx_n_s_strip); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_72); __pyx_t_72 = 0;
  __pyx_t_72 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_72 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_72)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_72);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_85 = (__pyx_t_72) ? __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_t_72) : __Pyx_PyObject_CallNoArg(__pyx_t_71);
  __Pyx_XDECREF(__pyx_t_72); __pyx_t_72 = 0;
  if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_alias); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_71))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_71);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_71);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_71, function);
    }
  }
  __pyx_t_81 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_71, __pyx_t_85, __pyx_n_u_ProbationRevoke) : __Pyx_PyObject_CallOneArg(__pyx_t_71, __pyx_n_u_ProbationRevoke);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;

  /* "alacorder/cal.pyx":538
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])
 *      cases.with_columns([             # <<<<<<<<<<<<<<
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),
 */
  __pyx_t_71 = PyList_New(13); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_GIVEREF(__pyx_t_87);
  PyList_SET_ITEM(__pyx_t_71, 0, __pyx_t_87);
  __Pyx_GIVEREF(__pyx_t_83);
  PyList_SET_ITEM(__pyx_t_71, 1, __pyx_t_83);
  __Pyx_GIVEREF(__pyx_t_77);
  PyList_SET_ITEM(__pyx_t_71, 2, __pyx_t_77);
  __Pyx_GIVEREF(__pyx_t_86);
  PyList_SET_ITEM(__pyx_t_71, 3, __pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_82);
  PyList_SET_ITEM(__pyx_t_71, 4, __pyx_t_82);
  __Pyx_GIVEREF(__pyx_t_80);
  PyList_SET_ITEM(__pyx_t_71, 5, __pyx_t_80);
  __Pyx_GIVEREF(__pyx_t_78);
  PyList_SET_ITEM(__pyx_t_71, 6, __pyx_t_78);
  __Pyx_GIVEREF(__pyx_t_70);
  PyList_SET_ITEM(__pyx_t_71, 7, __pyx_t_70);
  __Pyx_GIVEREF(__pyx_t_76);
  PyList_SET_ITEM(__pyx_t_71, 8, __pyx_t_76);
  __Pyx_GIVEREF(__pyx_t_75);
  PyList_SET_ITEM(__pyx_t_71, 9, __pyx_t_75);
  __Pyx_GIVEREF(__pyx_t_73);
  PyList_SET_ITEM(__pyx_t_71, 10, __pyx_t_73);
  __Pyx_GIVEREF(__pyx_t_74);
  PyList_SET_ITEM(__pyx_t_71, 11, __pyx_t_74);
  __Pyx_GIVEREF(__pyx_t_81);
  PyList_SET_ITEM(__pyx_t_71, 12, __pyx_t_81);
  __pyx_t_87 = 0;
  __pyx_t_83 = 0;
  __pyx_t_77 = 0;
  __pyx_t_86 = 0;
  __pyx_t_82 = 0;
  __pyx_t_80 = 0;
  __pyx_t_78 = 0;
  __pyx_t_70 = 0;
  __pyx_t_76 = 0;
  __pyx_t_75 = 0;
  __pyx_t_73 = 0;
  __pyx_t_74 = 0;
  __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_81, __pyx_t_71) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_71);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":553
 *           pl.col("AllPagesText").str.extract_all(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'Probation Revoke: ','').str.strip().alias("ProbationRevoke")])
 * 
 *      dlog(debug, [cases.columns, cases.shape, "alac 899"])             # <<<<<<<<<<<<<<
 * 
 *      # clean columns, unnest totals
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_71 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_columns); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_shape); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_74 = PyList_New(3); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_GIVEREF(__pyx_t_71);
  PyList_SET_ITEM(__pyx_t_74, 0, __pyx_t_71);
  __Pyx_GIVEREF(__pyx_t_81);
  PyList_SET_ITEM(__pyx_t_74, 1, __pyx_t_81);
  __Pyx_INCREF(__pyx_kp_u_alac_899);
  __Pyx_GIVEREF(__pyx_kp_u_alac_899);
  PyList_SET_ITEM(__pyx_t_74, 2, __pyx_kp_u_alac_899);
  __pyx_t_71 = 0;
  __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  __pyx_t_90 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_90 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_81, __pyx_v_debug, __pyx_t_74};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_90, 2+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_81, __pyx_v_debug, __pyx_t_74};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_90, 2+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  } else
  #endif
  {
    __pyx_t_71 = PyTuple_New(2+__pyx_t_90); if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_71);
    if (__pyx_t_81) {
      __Pyx_GIVEREF(__pyx_t_81); PyTuple_SET_ITEM(__pyx_t_71, 0, __pyx_t_81); __pyx_t_81 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_71, 0+__pyx_t_90, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_74);
    PyTuple_SET_ITEM(__pyx_t_71, 1+__pyx_t_90, __pyx_t_74);
    __pyx_t_74 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_71, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":556
 * 
 *      # clean columns, unnest totals
 *      cases = cases.with_columns(             # <<<<<<<<<<<<<<
 *           pl.col("RE_Phone").str.replace_all(r'[^0-9]','').alias("CLEAN_Phone"),
 *           pl.concat_str([pl.col("SHORTCOUNTY"),pl.lit("-"),pl.col("SHORTCASENO")]).alias("CaseNumber"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":557
 *      # clean columns, unnest totals
 *      cases = cases.with_columns(
 *           pl.col("RE_Phone").str.replace_all(r'[^0-9]','').alias("CLEAN_Phone"),             # <<<<<<<<<<<<<<
 *           pl.concat_str([pl.col("SHORTCOUNTY"),pl.lit("-"),pl.col("SHORTCASENO")]).alias("CaseNumber"),
 *           pl.concat_str([pl.col("Address1"), pl.lit(" "), pl.col("Address2")]).str.replace_all(r'JID: \w{3} Hardship.*|Defendant Information.*','').str.strip().alias("StreetAddress"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_74 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_81, __pyx_n_u_RE_Phone) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_RE_Phone);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_74, __pyx_n_s_str); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_Call(__pyx_t_74, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
  __pyx_t_74 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_74))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_74);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_74);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_74, function);
    }
  }
  __pyx_t_71 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_74, __pyx_t_73, __pyx_n_u_CLEAN_Phone) : __Pyx_PyObject_CallOneArg(__pyx_t_74, __pyx_n_u_CLEAN_Phone);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_71)) __PYX_ERR(0, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_71);
  __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;

  /* "alacorder/cal.pyx":558
 *      cases = cases.with_columns(
 *           pl.col("RE_Phone").str.replace_all(r'[^0-9]','').alias("CLEAN_Phone"),
 *           pl.concat_str([pl.col("SHORTCOUNTY"),pl.lit("-"),pl.col("SHORTCASENO")]).alias("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.concat_str([pl.col("Address1"), pl.lit(" "), pl.col("Address2")]).str.replace_all(r'JID: \w{3} Hardship.*|Defendant Information.*','').str.strip().alias("StreetAddress"),
 *           pl.col("Name"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_concat_str); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_col); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_81 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_76, __pyx_n_u_SHORTCOUNTY) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_SHORTCOUNTY);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_lit); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_70 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_76, __pyx_kp_u__63) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_kp_u__63);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_78 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_76, __pyx_n_u_SHORTCASENO) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_SHORTCASENO);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = PyList_New(3); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_GIVEREF(__pyx_t_81);
  PyList_SET_ITEM(__pyx_t_80, 0, __pyx_t_81);
  __Pyx_GIVEREF(__pyx_t_70);
  PyList_SET_ITEM(__pyx_t_80, 1, __pyx_t_70);
  __Pyx_GIVEREF(__pyx_t_78);
  PyList_SET_ITEM(__pyx_t_80, 2, __pyx_t_78);
  __pyx_t_81 = 0;
  __pyx_t_70 = 0;
  __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_73 = (__pyx_t_78) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_78, __pyx_t_80) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_t_80);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
  __pyx_t_75 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_75))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_75);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_75);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_75, function);
    }
  }
  __pyx_t_74 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_75, __pyx_t_73, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_75, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_74)) __PYX_ERR(0, 558, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_74);
  __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;

  /* "alacorder/cal.pyx":559
 *           pl.col("RE_Phone").str.replace_all(r'[^0-9]','').alias("CLEAN_Phone"),
 *           pl.concat_str([pl.col("SHORTCOUNTY"),pl.lit("-"),pl.col("SHORTCASENO")]).alias("CaseNumber"),
 *           pl.concat_str([pl.col("Address1"), pl.lit(" "), pl.col("Address2")]).str.replace_all(r'JID: \w{3} Hardship.*|Defendant Information.*','').str.strip().alias("StreetAddress"),             # <<<<<<<<<<<<<<
 *           pl.col("Name"),
 *           pl.when(pl.col("PROBATIONOFFICENUMBERRAW")=="0-000000-00").then(pl.lit('')).otherwise(pl.col("PROBATIONOFFICENUMBERRAW")).alias("ProbationOfficeName"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_78, __pyx_n_s_pl); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_concat_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_78 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_81, __pyx_n_u_Address1) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_Address1);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_lit); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_76 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_81, __pyx_kp_u__64) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_kp_u__64);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_82 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_81, __pyx_n_u_Address2) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_n_u_Address2);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = PyList_New(3); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_78);
  PyList_SET_ITEM(__pyx_t_86, 0, __pyx_t_78);
  __Pyx_GIVEREF(__pyx_t_76);
  PyList_SET_ITEM(__pyx_t_86, 1, __pyx_t_76);
  __Pyx_GIVEREF(__pyx_t_82);
  PyList_SET_ITEM(__pyx_t_86, 2, __pyx_t_82);
  __pyx_t_78 = 0;
  __pyx_t_76 = 0;
  __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_80 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_82, __pyx_t_86) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_t_86);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_Call(__pyx_t_80, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_strip); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_73 = (__pyx_t_80) ? __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_t_80) : __Pyx_PyObject_CallNoArg(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_75 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_73, __pyx_n_u_StreetAddress) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_StreetAddress);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_75)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_75);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;

  /* "alacorder/cal.pyx":560
 *           pl.concat_str([pl.col("SHORTCOUNTY"),pl.lit("-"),pl.col("SHORTCASENO")]).alias("CaseNumber"),
 *           pl.concat_str([pl.col("Address1"), pl.lit(" "), pl.col("Address2")]).str.replace_all(r'JID: \w{3} Hardship.*|Defendant Information.*','').str.strip().alias("StreetAddress"),
 *           pl.col("Name"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("PROBATIONOFFICENUMBERRAW")=="0-000000-00").then(pl.lit('')).otherwise(pl.col("PROBATIONOFFICENUMBERRAW")).alias("ProbationOfficeName"),
 *           pl.when(pl.col("DLRAW")=="AL").then(pl.lit('')).otherwise(pl.col("DLRAW")).alias("DriverLicenseNo"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_73, __pyx_n_s_pl); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_70 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_73, __pyx_n_u_Name) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_Name);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;

  /* "alacorder/cal.pyx":561
 *           pl.concat_str([pl.col("Address1"), pl.lit(" "), pl.col("Address2")]).str.replace_all(r'JID: \w{3} Hardship.*|Defendant Information.*','').str.strip().alias("StreetAddress"),
 *           pl.col("Name"),
 *           pl.when(pl.col("PROBATIONOFFICENUMBERRAW")=="0-000000-00").then(pl.lit('')).otherwise(pl.col("PROBATIONOFFICENUMBERRAW")).alias("ProbationOfficeName"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("DLRAW")=="AL").then(pl.lit('')).otherwise(pl.col("DLRAW")).alias("DriverLicenseNo"),
 *           pl.when(pl.col("SIDRAW")=="AL000000000").then(pl.lit('')).otherwise(pl.col("SIDRAW")).alias("StateID"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_when); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_76 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_81, __pyx_n_u_PROBATIONOFFICENUMBERRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_n_u_PROBATIONOFFICENUMBERRAW);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = PyObject_RichCompare(__pyx_t_76, __pyx_kp_u_0_000000_00, Py_EQ); __Pyx_XGOTREF(__pyx_t_77); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_82 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_76, __pyx_t_77) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_t_77);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_then); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_77, __pyx_n_s_pl); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_lit); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_82 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_77, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_86 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_76, __pyx_t_82) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_t_82);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_col); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_86 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_82, __pyx_n_u_PROBATIONOFFICENUMBERRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_PROBATIONOFFICENUMBERRAW);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_73 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_76, __pyx_t_86) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_t_86);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_80 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_73, __pyx_n_u_ProbationOfficeName) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_ProbationOfficeName);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;

  /* "alacorder/cal.pyx":562
 *           pl.col("Name"),
 *           pl.when(pl.col("PROBATIONOFFICENUMBERRAW")=="0-000000-00").then(pl.lit('')).otherwise(pl.col("PROBATIONOFFICENUMBERRAW")).alias("ProbationOfficeName"),
 *           pl.when(pl.col("DLRAW")=="AL").then(pl.lit('')).otherwise(pl.col("DLRAW")).alias("DriverLicenseNo"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("SIDRAW")=="AL000000000").then(pl.lit('')).otherwise(pl.col("SIDRAW")).alias("StateID"),
 *           pl.col("TOTALS").arr.get(0).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtDue"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_when); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_82 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_81, __pyx_n_u_DLRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_n_u_DLRAW);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = PyObject_RichCompare(__pyx_t_82, __pyx_n_u_AL, Py_EQ); __Pyx_XGOTREF(__pyx_t_83); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_76 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_82, __pyx_t_83) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_t_83);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_then); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_83, __pyx_n_s_pl); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_lit); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_76 = (__pyx_t_83) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_83, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_86 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_82, __pyx_t_76) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_t_76);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_col); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_86 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_76, __pyx_n_u_DLRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_n_u_DLRAW);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_73 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_82, __pyx_t_86) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_t_86);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_78 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_73, __pyx_n_u_DriverLicenseNo) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_n_u_DriverLicenseNo);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;

  /* "alacorder/cal.pyx":563
 *           pl.when(pl.col("PROBATIONOFFICENUMBERRAW")=="0-000000-00").then(pl.lit('')).otherwise(pl.col("PROBATIONOFFICENUMBERRAW")).alias("ProbationOfficeName"),
 *           pl.when(pl.col("DLRAW")=="AL").then(pl.lit('')).otherwise(pl.col("DLRAW")).alias("DriverLicenseNo"),
 *           pl.when(pl.col("SIDRAW")=="AL000000000").then(pl.lit('')).otherwise(pl.col("SIDRAW")).alias("StateID"),             # <<<<<<<<<<<<<<
 *           pl.col("TOTALS").arr.get(0).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtDue"),
 *           pl.col("TOTALS").arr.get(1).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtPaid"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_when); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_76 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_81, __pyx_n_u_SIDRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_SIDRAW);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = PyObject_RichCompare(__pyx_t_76, __pyx_n_u_AL000000000, Py_EQ); __Pyx_XGOTREF(__pyx_t_87); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_82 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_76, __pyx_t_87) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_87);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_then); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_87, __pyx_n_s_pl); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_lit); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_82 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_87, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_86 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_76, __pyx_t_82) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_82);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_col); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_76))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_76);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_76);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_76, function);
    }
  }
  __pyx_t_86 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_76, __pyx_t_82, __pyx_n_u_SIDRAW) : __Pyx_PyObject_CallOneArg(__pyx_t_76, __pyx_n_u_SIDRAW);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_73 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_76, __pyx_t_86) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_86);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_77 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_73, __pyx_n_u_StateID) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_n_u_StateID);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;

  /* "alacorder/cal.pyx":564
 *           pl.when(pl.col("DLRAW")=="AL").then(pl.lit('')).otherwise(pl.col("DLRAW")).alias("DriverLicenseNo"),
 *           pl.when(pl.col("SIDRAW")=="AL000000000").then(pl.lit('')).otherwise(pl.col("SIDRAW")).alias("StateID"),
 *           pl.col("TOTALS").arr.get(0).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtDue"),             # <<<<<<<<<<<<<<
 *           pl.col("TOTALS").arr.get(1).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtPaid"),
 *           pl.col("TOTALS").arr.get(2).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalBalance"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_col); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_86 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_76, __pyx_n_u_TOTALS) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_n_u_TOTALS);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_arr); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_get); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_73 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_82, __pyx_int_0) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_int_0);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_Call(__pyx_t_73, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_cast); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_86, __pyx_n_s_pl); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_Float64); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = PyTuple_New(1); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_82);
  PyTuple_SET_ITEM(__pyx_t_86, 0, __pyx_t_82);
  __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  if (PyDict_SetItem(__pyx_t_82, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 564, __pyx_L1_error)
  __pyx_t_76 = __Pyx_PyObject_Call(__pyx_t_73, __pyx_t_86, __pyx_t_82); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_alias); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_82))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_82);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_82);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_82, function);
    }
  }
  __pyx_t_83 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_82, __pyx_t_76, __pyx_n_u_TotalAmtDue) : __Pyx_PyObject_CallOneArg(__pyx_t_82, __pyx_n_u_TotalAmtDue);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;

  /* "alacorder/cal.pyx":565
 *           pl.when(pl.col("SIDRAW")=="AL000000000").then(pl.lit('')).otherwise(pl.col("SIDRAW")).alias("StateID"),
 *           pl.col("TOTALS").arr.get(0).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtDue"),
 *           pl.col("TOTALS").arr.get(1).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtPaid"),             # <<<<<<<<<<<<<<
 *           pl.col("TOTALS").arr.get(2).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalBalance"),
 *           pl.col("TOTALS").arr.get(3).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtHold"))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_73, __pyx_n_s_pl); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_col); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_86 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_73, __pyx_n_u_TOTALS) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_TOTALS);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_arr); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_get); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_76 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_87, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_Call(__pyx_t_76, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_cast); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_86, __pyx_n_s_pl); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_Float64); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = PyTuple_New(1); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_87);
  PyTuple_SET_ITEM(__pyx_t_86, 0, __pyx_t_87);
  __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  if (PyDict_SetItem(__pyx_t_87, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 565, __pyx_L1_error)
  __pyx_t_73 = __Pyx_PyObject_Call(__pyx_t_76, __pyx_t_86, __pyx_t_87); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_82 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_73, __pyx_n_u_TotalAmtPaid) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_TotalAmtPaid);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;

  /* "alacorder/cal.pyx":566
 *           pl.col("TOTALS").arr.get(0).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtDue"),
 *           pl.col("TOTALS").arr.get(1).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtPaid"),
 *           pl.col("TOTALS").arr.get(2).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalBalance"),             # <<<<<<<<<<<<<<
 *           pl.col("TOTALS").arr.get(3).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtHold"))
 *      cases = cases.with_columns(
 */
  __Pyx_GetModuleGlobalName(__pyx_t_76, __pyx_n_s_pl); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_col); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_86 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_76, __pyx_n_u_TOTALS) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_TOTALS);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_arr); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_get); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_73 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_81, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_int_2);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_Call(__pyx_t_73, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_cast); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_86, __pyx_n_s_pl); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_Float64); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = PyTuple_New(1); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_81);
  PyTuple_SET_ITEM(__pyx_t_86, 0, __pyx_t_81);
  __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  if (PyDict_SetItem(__pyx_t_81, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 566, __pyx_L1_error)
  __pyx_t_76 = __Pyx_PyObject_Call(__pyx_t_73, __pyx_t_86, __pyx_t_81); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_alias); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_76 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_76)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_76);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_87 = (__pyx_t_76) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_76, __pyx_n_u_TotalBalance) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_TotalBalance);
  __Pyx_XDECREF(__pyx_t_76); __pyx_t_76 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 566, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;

  /* "alacorder/cal.pyx":567
 *           pl.col("TOTALS").arr.get(1).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtPaid"),
 *           pl.col("TOTALS").arr.get(2).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalBalance"),
 *           pl.col("TOTALS").arr.get(3).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtHold"))             # <<<<<<<<<<<<<<
 *      cases = cases.with_columns(
 *           pl.when(pl.col("CLEAN_Phone").str.n_chars()<7).then(None).otherwise(pl.col("CLEAN_Phone")).alias("Phone"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_73, __pyx_n_s_pl); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_col); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_85))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_85);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_85);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_85, function);
    }
  }
  __pyx_t_86 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_85, __pyx_t_73, __pyx_n_u_TOTALS) : __Pyx_PyObject_CallOneArg(__pyx_t_85, __pyx_n_u_TOTALS);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_arr); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_85, __pyx_n_s_get); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_86))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_86);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_86);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_86, function);
    }
  }
  __pyx_t_76 = (__pyx_t_85) ? __Pyx_PyObject_Call2Args(__pyx_t_86, __pyx_t_85, __pyx_int_3) : __Pyx_PyObject_CallOneArg(__pyx_t_86, __pyx_int_3);
  __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
  if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_GetAttrStr(__pyx_t_76, __pyx_n_s_str); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = __Pyx_PyObject_Call(__pyx_t_76, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __pyx_t_76 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_cast); if (unlikely(!__pyx_t_76)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_76);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_86, __pyx_n_s_pl); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_86, __pyx_n_s_Float64); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __pyx_t_86 = PyTuple_New(1); if (unlikely(!__pyx_t_86)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_86);
  __Pyx_GIVEREF(__pyx_t_85);
  PyTuple_SET_ITEM(__pyx_t_86, 0, __pyx_t_85);
  __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  if (PyDict_SetItem(__pyx_t_85, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 567, __pyx_L1_error)
  __pyx_t_73 = __Pyx_PyObject_Call(__pyx_t_76, __pyx_t_86, __pyx_t_85); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_76); __pyx_t_76 = 0;
  __Pyx_DECREF(__pyx_t_86); __pyx_t_86 = 0;
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_85)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_85);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_85))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_85);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_85);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_85, function);
    }
  }
  __pyx_t_81 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_85, __pyx_t_73, __pyx_n_u_TotalAmtHold) : __Pyx_PyObject_CallOneArg(__pyx_t_85, __pyx_n_u_TotalAmtHold);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_85); __pyx_t_85 = 0;
  __pyx_t_85 = NULL;
  __pyx_t_90 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_85 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_85)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_85);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_90 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[12] = {__pyx_t_85, __pyx_t_71, __pyx_t_74, __pyx_t_75, __pyx_t_70, __pyx_t_80, __pyx_t_78, __pyx_t_77, __pyx_t_83, __pyx_t_82, __pyx_t_87, __pyx_t_81};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_90, 11+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
    __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
    __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
    __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
    __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
    __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
    __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
    __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
    __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
    __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
    __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[12] = {__pyx_t_85, __pyx_t_71, __pyx_t_74, __pyx_t_75, __pyx_t_70, __pyx_t_80, __pyx_t_78, __pyx_t_77, __pyx_t_83, __pyx_t_82, __pyx_t_87, __pyx_t_81};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_90, 11+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_85); __pyx_t_85 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_71); __pyx_t_71 = 0;
    __Pyx_DECREF(__pyx_t_74); __pyx_t_74 = 0;
    __Pyx_DECREF(__pyx_t_75); __pyx_t_75 = 0;
    __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
    __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
    __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
    __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
    __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
    __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
    __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
    __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  } else
  #endif
  {
    __pyx_t_73 = PyTuple_New(11+__pyx_t_90); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_73);
    if (__pyx_t_85) {
      __Pyx_GIVEREF(__pyx_t_85); PyTuple_SET_ITEM(__pyx_t_73, 0, __pyx_t_85); __pyx_t_85 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_71);
    PyTuple_SET_ITEM(__pyx_t_73, 0+__pyx_t_90, __pyx_t_71);
    __Pyx_GIVEREF(__pyx_t_74);
    PyTuple_SET_ITEM(__pyx_t_73, 1+__pyx_t_90, __pyx_t_74);
    __Pyx_GIVEREF(__pyx_t_75);
    PyTuple_SET_ITEM(__pyx_t_73, 2+__pyx_t_90, __pyx_t_75);
    __Pyx_GIVEREF(__pyx_t_70);
    PyTuple_SET_ITEM(__pyx_t_73, 3+__pyx_t_90, __pyx_t_70);
    __Pyx_GIVEREF(__pyx_t_80);
    PyTuple_SET_ITEM(__pyx_t_73, 4+__pyx_t_90, __pyx_t_80);
    __Pyx_GIVEREF(__pyx_t_78);
    PyTuple_SET_ITEM(__pyx_t_73, 5+__pyx_t_90, __pyx_t_78);
    __Pyx_GIVEREF(__pyx_t_77);
    PyTuple_SET_ITEM(__pyx_t_73, 6+__pyx_t_90, __pyx_t_77);
    __Pyx_GIVEREF(__pyx_t_83);
    PyTuple_SET_ITEM(__pyx_t_73, 7+__pyx_t_90, __pyx_t_83);
    __Pyx_GIVEREF(__pyx_t_82);
    PyTuple_SET_ITEM(__pyx_t_73, 8+__pyx_t_90, __pyx_t_82);
    __Pyx_GIVEREF(__pyx_t_87);
    PyTuple_SET_ITEM(__pyx_t_73, 9+__pyx_t_90, __pyx_t_87);
    __Pyx_GIVEREF(__pyx_t_81);
    PyTuple_SET_ITEM(__pyx_t_73, 10+__pyx_t_90, __pyx_t_81);
    __pyx_t_71 = 0;
    __pyx_t_74 = 0;
    __pyx_t_75 = 0;
    __pyx_t_70 = 0;
    __pyx_t_80 = 0;
    __pyx_t_78 = 0;
    __pyx_t_77 = 0;
    __pyx_t_83 = 0;
    __pyx_t_82 = 0;
    __pyx_t_87 = 0;
    __pyx_t_81 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_73, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 556, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":568
 *           pl.col("TOTALS").arr.get(2).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalBalance"),
 *           pl.col("TOTALS").arr.get(3).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtHold"))
 *      cases = cases.with_columns(             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("CLEAN_Phone").str.n_chars()<7).then(None).otherwise(pl.col("CLEAN_Phone")).alias("Phone"),
 *           pl.when(True).then((pl.col("TotalBalance") - pl.col("D999"))).otherwise(None).alias("PaymentToRestore"))
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":569
 *           pl.col("TOTALS").arr.get(3).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtHold"))
 *      cases = cases.with_columns(
 *           pl.when(pl.col("CLEAN_Phone").str.n_chars()<7).then(None).otherwise(pl.col("CLEAN_Phone")).alias("Phone"),             # <<<<<<<<<<<<<<
 *           pl.when(True).then((pl.col("TotalBalance") - pl.col("D999"))).otherwise(None).alias("PaymentToRestore"))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_83, __pyx_n_s_pl); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_when); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_80, __pyx_n_s_pl); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_col); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_78 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_80, __pyx_n_u_CLEAN_Phone) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_CLEAN_Phone);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_str); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_70, __pyx_n_s_n_chars); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_83 = (__pyx_t_70) ? __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_t_70) : __Pyx_PyObject_CallNoArg(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = PyObject_RichCompare(__pyx_t_83, __pyx_int_7, Py_LT); __Pyx_XGOTREF(__pyx_t_78); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_82 = (__pyx_t_83) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_83, __pyx_t_78) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_t_78);
  __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_then); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_87 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_82, Py_None) : __Pyx_PyObject_CallOneArg(__pyx_t_77, Py_None);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_78 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_col); if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_78))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_78);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_78);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_78, function);
    }
  }
  __pyx_t_87 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_78, __pyx_t_82, __pyx_n_u_CLEAN_Phone) : __Pyx_PyObject_CallOneArg(__pyx_t_78, __pyx_n_u_CLEAN_Phone);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __pyx_t_78 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_78 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_78)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_78);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_81 = (__pyx_t_78) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_78, __pyx_t_87) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_t_87);
  __Pyx_XDECREF(__pyx_t_78); __pyx_t_78 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_alias); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_77))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_77);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_77);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_77, function);
    }
  }
  __pyx_t_73 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_77, __pyx_t_81, __pyx_n_u_Phone_3) : __Pyx_PyObject_CallOneArg(__pyx_t_77, __pyx_n_u_Phone_3);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;

  /* "alacorder/cal.pyx":570
 *      cases = cases.with_columns(
 *           pl.when(pl.col("CLEAN_Phone").str.n_chars()<7).then(None).otherwise(pl.col("CLEAN_Phone")).alias("Phone"),
 *           pl.when(True).then((pl.col("TotalBalance") - pl.col("D999"))).otherwise(None).alias("PaymentToRestore"))             # <<<<<<<<<<<<<<
 * 
 *      # clean Charges strings
 */
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_when); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_78 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_82, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_83, Py_True);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_78, __pyx_n_s_then); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_70 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_col); if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_70))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_70);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_70);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_70, function);
    }
  }
  __pyx_t_78 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_70, __pyx_t_82, __pyx_n_u_TotalBalance) : __Pyx_PyObject_CallOneArg(__pyx_t_70, __pyx_n_u_TotalBalance);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_78)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_78);
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_82, __pyx_n_s_pl); if (unlikely(!__pyx_t_82)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_82);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_82, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_82); __pyx_t_82 = 0;
  __pyx_t_82 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_82 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_82)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_82);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_70 = (__pyx_t_82) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_82, __pyx_n_u_D999) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_D999);
  __Pyx_XDECREF(__pyx_t_82); __pyx_t_82 = 0;
  if (unlikely(!__pyx_t_70)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_70);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = PyNumber_Subtract(__pyx_t_78, __pyx_t_70); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_78); __pyx_t_78 = 0;
  __Pyx_DECREF(__pyx_t_70); __pyx_t_70 = 0;
  __pyx_t_70 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_70 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_70)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_70);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_87 = (__pyx_t_70) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_70, __pyx_t_80) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_t_80);
  __Pyx_XDECREF(__pyx_t_70); __pyx_t_70 = 0;
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_81 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_87, Py_None) : __Pyx_PyObject_CallOneArg(__pyx_t_83, Py_None);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_alias); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_83))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_83);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_83);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_83, function);
    }
  }
  __pyx_t_77 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_83, __pyx_t_81, __pyx_n_u_PaymentToRestore) : __Pyx_PyObject_CallOneArg(__pyx_t_83, __pyx_n_u_PaymentToRestore);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  __pyx_t_90 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_90 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_83, __pyx_t_73, __pyx_t_77};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_90, 2+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
    __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_83, __pyx_t_73, __pyx_t_77};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_90, 2+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
    __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  } else
  #endif
  {
    __pyx_t_81 = PyTuple_New(2+__pyx_t_90); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_81);
    if (__pyx_t_83) {
      __Pyx_GIVEREF(__pyx_t_83); PyTuple_SET_ITEM(__pyx_t_81, 0, __pyx_t_83); __pyx_t_83 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_73);
    PyTuple_SET_ITEM(__pyx_t_81, 0+__pyx_t_90, __pyx_t_73);
    __Pyx_GIVEREF(__pyx_t_77);
    PyTuple_SET_ITEM(__pyx_t_81, 1+__pyx_t_90, __pyx_t_77);
    __pyx_t_73 = 0;
    __pyx_t_77 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_81, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":574
 *      # clean Charges strings
 *      # explode Charges for table parsing
 *      all_charges = cases.explode("RE_Charges").select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Charges").str.replace_all(r'[A-Z][a-z][A-Za-z\s\$]+.+','').str.strip().alias("Charges")])
 */
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_explode); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_2 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_77, __pyx_n_u_RE_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_RE_Charges);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_select); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":575
 *      # explode Charges for table parsing
 *      all_charges = cases.explode("RE_Charges").select([
 *           pl.col("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.col("RE_Charges").str.replace_all(r'[A-Z][a-z][A-Za-z\s\$]+.+','').str.strip().alias("Charges")])
 *      cases.drop_in_place("RE_Charges")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_77, __pyx_n_s_pl); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_col); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_2 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_77, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;

  /* "alacorder/cal.pyx":576
 *      all_charges = cases.explode("RE_Charges").select([
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Charges").str.replace_all(r'[A-Z][a-z][A-Za-z\s\$]+.+','').str.strip().alias("Charges")])             # <<<<<<<<<<<<<<
 *      cases.drop_in_place("RE_Charges")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_87, __pyx_n_s_pl); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_col); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_83 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_87, __pyx_n_u_RE_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_RE_Charges);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_str); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_Call(__pyx_t_83, __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_str); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_strip); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_77 = (__pyx_t_83) ? __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_83) : __Pyx_PyObject_CallNoArg(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_alias); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_73 = (__pyx_t_77) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_77, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;

  /* "alacorder/cal.pyx":574
 *      # clean Charges strings
 *      # explode Charges for table parsing
 *      all_charges = cases.explode("RE_Charges").select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Charges").str.replace_all(r'[A-Z][a-z][A-Za-z\s\$]+.+','').str.strip().alias("Charges")])
 */
  __pyx_t_80 = PyList_New(2); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_80, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_73);
  PyList_SET_ITEM(__pyx_t_80, 1, __pyx_t_73);
  __pyx_t_2 = 0;
  __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_1 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_73, __pyx_t_80) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_t_80);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_v_all_charges = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":577
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Charges").str.replace_all(r'[A-Z][a-z][A-Za-z\s\$]+.+','').str.strip().alias("Charges")])
 *      cases.drop_in_place("RE_Charges")             # <<<<<<<<<<<<<<
 * 
 *      # clean Fees strings
 */
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_drop_in_place); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_80 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_80 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_80)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_80);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_1 = (__pyx_t_80) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_80, __pyx_n_u_RE_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_RE_Charges);
  __Pyx_XDECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":581
 *      # clean Fees strings
 *      # explode Fees for table parsing
 *      all_fees = cases.explode("RE_Fees").select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Fees").str.replace_all(r"[^A-Z0-9|\.|\s|\$|\n]"," ").str.strip().alias("Fees")])
 */
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_explode); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_81 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_73, __pyx_n_u_RE_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_RE_Fees);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_select); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;

  /* "alacorder/cal.pyx":582
 *      # explode Fees for table parsing
 *      all_fees = cases.explode("RE_Fees").select([
 *           pl.col("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.col("RE_Fees").str.replace_all(r"[^A-Z0-9|\.|\s|\$|\n]"," ").str.strip().alias("Fees")])
 *      cases.drop_in_place("RE_Fees")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_73, __pyx_n_s_pl); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_81 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_73, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":583
 *      all_fees = cases.explode("RE_Fees").select([
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Fees").str.replace_all(r"[^A-Z0-9|\.|\s|\$|\n]"," ").str.strip().alias("Fees")])             # <<<<<<<<<<<<<<
 *      cases.drop_in_place("RE_Fees")
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_83, __pyx_n_s_pl); if (unlikely(!__pyx_t_83)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_83);
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_83, __pyx_n_s_col); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_83); __pyx_t_83 = 0;
  __pyx_t_83 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_83 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_83)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_83);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_77 = (__pyx_t_83) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_83, __pyx_n_u_RE_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_RE_Fees);
  __Pyx_XDECREF(__pyx_t_83); __pyx_t_83 = 0;
  if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_str); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_Call(__pyx_t_77, __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_str); if (unlikely(!__pyx_t_77)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_77);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_77, __pyx_n_s_strip); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_77); __pyx_t_77 = 0;
  __pyx_t_77 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_77 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_77)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_77);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_73 = (__pyx_t_77) ? __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_t_77) : __Pyx_PyObject_CallNoArg(__pyx_t_87);
  __Pyx_XDECREF(__pyx_t_77); __pyx_t_77 = 0;
  if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_alias); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_2 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_73, __pyx_n_u_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_Fees);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;

  /* "alacorder/cal.pyx":581
 *      # clean Fees strings
 *      # explode Fees for table parsing
 *      all_fees = cases.explode("RE_Fees").select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Fees").str.replace_all(r"[^A-Z0-9|\.|\s|\$|\n]"," ").str.strip().alias("Fees")])
 */
  __pyx_t_87 = PyList_New(2); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_GIVEREF(__pyx_t_81);
  PyList_SET_ITEM(__pyx_t_87, 0, __pyx_t_81);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_87, 1, __pyx_t_2);
  __pyx_t_81 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_2, __pyx_t_87) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_87);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_v_all_fees = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":584
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Fees").str.replace_all(r"[^A-Z0-9|\.|\s|\$|\n]"," ").str.strip().alias("Fees")])
 *      cases.drop_in_place("RE_Fees")             # <<<<<<<<<<<<<<
 * 
 *      dlog(debug, [cases.columns, cases.shape, "alac 931"])
 */
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_drop_in_place); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_1 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_87, __pyx_n_u_RE_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_RE_Fees);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":586
 *      cases.drop_in_place("RE_Fees")
 * 
 *      dlog(debug, [cases.columns, cases.shape, "alac 931"])             # <<<<<<<<<<<<<<
 * 
 *      # add Charges, Fees [str] to cases table
 */
  __Pyx_GetModuleGlobalName(__pyx_t_80, __pyx_n_s_dlog); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_columns); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_shape); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_81 = PyList_New(3); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_GIVEREF(__pyx_t_87);
  PyList_SET_ITEM(__pyx_t_81, 0, __pyx_t_87);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_81, 1, __pyx_t_2);
  __Pyx_INCREF(__pyx_kp_u_alac_931);
  __Pyx_GIVEREF(__pyx_kp_u_alac_931);
  PyList_SET_ITEM(__pyx_t_81, 2, __pyx_kp_u_alac_931);
  __pyx_t_87 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_90 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
      __pyx_t_90 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_80)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_debug, __pyx_t_81};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_80, __pyx_temp+1-__pyx_t_90, 2+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_80)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_v_debug, __pyx_t_81};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_80, __pyx_temp+1-__pyx_t_90, 2+__pyx_t_90); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  } else
  #endif
  {
    __pyx_t_87 = PyTuple_New(2+__pyx_t_90); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_87);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_87, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_87, 0+__pyx_t_90, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_81);
    PyTuple_SET_ITEM(__pyx_t_87, 1+__pyx_t_90, __pyx_t_81);
    __pyx_t_81 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_80, __pyx_t_87, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 586, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  }
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":589
 * 
 *      # add Charges, Fees [str] to cases table
 *      clean_ch_list = all_charges.groupby("CaseNumber").agg(pl.col("Charges"))             # <<<<<<<<<<<<<<
 *      clean_fs_list = all_fees.groupby("CaseNumber").agg(pl.col("Fees"))
 *      cases = cases.join(clean_ch_list, on="CaseNumber", how="left")
 */
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_v_all_charges, __pyx_n_s_groupby); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_80 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_81, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_80, __pyx_n_s_agg); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_81, __pyx_n_s_pl); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_80 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_81, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_2, __pyx_t_80) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_t_80);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_v_clean_ch_list = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":590
 *      # add Charges, Fees [str] to cases table
 *      clean_ch_list = all_charges.groupby("CaseNumber").agg(pl.col("Charges"))
 *      clean_fs_list = all_fees.groupby("CaseNumber").agg(pl.col("Fees"))             # <<<<<<<<<<<<<<
 *      cases = cases.join(clean_ch_list, on="CaseNumber", how="left")
 *      cases = cases.join(clean_fs_list, on="CaseNumber", how="left")
 */
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_v_all_fees, __pyx_n_s_groupby); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_87 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_2, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_agg); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_87 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_2, __pyx_n_u_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_n_u_Fees);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_1 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_81, __pyx_t_87) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_87);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __pyx_v_clean_fs_list = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":591
 *      clean_ch_list = all_charges.groupby("CaseNumber").agg(pl.col("Charges"))
 *      clean_fs_list = all_fees.groupby("CaseNumber").agg(pl.col("Fees"))
 *      cases = cases.join(clean_ch_list, on="CaseNumber", how="left")             # <<<<<<<<<<<<<<
 *      cases = cases.join(clean_fs_list, on="CaseNumber", how="left")
 *      cases = cases.with_columns(pl.col("Charges").arr.join("; ").str.replace_all(r'(null;?)',''))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_join); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_80 = PyTuple_New(1); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_INCREF(__pyx_v_clean_ch_list);
  __Pyx_GIVEREF(__pyx_v_clean_ch_list);
  PyTuple_SET_ITEM(__pyx_t_80, 0, __pyx_v_clean_ch_list);
  __pyx_t_87 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  if (PyDict_SetItem(__pyx_t_87, __pyx_n_s_on, __pyx_n_u_CaseNumber) < 0) __PYX_ERR(0, 591, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_87, __pyx_n_s_how, __pyx_n_u_left) < 0) __PYX_ERR(0, 591, __pyx_L1_error)
  __pyx_t_81 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_80, __pyx_t_87); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_81);
  __pyx_t_81 = 0;

  /* "alacorder/cal.pyx":592
 *      clean_fs_list = all_fees.groupby("CaseNumber").agg(pl.col("Fees"))
 *      cases = cases.join(clean_ch_list, on="CaseNumber", how="left")
 *      cases = cases.join(clean_fs_list, on="CaseNumber", how="left")             # <<<<<<<<<<<<<<
 *      cases = cases.with_columns(pl.col("Charges").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))
 */
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_join); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __pyx_t_87 = PyTuple_New(1); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_INCREF(__pyx_v_clean_fs_list);
  __Pyx_GIVEREF(__pyx_v_clean_fs_list);
  PyTuple_SET_ITEM(__pyx_t_87, 0, __pyx_v_clean_fs_list);
  __pyx_t_80 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  if (PyDict_SetItem(__pyx_t_80, __pyx_n_s_on, __pyx_n_u_CaseNumber) < 0) __PYX_ERR(0, 592, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_80, __pyx_n_s_how, __pyx_n_u_left) < 0) __PYX_ERR(0, 592, __pyx_L1_error)
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_t_87, __pyx_t_80); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":593
 *      cases = cases.join(clean_ch_list, on="CaseNumber", how="left")
 *      cases = cases.join(clean_fs_list, on="CaseNumber", how="left")
 *      cases = cases.with_columns(pl.col("Charges").arr.join("; ").str.replace_all(r'(null;?)',''))             # <<<<<<<<<<<<<<
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.fill_null('')
 */
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_col); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_73))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_73);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_73);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_73, function);
    }
  }
  __pyx_t_81 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_73, __pyx_t_2, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_73, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_arr); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_join); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_81))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_81);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_81);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_81, function);
    }
  }
  __pyx_t_87 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_81, __pyx_t_73, __pyx_kp_u__69) : __Pyx_PyObject_CallOneArg(__pyx_t_81, __pyx_kp_u__69);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_str); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_Call(__pyx_t_87, __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_1 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_87, __pyx_t_81) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_81);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":594
 *      cases = cases.join(clean_fs_list, on="CaseNumber", how="left")
 *      cases = cases.with_columns(pl.col("Charges").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))             # <<<<<<<<<<<<<<
 *      cases = cases.fill_null('')
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 */
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_GetModuleGlobalName(__pyx_t_73, __pyx_n_s_pl); if (unlikely(!__pyx_t_73)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_73);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_73, __pyx_n_s_col); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_73); __pyx_t_73 = 0;
  __pyx_t_73 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_73 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_73)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_73);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_87 = (__pyx_t_73) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_73, __pyx_n_u_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_n_u_Fees);
  __Pyx_XDECREF(__pyx_t_73); __pyx_t_73 = 0;
  if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_arr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_join); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_87))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_87);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_87);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_87, function);
    }
  }
  __pyx_t_81 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_87, __pyx_t_2, __pyx_kp_u__69) : __Pyx_PyObject_CallOneArg(__pyx_t_87, __pyx_kp_u__69);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_GetAttrStr(__pyx_t_81, __pyx_n_s_str); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = __Pyx_PyObject_GetAttrStr(__pyx_t_87, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_81)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_81);
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  __pyx_t_87 = __Pyx_PyObject_Call(__pyx_t_81, __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_87)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_87);
  __Pyx_DECREF(__pyx_t_81); __pyx_t_81 = 0;
  __pyx_t_81 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_81 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_81)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_81);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_1 = (__pyx_t_81) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_81, __pyx_t_87) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_t_87);
  __Pyx_XDECREF(__pyx_t_81); __pyx_t_81 = 0;
  __Pyx_DECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":595
 *      cases = cases.with_columns(pl.col("Charges").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.fill_null('')             # <<<<<<<<<<<<<<
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees
 */
  __pyx_t_80 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_fill_null); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __pyx_t_87 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_80))) {
    __pyx_t_87 = PyMethod_GET_SELF(__pyx_t_80);
    if (likely(__pyx_t_87)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_80);
      __Pyx_INCREF(__pyx_t_87);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_80, function);
    }
  }
  __pyx_t_1 = (__pyx_t_87) ? __Pyx_PyObject_Call2Args(__pyx_t_80, __pyx_t_87, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_80, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_87); __pyx_t_87 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_80); __pyx_t_80 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":596
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.fill_null('')
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')             # <<<<<<<<<<<<<<
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cases, __pyx_n_s_select); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_80 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_cases, __pyx_t_80);
  __pyx_t_80 = 0;

  /* "alacorder/cal.pyx":597
 *      cases = cases.fill_null('')
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees             # <<<<<<<<<<<<<<
 * def split_charges(df, debug=False):
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_80 = PyTuple_New(3); if (unlikely(!__pyx_t_80)) __PYX_ERR(0, 597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_80);
  __Pyx_INCREF(__pyx_v_cases);
  __Pyx_GIVEREF(__pyx_v_cases);
  PyTuple_SET_ITEM(__pyx_t_80, 0, __pyx_v_cases);
  __Pyx_INCREF(__pyx_v_all_charges);
  __Pyx_GIVEREF(__pyx_v_all_charges);
  PyTuple_SET_ITEM(__pyx_t_80, 1, __pyx_v_all_charges);
  __Pyx_INCREF(__pyx_v_all_fees);
  __Pyx_GIVEREF(__pyx_v_all_fees);
  PyTuple_SET_ITEM(__pyx_t_80, 2, __pyx_v_all_fees);
  __pyx_r = __pyx_t_80;
  __pyx_t_80 = 0;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":454
 * #   #   #   #           TABLE PARSERS           #   #   #   #
 * 
 * def split_cases(df, debug=False):             # <<<<<<<<<<<<<<
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_XDECREF(__pyx_t_24);
  __Pyx_XDECREF(__pyx_t_25);
  __Pyx_XDECREF(__pyx_t_26);
  __Pyx_XDECREF(__pyx_t_27);
  __Pyx_XDECREF(__pyx_t_28);
  __Pyx_XDECREF(__pyx_t_29);
  __Pyx_XDECREF(__pyx_t_30);
  __Pyx_XDECREF(__pyx_t_31);
  __Pyx_XDECREF(__pyx_t_32);
  __Pyx_XDECREF(__pyx_t_33);
  __Pyx_XDECREF(__pyx_t_34);
  __Pyx_XDECREF(__pyx_t_35);
  __Pyx_XDECREF(__pyx_t_36);
  __Pyx_XDECREF(__pyx_t_37);
  __Pyx_XDECREF(__pyx_t_38);
  __Pyx_XDECREF(__pyx_t_39);
  __Pyx_XDECREF(__pyx_t_40);
  __Pyx_XDECREF(__pyx_t_41);
  __Pyx_XDECREF(__pyx_t_42);
  __Pyx_XDECREF(__pyx_t_43);
  __Pyx_XDECREF(__pyx_t_44);
  __Pyx_XDECREF(__pyx_t_45);
  __Pyx_XDECREF(__pyx_t_46);
  __Pyx_XDECREF(__pyx_t_47);
  __Pyx_XDECREF(__pyx_t_48);
  __Pyx_XDECREF(__pyx_t_49);
  __Pyx_XDECREF(__pyx_t_50);
  __Pyx_XDECREF(__pyx_t_51);
  __Pyx_XDECREF(__pyx_t_52);
  __Pyx_XDECREF(__pyx_t_53);
  __Pyx_XDECREF(__pyx_t_54);
  __Pyx_XDECREF(__pyx_t_55);
  __Pyx_XDECREF(__pyx_t_56);
  __Pyx_XDECREF(__pyx_t_57);
  __Pyx_XDECREF(__pyx_t_58);
  __Pyx_XDECREF(__pyx_t_59);
  __Pyx_XDECREF(__pyx_t_60);
  __Pyx_XDECREF(__pyx_t_61);
  __Pyx_XDECREF(__pyx_t_62);
  __Pyx_XDECREF(__pyx_t_63);
  __Pyx_XDECREF(__pyx_t_64);
  __Pyx_XDECREF(__pyx_t_65);
  __Pyx_XDECREF(__pyx_t_66);
  __Pyx_XDECREF(__pyx_t_67);
  __Pyx_XDECREF(__pyx_t_68);
  __Pyx_XDECREF(__pyx_t_69);
  __Pyx_XDECREF(__pyx_t_70);
  __Pyx_XDECREF(__pyx_t_71);
  __Pyx_XDECREF(__pyx_t_72);
  __Pyx_XDECREF(__pyx_t_73);
  __Pyx_XDECREF(__pyx_t_74);
  __Pyx_XDECREF(__pyx_t_75);
  __Pyx_XDECREF(__pyx_t_76);
  __Pyx_XDECREF(__pyx_t_77);
  __Pyx_XDECREF(__pyx_t_78);
  __Pyx_XDECREF(__pyx_t_79);
  __Pyx_XDECREF(__pyx_t_80);
  __Pyx_XDECREF(__pyx_t_81);
  __Pyx_XDECREF(__pyx_t_82);
  __Pyx_XDECREF(__pyx_t_83);
  __Pyx_XDECREF(__pyx_t_84);
  __Pyx_XDECREF(__pyx_t_85);
  __Pyx_XDECREF(__pyx_t_86);
  __Pyx_XDECREF(__pyx_t_87);
  __Pyx_XDECREF(__pyx_t_88);
  __Pyx_XDECREF(__pyx_t_89);
  __Pyx_AddTraceback("alacorder.cal.split_cases", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_cases);
  __Pyx_XDECREF(__pyx_v_all_charges);
  __Pyx_XDECREF(__pyx_v_all_fees);
  __Pyx_XDECREF(__pyx_v_clean_ch_list);
  __Pyx_XDECREF(__pyx_v_clean_fs_list);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":598
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):             # <<<<<<<<<<<<<<
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_27split_charges(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_27split_charges = {"split_charges", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_27split_charges, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9alacorder_3cal_27split_charges(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_df = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split_charges (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_df,&__pyx_n_s_debug,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_df)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "split_charges") < 0)) __PYX_ERR(0, 598, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_df = values[0];
    __pyx_v_debug = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("split_charges", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 598, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.split_charges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_26split_charges(__pyx_self, __pyx_v_df, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":607
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")             # <<<<<<<<<<<<<<
 *           ])
 *      charges = charges.with_columns([
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_13split_charges_lambda(PyObject *__pyx_self, PyObject *__pyx_v_x); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_13split_charges_lambda = {"lambda", (PyCFunction)__pyx_pw_9alacorder_3cal_13split_charges_lambda, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_13split_charges_lambda(PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda (wrapper)", 0);
  __pyx_r = __pyx_lambda_funcdef_lambda(__pyx_self, ((PyObject *)__pyx_v_x));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_lambda(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_x); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 607, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A);
    __Pyx_GIVEREF(__pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.split_charges.lambda", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":598
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):             # <<<<<<<<<<<<<<
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 */

static PyObject *__pyx_pf_9alacorder_3cal_26split_charges(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_charges = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("split_charges", 0);

  /* "alacorder/cal.pyx":599
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):
 *      dlog(debug, [df.columns, df.shape, "alac 945"])             # <<<<<<<<<<<<<<
 *      charges = df.with_columns([
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_shape); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
  __Pyx_INCREF(__pyx_kp_u_alac_945);
  __Pyx_GIVEREF(__pyx_kp_u_alac_945);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_alac_945);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_debug, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_debug, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_3 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_6, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_6, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":600
 * def split_charges(df, debug=False):
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":601
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 *           pl.col("Charges").str.slice(0,3).alias("Num"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_slice); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_alias); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_n_u_Num) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_Num);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":602
 *      charges = df.with_columns([
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 *           pl.col("Charges").str.slice(4,4).alias("Code"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_4, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_slice); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__73, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_n_u_Code) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_Code);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":603
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_8 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_4, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_slice); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__74, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_n_u_Sort) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Sort);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":604
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_9 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_extract); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 604, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__75, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_8 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_n_u_CourtActionDate) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_CourtActionDate);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":605
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_9, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_extract); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  if (PyDict_SetItem(__pyx_t_11, __pyx_n_s_group_index, __pyx_int_0) < 0) __PYX_ERR(0, 605, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__76, __pyx_t_11); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_alias); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_10 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_9, __pyx_n_u_Cite) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_Cite);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "alacorder/cal.pyx":606
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_9 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_4, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_str); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_extract); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 606, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__77, __pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_11 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_4, __pyx_n_u_CourtAction) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_CourtAction);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "alacorder/cal.pyx":607
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")             # <<<<<<<<<<<<<<
 *           ])
 *      charges = charges.with_columns([
 */
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_9 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_apply); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_CyFunction_New(&__pyx_mdef_9alacorder_3cal_13split_charges_lambda, 0, __pyx_n_s_split_charges_locals_lambda, NULL, __pyx_n_s_alacorder_cal, __pyx_d, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_4 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_4, __pyx_n_u_Split) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_Split);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "alacorder/cal.pyx":600
 * def split_charges(df, debug=False):
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 */
  __pyx_t_14 = PyList_New(7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_14, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_14, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_14, 2, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_14, 3, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_14, 4, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_14, 5, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_14, 6, __pyx_t_12);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_10 = 0;
  __pyx_t_11 = 0;
  __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_12, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_charges = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":609
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")
 *           ])
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).alias("Disposition"),
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).is_not().alias("Filing"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":610
 *           ])
 *      charges = charges.with_columns([
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).alias("Disposition"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).is_not().alias("Filing"),
 *           pl.col("Charges").str.contains(pl.lit("FELONY")).alias("Felony"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_11 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_10, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_contains); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_8 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_10, __pyx_n_u_CourtActionDate) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_CourtActionDate);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_12 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_7, __pyx_t_8) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_8);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_14 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_12, __pyx_n_u_Disposition) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_Disposition);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 610, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "alacorder/cal.pyx":611
 *      charges = charges.with_columns([
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).alias("Disposition"),
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).is_not().alias("Filing"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains(pl.lit("FELONY")).alias("Felony"),
 *           pl.col("Charges").str.contains("GUILTY PLEA").alias("GUILTY_PLEA"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_10, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_contains); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_10, __pyx_n_u_CourtActionDate) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_CourtActionDate);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_8 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_is_not); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_12 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_11 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_12, __pyx_n_u_Filing) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_Filing);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":612
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).alias("Disposition"),
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).is_not().alias("Filing"),
 *           pl.col("Charges").str.contains(pl.lit("FELONY")).alias("Felony"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains("GUILTY PLEA").alias("GUILTY_PLEA"),
 *           pl.col("Charges").str.contains("CONVICTED").alias("CONVICTED")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_8 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_contains); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_lit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_5, __pyx_n_u_FELONY) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_FELONY);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_12 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_10, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_7 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_12, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":613
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).is_not().alias("Filing"),
 *           pl.col("Charges").str.contains(pl.lit("FELONY")).alias("Felony"),
 *           pl.col("Charges").str.contains("GUILTY PLEA").alias("GUILTY_PLEA"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains("CONVICTED").alias("CONVICTED")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_10, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_contains); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_12 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_kp_u_GUILTY_PLEA) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_kp_u_GUILTY_PLEA);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_8 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_12, __pyx_n_u_GUILTY_PLEA_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_GUILTY_PLEA_2);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":614
 *           pl.col("Charges").str.contains(pl.lit("FELONY")).alias("Felony"),
 *           pl.col("Charges").str.contains("GUILTY PLEA").alias("GUILTY_PLEA"),
 *           pl.col("Charges").str.contains("CONVICTED").alias("CONVICTED")             # <<<<<<<<<<<<<<
 *           ])
 *      charges = charges.with_columns([
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_10, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_contains); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_n_u_CONVICTED) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_CONVICTED);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_n_u_CONVICTED) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_CONVICTED);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":609
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")
 *           ])
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).alias("Disposition"),
 *           pl.col("Charges").str.contains(pl.col("CourtActionDate")).is_not().alias("Filing"),
 */
  __pyx_t_5 = PyList_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_5, 3, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_5, 4, __pyx_t_3);
  __pyx_t_14 = 0;
  __pyx_t_11 = 0;
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":616
 *           pl.col("Charges").str.contains("CONVICTED").alias("CONVICTED")
 *           ])
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(1)).otherwise(pl.col("Split").arr.get(0).str.slice(9)).str.strip().alias("Description"),
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(0).str.slice(19)).otherwise(pl.col("Split").arr.get(1)).str.strip().alias("SEG_2")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":617
 *           ])
 *      charges = charges.with_columns([
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(1)).otherwise(pl.col("Split").arr.get(0).str.slice(9)).str.strip().alias("Description"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(0).str.slice(19)).otherwise(pl.col("Split").arr.get(1)).str.strip().alias("SEG_2")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_when); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_n_u_Disposition) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_Disposition);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_11 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_10, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_then); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_14 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_10, __pyx_n_u_Split) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_Split);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_arr); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_11 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_4, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_7 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_14, __pyx_t_11) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_n_u_Split) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_Split);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_arr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_get); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_11 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_10, __pyx_int_0) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_int_0);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_slice); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_7 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_14, __pyx_int_9) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_int_9);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_11, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_3 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_3, __pyx_n_u_Description) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Description);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":618
 *      charges = charges.with_columns([
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(1)).otherwise(pl.col("Split").arr.get(0).str.slice(9)).str.strip().alias("Description"),
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(0).str.slice(19)).otherwise(pl.col("Split").arr.get(1)).str.strip().alias("SEG_2")             # <<<<<<<<<<<<<<
 *           ])
 *      dlog(debug, [charges.columns, charges.shape, "alac 965"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_when); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_4, __pyx_n_u_Disposition) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Disposition);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_11 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_then); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_9 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_4, __pyx_n_u_Split) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_Split);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_arr); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_get); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_14 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_13, __pyx_int_0) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_0);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_slice); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_11 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_9, __pyx_int_19) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_int_19);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_7 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_14, __pyx_t_11) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_11 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_14, __pyx_n_u_Split) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Split);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_arr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_get); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_9, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_12 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_11, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_strip); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_3 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_8 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_3, __pyx_n_u_SEG_2) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_SEG_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "alacorder/cal.pyx":616
 *           pl.col("Charges").str.contains("CONVICTED").alias("CONVICTED")
 *           ])
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(1)).otherwise(pl.col("Split").arr.get(0).str.slice(9)).str.strip().alias("Description"),
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(0).str.slice(19)).otherwise(pl.col("Split").arr.get(1)).str.strip().alias("SEG_2")
 */
  __pyx_t_12 = PyList_New(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_12, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_12, 1, __pyx_t_8);
  __pyx_t_5 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_12) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_12);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":620
 *           pl.when(pl.col("Disposition")).then(pl.col("Split").arr.get(0).str.slice(19)).otherwise(pl.col("Split").arr.get(1)).str.strip().alias("SEG_2")
 *           ])
 *      dlog(debug, [charges.columns, charges.shape, "alac 965"])             # <<<<<<<<<<<<<<
 *      charges = charges.with_columns([
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_columns); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_shape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_8);
  __Pyx_INCREF(__pyx_kp_u_alac_965);
  __Pyx_GIVEREF(__pyx_kp_u_alac_965);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_alac_965);
  __pyx_t_12 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_debug, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_debug, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_12 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_6, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_6, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":621
 *           ])
 *      dlog(debug, [charges.columns, charges.shape, "alac 965"])
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":622
 *      dlog(debug, [charges.columns, charges.shape, "alac 965"])
 *      charges = charges.with_columns([
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),             # <<<<<<<<<<<<<<
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_8, __pyx_n_u_SEG_2) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_SEG_2);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_extract); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 622, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__78, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_replace); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_tuple__79, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_12 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_3, __pyx_n_u_TypeDescription) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_TypeDescription);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":623
 *      charges = charges.with_columns([
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),             # <<<<<<<<<<<<<<
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),
 *           pl.col("Code").str.contains('(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)').alias("CERV_DISQ_MATCH"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_5, __pyx_n_u_SEG_2) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_SEG_2);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_extract); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_n_s_group_index, __pyx_int_1) < 0) __PYX_ERR(0, 623, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_tuple__80, __pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_8 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_5, __pyx_n_u_Category) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_Category);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":624
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),             # <<<<<<<<<<<<<<
 *           pl.col("Code").str.contains('(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)').alias("CERV_DISQ_MATCH"),
 *           pl.col("Code").str.contains(r'(RAP1|RAP2|SOD1|SOD2|STSA|SXA1|SXA2|ECHI|SX12|CSSC|FTCS|MURD|MRDI|MURR|FMUR|PMIO|POBM|MIPR|POMA|INCE)').alias("PARDON_DISQ_MATCH"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_pl); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_7 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_11, __pyx_n_u_Description) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Description);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_contains); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_3 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_9, __pyx_kp_u_A_ATT_ATTEMPT_S_SOLICIT_CONSP) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u_A_ATT_ATTEMPT_S_SOLICIT_CONSP);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_is_not); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_10 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":625
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),
 *           pl.col("Code").str.contains('(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)').alias("CERV_DISQ_MATCH"),             # <<<<<<<<<<<<<<
 *           pl.col("Code").str.contains(r'(RAP1|RAP2|SOD1|SOD2|STSA|SXA1|SXA2|ECHI|SX12|CSSC|FTCS|MURD|MRDI|MURR|FMUR|PMIO|POBM|MIPR|POMA|INCE)').alias("PARDON_DISQ_MATCH"),
 *           pl.col("Charges").str.contains(r'(CM\d\d|CMUR)|(CAPITAL)').alias("PERM_DISQ_MATCH")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_3 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_9, __pyx_n_u_Code) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_Code);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_str); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_contains); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_11, __pyx_kp_u_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_kp_u_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_n_u_CERV_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_CERV_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 625, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":626
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),
 *           pl.col("Code").str.contains('(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)').alias("CERV_DISQ_MATCH"),
 *           pl.col("Code").str.contains(r'(RAP1|RAP2|SOD1|SOD2|STSA|SXA1|SXA2|ECHI|SX12|CSSC|FTCS|MURD|MRDI|MURR|FMUR|PMIO|POBM|MIPR|POMA|INCE)').alias("PARDON_DISQ_MATCH"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.contains(r'(CM\d\d|CMUR)|(CAPITAL)').alias("PERM_DISQ_MATCH")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_11 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_9, __pyx_n_u_Code) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_Code);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_str); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_contains); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_5 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_14, __pyx_kp_u_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_kp_u_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_11);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_11, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_5, __pyx_n_u_PARDON_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_n_u_PARDON_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

  /* "alacorder/cal.pyx":627
 *           pl.col("Code").str.contains('(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)').alias("CERV_DISQ_MATCH"),
 *           pl.col("Code").str.contains(r'(RAP1|RAP2|SOD1|SOD2|STSA|SXA1|SXA2|ECHI|SX12|CSSC|FTCS|MURD|MRDI|MURR|FMUR|PMIO|POBM|MIPR|POMA|INCE)').alias("PARDON_DISQ_MATCH"),
 *           pl.col("Charges").str.contains(r'(CM\d\d|CMUR)|(CAPITAL)').alias("PERM_DISQ_MATCH")             # <<<<<<<<<<<<<<
 *           ])
 *      charges = charges.with_columns(
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_14 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_9, __pyx_n_u_Charges) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_Charges);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_str); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_contains); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_5 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, __pyx_kp_u_CM_d_d_CMUR_CAPITAL) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_u_CM_d_d_CMUR_CAPITAL);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_11 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_5, __pyx_n_u_PERM_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_PERM_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "alacorder/cal.pyx":621
 *           ])
 *      dlog(debug, [charges.columns, charges.shape, "alac 965"])
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),
 */
  __pyx_t_14 = PyList_New(6); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_14, 0, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_14, 1, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_14, 2, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_14, 3, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_14, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_11);
  PyList_SET_ITEM(__pyx_t_14, 5, __pyx_t_11);
  __pyx_t_12 = 0;
  __pyx_t_8 = 0;
  __pyx_t_10 = 0;
  __pyx_t_7 = 0;
  __pyx_t_3 = 0;
  __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_11, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":629
 *           pl.col("Charges").str.contains(r'(CM\d\d|CMUR)|(CAPITAL)').alias("PERM_DISQ_MATCH")
 *           ])
 *      charges = charges.with_columns(             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("GUILTY_PLEA") | pl.col("CONVICTED")).then(pl.lit(True)).otherwise(False).alias("Conviction")
 *           )
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":630
 *           ])
 *      charges = charges.with_columns(
 *           pl.when(pl.col("GUILTY_PLEA") | pl.col("CONVICTED")).then(pl.lit(True)).otherwise(False).alias("Conviction")             # <<<<<<<<<<<<<<
 *           )
 *      charges = charges.with_columns([
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_when); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_col); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_n_u_GUILTY_PLEA_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_GUILTY_PLEA_2);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_5 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_12, __pyx_n_u_CONVICTED) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_CONVICTED);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_Or(__pyx_t_10, __pyx_t_5); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_5, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_then); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_lit); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_7 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_13, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_5, Py_True);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_5, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_3, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_8, Py_False);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_14 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_11, __pyx_n_u_Conviction) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Conviction);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":632
 *           pl.when(pl.col("GUILTY_PLEA") | pl.col("CONVICTED")).then(pl.lit(True)).otherwise(False).alias("Conviction")
 *           )
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("Conviction") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqConviction"),
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqCharge"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":633
 *           )
 *      charges = charges.with_columns([
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("Conviction") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqConviction"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqCharge"),
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Conviction") & pl.col("Felony")).then(True).otherwise(False).alias("PardonDisqConviction"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_when); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_7 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_13, __pyx_n_u_CERV_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_CERV_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_10 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_13, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = PyNumber_And(__pyx_t_7, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_10 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_7, __pyx_n_u_Conviction) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_Conviction);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_And(__pyx_t_12, __pyx_t_10); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_12, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyNumber_And(__pyx_t_13, __pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_then); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_3, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_5, Py_True);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_11, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_5, Py_False);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_14 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_8, __pyx_n_u_CERVDisqConviction) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_CERVDisqConviction);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 633, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":634
 *      charges = charges.with_columns([
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("Conviction") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqConviction"),
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqCharge"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Conviction") & pl.col("Felony")).then(True).otherwise(False).alias("PardonDisqConviction"),
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PardonDisqCharge"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_when); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_7 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_13, __pyx_n_u_CERV_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_CERV_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_12 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_13, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_And(__pyx_t_7, __pyx_t_12); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_12 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_7, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_And(__pyx_t_9, __pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_3 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_12, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_then); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_3, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_10, Py_True);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_11, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_10, Py_False);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_n_u_CERVDisqCharge) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_CERVDisqCharge);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":635
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("Conviction") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqConviction"),
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqCharge"),
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Conviction") & pl.col("Felony")).then(True).otherwise(False).alias("PardonDisqConviction"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PardonDisqCharge"),
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Felony") & pl.col("Conviction")).then(True).otherwise(False).alias("PermanentDisqConviction"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_when); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_9, __pyx_n_u_PARDON_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_PARDON_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyNumber_And(__pyx_t_13, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_7 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_13, __pyx_n_u_Conviction) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Conviction);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_And(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_4, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyNumber_And(__pyx_t_9, __pyx_t_7); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_7, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_then); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_3, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_12, Py_True);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_11, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_12, Py_False);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_8, __pyx_n_u_PardonDisqConviction) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_PardonDisqConviction);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 635, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "alacorder/cal.pyx":636
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqCharge"),
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Conviction") & pl.col("Felony")).then(True).otherwise(False).alias("PardonDisqConviction"),
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PardonDisqCharge"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Felony") & pl.col("Conviction")).then(True).otherwise(False).alias("PermanentDisqConviction"),
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PermanentDisqCharge")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_when); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_n_u_PARDON_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_PARDON_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_9, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = PyNumber_And(__pyx_t_13, __pyx_t_4); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_4 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_13, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_And(__pyx_t_15, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_then); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_3, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_7, Py_True);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_11, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_7, Py_False);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_12 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_n_u_PardonDisqCharge) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_PardonDisqCharge);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 636, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":637
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Conviction") & pl.col("Felony")).then(True).otherwise(False).alias("PardonDisqConviction"),
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PardonDisqCharge"),
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Felony") & pl.col("Conviction")).then(True).otherwise(False).alias("PermanentDisqConviction"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PermanentDisqCharge")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_when); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_pl); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_9 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_15, __pyx_n_u_PERM_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_PERM_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_pl); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_13 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_15, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = PyNumber_And(__pyx_t_9, __pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_9, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = PyNumber_And(__pyx_t_16, __pyx_t_13); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_13 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_16, __pyx_n_u_Conviction) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Conviction);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = PyNumber_And(__pyx_t_15, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_3 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_9);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_then); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_3, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_4, Py_True);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_11, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_4, Py_False);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_8, __pyx_n_u_PermanentDisqConviction) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_PermanentDisqConviction);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":638
 *           pl.when(pl.col("PARDON_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PardonDisqCharge"),
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("A_S_C_DISQ") & pl.col("Felony") & pl.col("Conviction")).then(True).otherwise(False).alias("PermanentDisqConviction"),
 *           pl.when(pl.col("PERM_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("PermanentDisqCharge")             # <<<<<<<<<<<<<<
 *           ])
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_when); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_pl); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_9 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_15, __pyx_n_u_PERM_DISQ_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_PERM_DISQ_MATCH);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_pl); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_16 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_15, __pyx_n_u_Felony) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_Felony);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = PyNumber_And(__pyx_t_9, __pyx_t_16); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_16 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_9, __pyx_n_u_A_S_C_DISQ) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_A_S_C_DISQ);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = PyNumber_And(__pyx_t_17, __pyx_t_16); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_3 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_16, __pyx_t_15) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_then); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_11 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_3, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_13, Py_True);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __pyx_t_11 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_11)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_8 = (__pyx_t_11) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_11, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_13, Py_False);
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_4 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_8, __pyx_n_u_PermanentDisqCharge) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_PermanentDisqCharge);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 638, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":632
 *           pl.when(pl.col("GUILTY_PLEA") | pl.col("CONVICTED")).then(pl.lit(True)).otherwise(False).alias("Conviction")
 *           )
 *      charges = charges.with_columns([             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("Conviction") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqConviction"),
 *           pl.when(pl.col("CERV_DISQ_MATCH") & pl.col("Felony") & pl.col("A_S_C_DISQ")).then(True).otherwise(False).alias("CERVDisqCharge"),
 */
  __pyx_t_13 = PyList_New(6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_13, 0, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_13, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_13, 2, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_13, 3, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_13, 4, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_13, 5, __pyx_t_4);
  __pyx_t_14 = 0;
  __pyx_t_5 = 0;
  __pyx_t_10 = 0;
  __pyx_t_12 = 0;
  __pyx_t_7 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":641
 *           ])
 * 
 *      charges = charges.select("Num","Code","Description","TypeDescription","Category","CourtAction","CourtActionDate","Conviction","Felony","CERVDisqCharge","CERVDisqConviction","PardonDisqCharge","PardonDisqConviction","PermanentDisqCharge","PermanentDisqConviction")             # <<<<<<<<<<<<<<
 * 
 *      dlog(debug, [charges.columns, charges.shape, "alac 989"])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_select); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__81, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":643
 *      charges = charges.select("Num","Code","Description","TypeDescription","Category","CourtAction","CourtActionDate","Conviction","Felony","CERVDisqCharge","CERVDisqConviction","PardonDisqCharge","PardonDisqConviction","PermanentDisqCharge","PermanentDisqConviction")
 * 
 *      dlog(debug, [charges.columns, charges.shape, "alac 989"])             # <<<<<<<<<<<<<<
 * 
 *      charges = charges.drop_nulls()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_dlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_columns); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_shape); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_7, 1, __pyx_t_4);
  __Pyx_INCREF(__pyx_kp_u_alac_989);
  __Pyx_GIVEREF(__pyx_kp_u_alac_989);
  PyList_SET_ITEM(__pyx_t_7, 2, __pyx_kp_u_alac_989);
  __pyx_t_13 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_debug, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_debug, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  {
    __pyx_t_13 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_6, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_6, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":645
 *      dlog(debug, [charges.columns, charges.shape, "alac 989"])
 * 
 *      charges = charges.drop_nulls()             # <<<<<<<<<<<<<<
 *      charges = charges.fill_null(pl.lit(''))
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_drop_nulls); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":646
 * 
 *      charges = charges.drop_nulls()
 *      charges = charges.fill_null(pl.lit(''))             # <<<<<<<<<<<<<<
 * 
 *      dlog(debug, [charges.columns, charges.shape, "alac 994"])
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_fill_null); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_lit); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_13 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_charges, __pyx_t_2);
  __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":648
 *      charges = charges.fill_null(pl.lit(''))
 * 
 *      dlog(debug, [charges.columns, charges.shape, "alac 994"])             # <<<<<<<<<<<<<<
 * 
 *      return charges
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_dlog); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_columns); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_charges, __pyx_n_s_shape); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_7, 1, __pyx_t_4);
  __Pyx_INCREF(__pyx_kp_u_alac_994);
  __Pyx_GIVEREF(__pyx_kp_u_alac_994);
  PyList_SET_ITEM(__pyx_t_7, 2, __pyx_kp_u_alac_994);
  __pyx_t_13 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_debug, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_debug, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  } else
  #endif
  {
    __pyx_t_13 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_6, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_6, __pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_13, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":650
 *      dlog(debug, [charges.columns, charges.shape, "alac 994"])
 * 
 *      return charges             # <<<<<<<<<<<<<<
 * def split_fees(df, debug=False):
 *      df = df.select([
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_charges);
  __pyx_r = __pyx_v_charges;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":598
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):             # <<<<<<<<<<<<<<
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("alacorder.cal.split_charges", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_charges);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":651
 * 
 *      return charges
 * def split_fees(df, debug=False):             # <<<<<<<<<<<<<<
 *      df = df.select([
 *           pl.col("CaseNumber"),
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_29split_fees(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_29split_fees = {"split_fees", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_29split_fees, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9alacorder_3cal_29split_fees(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_df = 0;
  PyObject *__pyx_v_debug = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split_fees (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_df,&__pyx_n_s_debug,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_False);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_df)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "split_fees") < 0)) __PYX_ERR(0, 651, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_df = values[0];
    __pyx_v_debug = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("split_fees", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 651, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.split_fees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_28split_fees(__pyx_self, __pyx_v_df, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_28split_fees(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_df, PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("split_fees", 0);
  __Pyx_INCREF(__pyx_v_df);

  /* "alacorder/cal.pyx":652
 *      return charges
 * def split_fees(df, debug=False):
 *      df = df.select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_select); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":653
 * def split_fees(df, debug=False):
 *      df = df.select([
 *           pl.col("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),
 *           pl.col("Fees").str.strip().str.replace(" ","").str.extract_all(r'\s\$\d+\.\d{2}').alias("FEE_SEP")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":654
 *      df = df.select([
 *           pl.col("CaseNumber"),
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),             # <<<<<<<<<<<<<<
 *           pl.col("Fees").str.strip().str.replace(" ","").str.extract_all(r'\s\$\d+\.\d{2}').alias("FEE_SEP")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, __pyx_n_u_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_Fees);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__83, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_kp_u__64) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_kp_u__64);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_4, __pyx_n_u_SPACE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_SPACE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":655
 *           pl.col("CaseNumber"),
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),
 *           pl.col("Fees").str.strip().str.replace(" ","").str.extract_all(r'\s\$\d+\.\d{2}').alias("FEE_SEP")             # <<<<<<<<<<<<<<
 *           ])
 *      dlog(debug, [df.columns, df.shape, "alac 1004"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_n_u_Fees) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_Fees);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_6 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_replace); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_tuple__84, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_extract_all); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_6, __pyx_kp_u_s_d_d_2) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u_s_d_d_2);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_alias); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_8 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, __pyx_n_u_FEE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_FEE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":652
 *      return charges
 * def split_fees(df, debug=False):
 *      df = df.select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),
 */
  __pyx_t_7 = PyList_New(3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_7, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_7, 2, __pyx_t_8);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":657
 *           pl.col("Fees").str.strip().str.replace(" ","").str.extract_all(r'\s\$\d+\.\d{2}').alias("FEE_SEP")
 *           ])
 *      dlog(debug, [df.columns, df.shape, "alac 1004"])             # <<<<<<<<<<<<<<
 *      df = df.select([
 *           pl.col("CaseNumber"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_shape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_5 = PyList_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_8);
  __Pyx_INCREF(__pyx_kp_u_alac_1004);
  __Pyx_GIVEREF(__pyx_kp_u_alac_1004);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_alac_1004);
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_11 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_11 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_debug, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_debug, __pyx_t_5};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_11, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_11, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 657, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":658
 *           ])
 *      dlog(debug, [df.columns, df.shape, "alac 1004"])
 *      df = df.select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_select); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":659
 *      dlog(debug, [df.columns, df.shape, "alac 1004"])
 *      df = df.select([
 *           pl.col("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good
 *           pl.col("SPACE_SEP").arr.get(1).alias("FeeStatus1"), # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_5, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 659, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":660
 *      df = df.select([
 *           pl.col("CaseNumber"),
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good             # <<<<<<<<<<<<<<
 *           pl.col("SPACE_SEP").arr.get(1).alias("FeeStatus1"), # good
 *           pl.col("FEE_SEP").arr.get(0).str.replace(r'\$','').alias("AmtDue"), # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_4, __pyx_n_u_SPACE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_n_u_SPACE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_arr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_int_0) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_int_0);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_8 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_5, __pyx_n_u_AdminFee1) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_AdminFee1);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":661
 *           pl.col("CaseNumber"),
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good
 *           pl.col("SPACE_SEP").arr.get(1).alias("FeeStatus1"), # good             # <<<<<<<<<<<<<<
 *           pl.col("FEE_SEP").arr.get(0).str.replace(r'\$','').alias("AmtDue"), # good
 *           pl.col("FEE_SEP").arr.get(1).str.replace(r'\$','').alias("AmtPaid"), # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_4, __pyx_n_u_SPACE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_SPACE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_arr); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_get); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_10, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_alias); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_n_u_FeeStatus1) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_n_u_FeeStatus1);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "alacorder/cal.pyx":662
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good
 *           pl.col("SPACE_SEP").arr.get(1).alias("FeeStatus1"), # good
 *           pl.col("FEE_SEP").arr.get(0).str.replace(r'\$','').alias("AmtDue"), # good             # <<<<<<<<<<<<<<
 *           pl.col("FEE_SEP").arr.get(1).str.replace(r'\$','').alias("AmtPaid"), # good
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("AmtHold1"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_10 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_4, __pyx_n_u_FEE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_FEE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_arr); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_get); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_5 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_int_0) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_0);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_str); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_replace); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_alias); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_6 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_10, __pyx_n_u_AmtDue) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_AmtDue);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":663
 *           pl.col("SPACE_SEP").arr.get(1).alias("FeeStatus1"), # good
 *           pl.col("FEE_SEP").arr.get(0).str.replace(r'\$','').alias("AmtDue"), # good
 *           pl.col("FEE_SEP").arr.get(1).str.replace(r'\$','').alias("AmtPaid"), # good             # <<<<<<<<<<<<<<
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("AmtHold1"),
 *           pl.col("SPACE_SEP").arr.get(5).alias("Code"), # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_9 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_4, __pyx_n_u_FEE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_FEE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_arr); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_get); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_12, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_str); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_replace); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_5 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_n_u_AmtPaid) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_AmtPaid);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":664
 *           pl.col("FEE_SEP").arr.get(0).str.replace(r'\$','').alias("AmtDue"), # good
 *           pl.col("FEE_SEP").arr.get(1).str.replace(r'\$','').alias("AmtPaid"), # good
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("AmtHold1"),             # <<<<<<<<<<<<<<
 *           pl.col("SPACE_SEP").arr.get(5).alias("Code"), # good
 *           pl.col("SPACE_SEP").arr.get(6).alias("Payor2"), # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_4, __pyx_n_u_FEE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_FEE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_arr); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_get); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_9 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_13, __pyx_int_neg_1) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_int_neg_1);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_str); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_replace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_12, __pyx_n_u_AmtHold1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_AmtHold1);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":665
 *           pl.col("FEE_SEP").arr.get(1).str.replace(r'\$','').alias("AmtPaid"), # good
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("AmtHold1"),
 *           pl.col("SPACE_SEP").arr.get(5).alias("Code"), # good             # <<<<<<<<<<<<<<
 *           pl.col("SPACE_SEP").arr.get(6).alias("Payor2"), # good
 *           pl.col("SPACE_SEP").arr.get(7).alias("Payee2"), # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_13 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_4, __pyx_n_u_SPACE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_SPACE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_arr); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_12 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, __pyx_int_5) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_int_5);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_9 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_12, __pyx_n_u_Code) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_Code);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 665, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":666
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("AmtHold1"),
 *           pl.col("SPACE_SEP").arr.get(5).alias("Code"), # good
 *           pl.col("SPACE_SEP").arr.get(6).alias("Payor2"), # good             # <<<<<<<<<<<<<<
 *           pl.col("SPACE_SEP").arr.get(7).alias("Payee2"), # good
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("Balance") # good
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_4, __pyx_n_u_SPACE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_SPACE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_arr); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_get); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_12 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_15, __pyx_int_6) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_int_6);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_13 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_12, __pyx_n_u_Payor2) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_Payor2);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 666, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "alacorder/cal.pyx":667
 *           pl.col("SPACE_SEP").arr.get(5).alias("Code"), # good
 *           pl.col("SPACE_SEP").arr.get(6).alias("Payor2"), # good
 *           pl.col("SPACE_SEP").arr.get(7).alias("Payee2"), # good             # <<<<<<<<<<<<<<
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("Balance") # good
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_15 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_4, __pyx_n_u_SPACE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_SPACE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_arr); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_get); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_12 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_16, __pyx_int_7) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_int_7);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_alias); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_12)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_12);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_14 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_12, __pyx_n_u_Payee2) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_Payee2);
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 667, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "alacorder/cal.pyx":668
 *           pl.col("SPACE_SEP").arr.get(6).alias("Payor2"), # good
 *           pl.col("SPACE_SEP").arr.get(7).alias("Payee2"), # good
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("Balance") # good             # <<<<<<<<<<<<<<
 *           ])
 *      out = df.with_columns([
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_16 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_4, __pyx_n_u_FEE_SEP) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_FEE_SEP);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_arr); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_get); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_12 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_17, __pyx_int_neg_1) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_int_neg_1);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_str); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_replace); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_tuple__86, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_15 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_16, __pyx_n_u_Balance) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_Balance);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "alacorder/cal.pyx":658
 *           ])
 *      dlog(debug, [df.columns, df.shape, "alac 1004"])
 *      df = df.select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good
 */
  __pyx_t_12 = PyList_New(10); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_7);
  PyList_SET_ITEM(__pyx_t_12, 0, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_12, 1, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_12, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_6);
  PyList_SET_ITEM(__pyx_t_12, 3, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_12, 4, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_12, 5, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_12, 6, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_12, 7, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_12, 8, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_15);
  PyList_SET_ITEM(__pyx_t_12, 9, __pyx_t_15);
  __pyx_t_7 = 0;
  __pyx_t_8 = 0;
  __pyx_t_3 = 0;
  __pyx_t_6 = 0;
  __pyx_t_5 = 0;
  __pyx_t_10 = 0;
  __pyx_t_9 = 0;
  __pyx_t_13 = 0;
  __pyx_t_14 = 0;
  __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_15, __pyx_t_12) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_12);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_df, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":670
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("Balance") # good
 *           ])
 *      out = df.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then(True).otherwise(False).alias("Total"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_df, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":671
 *           ])
 *      out = df.with_columns([
 *           pl.col("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then(True).otherwise(False).alias("Total"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("AdminFee1")).alias("AdminFee"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_15, __pyx_n_s_pl); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_12 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_15, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 671, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "alacorder/cal.pyx":672
 *      out = df.with_columns([
 *           pl.col("CaseNumber"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then(True).otherwise(False).alias("Total"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("AdminFee1")).alias("AdminFee"),
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.lit('')).otherwise(pl.col("Payor2")).alias("Payor1"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_when); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_10 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_6, __pyx_n_u_AdminFee1) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_AdminFee1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_10, __pyx_n_u_ACTIVE, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_9 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_10, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_then); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_9, Py_True) : __Pyx_PyObject_CallOneArg(__pyx_t_5, Py_True);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_15 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_13, Py_False) : __Pyx_PyObject_CallOneArg(__pyx_t_5, Py_False);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_alias); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_14 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_15, __pyx_n_u_Total) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_Total);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 672, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":673
 *           pl.col("CaseNumber"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then(True).otherwise(False).alias("Total"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("AdminFee1")).alias("AdminFee"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.lit('')).otherwise(pl.col("Payor2")).alias("Payor1"),
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.col("Payor2")).otherwise(pl.col("Payee2")).alias("Payee1"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_when); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_n_u_AdminFee1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_AdminFee1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = PyObject_RichCompare(__pyx_t_3, __pyx_n_u_ACTIVE, Py_NE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_9 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_3, __pyx_t_8) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_8);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_then); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_n_u_AdminFee1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_AdminFee1);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_15 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_5 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_15, __pyx_n_u_AdminFee) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_AdminFee);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 673, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":674
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then(True).otherwise(False).alias("Total"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("AdminFee1")).alias("AdminFee"),
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.lit('')).otherwise(pl.col("Payor2")).alias("Payor1"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.col("Payor2")).otherwise(pl.col("Payee2")).alias("Payee1"),
 *           pl.when(pl.col("AdminFee1")=="Total:").then(pl.lit(None)).otherwise(pl.col("FeeStatus1")).alias("FeeStatus2"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_when); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_7 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_16, __pyx_n_u_Payor2) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_Payor2);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_contains); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_6 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_17, __pyx_kp_u_R0_9_d_3) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u_R0_9_d_3);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_is_not); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_9 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_9);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_then); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_lit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_8 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_9, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_13 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_t_8) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_8);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_13 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_n_u_Payor2) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_Payor2);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_15 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_7, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_alias); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_10 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_15, __pyx_n_u_Payor1) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_Payor1);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":675
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("AdminFee1")).alias("AdminFee"),
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.lit('')).otherwise(pl.col("Payor2")).alias("Payor1"),
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.col("Payor2")).otherwise(pl.col("Payee2")).alias("Payee1"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("AdminFee1")=="Total:").then(pl.lit(None)).otherwise(pl.col("FeeStatus1")).alias("FeeStatus2"),
 *           pl.when(pl.col("AmtHold1")=="L").then("$0.00").otherwise(pl.col("AmtHold1").str.replace_all(r'[A-Z]|\$','')).alias("AmtHold")
 */
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_when); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_17 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_16, __pyx_n_u_Payor2) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_Payor2);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_str); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_contains); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_4, __pyx_kp_u_R0_9_d_3) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_kp_u_R0_9_d_3);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_is_not); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_8 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_7 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_17, __pyx_t_8) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_8);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_then); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_8, __pyx_n_u_Payor2) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_Payor2);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_13 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_17, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_13 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_7, __pyx_n_u_Payee2) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_Payee2);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_15 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_17, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_alias); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_3 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_15, __pyx_n_u_Payee1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_Payee1);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":676
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.lit('')).otherwise(pl.col("Payor2")).alias("Payor1"),
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.col("Payor2")).otherwise(pl.col("Payee2")).alias("Payee1"),
 *           pl.when(pl.col("AdminFee1")=="Total:").then(pl.lit(None)).otherwise(pl.col("FeeStatus1")).alias("FeeStatus2"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("AmtHold1")=="L").then("$0.00").otherwise(pl.col("AmtHold1").str.replace_all(r'[A-Z]|\$','')).alias("AmtHold")
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_when); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_6, __pyx_n_u_AdminFee1) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_AdminFee1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_RichCompare(__pyx_t_7, __pyx_kp_u_Total_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_17 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_then); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pl); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lit); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_17 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, Py_None) : __Pyx_PyObject_CallOneArg(__pyx_t_7, Py_None);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_13 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, __pyx_t_17) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_17);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_pl); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_13 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_17, __pyx_n_u_FeeStatus1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_FeeStatus1);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_15 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_7, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_alias); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_9 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_15, __pyx_n_u_FeeStatus2) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_FeeStatus2);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":677
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.col("Payor2")).otherwise(pl.col("Payee2")).alias("Payee1"),
 *           pl.when(pl.col("AdminFee1")=="Total:").then(pl.lit(None)).otherwise(pl.col("FeeStatus1")).alias("FeeStatus2"),
 *           pl.when(pl.col("AmtHold1")=="L").then("$0.00").otherwise(pl.col("AmtHold1").str.replace_all(r'[A-Z]|\$','')).alias("AmtHold")             # <<<<<<<<<<<<<<
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1026"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_pl); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_when); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_17 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_6, __pyx_n_u_AmtHold1) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_AmtHold1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = PyObject_RichCompare(__pyx_t_17, __pyx_n_u_L, Py_EQ); __Pyx_XGOTREF(__pyx_t_16); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_7 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_17, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_then); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_13 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_kp_u_0_00) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_u_0_00);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_col); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_13 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_7, __pyx_n_u_AmtHold1) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_AmtHold1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_str); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_replace_all); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_tuple__87, NULL); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_15 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_16);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_15, __pyx_n_s_alias); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_8 = (__pyx_t_15) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_15, __pyx_n_u_AmtHold) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_AmtHold);
  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":670
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("Balance") # good
 *           ])
 *      out = df.with_columns([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then(True).otherwise(False).alias("Total"),
 */
  __pyx_t_4 = PyList_New(7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_4, 1, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_4, 2, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_4, 3, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_4, 4, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_4, 5, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_4, 6, __pyx_t_8);
  __pyx_t_12 = 0;
  __pyx_t_14 = 0;
  __pyx_t_5 = 0;
  __pyx_t_10 = 0;
  __pyx_t_3 = 0;
  __pyx_t_9 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_8, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 670, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":679
 *           pl.when(pl.col("AmtHold1")=="L").then("$0.00").otherwise(pl.col("AmtHold1").str.replace_all(r'[A-Z]|\$','')).alias("AmtHold")
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1026"])             # <<<<<<<<<<<<<<
 *      out = out.select([
 *           pl.col("CaseNumber"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_out, __pyx_n_s_columns); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_out, __pyx_n_s_shape); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = PyList_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_9, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_9, 1, __pyx_t_8);
  __Pyx_INCREF(__pyx_kp_u_alac_1026);
  __Pyx_GIVEREF(__pyx_kp_u_alac_1026);
  PyList_SET_ITEM(__pyx_t_9, 2, __pyx_kp_u_alac_1026);
  __pyx_t_4 = 0;
  __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_11 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_11 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_debug, __pyx_t_9};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_v_debug, __pyx_t_9};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_11, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_11, __pyx_t_9);
    __pyx_t_9 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":680
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1026"])
 *      out = out.select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("Total"),
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_out, __pyx_n_s_select); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "alacorder/cal.pyx":681
 *      dlog(debug, [out.columns, out.shape, "alac 1026"])
 *      out = out.select([
 *           pl.col("CaseNumber"),             # <<<<<<<<<<<<<<
 *           pl.col("Total"),
 *           pl.col("AdminFee"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_8, function);
    }
  }
  __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_9, __pyx_n_u_CaseNumber) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_CaseNumber);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "alacorder/cal.pyx":682
 *      out = out.select([
 *           pl.col("CaseNumber"),
 *           pl.col("Total"),             # <<<<<<<<<<<<<<
 *           pl.col("AdminFee"),
 *           pl.when(pl.col("FeeStatus2").str.contains("$", literal=True)).then(pl.lit(None)).otherwise(pl.col("FeeStatus2")).alias("FeeStatus"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_8 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_9, __pyx_n_u_Total) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_n_u_Total);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":683
 *           pl.col("CaseNumber"),
 *           pl.col("Total"),
 *           pl.col("AdminFee"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("FeeStatus2").str.contains("$", literal=True)).then(pl.lit(None)).otherwise(pl.col("FeeStatus2")).alias("FeeStatus"),
 *           pl.col("Code"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_10, function);
    }
  }
  __pyx_t_3 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_n_u_AdminFee) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_AdminFee);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "alacorder/cal.pyx":684
 *           pl.col("Total"),
 *           pl.col("AdminFee"),
 *           pl.when(pl.col("FeeStatus2").str.contains("$", literal=True)).then(pl.lit(None)).otherwise(pl.col("FeeStatus2")).alias("FeeStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("Code"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("Payor1")).alias("Payor"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_pl); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_when); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_12 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_16, __pyx_n_u_FeeStatus2) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_FeeStatus2);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_str); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_contains); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_literal, Py_True) < 0) __PYX_ERR(0, 684, __pyx_L1_error)
  __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_tuple__89, __pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_14 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_13, __pyx_t_16) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_16);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_then); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_lit); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_14 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_16, Py_None) : __Pyx_PyObject_CallOneArg(__pyx_t_13, Py_None);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_5 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_13, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_col); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_13, function);
    }
  }
  __pyx_t_5 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_14, __pyx_n_u_FeeStatus2) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_n_u_FeeStatus2);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_9 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_13, __pyx_t_5) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_5);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_alias); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_15);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_15, function);
    }
  }
  __pyx_t_10 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_9, __pyx_n_u_FeeStatus) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_n_u_FeeStatus);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

  /* "alacorder/cal.pyx":685
 *           pl.col("AdminFee"),
 *           pl.when(pl.col("FeeStatus2").str.contains("$", literal=True)).then(pl.lit(None)).otherwise(pl.col("FeeStatus2")).alias("FeeStatus"),
 *           pl.col("Code"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("Payor1")).alias("Payor"),
 *           pl.when(pl.col("Payee1").str.contains(r'\$|\.')).then('').otherwise(pl.col("Payee1")).alias("Payee"),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_15 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_9, __pyx_n_u_Code) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_Code);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":686
 *           pl.when(pl.col("FeeStatus2").str.contains("$", literal=True)).then(pl.lit(None)).otherwise(pl.col("FeeStatus2")).alias("FeeStatus"),
 *           pl.col("Code"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("Payor1")).alias("Payor"),             # <<<<<<<<<<<<<<
 *           pl.when(pl.col("Payee1").str.contains(r'\$|\.')).then('').otherwise(pl.col("Payee1")).alias("Payee"),
 *           pl.col("AmtDue").str.strip().cast(pl.Float64, strict=False),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_when); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_16 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_7, __pyx_n_u_AdminFee1) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_AdminFee1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = PyObject_RichCompare(__pyx_t_16, __pyx_n_u_ACTIVE, Py_NE); __Pyx_XGOTREF(__pyx_t_17); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_14 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_16, __pyx_t_17) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_17);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_then); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_13 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_14, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_13 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_14, __pyx_n_u_Payor1) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_Payor1);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_9 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_17, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
    }
  }
  __pyx_t_5 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_9, __pyx_n_u_Payor) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_n_u_Payor);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 686, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

  /* "alacorder/cal.pyx":687
 *           pl.col("Code"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("Payor1")).alias("Payor"),
 *           pl.when(pl.col("Payee1").str.contains(r'\$|\.')).then('').otherwise(pl.col("Payee1")).alias("Payee"),             # <<<<<<<<<<<<<<
 *           pl.col("AmtDue").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("AmtPaid").str.strip().cast(pl.Float64, strict=False),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_when); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_pl); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_col); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_18))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_18);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_18, function);
    }
  }
  __pyx_t_7 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_18, __pyx_t_6, __pyx_n_u_Payee1) : __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_n_u_Payee1);
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_str); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_contains); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_18)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_18);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_14 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_18, __pyx_kp_u__90) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__90);
  __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_17 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_7, __pyx_t_14) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_14);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_then); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_13 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_17, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_kp_u__8);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_otherwise); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_pl); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_13 = (__pyx_t_17) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_17, __pyx_n_u_Payee1) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_Payee1);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_9 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_14, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_alias); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_12 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_16, __pyx_t_9, __pyx_n_u_Payee) : __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_n_u_Payee);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

  /* "alacorder/cal.pyx":688
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("Payor1")).alias("Payor"),
 *           pl.when(pl.col("Payee1").str.contains(r'\$|\.')).then('').otherwise(pl.col("Payee1")).alias("Payee"),
 *           pl.col("AmtDue").str.strip().cast(pl.Float64, strict=False),             # <<<<<<<<<<<<<<
 *           pl.col("AmtPaid").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("Balance").str.strip().cast(pl.Float64, strict=False),
 */
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_pl); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_col); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_9 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_13, __pyx_n_u_AmtDue) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_u_AmtDue);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_str); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_16 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_cast); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_Float64); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = PyTuple_New(1); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_14);
  PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_14);
  __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 688, __pyx_L1_error)
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_16, __pyx_t_14); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "alacorder/cal.pyx":689
 *           pl.when(pl.col("Payee1").str.contains(r'\$|\.')).then('').otherwise(pl.col("Payee1")).alias("Payee"),
 *           pl.col("AmtDue").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("AmtPaid").str.strip().cast(pl.Float64, strict=False),             # <<<<<<<<<<<<<<
 *           pl.col("Balance").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("AmtHold").str.strip().cast(pl.Float64, strict=False)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_col); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_16 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_17, __pyx_t_9, __pyx_n_u_AmtPaid) : __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_n_u_AmtPaid);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_str); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_strip); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_16))) {
    __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
    if (likely(__pyx_t_17)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
      __Pyx_INCREF(__pyx_t_17);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_16, function);
    }
  }
  __pyx_t_14 = (__pyx_t_17) ? __Pyx_PyObject_CallOneArg(__pyx_t_16, __pyx_t_17) : __Pyx_PyObject_CallNoArg(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_cast); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_Float64); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyTuple_New(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_17);
  PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_17);
  __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  if (PyDict_SetItem(__pyx_t_17, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 689, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_16, __pyx_t_14, __pyx_t_17); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

  /* "alacorder/cal.pyx":690
 *           pl.col("AmtDue").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("AmtPaid").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("Balance").str.strip().cast(pl.Float64, strict=False),             # <<<<<<<<<<<<<<
 *           pl.col("AmtHold").str.strip().cast(pl.Float64, strict=False)
 *           ])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_pl); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_col); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  __pyx_t_16 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_14 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_16, __pyx_n_u_Balance) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_n_u_Balance);
  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_str); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_14);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_14, function);
    }
  }
  __pyx_t_17 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_cast); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_17, __pyx_n_s_pl); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_Float64); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = PyTuple_New(1); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_7);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 690, __pyx_L1_error)
  __pyx_t_16 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_17, __pyx_t_7); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":691
 *           pl.col("AmtPaid").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("Balance").str.strip().cast(pl.Float64, strict=False),
 *           pl.col("AmtHold").str.strip().cast(pl.Float64, strict=False)             # <<<<<<<<<<<<<<
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1040"])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_pl); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_col); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_18))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_18);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_18, function);
    }
  }
  __pyx_t_17 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_18, __pyx_t_14, __pyx_n_u_AmtHold) : __Pyx_PyObject_CallOneArg(__pyx_t_18, __pyx_n_u_AmtHold);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_str); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_18, __pyx_n_s_strip); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __pyx_t_18 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_17))) {
    __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_17);
    if (likely(__pyx_t_18)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_17);
      __Pyx_INCREF(__pyx_t_18);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_17, function);
    }
  }
  __pyx_t_7 = (__pyx_t_18) ? __Pyx_PyObject_CallOneArg(__pyx_t_17, __pyx_t_18) : __Pyx_PyObject_CallNoArg(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_cast); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_17);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_pl); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_Float64); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_18);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_18);
  __pyx_t_18 = 0;
  __pyx_t_18 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  if (PyDict_SetItem(__pyx_t_18, __pyx_n_s_strict, Py_False) < 0) __PYX_ERR(0, 691, __pyx_L1_error)
  __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_17, __pyx_t_7, __pyx_t_18); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;

  /* "alacorder/cal.pyx":680
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1026"])
 *      out = out.select([             # <<<<<<<<<<<<<<
 *           pl.col("CaseNumber"),
 *           pl.col("Total"),
 */
  __pyx_t_18 = PyList_New(11); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_18, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_8);
  PyList_SET_ITEM(__pyx_t_18, 1, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_18, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_10);
  PyList_SET_ITEM(__pyx_t_18, 3, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_15);
  PyList_SET_ITEM(__pyx_t_18, 4, __pyx_t_15);
  __Pyx_GIVEREF(__pyx_t_5);
  PyList_SET_ITEM(__pyx_t_18, 5, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_12);
  PyList_SET_ITEM(__pyx_t_18, 6, __pyx_t_12);
  __Pyx_GIVEREF(__pyx_t_13);
  PyList_SET_ITEM(__pyx_t_18, 7, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_9);
  PyList_SET_ITEM(__pyx_t_18, 8, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_16);
  PyList_SET_ITEM(__pyx_t_18, 9, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_18, 10, __pyx_t_14);
  __pyx_t_4 = 0;
  __pyx_t_8 = 0;
  __pyx_t_3 = 0;
  __pyx_t_10 = 0;
  __pyx_t_15 = 0;
  __pyx_t_5 = 0;
  __pyx_t_12 = 0;
  __pyx_t_13 = 0;
  __pyx_t_9 = 0;
  __pyx_t_16 = 0;
  __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_14) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_14, __pyx_t_18) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_18);
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":693
 *           pl.col("AmtHold").str.strip().cast(pl.Float64, strict=False)
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1040"])             # <<<<<<<<<<<<<<
 *      out = out.drop_nulls("Balance")
 *      return out
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_dlog); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_v_out, __pyx_n_s_columns); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_18);
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_out, __pyx_n_s_shape); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_16 = PyList_New(3); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_18);
  PyList_SET_ITEM(__pyx_t_16, 0, __pyx_t_18);
  __Pyx_GIVEREF(__pyx_t_14);
  PyList_SET_ITEM(__pyx_t_16, 1, __pyx_t_14);
  __Pyx_INCREF(__pyx_kp_u_alac_1040);
  __Pyx_GIVEREF(__pyx_kp_u_alac_1040);
  PyList_SET_ITEM(__pyx_t_16, 2, __pyx_kp_u_alac_1040);
  __pyx_t_18 = 0;
  __pyx_t_14 = 0;
  __pyx_t_14 = NULL;
  __pyx_t_11 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_14)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_11 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_14, __pyx_v_debug, __pyx_t_16};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_14, __pyx_v_debug, __pyx_t_16};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
  } else
  #endif
  {
    __pyx_t_18 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_18);
    if (__pyx_t_14) {
      __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_14); __pyx_t_14 = NULL;
    }
    __Pyx_INCREF(__pyx_v_debug);
    __Pyx_GIVEREF(__pyx_v_debug);
    PyTuple_SET_ITEM(__pyx_t_18, 0+__pyx_t_11, __pyx_v_debug);
    __Pyx_GIVEREF(__pyx_t_16);
    PyTuple_SET_ITEM(__pyx_t_18, 1+__pyx_t_11, __pyx_t_16);
    __pyx_t_16 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_18, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":694
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1040"])
 *      out = out.drop_nulls("Balance")             # <<<<<<<<<<<<<<
 *      return out
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_out, __pyx_n_s_drop_nulls); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_18 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_18 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_18)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_18);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_18) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_18, __pyx_n_u_Balance) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_n_u_Balance);
  __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_out, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":695
 *      dlog(debug, [out.columns, out.shape, "alac 1040"])
 *      out = out.drop_nulls("Balance")
 *      return out             # <<<<<<<<<<<<<<
 * 
 * #   #   #   #         FETCH (PDF SCRAPER)       #   #   #   #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":651
 * 
 *      return charges
 * def split_fees(df, debug=False):             # <<<<<<<<<<<<<<
 *      df = df.select([
 *           pl.col("CaseNumber"),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("alacorder.cal.split_fees", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_df);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":699
 * #   #   #   #         FETCH (PDF SCRAPER)       #   #   #   #
 * 
 * def read_query(path, qmax=0, qskip=0, window=None):             # <<<<<<<<<<<<<<
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_31read_query(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_31read_query = {"read_query", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_31read_query, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9alacorder_3cal_31read_query(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_path = 0;
  PyObject *__pyx_v_qmax = 0;
  PyObject *__pyx_v_qskip = 0;
  CYTHON_UNUSED PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("read_query (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_path,&__pyx_n_s_qmax,&__pyx_n_s_qskip,&__pyx_n_s_window,0};
    PyObject* values[4] = {0,0,0,0};
    values[1] = ((PyObject *)__pyx_int_0);
    values[2] = ((PyObject *)__pyx_int_0);
    values[3] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_path)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_qmax);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_qskip);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "read_query") < 0)) __PYX_ERR(0, 699, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_path = values[0];
    __pyx_v_qmax = values[1];
    __pyx_v_qskip = values[2];
    __pyx_v_window = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("read_query", 0, 1, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 699, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.read_query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_30read_query(__pyx_self, __pyx_v_path, __pyx_v_qmax, __pyx_v_qskip, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_30read_query(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path, PyObject *__pyx_v_qmax, PyObject *__pyx_v_qskip, CYTHON_UNUSED PyObject *__pyx_v_window) {
  PyObject *__pyx_v_query = NULL;
  PyObject *__pyx_v_qs = NULL;
  PyObject *__pyx_v_pscols = NULL;
  PyObject *__pyx_v_tempcols = NULL;
  PyObject *__pyx_v_col = NULL;
  int __pyx_v_goodquery;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("read_query", 0);

  /* "alacorder/cal.pyx":700
 * 
 * def read_query(path, qmax=0, qskip=0, window=None):
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):             # <<<<<<<<<<<<<<
 *         query = pl.read_excel(path)
 *     elif os.path.splitext(path)[1] == ".csv":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_splitext); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_path);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_kp_u_xlsx, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 700, __pyx_L1_error)
  if (!__pyx_t_5) {
  } else {
    __pyx_t_4 = __pyx_t_5;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_kp_u_xls, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 700, __pyx_L1_error)
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (__pyx_t_4 != 0);
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":701
 * def read_query(path, qmax=0, qskip=0, window=None):
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)             # <<<<<<<<<<<<<<
 *     elif os.path.splitext(path)[1] == ".csv":
 *         query = pl.read_csv(path)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read_excel); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_query = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":700
 * 
 * def read_query(path, qmax=0, qskip=0, window=None):
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):             # <<<<<<<<<<<<<<
 *         query = pl.read_excel(path)
 *     elif os.path.splitext(path)[1] == ".csv":
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":702
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)
 *     elif os.path.splitext(path)[1] == ".csv":             # <<<<<<<<<<<<<<
 *         query = pl.read_csv(path)
 *     elif os.path.splitext(path)[1] == ".json":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_os); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_path); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_splitext); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_path);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_3, __pyx_kp_u_csv, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":703
 *         query = pl.read_excel(path)
 *     elif os.path.splitext(path)[1] == ".csv":
 *         query = pl.read_csv(path)             # <<<<<<<<<<<<<<
 *     elif os.path.splitext(path)[1] == ".json":
 *         query = pl.read_json(path)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_read_csv); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 703, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_query = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":702
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)
 *     elif os.path.splitext(path)[1] == ".csv":             # <<<<<<<<<<<<<<
 *         query = pl.read_csv(path)
 *     elif os.path.splitext(path)[1] == ".json":
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":704
 *     elif os.path.splitext(path)[1] == ".csv":
 *         query = pl.read_csv(path)
 *     elif os.path.splitext(path)[1] == ".json":             # <<<<<<<<<<<<<<
 *         query = pl.read_json(path)
 *     elif os.path.splitext(path)[1] == ".parquet":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_splitext); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_path);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_kp_u_json, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":705
 *         query = pl.read_csv(path)
 *     elif os.path.splitext(path)[1] == ".json":
 *         query = pl.read_json(path)             # <<<<<<<<<<<<<<
 *     elif os.path.splitext(path)[1] == ".parquet":
 *         query = pl.read_parquet(path)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pl); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_read_json); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 705, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_query = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":704
 *     elif os.path.splitext(path)[1] == ".csv":
 *         query = pl.read_csv(path)
 *     elif os.path.splitext(path)[1] == ".json":             # <<<<<<<<<<<<<<
 *         query = pl.read_json(path)
 *     elif os.path.splitext(path)[1] == ".parquet":
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":706
 *     elif os.path.splitext(path)[1] == ".json":
 *         query = pl.read_json(path)
 *     elif os.path.splitext(path)[1] == ".parquet":             # <<<<<<<<<<<<<<
 *         query = pl.read_parquet(path)
 *     else:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_os); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_splitext); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_path);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_5 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_kp_u_parquet, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 706, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":707
 *         query = pl.read_json(path)
 *     elif os.path.splitext(path)[1] == ".parquet":
 *         query = pl.read_parquet(path)             # <<<<<<<<<<<<<<
 *     else:
 *         return None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_read_parquet); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_1, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_path);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 707, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_query = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":706
 *     elif os.path.splitext(path)[1] == ".json":
 *         query = pl.read_json(path)
 *     elif os.path.splitext(path)[1] == ".parquet":             # <<<<<<<<<<<<<<
 *         query = pl.read_parquet(path)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":709
 *         query = pl.read_parquet(path)
 *     else:
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     assert "TEMP_" not in query.columns # remove 'TEMP_' from all column headers and retry
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }
  __pyx_L3:;

  /* "alacorder/cal.pyx":711
 *         return None
 * 
 *     assert "TEMP_" not in query.columns # remove 'TEMP_' from all column headers and retry             # <<<<<<<<<<<<<<
 * 
 *     if qskip > 0:
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_TEMP, __pyx_t_2, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 711, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!(__pyx_t_5 != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      __PYX_ERR(0, 711, __pyx_L1_error)
    }
  }
  #endif

  /* "alacorder/cal.pyx":713
 *     assert "TEMP_" not in query.columns # remove 'TEMP_' from all column headers and retry
 * 
 *     if qskip > 0:             # <<<<<<<<<<<<<<
 *         qs = qskip - 1
 *         query = query[qs:-1]
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_qskip, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 713, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":714
 * 
 *     if qskip > 0:
 *         qs = qskip - 1             # <<<<<<<<<<<<<<
 *         query = query[qs:-1]
 * 
 */
    __pyx_t_2 = __Pyx_PyInt_SubtractObjC(__pyx_v_qskip, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 714, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_qs = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":715
 *     if qskip > 0:
 *         qs = qskip - 1
 *         query = query[qs:-1]             # <<<<<<<<<<<<<<
 * 
 *     if qmax > query.shape[1]:
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_query, 0, -1L, &__pyx_v_qs, NULL, NULL, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 715, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_query, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":713
 *     assert "TEMP_" not in query.columns # remove 'TEMP_' from all column headers and retry
 * 
 *     if qskip > 0:             # <<<<<<<<<<<<<<
 *         qs = qskip - 1
 *         query = query[qs:-1]
 */
  }

  /* "alacorder/cal.pyx":717
 *         query = query[qs:-1]
 * 
 *     if qmax > query.shape[1]:             # <<<<<<<<<<<<<<
 *         query = query[0:qmax]
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_shape); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_qmax, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 717, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_5) {

    /* "alacorder/cal.pyx":718
 * 
 *     if qmax > query.shape[1]:
 *         query = query[0:qmax]             # <<<<<<<<<<<<<<
 * 
 *     pscols = ["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER"]
 */
    __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_query, 0, 0, NULL, &__pyx_v_qmax, NULL, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_query, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":717
 *         query = query[qs:-1]
 * 
 *     if qmax > query.shape[1]:             # <<<<<<<<<<<<<<
 *         query = query[0:qmax]
 * 
 */
  }

  /* "alacorder/cal.pyx":720
 *         query = query[0:qmax]
 * 
 *     pscols = ["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER"]             # <<<<<<<<<<<<<<
 *     tempcols = ["TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER"]
 * 
 */
  __pyx_t_2 = PyList_New(10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_NAME);
  __Pyx_GIVEREF(__pyx_n_u_NAME);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_NAME);
  __Pyx_INCREF(__pyx_n_u_PARTY_TYPE);
  __Pyx_GIVEREF(__pyx_n_u_PARTY_TYPE);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_PARTY_TYPE);
  __Pyx_INCREF(__pyx_n_u_SSN);
  __Pyx_GIVEREF(__pyx_n_u_SSN);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_SSN);
  __Pyx_INCREF(__pyx_n_u_DOB);
  __Pyx_GIVEREF(__pyx_n_u_DOB);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_DOB);
  __Pyx_INCREF(__pyx_n_u_COUNTY);
  __Pyx_GIVEREF(__pyx_n_u_COUNTY);
  PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_COUNTY);
  __Pyx_INCREF(__pyx_n_u_DIVISION);
  __Pyx_GIVEREF(__pyx_n_u_DIVISION);
  PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_u_DIVISION);
  __Pyx_INCREF(__pyx_n_u_CASE_YEAR);
  __Pyx_GIVEREF(__pyx_n_u_CASE_YEAR);
  PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_u_CASE_YEAR);
  __Pyx_INCREF(__pyx_n_u_NO_RECORDS);
  __Pyx_GIVEREF(__pyx_n_u_NO_RECORDS);
  PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_u_NO_RECORDS);
  __Pyx_INCREF(__pyx_n_u_FILED_BEFORE);
  __Pyx_GIVEREF(__pyx_n_u_FILED_BEFORE);
  PyList_SET_ITEM(__pyx_t_2, 8, __pyx_n_u_FILED_BEFORE);
  __Pyx_INCREF(__pyx_n_u_FILED_AFTER);
  __Pyx_GIVEREF(__pyx_n_u_FILED_AFTER);
  PyList_SET_ITEM(__pyx_t_2, 9, __pyx_n_u_FILED_AFTER);
  __pyx_v_pscols = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":721
 * 
 *     pscols = ["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER"]
 *     tempcols = ["TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER"]             # <<<<<<<<<<<<<<
 * 
 *     # add missing progress cols
 */
  __pyx_t_2 = PyList_New(10); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_TEMP_NAME);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_NAME);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_TEMP_NAME);
  __Pyx_INCREF(__pyx_n_u_TEMP_PARTY_TYPE);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_PARTY_TYPE);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_u_TEMP_PARTY_TYPE);
  __Pyx_INCREF(__pyx_n_u_TEMP_SSN);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_SSN);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_u_TEMP_SSN);
  __Pyx_INCREF(__pyx_n_u_TEMP_DOB);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_DOB);
  PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_u_TEMP_DOB);
  __Pyx_INCREF(__pyx_n_u_TEMP_COUNTY);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_COUNTY);
  PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_u_TEMP_COUNTY);
  __Pyx_INCREF(__pyx_n_u_TEMP_DIVISION);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_DIVISION);
  PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_u_TEMP_DIVISION);
  __Pyx_INCREF(__pyx_n_u_TEMP_CASE_YEAR);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_CASE_YEAR);
  PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_u_TEMP_CASE_YEAR);
  __Pyx_INCREF(__pyx_n_u_TEMP_NO_RECORDS);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_NO_RECORDS);
  PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_u_TEMP_NO_RECORDS);
  __Pyx_INCREF(__pyx_n_u_TEMP_FILED_BEFORE);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_FILED_BEFORE);
  PyList_SET_ITEM(__pyx_t_2, 8, __pyx_n_u_TEMP_FILED_BEFORE);
  __Pyx_INCREF(__pyx_n_u_TEMP_FILED_AFTER);
  __Pyx_GIVEREF(__pyx_n_u_TEMP_FILED_AFTER);
  PyList_SET_ITEM(__pyx_t_2, 9, __pyx_n_u_TEMP_FILED_AFTER);
  __pyx_v_tempcols = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":724
 * 
 *     # add missing progress cols
 *     for col in ("RETRIEVED","CASES_FOUND","QUERY_COMPLETE"):             # <<<<<<<<<<<<<<
 *         if col not in query.columns:
 *             query = query.with_columns(pl.lit('').alias(col))
 */
  __pyx_t_2 = __pyx_tuple__91; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
  for (;;) {
    if (__pyx_t_6 >= 3) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 724, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 724, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_col, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":725
 *     # add missing progress cols
 *     for col in ("RETRIEVED","CASES_FOUND","QUERY_COMPLETE"):
 *         if col not in query.columns:             # <<<<<<<<<<<<<<
 *             query = query.with_columns(pl.lit('').alias(col))
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_columns); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 725, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_v_col, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 725, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (__pyx_t_4) {

      /* "alacorder/cal.pyx":726
 *     for col in ("RETRIEVED","CASES_FOUND","QUERY_COMPLETE"):
 *         if col not in query.columns:
 *             query = query.with_columns(pl.lit('').alias(col))             # <<<<<<<<<<<<<<
 * 
 *     # add matching temp columns for valid columns (i.e. 'Name' -> 'TEMP_NAME')
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_pl); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_lit); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_8 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_9, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_alias); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_v_col) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_col);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_3 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 726, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_query, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "alacorder/cal.pyx":725
 *     # add missing progress cols
 *     for col in ("RETRIEVED","CASES_FOUND","QUERY_COMPLETE"):
 *         if col not in query.columns:             # <<<<<<<<<<<<<<
 *             query = query.with_columns(pl.lit('').alias(col))
 * 
 */
    }

    /* "alacorder/cal.pyx":724
 * 
 *     # add missing progress cols
 *     for col in ("RETRIEVED","CASES_FOUND","QUERY_COMPLETE"):             # <<<<<<<<<<<<<<
 *         if col not in query.columns:
 *             query = query.with_columns(pl.lit('').alias(col))
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":729
 * 
 *     # add matching temp columns for valid columns (i.e. 'Name' -> 'TEMP_NAME')
 *     goodquery = False             # <<<<<<<<<<<<<<
 *     for col in query.columns:
 *         if col.upper().strip().replace(' ','_') in pscols:
 */
  __pyx_v_goodquery = 0;

  /* "alacorder/cal.pyx":730
 *     # add matching temp columns for valid columns (i.e. 'Name' -> 'TEMP_NAME')
 *     goodquery = False
 *     for col in query.columns:             # <<<<<<<<<<<<<<
 *         if col.upper().strip().replace(' ','_') in pscols:
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
    __pyx_t_11 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 730, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 730, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_11)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 730, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 730, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 730, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 730, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_11(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 730, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_col, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":731
 *     goodquery = False
 *     for col in query.columns:
 *         if col.upper().strip().replace(' ','_') in pscols:             # <<<<<<<<<<<<<<
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])
 *             goodquery = True
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_col, __pyx_n_s_upper); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_replace); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__93, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_v_pscols, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 731, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (__pyx_t_5) {

      /* "alacorder/cal.pyx":732
 *     for col in query.columns:
 *         if col.upper().strip().replace(' ','_') in pscols:
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])             # <<<<<<<<<<<<<<
 *             goodquery = True
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_pl); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_col); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_8, __pyx_v_col) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_v_col);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_alias); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_col, __pyx_n_s_upper); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_8 = (__pyx_t_13) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_13) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_strip); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_10 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_replace); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_tuple__93, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_FormatSimple(__pyx_t_10, __pyx_empty_unicode); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyUnicode_Concat(__pyx_n_u_TEMP, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_1 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_12, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_10);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyList_New(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_1);
      PyList_SET_ITEM(__pyx_t_9, 0, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_1, __pyx_t_9) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_9);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 732, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_query, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "alacorder/cal.pyx":733
 *         if col.upper().strip().replace(' ','_') in pscols:
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])
 *             goodquery = True             # <<<<<<<<<<<<<<
 * 
 *     # add other temp columns as empty
 */
      __pyx_v_goodquery = 1;

      /* "alacorder/cal.pyx":731
 *     goodquery = False
 *     for col in query.columns:
 *         if col.upper().strip().replace(' ','_') in pscols:             # <<<<<<<<<<<<<<
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])
 *             goodquery = True
 */
    }

    /* "alacorder/cal.pyx":730
 *     # add matching temp columns for valid columns (i.e. 'Name' -> 'TEMP_NAME')
 *     goodquery = False
 *     for col in query.columns:             # <<<<<<<<<<<<<<
 *         if col.upper().strip().replace(' ','_') in pscols:
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":736
 * 
 *     # add other temp columns as empty
 *     for col in tempcols:             # <<<<<<<<<<<<<<
 *         if col not in query.columns:
 *             query = query.with_columns([pl.lit('').alias(col)])
 */
  __pyx_t_3 = __pyx_v_tempcols; __Pyx_INCREF(__pyx_t_3); __pyx_t_6 = 0;
  for (;;) {
    if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_3)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 736, __pyx_L1_error)
    #else
    __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_col, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "alacorder/cal.pyx":737
 *     # add other temp columns as empty
 *     for col in tempcols:
 *         if col not in query.columns:             # <<<<<<<<<<<<<<
 *             query = query.with_columns([pl.lit('').alias(col)])
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_columns); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 737, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_v_col, __pyx_t_2, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 737, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_4 = (__pyx_t_5 != 0);
    if (__pyx_t_4) {

      /* "alacorder/cal.pyx":738
 *     for col in tempcols:
 *         if col not in query.columns:
 *             query = query.with_columns([pl.lit('').alias(col)])             # <<<<<<<<<<<<<<
 * 
 *     if goodquery:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_with_columns); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_pl); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_lit); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_10, __pyx_kp_u__8) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_alias); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_1, __pyx_v_col) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_v_col);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = PyList_New(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_9);
      PyList_SET_ITEM(__pyx_t_12, 0, __pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_2 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_9, __pyx_t_12) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_12);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF_SET(__pyx_v_query, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "alacorder/cal.pyx":737
 *     # add other temp columns as empty
 *     for col in tempcols:
 *         if col not in query.columns:             # <<<<<<<<<<<<<<
 *             query = query.with_columns([pl.lit('').alias(col)])
 * 
 */
    }

    /* "alacorder/cal.pyx":736
 * 
 *     # add other temp columns as empty
 *     for col in tempcols:             # <<<<<<<<<<<<<<
 *         if col not in query.columns:
 *             query = query.with_columns([pl.lit('').alias(col)])
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":740
 *             query = query.with_columns([pl.lit('').alias(col)])
 * 
 *     if goodquery:             # <<<<<<<<<<<<<<
 *         print(f"{query.shape[1]} queries found in input query file.")
 *         return query
 */
  __pyx_t_4 = (__pyx_v_goodquery != 0);
  if (__pyx_t_4) {

    /* "alacorder/cal.pyx":741
 * 
 *     if goodquery:
 *         print(f"{query.shape[1]} queries found in input query file.")             # <<<<<<<<<<<<<<
 *         return query
 *     else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_shape); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_3, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_t_3, __pyx_kp_u_queries_found_in_input_query_fi); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 741, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":742
 *     if goodquery:
 *         print(f"{query.shape[1]} queries found in input query file.")
 *         return query             # <<<<<<<<<<<<<<
 *     else:
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_query);
    __pyx_r = __pyx_v_query;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":740
 *             query = query.with_columns([pl.lit('').alias(col)])
 * 
 *     if goodquery:             # <<<<<<<<<<<<<<
 *         print(f"{query.shape[1]} queries found in input query file.")
 *         return query
 */
  }

  /* "alacorder/cal.pyx":744
 *         return query
 *     else:
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")             # <<<<<<<<<<<<<<
 *         return None
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__94, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 744, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":745
 *     else:
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")
 *         return None             # <<<<<<<<<<<<<<
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):
 *      """
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":699
 * #   #   #   #         FETCH (PDF SCRAPER)       #   #   #   #
 * 
 * def read_query(path, qmax=0, qskip=0, window=None):             # <<<<<<<<<<<<<<
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.read_query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_query);
  __Pyx_XDECREF(__pyx_v_qs);
  __Pyx_XDECREF(__pyx_v_pscols);
  __Pyx_XDECREF(__pyx_v_tempcols);
  __Pyx_XDECREF(__pyx_v_col);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":746
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")
 *         return None
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Fetch cases from Alacourt.com with input query spreadsheet headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_33fetch(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_32fetch[] = "\n     Fetch cases from Alacourt.com with input query spreadsheet headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE.\n     Args:\n        querypath (str): Path to query table/spreadsheet (.xls, .xlsx)\n        dirpath (str): Path to PDF output directory\n        cID (str): Customer ID on Alacourt.com\n        uID (str): User ID on Alacourt.com\n        pwd (str): Password on Alacourt.com\n        qmax (int): Maximum queries to conduct on Alacourt.com\n        qskip (int): Skip entries at top of query file\n        no_update (bool): Do not update query template after completion\n        debug (bool): Print detailed runtime information to console\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_33fetch = {"fetch", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_33fetch, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_32fetch};
static PyObject *__pyx_pw_9alacorder_3cal_33fetch(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_querypath = 0;
  PyObject *__pyx_v_dirpath = 0;
  PyObject *__pyx_v_cID = 0;
  PyObject *__pyx_v_uID = 0;
  PyObject *__pyx_v_pwd = 0;
  PyObject *__pyx_v_qmax = 0;
  PyObject *__pyx_v_qskip = 0;
  PyObject *__pyx_v_cf = 0;
  PyObject *__pyx_v_no_update = 0;
  CYTHON_UNUSED PyObject *__pyx_v_debug = 0;
  PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fetch (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_querypath,&__pyx_n_s_dirpath,&__pyx_n_s_cID,&__pyx_n_s_uID,&__pyx_n_s_pwd,&__pyx_n_s_qmax,&__pyx_n_s_qskip,&__pyx_n_s_cf,&__pyx_n_s_no_update,&__pyx_n_s_debug,&__pyx_n_s_window,0};
    PyObject* values[11] = {0,0,0,0,0,0,0,0,0,0,0};
    values[0] = ((PyObject *)__pyx_kp_u__8);
    values[1] = ((PyObject *)__pyx_kp_u__8);
    values[2] = ((PyObject *)__pyx_kp_u__8);
    values[3] = ((PyObject *)__pyx_kp_u__8);
    values[4] = ((PyObject *)__pyx_kp_u__8);
    values[5] = ((PyObject *)__pyx_int_0);
    values[6] = ((PyObject *)__pyx_int_0);
    values[7] = ((PyObject *)Py_None);
    values[8] = ((PyObject *)Py_False);
    values[9] = ((PyObject *)Py_False);
    values[10] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_querypath);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dirpath);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cID);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_uID);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pwd);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_qmax);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_qskip);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cf);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_no_update);
          if (value) { values[8] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[9] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[10] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "fetch") < 0)) __PYX_ERR(0, 746, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_querypath = values[0];
    __pyx_v_dirpath = values[1];
    __pyx_v_cID = values[2];
    __pyx_v_uID = values[3];
    __pyx_v_pwd = values[4];
    __pyx_v_qmax = values[5];
    __pyx_v_qskip = values[6];
    __pyx_v_cf = values[7];
    __pyx_v_no_update = values[8];
    __pyx_v_debug = values[9];
    __pyx_v_window = values[10];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("fetch", 0, 0, 11, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 746, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.fetch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_32fetch(__pyx_self, __pyx_v_querypath, __pyx_v_dirpath, __pyx_v_cID, __pyx_v_uID, __pyx_v_pwd, __pyx_v_qmax, __pyx_v_qskip, __pyx_v_cf, __pyx_v_no_update, __pyx_v_debug, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_32fetch(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_querypath, PyObject *__pyx_v_dirpath, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_qmax, PyObject *__pyx_v_qskip, PyObject *__pyx_v_cf, PyObject *__pyx_v_no_update, CYTHON_UNUSED PyObject *__pyx_v_debug, PyObject *__pyx_v_window) {
  PyObject *__pyx_v_query = NULL;
  PyObject *__pyx_v_opt = NULL;
  PyObject *__pyx_v_driver = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_r = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_v_url = NULL;
  PyObject *__pyx_v_qwrite = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  Py_UCS4 __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fetch", 0);
  __Pyx_INCREF(__pyx_v_querypath);
  __Pyx_INCREF(__pyx_v_dirpath);
  __Pyx_INCREF(__pyx_v_cID);
  __Pyx_INCREF(__pyx_v_uID);
  __Pyx_INCREF(__pyx_v_pwd);
  __Pyx_INCREF(__pyx_v_qmax);
  __Pyx_INCREF(__pyx_v_qskip);
  __Pyx_INCREF(__pyx_v_cf);

  /* "alacorder/cal.pyx":760
 *         debug (bool): Print detailed runtime information to console
 *      """
 *      if cf != None:             # <<<<<<<<<<<<<<
 *         querypath = cf['INPUTS']
 *         dirpath = cf['OUTPUT_PATH']
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_cf, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 760, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 760, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":761
 *      """
 *      if cf != None:
 *         querypath = cf['INPUTS']             # <<<<<<<<<<<<<<
 *         dirpath = cf['OUTPUT_PATH']
 *         cID = cf['ALA_CUSTOMER_ID']
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_INPUTS); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_querypath, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":762
 *      if cf != None:
 *         querypath = cf['INPUTS']
 *         dirpath = cf['OUTPUT_PATH']             # <<<<<<<<<<<<<<
 *         cID = cf['ALA_CUSTOMER_ID']
 *         uID = cf['ALA_USER_ID']
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_OUTPUT_PATH); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 762, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_dirpath, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":763
 *         querypath = cf['INPUTS']
 *         dirpath = cf['OUTPUT_PATH']
 *         cID = cf['ALA_CUSTOMER_ID']             # <<<<<<<<<<<<<<
 *         uID = cf['ALA_USER_ID']
 *         pwd = cf['ALA_PASSWORD']
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_ALA_CUSTOMER_ID); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 763, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_cID, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":764
 *         dirpath = cf['OUTPUT_PATH']
 *         cID = cf['ALA_CUSTOMER_ID']
 *         uID = cf['ALA_USER_ID']             # <<<<<<<<<<<<<<
 *         pwd = cf['ALA_PASSWORD']
 *         qmax = cf['FETCH_MAX']
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_ALA_USER_ID); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_uID, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":765
 *         cID = cf['ALA_CUSTOMER_ID']
 *         uID = cf['ALA_USER_ID']
 *         pwd = cf['ALA_PASSWORD']             # <<<<<<<<<<<<<<
 *         qmax = cf['FETCH_MAX']
 *         qskip = cf['FETCH_SKIP']
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_ALA_PASSWORD); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 765, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_pwd, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":766
 *         uID = cf['ALA_USER_ID']
 *         pwd = cf['ALA_PASSWORD']
 *         qmax = cf['FETCH_MAX']             # <<<<<<<<<<<<<<
 *         qskip = cf['FETCH_SKIP']
 *      else:
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_FETCH_MAX); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 766, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_qmax, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":767
 *         pwd = cf['ALA_PASSWORD']
 *         qmax = cf['FETCH_MAX']
 *         qskip = cf['FETCH_SKIP']             # <<<<<<<<<<<<<<
 *      else:
 *         cf = {
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_FETCH_SKIP); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 767, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_qskip, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":760
 *         debug (bool): Print detailed runtime information to console
 *      """
 *      if cf != None:             # <<<<<<<<<<<<<<
 *         querypath = cf['INPUTS']
 *         dirpath = cf['OUTPUT_PATH']
 */
    goto __pyx_L3;
  }

  /* "alacorder/cal.pyx":770
 *      else:
 *         cf = {
 *         'INPUTS': querypath,             # <<<<<<<<<<<<<<
 *         'OUTPUT_PATH': dirpath,
 *         'ALA_CUSTOMER_ID': cID,
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyDict_NewPresized(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 770, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_INPUTS, __pyx_v_querypath) < 0) __PYX_ERR(0, 770, __pyx_L1_error)

    /* "alacorder/cal.pyx":771
 *         cf = {
 *         'INPUTS': querypath,
 *         'OUTPUT_PATH': dirpath,             # <<<<<<<<<<<<<<
 *         'ALA_CUSTOMER_ID': cID,
 *         'ALA_USER_ID': uID,
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_OUTPUT_PATH, __pyx_v_dirpath) < 0) __PYX_ERR(0, 770, __pyx_L1_error)

    /* "alacorder/cal.pyx":772
 *         'INPUTS': querypath,
 *         'OUTPUT_PATH': dirpath,
 *         'ALA_CUSTOMER_ID': cID,             # <<<<<<<<<<<<<<
 *         'ALA_USER_ID': uID,
 *         'ALA_PASSWORD': pwd,
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ALA_CUSTOMER_ID, __pyx_v_cID) < 0) __PYX_ERR(0, 770, __pyx_L1_error)

    /* "alacorder/cal.pyx":773
 *         'OUTPUT_PATH': dirpath,
 *         'ALA_CUSTOMER_ID': cID,
 *         'ALA_USER_ID': uID,             # <<<<<<<<<<<<<<
 *         'ALA_PASSWORD': pwd,
 *         'FETCH_MAX': qmax,
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ALA_USER_ID, __pyx_v_uID) < 0) __PYX_ERR(0, 770, __pyx_L1_error)

    /* "alacorder/cal.pyx":774
 *         'ALA_CUSTOMER_ID': cID,
 *         'ALA_USER_ID': uID,
 *         'ALA_PASSWORD': pwd,             # <<<<<<<<<<<<<<
 *         'FETCH_MAX': qmax,
 *         'FETCH_SKIP': qskip
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_ALA_PASSWORD, __pyx_v_pwd) < 0) __PYX_ERR(0, 770, __pyx_L1_error)

    /* "alacorder/cal.pyx":775
 *         'ALA_USER_ID': uID,
 *         'ALA_PASSWORD': pwd,
 *         'FETCH_MAX': qmax,             # <<<<<<<<<<<<<<
 *         'FETCH_SKIP': qskip
 *         }
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FETCH_MAX, __pyx_v_qmax) < 0) __PYX_ERR(0, 770, __pyx_L1_error)

    /* "alacorder/cal.pyx":776
 *         'ALA_PASSWORD': pwd,
 *         'FETCH_MAX': qmax,
 *         'FETCH_SKIP': qskip             # <<<<<<<<<<<<<<
 *         }
 * 
 */
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_FETCH_SKIP, __pyx_v_qskip) < 0) __PYX_ERR(0, 770, __pyx_L1_error)
    __Pyx_DECREF_SET(__pyx_v_cf, __pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "alacorder/cal.pyx":779
 *         }
 * 
 *      query = read_query(cf['INPUTS'], qmax=qmax, qskip=qskip)             # <<<<<<<<<<<<<<
 * 
 *      # start browser and authenticate
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_read_query); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_INPUTS); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_qmax, __pyx_v_qmax) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_qskip, __pyx_v_qskip) < 0) __PYX_ERR(0, 779, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_query = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":782
 * 
 *      # start browser and authenticate
 *      opt = webdriver.ChromeOptions()             # <<<<<<<<<<<<<<
 *      opt.add_experimental_option('prefs', {
 *           "download.default_directory": dirpath, #Change default directory for downloads
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_webdriver); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ChromeOptions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 782, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_opt = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":783
 *      # start browser and authenticate
 *      opt = webdriver.ChromeOptions()
 *      opt.add_experimental_option('prefs', {             # <<<<<<<<<<<<<<
 *           "download.default_directory": dirpath, #Change default directory for downloads
 *           "download.prompt_for_download": False, #To auto download the file
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_opt, __pyx_n_s_add_experimental_option); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "alacorder/cal.pyx":784
 *      opt = webdriver.ChromeOptions()
 *      opt.add_experimental_option('prefs', {
 *           "download.default_directory": dirpath, #Change default directory for downloads             # <<<<<<<<<<<<<<
 *           "download.prompt_for_download": False, #To auto download the file
 *           "download.directory_upgrade": True,
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 784, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_download_default_directory, __pyx_v_dirpath) < 0) __PYX_ERR(0, 784, __pyx_L1_error)

  /* "alacorder/cal.pyx":785
 *      opt.add_experimental_option('prefs', {
 *           "download.default_directory": dirpath, #Change default directory for downloads
 *           "download.prompt_for_download": False, #To auto download the file             # <<<<<<<<<<<<<<
 *           "download.directory_upgrade": True,
 *           "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_download_prompt_for_download, Py_False) < 0) __PYX_ERR(0, 784, __pyx_L1_error)

  /* "alacorder/cal.pyx":786
 *           "download.default_directory": dirpath, #Change default directory for downloads
 *           "download.prompt_for_download": False, #To auto download the file
 *           "download.directory_upgrade": True,             # <<<<<<<<<<<<<<
 *           "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 *      })
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_download_directory_upgrade, Py_True) < 0) __PYX_ERR(0, 784, __pyx_L1_error)

  /* "alacorder/cal.pyx":787
 *           "download.prompt_for_download": False, #To auto download the file
 *           "download.directory_upgrade": True,
 *           "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome             # <<<<<<<<<<<<<<
 *      })
 *      print("Starting browser... Do not close while in progress!")
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_plugins_always_open_pdf_external, Py_True) < 0) __PYX_ERR(0, 784, __pyx_L1_error)
  __pyx_t_1 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_n_u_prefs, __pyx_t_3};
    __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_n_u_prefs, __pyx_t_3};
    __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_1) {
      __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_1); __pyx_t_1 = NULL;
    }
    __Pyx_INCREF(__pyx_n_u_prefs);
    __Pyx_GIVEREF(__pyx_n_u_prefs);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_n_u_prefs);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 783, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":789
 *           "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 *      })
 *      print("Starting browser... Do not close while in progress!")             # <<<<<<<<<<<<<<
 *      driver = webdriver.Chrome(options=opt)
 *      login(driver, cID=cID, uID=uID, pwd=pwd, window=window)
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__95, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":790
 *      })
 *      print("Starting browser... Do not close while in progress!")
 *      driver = webdriver.Chrome(options=opt)             # <<<<<<<<<<<<<<
 *      login(driver, cID=cID, uID=uID, pwd=pwd, window=window)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_webdriver); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Chrome); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_options, __pyx_v_opt) < 0) __PYX_ERR(0, 790, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 790, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_driver = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":791
 *      print("Starting browser... Do not close while in progress!")
 *      driver = webdriver.Chrome(options=opt)
 *      login(driver, cID=cID, uID=uID, pwd=pwd, window=window)             # <<<<<<<<<<<<<<
 * 
 *      for i, r in enumerate(query.rows(named=True)):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_login); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_driver);
  __Pyx_GIVEREF(__pyx_v_driver);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_driver);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_cID, __pyx_v_cID) < 0) __PYX_ERR(0, 791, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_uID, __pyx_v_uID) < 0) __PYX_ERR(0, 791, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_pwd, __pyx_v_pwd) < 0) __PYX_ERR(0, 791, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 791, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":793
 *      login(driver, cID=cID, uID=uID, pwd=pwd, window=window)
 * 
 *      for i, r in enumerate(query.rows(named=True)):             # <<<<<<<<<<<<<<
 *         if query[i,'QUERY_COMPLETE'] == "Y":
 *             continue
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_t_3 = __pyx_int_0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_rows); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_named, Py_True) < 0) __PYX_ERR(0, 793, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
    __pyx_t_5 = __pyx_t_7; __Pyx_INCREF(__pyx_t_5); __pyx_t_8 = 0;
    __pyx_t_9 = NULL;
  } else {
    __pyx_t_8 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 793, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  for (;;) {
    if (likely(!__pyx_t_9)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_7); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 793, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 793, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      } else {
        if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_8); __Pyx_INCREF(__pyx_t_7); __pyx_t_8++; if (unlikely(0 < 0)) __PYX_ERR(0, 793, __pyx_L1_error)
        #else
        __pyx_t_7 = PySequence_ITEM(__pyx_t_5, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 793, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        #endif
      }
    } else {
      __pyx_t_7 = __pyx_t_9(__pyx_t_5);
      if (unlikely(!__pyx_t_7)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 793, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_7);
    }
    __Pyx_XDECREF_SET(__pyx_v_r, __pyx_t_7);
    __pyx_t_7 = 0;
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 793, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3);
    __pyx_t_3 = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":794
 * 
 *      for i, r in enumerate(query.rows(named=True)):
 *         if query[i,'QUERY_COMPLETE'] == "Y":             # <<<<<<<<<<<<<<
 *             continue
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 */
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_i);
    __Pyx_GIVEREF(__pyx_v_i);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_i);
    __Pyx_INCREF(__pyx_n_u_QUERY_COMPLETE);
    __Pyx_GIVEREF(__pyx_n_u_QUERY_COMPLETE);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_n_u_QUERY_COMPLETE);
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_query, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_n_u_Y, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 794, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":795
 *      for i, r in enumerate(query.rows(named=True)):
 *         if query[i,'QUERY_COMPLETE'] == "Y":
 *             continue             # <<<<<<<<<<<<<<
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *             login(driver, cID, uID, pwd, window=window)
 */
      goto __pyx_L4_continue;

      /* "alacorder/cal.pyx":794
 * 
 *      for i, r in enumerate(query.rows(named=True)):
 *         if query[i,'QUERY_COMPLETE'] == "Y":             # <<<<<<<<<<<<<<
 *             continue
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 */
    }

    /* "alacorder/cal.pyx":796
 *         if query[i,'QUERY_COMPLETE'] == "Y":
 *             continue
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":             # <<<<<<<<<<<<<<
 *             login(driver, cID, uID, pwd, window=window)
 *         driver.implicitly_wait(1)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_current_url); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u_https_v2_alacourt_com_frmlogin_a, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 796, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":797
 *             continue
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *             login(driver, cID, uID, pwd, window=window)             # <<<<<<<<<<<<<<
 *         driver.implicitly_wait(1)
 *         results = party_search(driver, name=r['TEMP_NAME'], party_type=r['TEMP_PARTY_TYPE'], ssn=r['TEMP_SSN'], dob=r['TEMP_DOB'], county=r['TEMP_COUNTY'], division=r['TEMP_DIVISION'], case_year=r['TEMP_CASE_YEAR'], filed_before=r['TEMP_FILED_BEFORE'], filed_after=r['TEMP_FILED_AFTER'], window=window)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_login); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_driver);
      __Pyx_GIVEREF(__pyx_v_driver);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_driver);
      __Pyx_INCREF(__pyx_v_cID);
      __Pyx_GIVEREF(__pyx_v_cID);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_cID);
      __Pyx_INCREF(__pyx_v_uID);
      __Pyx_GIVEREF(__pyx_v_uID);
      PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_v_uID);
      __Pyx_INCREF(__pyx_v_pwd);
      __Pyx_GIVEREF(__pyx_v_pwd);
      PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_v_pwd);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 797, __pyx_L1_error)
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 797, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":796
 *         if query[i,'QUERY_COMPLETE'] == "Y":
 *             continue
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":             # <<<<<<<<<<<<<<
 *             login(driver, cID, uID, pwd, window=window)
 *         driver.implicitly_wait(1)
 */
    }

    /* "alacorder/cal.pyx":798
 *         if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *             login(driver, cID, uID, pwd, window=window)
 *         driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 *         results = party_search(driver, name=r['TEMP_NAME'], party_type=r['TEMP_PARTY_TYPE'], ssn=r['TEMP_SSN'], dob=r['TEMP_DOB'], county=r['TEMP_COUNTY'], division=r['TEMP_DIVISION'], case_year=r['TEMP_CASE_YEAR'], filed_before=r['TEMP_FILED_BEFORE'], filed_after=r['TEMP_FILED_AFTER'], window=window)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_10 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_int_1);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 798, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "alacorder/cal.pyx":799
 *             login(driver, cID, uID, pwd, window=window)
 *         driver.implicitly_wait(1)
 *         results = party_search(driver, name=r['TEMP_NAME'], party_type=r['TEMP_PARTY_TYPE'], ssn=r['TEMP_SSN'], dob=r['TEMP_DOB'], county=r['TEMP_COUNTY'], division=r['TEMP_DIVISION'], case_year=r['TEMP_CASE_YEAR'], filed_before=r['TEMP_FILED_BEFORE'], filed_after=r['TEMP_FILED_AFTER'], window=window)             # <<<<<<<<<<<<<<
 * 
 *         if len(results) > 0:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_party_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_driver);
    __Pyx_GIVEREF(__pyx_v_driver);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_driver);
    __pyx_t_7 = __Pyx_PyDict_NewPresized(10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_NAME); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_name, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_PARTY_TYPE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_party_type, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_SSN); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_ssn, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_DOB); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_dob, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_COUNTY); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_county, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_DIVISION); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_division, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_CASE_YEAR); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_case_year, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_FILED_BEFORE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_filed_before, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_r, __pyx_n_u_TEMP_FILED_AFTER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_filed_after, __pyx_t_4) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 799, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 799, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF_SET(__pyx_v_results, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "alacorder/cal.pyx":801
 *         results = party_search(driver, name=r['TEMP_NAME'], party_type=r['TEMP_PARTY_TYPE'], ssn=r['TEMP_SSN'], dob=r['TEMP_DOB'], county=r['TEMP_COUNTY'], division=r['TEMP_DIVISION'], case_year=r['TEMP_CASE_YEAR'], filed_before=r['TEMP_FILED_BEFORE'], filed_after=r['TEMP_FILED_AFTER'], window=window)
 * 
 *         if len(results) > 0:             # <<<<<<<<<<<<<<
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")
 *             if window != None:
 */
    __pyx_t_11 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 801, __pyx_L1_error)
    __pyx_t_2 = ((__pyx_t_11 > 0) != 0);
    if (__pyx_t_2) {

      /* "alacorder/cal.pyx":802
 * 
 *         if len(results) > 0:
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")             # <<<<<<<<<<<<<<
 *             if window != None:
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 */
      __pyx_t_4 = PyTuple_New(9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = 0;
      __pyx_t_12 = 127;
      __Pyx_INCREF(__pyx_kp_u__96);
      __pyx_t_11 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__96);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u__96);
      __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_v_i, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_12;
      __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u__42);
      __pyx_t_11 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__42);
      PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u__42);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_shape); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_7, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_12;
      __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u__64);
      __pyx_t_11 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__64);
      PyTuple_SET_ITEM(__pyx_t_4, 4, __pyx_kp_u__64);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_TEMP_NAME);
      __Pyx_GIVEREF(__pyx_n_u_TEMP_NAME);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_n_u_TEMP_NAME);
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_query, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_12 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_12) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_12;
      __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_4, 5, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u__97);
      __pyx_t_11 += 3;
      __Pyx_GIVEREF(__pyx_kp_u__97);
      PyTuple_SET_ITEM(__pyx_t_4, 6, __pyx_kp_u__97);
      __pyx_t_13 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 802, __pyx_L1_error)
      __pyx_t_7 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_t_13, 0, ' ', 'd'); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_4, 7, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_INCREF(__pyx_kp_u_records_returned);
      __pyx_t_11 += 18;
      __Pyx_GIVEREF(__pyx_kp_u_records_returned);
      PyTuple_SET_ITEM(__pyx_t_4, 8, __pyx_kp_u_records_returned);
      __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_4, 9, __pyx_t_11, __pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 802, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":803
 *         if len(results) > 0:
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")
 *             if window != None:             # <<<<<<<<<<<<<<
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 */
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_window, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 803, __pyx_L1_error)
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 803, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_2) {

        /* "alacorder/cal.pyx":804
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")
 *             if window != None:
 *                 window.write_event_value('PROGRESS-TEXT', 0)             # <<<<<<<<<<<<<<
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 *                 for i, url in enumerate(results):
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 804, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__98, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 804, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "alacorder/cal.pyx":805
 *             if window != None:
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)             # <<<<<<<<<<<<<<
 *                 for i, url in enumerate(results):
 *                     window.write_event_value('PROGRESS-TEXT', i+1)
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 805, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_tuple__99, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 805, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "alacorder/cal.pyx":806
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 *                 for i, url in enumerate(results):             # <<<<<<<<<<<<<<
 *                     window.write_event_value('PROGRESS-TEXT', i+1)
 *                     downloadPDF(driver, url)
 */
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_4 = __pyx_int_0;
        if (likely(PyList_CheckExact(__pyx_v_results)) || PyTuple_CheckExact(__pyx_v_results)) {
          __pyx_t_7 = __pyx_v_results; __Pyx_INCREF(__pyx_t_7); __pyx_t_11 = 0;
          __pyx_t_14 = NULL;
        } else {
          __pyx_t_11 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_v_results); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 806, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_14 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 806, __pyx_L1_error)
        }
        for (;;) {
          if (likely(!__pyx_t_14)) {
            if (likely(PyList_CheckExact(__pyx_t_7))) {
              if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_7)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_11); __Pyx_INCREF(__pyx_t_1); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 806, __pyx_L1_error)
              #else
              __pyx_t_1 = PySequence_ITEM(__pyx_t_7, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 806, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            } else {
              if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_11); __Pyx_INCREF(__pyx_t_1); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 806, __pyx_L1_error)
              #else
              __pyx_t_1 = PySequence_ITEM(__pyx_t_7, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 806, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              #endif
            }
          } else {
            __pyx_t_1 = __pyx_t_14(__pyx_t_7);
            if (unlikely(!__pyx_t_1)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 806, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_1);
          }
          __Pyx_XDECREF_SET(__pyx_v_url, __pyx_t_1);
          __pyx_t_1 = 0;
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_4);
          __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 806, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4);
          __pyx_t_4 = __pyx_t_1;
          __pyx_t_1 = 0;

          /* "alacorder/cal.pyx":807
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 *                 for i, url in enumerate(results):
 *                     window.write_event_value('PROGRESS-TEXT', i+1)             # <<<<<<<<<<<<<<
 *                     downloadPDF(driver, url)
 *             else:
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 807, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_15 = __Pyx_PyInt_AddObjC(__pyx_v_i, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 807, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_15);
          __pyx_t_16 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_16)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_16, __pyx_kp_u_PROGRESS_TEXT, __pyx_t_15};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 807, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_16, __pyx_kp_u_PROGRESS_TEXT, __pyx_t_15};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 807, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          } else
          #endif
          {
            __pyx_t_17 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 807, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            if (__pyx_t_16) {
              __Pyx_GIVEREF(__pyx_t_16); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_16); __pyx_t_16 = NULL;
            }
            __Pyx_INCREF(__pyx_kp_u_PROGRESS_TEXT);
            __Pyx_GIVEREF(__pyx_kp_u_PROGRESS_TEXT);
            PyTuple_SET_ITEM(__pyx_t_17, 0+__pyx_t_6, __pyx_kp_u_PROGRESS_TEXT);
            __Pyx_GIVEREF(__pyx_t_15);
            PyTuple_SET_ITEM(__pyx_t_17, 1+__pyx_t_6, __pyx_t_15);
            __pyx_t_15 = 0;
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_17, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 807, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "alacorder/cal.pyx":808
 *                 for i, url in enumerate(results):
 *                     window.write_event_value('PROGRESS-TEXT', i+1)
 *                     downloadPDF(driver, url)             # <<<<<<<<<<<<<<
 *             else:
 *                 for i, url in enumerate(tqdm.rich.tqdm(results)):
 */
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_downloadPDF); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 808, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_17 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_17)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_17);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_17, __pyx_v_driver, __pyx_v_url};
            __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 808, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_17, __pyx_v_driver, __pyx_v_url};
            __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 808, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_GOTREF(__pyx_t_1);
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 808, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_15);
            if (__pyx_t_17) {
              __Pyx_GIVEREF(__pyx_t_17); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_17); __pyx_t_17 = NULL;
            }
            __Pyx_INCREF(__pyx_v_driver);
            __Pyx_GIVEREF(__pyx_v_driver);
            PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_6, __pyx_v_driver);
            __Pyx_INCREF(__pyx_v_url);
            __Pyx_GIVEREF(__pyx_v_url);
            PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_6, __pyx_v_url);
            __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 808, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "alacorder/cal.pyx":806
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 *                 for i, url in enumerate(results):             # <<<<<<<<<<<<<<
 *                     window.write_event_value('PROGRESS-TEXT', i+1)
 *                     downloadPDF(driver, url)
 */
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "alacorder/cal.pyx":803
 *         if len(results) > 0:
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")
 *             if window != None:             # <<<<<<<<<<<<<<
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 */
        goto __pyx_L9;
      }

      /* "alacorder/cal.pyx":810
 *                     downloadPDF(driver, url)
 *             else:
 *                 for i, url in enumerate(tqdm.rich.tqdm(results)):             # <<<<<<<<<<<<<<
 *                     downloadPDF(driver, url)
 *             query[i,'CASES_FOUND'] = len(results)
 */
      /*else*/ {
        __Pyx_INCREF(__pyx_int_0);
        __pyx_t_4 = __pyx_int_0;
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_rich); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_tqdm); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_7 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_10, __pyx_v_results) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_results);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 810, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (likely(PyList_CheckExact(__pyx_t_7)) || PyTuple_CheckExact(__pyx_t_7)) {
          __pyx_t_1 = __pyx_t_7; __Pyx_INCREF(__pyx_t_1); __pyx_t_11 = 0;
          __pyx_t_14 = NULL;
        } else {
          __pyx_t_11 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 810, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_14 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 810, __pyx_L1_error)
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        for (;;) {
          if (likely(!__pyx_t_14)) {
            if (likely(PyList_CheckExact(__pyx_t_1))) {
              if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 810, __pyx_L1_error)
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 810, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            } else {
              if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              __pyx_t_7 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_11); __Pyx_INCREF(__pyx_t_7); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 810, __pyx_L1_error)
              #else
              __pyx_t_7 = PySequence_ITEM(__pyx_t_1, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 810, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            }
          } else {
            __pyx_t_7 = __pyx_t_14(__pyx_t_1);
            if (unlikely(!__pyx_t_7)) {
              PyObject* exc_type = PyErr_Occurred();
              if (exc_type) {
                if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                else __PYX_ERR(0, 810, __pyx_L1_error)
              }
              break;
            }
            __Pyx_GOTREF(__pyx_t_7);
          }
          __Pyx_XDECREF_SET(__pyx_v_url, __pyx_t_7);
          __pyx_t_7 = 0;
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_4);
          __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_4, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 810, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4);
          __pyx_t_4 = __pyx_t_7;
          __pyx_t_7 = 0;

          /* "alacorder/cal.pyx":811
 *             else:
 *                 for i, url in enumerate(tqdm.rich.tqdm(results)):
 *                     downloadPDF(driver, url)             # <<<<<<<<<<<<<<
 *             query[i,'CASES_FOUND'] = len(results)
 *             query[i,'RETRIEVED'] = time.time()
 */
          __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_downloadPDF); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 811, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_15 = NULL;
          __pyx_t_6 = 0;
          if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_15)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_15);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_6 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_driver, __pyx_v_url};
            __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 811, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_v_driver, __pyx_v_url};
            __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 811, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_GOTREF(__pyx_t_7);
          } else
          #endif
          {
            __pyx_t_17 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_17)) __PYX_ERR(0, 811, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_17);
            if (__pyx_t_15) {
              __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_15); __pyx_t_15 = NULL;
            }
            __Pyx_INCREF(__pyx_v_driver);
            __Pyx_GIVEREF(__pyx_v_driver);
            PyTuple_SET_ITEM(__pyx_t_17, 0+__pyx_t_6, __pyx_v_driver);
            __Pyx_INCREF(__pyx_v_url);
            __Pyx_GIVEREF(__pyx_v_url);
            PyTuple_SET_ITEM(__pyx_t_17, 1+__pyx_t_6, __pyx_v_url);
            __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_17, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 811, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "alacorder/cal.pyx":810
 *                     downloadPDF(driver, url)
 *             else:
 *                 for i, url in enumerate(tqdm.rich.tqdm(results)):             # <<<<<<<<<<<<<<
 *                     downloadPDF(driver, url)
 *             query[i,'CASES_FOUND'] = len(results)
 */
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L9:;

      /* "alacorder/cal.pyx":812
 *                 for i, url in enumerate(tqdm.rich.tqdm(results)):
 *                     downloadPDF(driver, url)
 *             query[i,'CASES_FOUND'] = len(results)             # <<<<<<<<<<<<<<
 *             query[i,'RETRIEVED'] = time.time()
 *             query[i,'QUERY_COMPLETE'] = "Y"
 */
      __pyx_t_11 = PyObject_Length(__pyx_v_results); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 812, __pyx_L1_error)
      __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 812, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 812, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_CASES_FOUND);
      __Pyx_GIVEREF(__pyx_n_u_CASES_FOUND);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_n_u_CASES_FOUND);
      if (unlikely(PyObject_SetItem(__pyx_v_query, __pyx_t_1, __pyx_t_4) < 0)) __PYX_ERR(0, 812, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":813
 *                     downloadPDF(driver, url)
 *             query[i,'CASES_FOUND'] = len(results)
 *             query[i,'RETRIEVED'] = time.time()             # <<<<<<<<<<<<<<
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             if not no_update:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_RETRIEVED);
      __Pyx_GIVEREF(__pyx_n_u_RETRIEVED);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_n_u_RETRIEVED);
      if (unlikely(PyObject_SetItem(__pyx_v_query, __pyx_t_7, __pyx_t_4) < 0)) __PYX_ERR(0, 813, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":814
 *             query[i,'CASES_FOUND'] = len(results)
 *             query[i,'RETRIEVED'] = time.time()
 *             query[i,'QUERY_COMPLETE'] = "Y"             # <<<<<<<<<<<<<<
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 */
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_QUERY_COMPLETE);
      __Pyx_GIVEREF(__pyx_n_u_QUERY_COMPLETE);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_n_u_QUERY_COMPLETE);
      if (unlikely(PyObject_SetItem(__pyx_v_query, __pyx_t_4, __pyx_n_u_Y) < 0)) __PYX_ERR(0, 814, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":815
 *             query[i,'RETRIEVED'] = time.time()
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             if not no_update:             # <<<<<<<<<<<<<<
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_no_update); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 815, __pyx_L1_error)
      __pyx_t_18 = ((!__pyx_t_2) != 0);
      if (__pyx_t_18) {

        /* "alacorder/cal.pyx":816
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")             # <<<<<<<<<<<<<<
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 *         else:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_drop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 816, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 816, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_qwrite, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "alacorder/cal.pyx":817
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)             # <<<<<<<<<<<<<<
 *         else:
 *             print(f"{query[i, 'TEMP_NAME']}: Found no results.")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_write); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_v_qwrite);
        __Pyx_GIVEREF(__pyx_v_qwrite);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_qwrite);
        __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_INPUTS); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_path, __pyx_t_10) < 0) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_overwrite, Py_True) < 0) __PYX_ERR(0, 817, __pyx_L1_error)
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 817, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "alacorder/cal.pyx":815
 *             query[i,'RETRIEVED'] = time.time()
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             if not no_update:             # <<<<<<<<<<<<<<
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 */
      }

      /* "alacorder/cal.pyx":801
 *         results = party_search(driver, name=r['TEMP_NAME'], party_type=r['TEMP_PARTY_TYPE'], ssn=r['TEMP_SSN'], dob=r['TEMP_DOB'], county=r['TEMP_COUNTY'], division=r['TEMP_DIVISION'], case_year=r['TEMP_CASE_YEAR'], filed_before=r['TEMP_FILED_BEFORE'], filed_after=r['TEMP_FILED_AFTER'], window=window)
 * 
 *         if len(results) > 0:             # <<<<<<<<<<<<<<
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")
 *             if window != None:
 */
      goto __pyx_L8;
    }

    /* "alacorder/cal.pyx":819
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 *         else:
 *             print(f"{query[i, 'TEMP_NAME']}: Found no results.")             # <<<<<<<<<<<<<<
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             query[i,'CASES_FOUND'] = 0
 */
    /*else*/ {
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_TEMP_NAME);
      __Pyx_GIVEREF(__pyx_n_u_TEMP_NAME);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_n_u_TEMP_NAME);
      __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_query, __pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyUnicode_Concat(__pyx_t_10, __pyx_kp_u_Found_no_results); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 819, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":820
 *         else:
 *             print(f"{query[i, 'TEMP_NAME']}: Found no results.")
 *             query[i,'QUERY_COMPLETE'] = "Y"             # <<<<<<<<<<<<<<
 *             query[i,'CASES_FOUND'] = 0
 *             query[i,'RETRIEVED'] = time.time()
 */
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 820, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_QUERY_COMPLETE);
      __Pyx_GIVEREF(__pyx_n_u_QUERY_COMPLETE);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_n_u_QUERY_COMPLETE);
      if (unlikely(PyObject_SetItem(__pyx_v_query, __pyx_t_10, __pyx_n_u_Y) < 0)) __PYX_ERR(0, 820, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":821
 *             print(f"{query[i, 'TEMP_NAME']}: Found no results.")
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             query[i,'CASES_FOUND'] = 0             # <<<<<<<<<<<<<<
 *             query[i,'RETRIEVED'] = time.time()
 *             if not no_update:
 */
      __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 821, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_CASES_FOUND);
      __Pyx_GIVEREF(__pyx_n_u_CASES_FOUND);
      PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_n_u_CASES_FOUND);
      if (unlikely(PyObject_SetItem(__pyx_v_query, __pyx_t_10, __pyx_int_0) < 0)) __PYX_ERR(0, 821, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":822
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             query[i,'CASES_FOUND'] = 0
 *             query[i,'RETRIEVED'] = time.time()             # <<<<<<<<<<<<<<
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_10 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_v_i);
      __Pyx_GIVEREF(__pyx_v_i);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_i);
      __Pyx_INCREF(__pyx_n_u_RETRIEVED);
      __Pyx_GIVEREF(__pyx_n_u_RETRIEVED);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_n_u_RETRIEVED);
      if (unlikely(PyObject_SetItem(__pyx_v_query, __pyx_t_4, __pyx_t_10) < 0)) __PYX_ERR(0, 822, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "alacorder/cal.pyx":823
 *             query[i,'CASES_FOUND'] = 0
 *             query[i,'RETRIEVED'] = time.time()
 *             if not no_update:             # <<<<<<<<<<<<<<
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 */
      __pyx_t_18 = __Pyx_PyObject_IsTrue(__pyx_v_no_update); if (unlikely(__pyx_t_18 < 0)) __PYX_ERR(0, 823, __pyx_L1_error)
      __pyx_t_2 = ((!__pyx_t_18) != 0);
      if (__pyx_t_2) {

        /* "alacorder/cal.pyx":824
 *             query[i,'RETRIEVED'] = time.time()
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")             # <<<<<<<<<<<<<<
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 * 
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_query, __pyx_n_s_drop); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_tuple__100, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 824, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_qwrite, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "alacorder/cal.pyx":825
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)             # <<<<<<<<<<<<<<
 * 
 *      if window != None:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_write); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_v_qwrite);
        __Pyx_GIVEREF(__pyx_v_qwrite);
        PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_v_qwrite);
        __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_7 = __Pyx_PyObject_Dict_GetItem(__pyx_v_cf, __pyx_n_u_INPUTS); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_path, __pyx_t_7) < 0) __PYX_ERR(0, 825, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_overwrite, Py_True) < 0) __PYX_ERR(0, 825, __pyx_L1_error)
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 825, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "alacorder/cal.pyx":823
 *             query[i,'CASES_FOUND'] = 0
 *             query[i,'RETRIEVED'] = time.time()
 *             if not no_update:             # <<<<<<<<<<<<<<
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 */
      }
    }
    __pyx_L8:;

    /* "alacorder/cal.pyx":793
 *      login(driver, cID=cID, uID=uID, pwd=pwd, window=window)
 * 
 *      for i, r in enumerate(query.rows(named=True)):             # <<<<<<<<<<<<<<
 *         if query[i,'QUERY_COMPLETE'] == "Y":
 *             continue
 */
    __pyx_L4_continue:;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":827
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 * 
 *      if window != None:             # <<<<<<<<<<<<<<
 *         window.write_event_value('COMPLETE-SQ',time.time())
 *      print("Completed query template.")
 */
  __pyx_t_3 = PyObject_RichCompare(__pyx_v_window, Py_None, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 827, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 827, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":828
 * 
 *      if window != None:
 *         window.write_event_value('COMPLETE-SQ',time.time())             # <<<<<<<<<<<<<<
 *      print("Completed query template.")
 *      return query
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_window, __pyx_n_s_write_event_value); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_time); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_7 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 828, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_COMPLETE_SQ, __pyx_t_7};
      __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_COMPLETE_SQ, __pyx_t_7};
      __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    } else
    #endif
    {
      __pyx_t_1 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (__pyx_t_10) {
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_10); __pyx_t_10 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_u_COMPLETE_SQ);
      __Pyx_GIVEREF(__pyx_kp_u_COMPLETE_SQ);
      PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_6, __pyx_kp_u_COMPLETE_SQ);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_6, __pyx_t_7);
      __pyx_t_7 = 0;
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 828, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "alacorder/cal.pyx":827
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 * 
 *      if window != None:             # <<<<<<<<<<<<<<
 *         window.write_event_value('COMPLETE-SQ',time.time())
 *      print("Completed query template.")
 */
  }

  /* "alacorder/cal.pyx":829
 *      if window != None:
 *         window.write_event_value('COMPLETE-SQ',time.time())
 *      print("Completed query template.")             # <<<<<<<<<<<<<<
 *      return query
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__101, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":830
 *         window.write_event_value('COMPLETE-SQ',time.time())
 *      print("Completed query template.")
 *      return query             # <<<<<<<<<<<<<<
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_query);
  __pyx_r = __pyx_v_query;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":746
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")
 *         return None
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Fetch cases from Alacourt.com with input query spreadsheet headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("alacorder.cal.fetch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_query);
  __Pyx_XDECREF(__pyx_v_opt);
  __Pyx_XDECREF(__pyx_v_driver);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_r);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XDECREF(__pyx_v_url);
  __Pyx_XDECREF(__pyx_v_qwrite);
  __Pyx_XDECREF(__pyx_v_querypath);
  __Pyx_XDECREF(__pyx_v_dirpath);
  __Pyx_XDECREF(__pyx_v_cID);
  __Pyx_XDECREF(__pyx_v_uID);
  __Pyx_XDECREF(__pyx_v_pwd);
  __Pyx_XDECREF(__pyx_v_qmax);
  __Pyx_XDECREF(__pyx_v_qskip);
  __Pyx_XDECREF(__pyx_v_cf);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":831
 *      print("Completed query template.")
 *      return query
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Collect PDFs via SJIS Party Search Form from Alacourt.com
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_35party_search(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_34party_search[] = "\n     Collect PDFs via SJIS Party Search Form from Alacourt.com\n     Returns list of URLs for downloadPDF() to download\n     \n     Args:\n         driver (WebDriver): selenium/chrome web driver object \n         name (str, optional): Name (LAST FIRST)\n         party_type (str, optional): \"Defendants\" | \"Plaintiffs\" | \"ALL\"\n         ssn (str, optional): Social Security Number\n         dob (str, optional): Date of Birth\n         county (str, optional): County\n         division (str, optional): \"All Divisions\"\n              \"Criminal Only\"\n              \"Civil Only\"\n              \"CS - CHILD SUPPORT\"\n              \"CV - CIRCUIT - CIVIL\"\n              \"CC - CIRCUIT - CRIMINAL\"\n              \"DV - DISTRICT - CIVIL\"\n              \"DC - DISTRICT - CRIMINAL\"\n              \"DR - DOMESTIC RELATIONS\"\n              \"EQ - EQUITY-CASES\"\n              \"MC - MUNICIPAL-CRIMINAL\"\n              \"TP - MUNICIPAL-PARKING\"\n              \"SM - SMALL CLAIMS\"\n              \"TR - TRAFFIC\"\n         case_year (str, optional): YYYY\n         filed_before (str, optional): M/DD/YYYY\n         filed_after (str, optional): M/DD/YYYY\n         debug (bool, optional): Print detailed logs.\n         cID (str, optional): Customer ID on Alacourt.com\n         uID (str, optional): User ID on Alacourt.com\n         pwd (str, optional): Password on Alacourt.com\n     \n     Returns:\n         List[str] of URLs to PDF\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_35party_search = {"party_search", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_35party_search, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_34party_search};
static PyObject *__pyx_pw_9alacorder_3cal_35party_search(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_driver = 0;
  PyObject *__pyx_v_name = 0;
  PyObject *__pyx_v_party_type = 0;
  PyObject *__pyx_v_ssn = 0;
  PyObject *__pyx_v_dob = 0;
  PyObject *__pyx_v_county = 0;
  PyObject *__pyx_v_division = 0;
  PyObject *__pyx_v_case_year = 0;
  PyObject *__pyx_v_filed_before = 0;
  PyObject *__pyx_v_filed_after = 0;
  PyObject *__pyx_v_debug = 0;
  PyObject *__pyx_v_cID = 0;
  PyObject *__pyx_v_uID = 0;
  PyObject *__pyx_v_pwd = 0;
  PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("party_search (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_driver,&__pyx_n_s_name,&__pyx_n_s_party_type,&__pyx_n_s_ssn,&__pyx_n_s_dob,&__pyx_n_s_county,&__pyx_n_s_division,&__pyx_n_s_case_year,&__pyx_n_s_filed_before,&__pyx_n_s_filed_after,&__pyx_n_s_debug,&__pyx_n_s_cID,&__pyx_n_s_uID,&__pyx_n_s_pwd,&__pyx_n_s_window,0};
    PyObject* values[15] = {0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
    values[1] = ((PyObject *)__pyx_kp_u__8);
    values[2] = ((PyObject *)__pyx_kp_u__8);
    values[3] = ((PyObject *)__pyx_kp_u__8);
    values[4] = ((PyObject *)__pyx_kp_u__8);
    values[5] = ((PyObject *)__pyx_kp_u__8);
    values[6] = ((PyObject *)__pyx_kp_u__8);
    values[7] = ((PyObject *)__pyx_kp_u__8);
    values[8] = ((PyObject *)__pyx_kp_u__8);
    values[9] = ((PyObject *)__pyx_kp_u__8);
    values[10] = ((PyObject *)Py_False);
    values[11] = ((PyObject *)__pyx_kp_u__8);
    values[12] = ((PyObject *)__pyx_kp_u__8);
    values[13] = ((PyObject *)__pyx_kp_u__8);
    values[14] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_driver)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_name);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_party_type);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_ssn);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_dob);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_county);
          if (value) { values[5] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_division);
          if (value) { values[6] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_case_year);
          if (value) { values[7] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_filed_before);
          if (value) { values[8] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  9:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_filed_after);
          if (value) { values[9] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 10:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[10] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 11:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cID);
          if (value) { values[11] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 12:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_uID);
          if (value) { values[12] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 13:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pwd);
          if (value) { values[13] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case 14:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[14] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "party_search") < 0)) __PYX_ERR(0, 831, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case 15: values[14] = PyTuple_GET_ITEM(__pyx_args, 14);
        CYTHON_FALLTHROUGH;
        case 14: values[13] = PyTuple_GET_ITEM(__pyx_args, 13);
        CYTHON_FALLTHROUGH;
        case 13: values[12] = PyTuple_GET_ITEM(__pyx_args, 12);
        CYTHON_FALLTHROUGH;
        case 12: values[11] = PyTuple_GET_ITEM(__pyx_args, 11);
        CYTHON_FALLTHROUGH;
        case 11: values[10] = PyTuple_GET_ITEM(__pyx_args, 10);
        CYTHON_FALLTHROUGH;
        case 10: values[9] = PyTuple_GET_ITEM(__pyx_args, 9);
        CYTHON_FALLTHROUGH;
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_driver = values[0];
    __pyx_v_name = values[1];
    __pyx_v_party_type = values[2];
    __pyx_v_ssn = values[3];
    __pyx_v_dob = values[4];
    __pyx_v_county = values[5];
    __pyx_v_division = values[6];
    __pyx_v_case_year = values[7];
    __pyx_v_filed_before = values[8];
    __pyx_v_filed_after = values[9];
    __pyx_v_debug = values[10];
    __pyx_v_cID = values[11];
    __pyx_v_uID = values[12];
    __pyx_v_pwd = values[13];
    __pyx_v_window = values[14];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("party_search", 0, 1, 15, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 831, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_34party_search(__pyx_self, __pyx_v_driver, __pyx_v_name, __pyx_v_party_type, __pyx_v_ssn, __pyx_v_dob, __pyx_v_county, __pyx_v_division, __pyx_v_case_year, __pyx_v_filed_before, __pyx_v_filed_after, __pyx_v_debug, __pyx_v_cID, __pyx_v_uID, __pyx_v_pwd, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_34party_search(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_driver, PyObject *__pyx_v_name, PyObject *__pyx_v_party_type, PyObject *__pyx_v_ssn, PyObject *__pyx_v_dob, PyObject *__pyx_v_county, PyObject *__pyx_v_division, PyObject *__pyx_v_case_year, PyObject *__pyx_v_filed_before, PyObject *__pyx_v_filed_after, PyObject *__pyx_v_debug, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_window) {
  CYTHON_UNUSED int __pyx_v_has_window;
  PyObject *__pyx_v_party_name_box = NULL;
  PyObject *__pyx_v_ssn_box = NULL;
  PyObject *__pyx_v_date_of_birth_box = NULL;
  PyObject *__pyx_v_party_type_select = NULL;
  PyObject *__pyx_v_pts = NULL;
  PyObject *__pyx_v_county_select = NULL;
  PyObject *__pyx_v_scounty = NULL;
  PyObject *__pyx_v_division_select = NULL;
  PyObject *__pyx_v_sdivision = NULL;
  PyObject *__pyx_v_case_year_select = NULL;
  PyObject *__pyx_v_scase_year = NULL;
  PyObject *__pyx_v_no_records_select = NULL;
  PyObject *__pyx_v_sno_records = NULL;
  PyObject *__pyx_v_filed_before_box = NULL;
  PyObject *__pyx_v_filed_after_box = NULL;
  PyObject *__pyx_v_search_button = NULL;
  PyObject *__pyx_v_page_counter = NULL;
  PyObject *__pyx_v_pages = NULL;
  PyObject *__pyx_v_results_indicator = NULL;
  PyObject *__pyx_v_results_count = NULL;
  PyObject *__pyx_v_pdflinks = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_hovers = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_a = NULL;
  PyObject *__pyx_v_pager_select = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_next_pg = NULL;
  PyObject *__pyx_v_next_button = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  Py_UCS4 __pyx_t_15;
  PyObject *(*__pyx_t_16)(PyObject *);
  Py_ssize_t __pyx_t_17;
  PyObject *(*__pyx_t_18)(PyObject *);
  int __pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("party_search", 0);

  /* "alacorder/cal.pyx":869
 *      """
 * 
 *      if "frmIndexSearchForm" not in driver.current_url:             # <<<<<<<<<<<<<<
 *           driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_current_url); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_frmIndexSearchForm, __pyx_t_1, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 869, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":870
 * 
 *      if "frmIndexSearchForm" not in driver.current_url:
 *           driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(5)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_kp_u_https_v2_alacourt_com_frmIndexSe) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_u_https_v2_alacourt_com_frmIndexSe);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":869
 *      """
 * 
 *      if "frmIndexSearchForm" not in driver.current_url:             # <<<<<<<<<<<<<<
 *           driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
 * 
 */
  }

  /* "alacorder/cal.pyx":872
 *           driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
 * 
 *      driver.implicitly_wait(5)             # <<<<<<<<<<<<<<
 * 
 *      has_window = False if window == "None" else True
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_int_5) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_int_5);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":874
 *      driver.implicitly_wait(5)
 * 
 *      has_window = False if window == "None" else True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (__Pyx_PyUnicode_Equals(__pyx_v_window, __pyx_n_u_None, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 874, __pyx_L1_error)
  if (__pyx_t_2) {
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = 1;
  }
  __pyx_v_has_window = __pyx_t_3;

  /* "alacorder/cal.pyx":878
 * 
 *      # connection error
 *      try:             # <<<<<<<<<<<<<<
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
 *      except selenium.common.exceptions.NoSuchElementException:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "alacorder/cal.pyx":879
 *      # connection error
 *      try:
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")             # <<<<<<<<<<<<<<
 *      except selenium.common.exceptions.NoSuchElementException:
 *           if debug:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 879, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 879, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_By); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 879, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_NAME); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 879, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_9) < 0) __PYX_ERR(0, 879, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_txtNam) < 0) __PYX_ERR(0, 879, __pyx_L4_error)
      __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 879, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_party_name_box = __pyx_t_9;
      __pyx_t_9 = 0;

      /* "alacorder/cal.pyx":878
 * 
 *      # connection error
 *      try:             # <<<<<<<<<<<<<<
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
 *      except selenium.common.exceptions.NoSuchElementException:
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":880
 *      try:
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
 *      except selenium.common.exceptions.NoSuchElementException:             # <<<<<<<<<<<<<<
 *           if debug:
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
 */
    __Pyx_ErrFetch(&__pyx_t_9, &__pyx_t_4, &__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_selenium); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 880, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_common); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 880, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_exceptions); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 880, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_NoSuchElementException); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 880, __pyx_L6_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_11 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_9, __pyx_t_10);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_ErrRestore(__pyx_t_9, __pyx_t_4, __pyx_t_1);
    __pyx_t_9 = 0; __pyx_t_4 = 0; __pyx_t_1 = 0;
    if (__pyx_t_11) {
      __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_9) < 0) __PYX_ERR(0, 880, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);

      /* "alacorder/cal.pyx":881
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
 *      except selenium.common.exceptions.NoSuchElementException:
 *           if debug:             # <<<<<<<<<<<<<<
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 */
      __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_debug); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 881, __pyx_L6_except_error)
      if (__pyx_t_3) {

        /* "alacorder/cal.pyx":882
 *      except selenium.common.exceptions.NoSuchElementException:
 *           if debug:
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")             # <<<<<<<<<<<<<<
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *                time.sleep(10)
 */
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__102, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 882, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "alacorder/cal.pyx":881
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
 *      except selenium.common.exceptions.NoSuchElementException:
 *           if debug:             # <<<<<<<<<<<<<<
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 */
      }

      /* "alacorder/cal.pyx":883
 *           if debug:
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":             # <<<<<<<<<<<<<<
 *                time.sleep(10)
 *                login(driver,cID=cID,uID=uID,pwd=pwd)
 */
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_current_url); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 883, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_10, __pyx_kp_u_https_v2_alacourt_com_frmlogin_a, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 883, __pyx_L6_except_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__pyx_t_3) {

        /* "alacorder/cal.pyx":884
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *                time.sleep(10)             # <<<<<<<<<<<<<<
 *                login(driver,cID=cID,uID=uID,pwd=pwd)
 *                driver.implicitly_wait(1)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 884, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sleep); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 884, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_12);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_12, function);
          }
        }
        __pyx_t_10 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_5, __pyx_int_10) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_int_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 884, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "alacorder/cal.pyx":885
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *                time.sleep(10)
 *                login(driver,cID=cID,uID=uID,pwd=pwd)             # <<<<<<<<<<<<<<
 *                driver.implicitly_wait(1)
 *           driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")
 */
        __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_login); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 885, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_12 = PyTuple_New(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 885, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_INCREF(__pyx_v_driver);
        __Pyx_GIVEREF(__pyx_v_driver);
        PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_v_driver);
        __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 885, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cID, __pyx_v_cID) < 0) __PYX_ERR(0, 885, __pyx_L6_except_error)
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uID, __pyx_v_uID) < 0) __PYX_ERR(0, 885, __pyx_L6_except_error)
        if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pwd, __pyx_v_pwd) < 0) __PYX_ERR(0, 885, __pyx_L6_except_error)
        __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_12, __pyx_t_5); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 885, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "alacorder/cal.pyx":886
 *                time.sleep(10)
 *                login(driver,cID=cID,uID=uID,pwd=pwd)
 *                driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 *           driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")
 *           print("Successfully connected and logged into Alacourt!")
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 886, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
          }
        }
        __pyx_t_13 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_int_1);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 886, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "alacorder/cal.pyx":883
 *           if debug:
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":             # <<<<<<<<<<<<<<
 *                time.sleep(10)
 *                login(driver,cID=cID,uID=uID,pwd=pwd)
 */
      }

      /* "alacorder/cal.pyx":887
 *                login(driver,cID=cID,uID=uID,pwd=pwd)
 *                driver.implicitly_wait(1)
 *           driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")             # <<<<<<<<<<<<<<
 *           print("Successfully connected and logged into Alacourt!")
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 887, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_13 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_kp_u_https_v2_alacourt_com_frmIndexSe_2) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_kp_u_https_v2_alacourt_com_frmIndexSe_2);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 887, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "alacorder/cal.pyx":888
 *                driver.implicitly_wait(1)
 *           driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")
 *           print("Successfully connected and logged into Alacourt!")             # <<<<<<<<<<<<<<
 * 
 *      # field search
 */
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 888, __pyx_L6_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L5_exception_handled;
    }
    goto __pyx_L6_except_error;
    __pyx_L6_except_error:;

    /* "alacorder/cal.pyx":878
 * 
 *      # connection error
 *      try:             # <<<<<<<<<<<<<<
 *           party_name_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtName")
 *      except selenium.common.exceptions.NoSuchElementException:
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L9_try_end:;
  }

  /* "alacorder/cal.pyx":891
 * 
 *      # field search
 *      if name != "":             # <<<<<<<<<<<<<<
 *           party_name_box.send_keys(name)
 *      if ssn != "":
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_name, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 891, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":892
 *      # field search
 *      if name != "":
 *           party_name_box.send_keys(name)             # <<<<<<<<<<<<<<
 *      if ssn != "":
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")
 */
    if (unlikely(!__pyx_v_party_name_box)) { __Pyx_RaiseUnboundLocalError("party_name_box"); __PYX_ERR(0, 892, __pyx_L1_error) }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_party_name_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_name) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_name);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 892, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":891
 * 
 *      # field search
 *      if name != "":             # <<<<<<<<<<<<<<
 *           party_name_box.send_keys(name)
 *      if ssn != "":
 */
  }

  /* "alacorder/cal.pyx":893
 *      if name != "":
 *           party_name_box.send_keys(name)
 *      if ssn != "":             # <<<<<<<<<<<<<<
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")
 *           ssn_box.send_keys(ssn)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_ssn, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 893, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":894
 *           party_name_box.send_keys(name)
 *      if ssn != "":
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")             # <<<<<<<<<<<<<<
 *           ssn_box.send_keys(ssn)
 *      if dob != "":
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_By); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NAME); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_13) < 0) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_txtSSN) < 0) __PYX_ERR(0, 894, __pyx_L1_error)
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_ssn_box = __pyx_t_13;
    __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":895
 *      if ssn != "":
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")
 *           ssn_box.send_keys(ssn)             # <<<<<<<<<<<<<<
 *      if dob != "":
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_ssn_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_v_ssn) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_ssn);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 895, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":893
 *      if name != "":
 *           party_name_box.send_keys(name)
 *      if ssn != "":             # <<<<<<<<<<<<<<
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")
 *           ssn_box.send_keys(ssn)
 */
  }

  /* "alacorder/cal.pyx":896
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")
 *           ssn_box.send_keys(ssn)
 *      if dob != "":             # <<<<<<<<<<<<<<
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 *           date_of_birth_box.send_keys(dob)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_dob, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 896, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":897
 *           ssn_box.send_keys(ssn)
 *      if dob != "":
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")             # <<<<<<<<<<<<<<
 *           date_of_birth_box.send_keys(dob)
 *      if party_type != "":
 */
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_By); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_1) < 0) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_txtDOB) < 0) __PYX_ERR(0, 897, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 897, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_date_of_birth_box = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":898
 *      if dob != "":
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 *           date_of_birth_box.send_keys(dob)             # <<<<<<<<<<<<<<
 *      if party_type != "":
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_date_of_birth_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_v_dob) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_dob);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 898, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":896
 *           ssn_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtSSN")
 *           ssn_box.send_keys(ssn)
 *      if dob != "":             # <<<<<<<<<<<<<<
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 *           date_of_birth_box.send_keys(dob)
 */
  }

  /* "alacorder/cal.pyx":899
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 *           date_of_birth_box.send_keys(dob)
 *      if party_type != "":             # <<<<<<<<<<<<<<
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
 *           pts = Select(party_type_select)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_party_type, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 899, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":900
 *           date_of_birth_box.send_keys(dob)
 *      if party_type != "":
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")             # <<<<<<<<<<<<<<
 *           pts = Select(party_type_select)
 *           if party_type == "plaintiffs":
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_By); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_NAME); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_9) < 0) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_rdlPar) < 0) __PYX_ERR(0, 900, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_party_type_select = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":901
 *      if party_type != "":
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
 *           pts = Select(party_type_select)             # <<<<<<<<<<<<<<
 *           if party_type == "plaintiffs":
 *                pts.select_by_visible_text("Plaintiffs")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_party_type_select) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_party_type_select);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 901, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_pts = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":902
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
 *           pts = Select(party_type_select)
 *           if party_type == "plaintiffs":             # <<<<<<<<<<<<<<
 *                pts.select_by_visible_text("Plaintiffs")
 *           if party_type == "defendants":
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_party_type, __pyx_n_u_plaintiffs, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 902, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "alacorder/cal.pyx":903
 *           pts = Select(party_type_select)
 *           if party_type == "plaintiffs":
 *                pts.select_by_visible_text("Plaintiffs")             # <<<<<<<<<<<<<<
 *           if party_type == "defendants":
 *                pts.select_by_visible_text("Defendants")
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_pts, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_n_u_Plaintiffs) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_Plaintiffs);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "alacorder/cal.pyx":902
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
 *           pts = Select(party_type_select)
 *           if party_type == "plaintiffs":             # <<<<<<<<<<<<<<
 *                pts.select_by_visible_text("Plaintiffs")
 *           if party_type == "defendants":
 */
    }

    /* "alacorder/cal.pyx":904
 *           if party_type == "plaintiffs":
 *                pts.select_by_visible_text("Plaintiffs")
 *           if party_type == "defendants":             # <<<<<<<<<<<<<<
 *                pts.select_by_visible_text("Defendants")
 *           if party_type == "all":
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_party_type, __pyx_n_u_defendants, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 904, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "alacorder/cal.pyx":905
 *                pts.select_by_visible_text("Plaintiffs")
 *           if party_type == "defendants":
 *                pts.select_by_visible_text("Defendants")             # <<<<<<<<<<<<<<
 *           if party_type == "all":
 *                pts.select_by_visible_text("ALL")
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_pts, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_n_u_Defendants) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_Defendants);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 905, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "alacorder/cal.pyx":904
 *           if party_type == "plaintiffs":
 *                pts.select_by_visible_text("Plaintiffs")
 *           if party_type == "defendants":             # <<<<<<<<<<<<<<
 *                pts.select_by_visible_text("Defendants")
 *           if party_type == "all":
 */
    }

    /* "alacorder/cal.pyx":906
 *           if party_type == "defendants":
 *                pts.select_by_visible_text("Defendants")
 *           if party_type == "all":             # <<<<<<<<<<<<<<
 *                pts.select_by_visible_text("ALL")
 * 
 */
    __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_party_type, __pyx_n_u_all, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 906, __pyx_L1_error)
    if (__pyx_t_3) {

      /* "alacorder/cal.pyx":907
 *                pts.select_by_visible_text("Defendants")
 *           if party_type == "all":
 *                pts.select_by_visible_text("ALL")             # <<<<<<<<<<<<<<
 * 
 *      if county != "":
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_pts, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_n_u_ALL) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_n_u_ALL);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 907, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "alacorder/cal.pyx":906
 *           if party_type == "defendants":
 *                pts.select_by_visible_text("Defendants")
 *           if party_type == "all":             # <<<<<<<<<<<<<<
 *                pts.select_by_visible_text("ALL")
 * 
 */
    }

    /* "alacorder/cal.pyx":899
 *           date_of_birth_box = driver.find_element(by=By.NAME,value="ctl00$ContentPlaceHolder1$txtDOB")
 *           date_of_birth_box.send_keys(dob)
 *      if party_type != "":             # <<<<<<<<<<<<<<
 *           party_type_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$rdlPartyType")
 *           pts = Select(party_type_select)
 */
  }

  /* "alacorder/cal.pyx":909
 *                pts.select_by_visible_text("ALL")
 * 
 *      if county != "":             # <<<<<<<<<<<<<<
 *           county_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCounties")
 *           scounty = Select(county_select)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_county, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 909, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":910
 * 
 *      if county != "":
 *           county_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCounties")             # <<<<<<<<<<<<<<
 *           scounty = Select(county_select)
 *           scounty.select_by_visible_text(county)
 */
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_By); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NAME); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_13) < 0) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_ddlCou) < 0) __PYX_ERR(0, 910, __pyx_L1_error)
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_county_select = __pyx_t_13;
    __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":911
 *      if county != "":
 *           county_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCounties")
 *           scounty = Select(county_select)             # <<<<<<<<<<<<<<
 *           scounty.select_by_visible_text(county)
 *      if division != "":
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_v_county_select) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_county_select);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_scounty = __pyx_t_13;
    __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":912
 *           county_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCounties")
 *           scounty = Select(county_select)
 *           scounty.select_by_visible_text(county)             # <<<<<<<<<<<<<<
 *      if division != "":
 *           division_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision")
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_scounty, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_9 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_9)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_v_county) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_county);
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":909
 *                pts.select_by_visible_text("ALL")
 * 
 *      if county != "":             # <<<<<<<<<<<<<<
 *           county_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCounties")
 *           scounty = Select(county_select)
 */
  }

  /* "alacorder/cal.pyx":913
 *           scounty = Select(county_select)
 *           scounty.select_by_visible_text(county)
 *      if division != "":             # <<<<<<<<<<<<<<
 *           division_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision")
 *           sdivision = Select(division_select)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_division, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 913, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":914
 *           scounty.select_by_visible_text(county)
 *      if division != "":
 *           division_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision")             # <<<<<<<<<<<<<<
 *           sdivision = Select(division_select)
 *           sdivision.select_by_visible_text(division)
 */
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_By); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_1) < 0) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_UcddlD) < 0) __PYX_ERR(0, 914, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 914, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_division_select = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":915
 *      if division != "":
 *           division_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision")
 *           sdivision = Select(division_select)             # <<<<<<<<<<<<<<
 *           sdivision.select_by_visible_text(division)
 *      if case_year != "":
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_v_division_select) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_division_select);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 915, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_sdivision = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":916
 *           division_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision")
 *           sdivision = Select(division_select)
 *           sdivision.select_by_visible_text(division)             # <<<<<<<<<<<<<<
 *      if case_year != "":
 *           case_year_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCaseYear")
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sdivision, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_v_division) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_division);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 916, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":913
 *           scounty = Select(county_select)
 *           scounty.select_by_visible_text(county)
 *      if division != "":             # <<<<<<<<<<<<<<
 *           division_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$UcddlDivisions1$ddlDivision")
 *           sdivision = Select(division_select)
 */
  }

  /* "alacorder/cal.pyx":917
 *           sdivision = Select(division_select)
 *           sdivision.select_by_visible_text(division)
 *      if case_year != "":             # <<<<<<<<<<<<<<
 *           case_year_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCaseYear")
 *           scase_year = Select(case_year_select)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_case_year, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 917, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":918
 *           sdivision.select_by_visible_text(division)
 *      if case_year != "":
 *           case_year_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCaseYear")             # <<<<<<<<<<<<<<
 *           scase_year = Select(case_year_select)
 *           scase_year.select_by_visible_text(case_year)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_By); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_NAME); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_9) < 0) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_ddlCas) < 0) __PYX_ERR(0, 918, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 918, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_case_year_select = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":919
 *      if case_year != "":
 *           case_year_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCaseYear")
 *           scase_year = Select(case_year_select)             # <<<<<<<<<<<<<<
 *           scase_year.select_by_visible_text(case_year)
 *      no_records_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlNumberOfRecords")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_case_year_select) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_case_year_select);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 919, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_scase_year = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":920
 *           case_year_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCaseYear")
 *           scase_year = Select(case_year_select)
 *           scase_year.select_by_visible_text(case_year)             # <<<<<<<<<<<<<<
 *      no_records_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlNumberOfRecords")
 *      sno_records = Select(no_records_select)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_scase_year, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 920, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_case_year) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_case_year);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 920, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":917
 *           sdivision = Select(division_select)
 *           sdivision.select_by_visible_text(division)
 *      if case_year != "":             # <<<<<<<<<<<<<<
 *           case_year_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlCaseYear")
 *           scase_year = Select(case_year_select)
 */
  }

  /* "alacorder/cal.pyx":921
 *           scase_year = Select(case_year_select)
 *           scase_year.select_by_visible_text(case_year)
 *      no_records_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlNumberOfRecords")             # <<<<<<<<<<<<<<
 *      sno_records = Select(no_records_select)
 *      sno_records.select_by_visible_text("1000")
 */
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_By); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_NAME); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_13) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_ddlNum) < 0) __PYX_ERR(0, 921, __pyx_L1_error)
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_no_records_select = __pyx_t_13;
  __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":922
 *           scase_year.select_by_visible_text(case_year)
 *      no_records_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlNumberOfRecords")
 *      sno_records = Select(no_records_select)             # <<<<<<<<<<<<<<
 *      sno_records.select_by_visible_text("1000")
 *      if filed_before != "":
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_Select); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_v_no_records_select) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_no_records_select);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 922, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_sno_records = __pyx_t_13;
  __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":923
 *      no_records_select = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$ddlNumberOfRecords")
 *      sno_records = Select(no_records_select)
 *      sno_records.select_by_visible_text("1000")             # <<<<<<<<<<<<<<
 *      if filed_before != "":
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_sno_records, __pyx_n_s_select_by_visible_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_kp_u_1000) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_u_1000);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":924
 *      sno_records = Select(no_records_select)
 *      sno_records.select_by_visible_text("1000")
 *      if filed_before != "":             # <<<<<<<<<<<<<<
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")
 *           filed_before_box.send_keys(filed_before)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_filed_before, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 924, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":925
 *      sno_records.select_by_visible_text("1000")
 *      if filed_before != "":
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")             # <<<<<<<<<<<<<<
 *           filed_before_box.send_keys(filed_before)
 *      if filed_after != "":
 */
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_By); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_1) < 0) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_txtFro) < 0) __PYX_ERR(0, 925, __pyx_L1_error)
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 925, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_filed_before_box = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":926
 *      if filed_before != "":
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")
 *           filed_before_box.send_keys(filed_before)             # <<<<<<<<<<<<<<
 *      if filed_after != "":
 *           filed_after_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtTo")
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_filed_before_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_13)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_v_filed_before) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_filed_before);
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 926, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":924
 *      sno_records = Select(no_records_select)
 *      sno_records.select_by_visible_text("1000")
 *      if filed_before != "":             # <<<<<<<<<<<<<<
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")
 *           filed_before_box.send_keys(filed_before)
 */
  }

  /* "alacorder/cal.pyx":927
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")
 *           filed_before_box.send_keys(filed_before)
 *      if filed_after != "":             # <<<<<<<<<<<<<<
 *           filed_after_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtTo")
 *           filed_after_box.send_keys(filed_after)
 */
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_filed_after, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 927, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":928
 *           filed_before_box.send_keys(filed_before)
 *      if filed_after != "":
 *           filed_after_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtTo")             # <<<<<<<<<<<<<<
 *           filed_after_box.send_keys(filed_after)
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_By); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_NAME); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_9) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_txtTo) < 0) __PYX_ERR(0, 928, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 928, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_filed_after_box = __pyx_t_9;
    __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":929
 *      if filed_after != "":
 *           filed_after_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtTo")
 *           filed_after_box.send_keys(filed_after)             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_filed_after_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 929, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_v_filed_after) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_filed_after);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 929, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":927
 *           filed_before_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtFrom")
 *           filed_before_box.send_keys(filed_before)
 *      if filed_after != "":             # <<<<<<<<<<<<<<
 *           filed_after_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtTo")
 *           filed_after_box.send_keys(filed_after)
 */
  }

  /* "alacorder/cal.pyx":931
 *           filed_after_box.send_keys(filed_after)
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 * 
 *      # submit search
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_9 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_1, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 931, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":934
 * 
 *      # submit search
 *      search_button = driver.find_element(by=By.ID,value="searchButton")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_By); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_ID); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_13) < 0) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_n_u_searchButton) < 0) __PYX_ERR(0, 934, __pyx_L1_error)
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_search_button = __pyx_t_13;
  __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":936
 *      search_button = driver.find_element(by=By.ID,value="searchButton")
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 *      try:
 *           search_button.click()
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_9)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_9, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 936, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "alacorder/cal.pyx":937
 * 
 *      driver.implicitly_wait(1)
 *      try:             # <<<<<<<<<<<<<<
 *           search_button.click()
 *      except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "alacorder/cal.pyx":938
 *      driver.implicitly_wait(1)
 *      try:
 *           search_button.click()             # <<<<<<<<<<<<<<
 *      except:
 *           driver.implicitly_wait(5)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_search_button, __pyx_n_s_click); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 938, __pyx_L26_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_13 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 938, __pyx_L26_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "alacorder/cal.pyx":937
 * 
 *      driver.implicitly_wait(1)
 *      try:             # <<<<<<<<<<<<<<
 *           search_button.click()
 *      except:
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L31_try_end;
    __pyx_L26_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":939
 *      try:
 *           search_button.click()
 *      except:             # <<<<<<<<<<<<<<
 *           driver.implicitly_wait(5)
 *           time.sleep(5)
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_4, &__pyx_t_9) < 0) __PYX_ERR(0, 939, __pyx_L28_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);

      /* "alacorder/cal.pyx":940
 *           search_button.click()
 *      except:
 *           driver.implicitly_wait(5)             # <<<<<<<<<<<<<<
 *           time.sleep(5)
 * 
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 940, __pyx_L28_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_1 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_int_5) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_int_5);
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 940, __pyx_L28_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "alacorder/cal.pyx":941
 *      except:
 *           driver.implicitly_wait(5)
 *           time.sleep(5)             # <<<<<<<<<<<<<<
 * 
 *      if debug:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 941, __pyx_L28_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sleep); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 941, __pyx_L28_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_1 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_12, __pyx_t_5, __pyx_int_5) : __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_int_5);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 941, __pyx_L28_except_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L27_exception_handled;
    }
    __pyx_L28_except_error:;

    /* "alacorder/cal.pyx":937
 * 
 *      driver.implicitly_wait(1)
 *      try:             # <<<<<<<<<<<<<<
 *           search_button.click()
 *      except:
 */
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
    goto __pyx_L1_error;
    __pyx_L27_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
    __pyx_L31_try_end:;
  }

  /* "alacorder/cal.pyx":943
 *           time.sleep(5)
 * 
 *      if debug:             # <<<<<<<<<<<<<<
 *           print("Submitted party search form...")
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_debug); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 943, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":944
 * 
 *      if debug:
 *           print("Submitted party search form...")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
    __pyx_t_9 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__104, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 944, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":943
 *           time.sleep(5)
 * 
 *      if debug:             # <<<<<<<<<<<<<<
 *           print("Submitted party search form...")
 * 
 */
  }

  /* "alacorder/cal.pyx":946
 *           print("Submitted party search form...")
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 * 
 *      # count pages
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_13 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_13)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_13);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_9 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_13, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 946, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":949
 * 
 *      # count pages
 *      try:             # <<<<<<<<<<<<<<
 *           page_counter = driver.find_element(by=By.ID,value="ContentPlaceHolder1_dg_tcPageXofY").text
 *           pages = int(page_counter.strip()[-1])
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "alacorder/cal.pyx":950
 *      # count pages
 *      try:
 *           page_counter = driver.find_element(by=By.ID,value="ContentPlaceHolder1_dg_tcPageXofY").text             # <<<<<<<<<<<<<<
 *           pages = int(page_counter.strip()[-1])
 * 
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_By); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_ID); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_1) < 0) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_n_u_ContentPlaceHolder1_dg_tcPageXof) < 0) __PYX_ERR(0, 950, __pyx_L35_error)
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 950, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_page_counter = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":951
 *      try:
 *           page_counter = driver.find_element(by=By.ID,value="ContentPlaceHolder1_dg_tcPageXofY").text
 *           pages = int(page_counter.strip()[-1])             # <<<<<<<<<<<<<<
 * 
 *      except:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_page_counter, __pyx_n_s_strip); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 951, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_4, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 951, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 951, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_pages = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":949
 * 
 *      # count pages
 *      try:             # <<<<<<<<<<<<<<
 *           page_counter = driver.find_element(by=By.ID,value="ContentPlaceHolder1_dg_tcPageXofY").text
 *           pages = int(page_counter.strip()[-1])
 */
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L40_try_end;
    __pyx_L35_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":953
 *           pages = int(page_counter.strip()[-1])
 * 
 *      except:             # <<<<<<<<<<<<<<
 *           pages = 1
 * 
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_1, &__pyx_t_9) < 0) __PYX_ERR(0, 953, __pyx_L37_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_t_9);

      /* "alacorder/cal.pyx":954
 * 
 *      except:
 *           pages = 1             # <<<<<<<<<<<<<<
 * 
 *      # count results
 */
      __Pyx_INCREF(__pyx_int_1);
      __Pyx_XDECREF_SET(__pyx_v_pages, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L36_exception_handled;
    }
    __pyx_L37_except_error:;

    /* "alacorder/cal.pyx":949
 * 
 *      # count pages
 *      try:             # <<<<<<<<<<<<<<
 *           page_counter = driver.find_element(by=By.ID,value="ContentPlaceHolder1_dg_tcPageXofY").text
 *           pages = int(page_counter.strip()[-1])
 */
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L36_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    __pyx_L40_try_end:;
  }

  /* "alacorder/cal.pyx":957
 * 
 *      # count results
 *      try:             # <<<<<<<<<<<<<<
 *           results_indicator = driver.find_element(by=By.ID, value="ContentPlaceHolder1_lblResultCount")
 *           results_count = int(results_indicator.text.replace("Search Results: ","").replace(" records returned.","").strip())
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_6);
    /*try:*/ {

      /* "alacorder/cal.pyx":958
 *      # count results
 *      try:
 *           results_indicator = driver.find_element(by=By.ID, value="ContentPlaceHolder1_lblResultCount")             # <<<<<<<<<<<<<<
 *           results_count = int(results_indicator.text.replace("Search Results: ","").replace(" records returned.","").strip())
 *      except:
 */
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 958, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 958, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_By); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 958, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ID); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 958, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_by, __pyx_t_13) < 0) __PYX_ERR(0, 958, __pyx_L43_error)
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_n_u_ContentPlaceHolder1_lblResultCou) < 0) __PYX_ERR(0, 958, __pyx_L43_error)
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 958, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_results_indicator = __pyx_t_13;
      __pyx_t_13 = 0;

      /* "alacorder/cal.pyx":959
 *      try:
 *           results_indicator = driver.find_element(by=By.ID, value="ContentPlaceHolder1_lblResultCount")
 *           results_count = int(results_indicator.text.replace("Search Results: ","").replace(" records returned.","").strip())             # <<<<<<<<<<<<<<
 *      except:
 *           pass
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_results_indicator, __pyx_n_s_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_replace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__105, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_replace); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_13 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyNumber_Int(__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 959, __pyx_L43_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_v_results_count = __pyx_t_9;
      __pyx_t_9 = 0;

      /* "alacorder/cal.pyx":957
 * 
 *      # count results
 *      try:             # <<<<<<<<<<<<<<
 *           results_indicator = driver.find_element(by=By.ID, value="ContentPlaceHolder1_lblResultCount")
 *           results_count = int(results_indicator.text.replace("Search Results: ","").replace(" records returned.","").strip())
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    goto __pyx_L48_try_end;
    __pyx_L43_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":960
 *           results_indicator = driver.find_element(by=By.ID, value="ContentPlaceHolder1_lblResultCount")
 *           results_count = int(results_indicator.text.replace("Search Results: ","").replace(" records returned.","").strip())
 *      except:             # <<<<<<<<<<<<<<
 *           pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L44_exception_handled;
    }
    __pyx_L44_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
    __pyx_L48_try_end:;
  }

  /* "alacorder/cal.pyx":963
 *           pass
 * 
 *      if debug:             # <<<<<<<<<<<<<<
 *           print(f"Found {results_count} results, fetching URLs and downloading PDFs...")
 * 
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_debug); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 963, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "alacorder/cal.pyx":964
 * 
 *      if debug:
 *           print(f"Found {results_count} results, fetching URLs and downloading PDFs...")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_9 = PyTuple_New(3); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_14 = 0;
    __pyx_t_15 = 127;
    __Pyx_INCREF(__pyx_kp_u_Found);
    __pyx_t_14 += 6;
    __Pyx_GIVEREF(__pyx_kp_u_Found);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_kp_u_Found);
    if (unlikely(!__pyx_v_results_count)) { __Pyx_RaiseUnboundLocalError("results_count"); __PYX_ERR(0, 964, __pyx_L1_error) }
    __pyx_t_13 = __Pyx_PyObject_FormatSimple(__pyx_v_results_count, __pyx_empty_unicode); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_15 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) > __pyx_t_15) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_13) : __pyx_t_15;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_13);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_13);
    __pyx_t_13 = 0;
    __Pyx_INCREF(__pyx_kp_u_results_fetching_URLs_and_downl);
    __pyx_t_14 += 47;
    __Pyx_GIVEREF(__pyx_kp_u_results_fetching_URLs_and_downl);
    PyTuple_SET_ITEM(__pyx_t_9, 2, __pyx_kp_u_results_fetching_URLs_and_downl);
    __pyx_t_13 = __Pyx_PyUnicode_Join(__pyx_t_9, 3, __pyx_t_14, __pyx_t_15); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 964, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":963
 *           pass
 * 
 *      if debug:             # <<<<<<<<<<<<<<
 *           print(f"Found {results_count} results, fetching URLs and downloading PDFs...")
 * 
 */
  }

  /* "alacorder/cal.pyx":968
 * 
 *      # get PDF links from each page
 *      pdflinks = []             # <<<<<<<<<<<<<<
 *      i = 0
 *      for i in range(0,pages):
 */
  __pyx_t_9 = PyList_New(0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_v_pdflinks = ((PyObject*)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":969
 *      # get PDF links from each page
 *      pdflinks = []
 *      i = 0             # <<<<<<<<<<<<<<
 *      for i in range(0,pages):
 *           driver.implicitly_wait(0.5)
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_i = __pyx_int_0;

  /* "alacorder/cal.pyx":970
 *      pdflinks = []
 *      i = 0
 *      for i in range(0,pages):             # <<<<<<<<<<<<<<
 *           driver.implicitly_wait(0.5)
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 */
  __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_int_0);
  __Pyx_INCREF(__pyx_v_pages);
  __Pyx_GIVEREF(__pyx_v_pages);
  PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_pages);
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_9, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 970, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (likely(PyList_CheckExact(__pyx_t_13)) || PyTuple_CheckExact(__pyx_t_13)) {
    __pyx_t_9 = __pyx_t_13; __Pyx_INCREF(__pyx_t_9); __pyx_t_14 = 0;
    __pyx_t_16 = NULL;
  } else {
    __pyx_t_14 = -1; __pyx_t_9 = PyObject_GetIter(__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_16 = Py_TYPE(__pyx_t_9)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 970, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  for (;;) {
    if (likely(!__pyx_t_16)) {
      if (likely(PyList_CheckExact(__pyx_t_9))) {
        if (__pyx_t_14 >= PyList_GET_SIZE(__pyx_t_9)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_13 = PyList_GET_ITEM(__pyx_t_9, __pyx_t_14); __Pyx_INCREF(__pyx_t_13); __pyx_t_14++; if (unlikely(0 < 0)) __PYX_ERR(0, 970, __pyx_L1_error)
        #else
        __pyx_t_13 = PySequence_ITEM(__pyx_t_9, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 970, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        #endif
      } else {
        if (__pyx_t_14 >= PyTuple_GET_SIZE(__pyx_t_9)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_13 = PyTuple_GET_ITEM(__pyx_t_9, __pyx_t_14); __Pyx_INCREF(__pyx_t_13); __pyx_t_14++; if (unlikely(0 < 0)) __PYX_ERR(0, 970, __pyx_L1_error)
        #else
        __pyx_t_13 = PySequence_ITEM(__pyx_t_9, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 970, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        #endif
      }
    } else {
      __pyx_t_13 = __pyx_t_16(__pyx_t_9);
      if (unlikely(!__pyx_t_13)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 970, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_13);
    }
    __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_13);
    __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":971
 *      i = 0
 *      for i in range(0,pages):
 *           driver.implicitly_wait(0.5)             # <<<<<<<<<<<<<<
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 *           for x in hovers:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 971, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_13 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_float_0_5) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_float_0_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 971, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":972
 *      for i in range(0,pages):
 *           driver.implicitly_wait(0.5)
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")             # <<<<<<<<<<<<<<
 *           for x in hovers:
 *                try:
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_elements); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_By); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_CLASS_NAME); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_11 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_12, __pyx_n_u_menuHover};
      __pyx_t_13 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 972, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
      PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_12, __pyx_n_u_menuHover};
      __pyx_t_13 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 972, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    } else
    #endif
    {
      __pyx_t_5 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 972, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_11, __pyx_t_12);
      __Pyx_INCREF(__pyx_n_u_menuHover);
      __Pyx_GIVEREF(__pyx_n_u_menuHover);
      PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_11, __pyx_n_u_menuHover);
      __pyx_t_12 = 0;
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 972, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_hovers, __pyx_t_13);
    __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":973
 *           driver.implicitly_wait(0.5)
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 *           for x in hovers:             # <<<<<<<<<<<<<<
 *                try:
 *                     a = x.get_attribute("href")
 */
    if (likely(PyList_CheckExact(__pyx_v_hovers)) || PyTuple_CheckExact(__pyx_v_hovers)) {
      __pyx_t_13 = __pyx_v_hovers; __Pyx_INCREF(__pyx_t_13); __pyx_t_17 = 0;
      __pyx_t_18 = NULL;
    } else {
      __pyx_t_17 = -1; __pyx_t_13 = PyObject_GetIter(__pyx_v_hovers); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 973, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_18 = Py_TYPE(__pyx_t_13)->tp_iternext; if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 973, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_18)) {
        if (likely(PyList_CheckExact(__pyx_t_13))) {
          if (__pyx_t_17 >= PyList_GET_SIZE(__pyx_t_13)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_17); __Pyx_INCREF(__pyx_t_1); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 973, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_13, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        } else {
          if (__pyx_t_17 >= PyTuple_GET_SIZE(__pyx_t_13)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_13, __pyx_t_17); __Pyx_INCREF(__pyx_t_1); __pyx_t_17++; if (unlikely(0 < 0)) __PYX_ERR(0, 973, __pyx_L1_error)
          #else
          __pyx_t_1 = PySequence_ITEM(__pyx_t_13, __pyx_t_17); __pyx_t_17++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 973, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          #endif
        }
      } else {
        __pyx_t_1 = __pyx_t_18(__pyx_t_13);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 973, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "alacorder/cal.pyx":974
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 *           for x in hovers:
 *                try:             # <<<<<<<<<<<<<<
 *                     a = x.get_attribute("href")
 *                     if "PDF" in a:
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        /*try:*/ {

          /* "alacorder/cal.pyx":975
 *           for x in hovers:
 *                try:
 *                     a = x.get_attribute("href")             # <<<<<<<<<<<<<<
 *                     if "PDF" in a:
 *                          pdflinks.append(a)
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_x, __pyx_n_s_get_attribute); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 975, __pyx_L54_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
            }
          }
          __pyx_t_1 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_12, __pyx_n_u_href) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_n_u_href);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 975, __pyx_L54_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF_SET(__pyx_v_a, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "alacorder/cal.pyx":976
 *                try:
 *                     a = x.get_attribute("href")
 *                     if "PDF" in a:             # <<<<<<<<<<<<<<
 *                          pdflinks.append(a)
 *                except:
 */
          __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_n_u_PDF, __pyx_v_a, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 976, __pyx_L54_error)
          __pyx_t_2 = (__pyx_t_3 != 0);
          if (__pyx_t_2) {

            /* "alacorder/cal.pyx":977
 *                     a = x.get_attribute("href")
 *                     if "PDF" in a:
 *                          pdflinks.append(a)             # <<<<<<<<<<<<<<
 *                except:
 *                     pass
 */
            __pyx_t_19 = __Pyx_PyList_Append(__pyx_v_pdflinks, __pyx_v_a); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(0, 977, __pyx_L54_error)

            /* "alacorder/cal.pyx":976
 *                try:
 *                     a = x.get_attribute("href")
 *                     if "PDF" in a:             # <<<<<<<<<<<<<<
 *                          pdflinks.append(a)
 *                except:
 */
          }

          /* "alacorder/cal.pyx":974
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 *           for x in hovers:
 *                try:             # <<<<<<<<<<<<<<
 *                     a = x.get_attribute("href")
 *                     if "PDF" in a:
 */
        }
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L61_try_end;
        __pyx_L54_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "alacorder/cal.pyx":978
 *                     if "PDF" in a:
 *                          pdflinks.append(a)
 *                except:             # <<<<<<<<<<<<<<
 *                     pass
 *           driver.implicitly_wait(0.5)
 */
        /*except:*/ {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L55_exception_handled;
        }
        __pyx_L55_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_XGIVEREF(__pyx_t_8);
        __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
        __pyx_L61_try_end:;
      }

      /* "alacorder/cal.pyx":973
 *           driver.implicitly_wait(0.5)
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 *           for x in hovers:             # <<<<<<<<<<<<<<
 *                try:
 *                     a = x.get_attribute("href")
 */
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":980
 *                except:
 *                     pass
 *           driver.implicitly_wait(0.5)             # <<<<<<<<<<<<<<
 *           try:
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_13 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_5, __pyx_float_0_5) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_float_0_5);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 980, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "alacorder/cal.pyx":981
 *                     pass
 *           driver.implicitly_wait(0.5)
 *           try:             # <<<<<<<<<<<<<<
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))
 *                next_pg = int(pager_select.text) + 1
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_7, &__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      /*try:*/ {

        /* "alacorder/cal.pyx":982
 *           driver.implicitly_wait(0.5)
 *           try:
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))             # <<<<<<<<<<<<<<
 *                next_pg = int(pager_select.text) + 1
 *                driver.implicitly_wait(0.5)
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_Select); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_By); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_NAME); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_by, __pyx_t_10) < 0) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (PyDict_SetItem(__pyx_t_12, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder1_dg_ctl) < 0) __PYX_ERR(0, 982, __pyx_L63_error)
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_empty_tuple, __pyx_t_12); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_12 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_12)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_12);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_13 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_12, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_10);
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 982, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_pager_select, __pyx_t_13);
        __pyx_t_13 = 0;

        /* "alacorder/cal.pyx":983
 *           try:
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))
 *                next_pg = int(pager_select.text) + 1             # <<<<<<<<<<<<<<
 *                driver.implicitly_wait(0.5)
 *           except:
 */
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_pager_select, __pyx_n_s_text); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 983, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_1 = __Pyx_PyNumber_Int(__pyx_t_13); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 983, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 983, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_next_pg, __pyx_t_13);
        __pyx_t_13 = 0;

        /* "alacorder/cal.pyx":984
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))
 *                next_pg = int(pager_select.text) + 1
 *                driver.implicitly_wait(0.5)             # <<<<<<<<<<<<<<
 *           except:
 *                try:
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 984, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_13 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_10, __pyx_float_0_5) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_float_0_5);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 984, __pyx_L63_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

        /* "alacorder/cal.pyx":981
 *                     pass
 *           driver.implicitly_wait(0.5)
 *           try:             # <<<<<<<<<<<<<<
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))
 *                next_pg = int(pager_select.text) + 1
 */
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L70_try_end;
      __pyx_L63_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "alacorder/cal.pyx":985
 *                next_pg = int(pager_select.text) + 1
 *                driver.implicitly_wait(0.5)
 *           except:             # <<<<<<<<<<<<<<
 *                try:
 *                     driver.implicitly_wait(0.5)
 */
      /*except:*/ {
        __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_1, &__pyx_t_10) < 0) __PYX_ERR(0, 985, __pyx_L65_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_GOTREF(__pyx_t_10);

        /* "alacorder/cal.pyx":986
 *                driver.implicitly_wait(0.5)
 *           except:
 *                try:             # <<<<<<<<<<<<<<
 *                     driver.implicitly_wait(0.5)
 *                     time.sleep(0.5)
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
          __Pyx_XGOTREF(__pyx_t_20);
          __Pyx_XGOTREF(__pyx_t_21);
          __Pyx_XGOTREF(__pyx_t_22);
          /*try:*/ {

            /* "alacorder/cal.pyx":987
 *           except:
 *                try:
 *                     driver.implicitly_wait(0.5)             # <<<<<<<<<<<<<<
 *                     time.sleep(0.5)
 *                     next_button = driver.find_element(by=By.ID, value = "ContentPlaceHolder1_dg_ibtnNext")
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 987, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_4 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_5, function);
              }
            }
            __pyx_t_12 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_float_0_5) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_float_0_5);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 987, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "alacorder/cal.pyx":988
 *                try:
 *                     driver.implicitly_wait(0.5)
 *                     time.sleep(0.5)             # <<<<<<<<<<<<<<
 *                     next_button = driver.find_element(by=By.ID, value = "ContentPlaceHolder1_dg_ibtnNext")
 *                     next_button.click()
 */
            __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_time); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 988, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sleep); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 988, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_5 = NULL;
            if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_4, function);
              }
            }
            __pyx_t_12 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_float_0_5) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_float_0_5);
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 988, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

            /* "alacorder/cal.pyx":989
 *                     driver.implicitly_wait(0.5)
 *                     time.sleep(0.5)
 *                     next_button = driver.find_element(by=By.ID, value = "ContentPlaceHolder1_dg_ibtnNext")             # <<<<<<<<<<<<<<
 *                     next_button.click()
 *                except:
 */
            __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 989, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 989, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_By); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 989, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_23 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_ID); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 989, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_23);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_by, __pyx_t_23) < 0) __PYX_ERR(0, 989, __pyx_L73_error)
            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_value, __pyx_n_u_ContentPlaceHolder1_dg_ibtnNext) < 0) __PYX_ERR(0, 989, __pyx_L73_error)
            __pyx_t_23 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_empty_tuple, __pyx_t_4); if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 989, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_23);
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF_SET(__pyx_v_next_button, __pyx_t_23);
            __pyx_t_23 = 0;

            /* "alacorder/cal.pyx":990
 *                     time.sleep(0.5)
 *                     next_button = driver.find_element(by=By.ID, value = "ContentPlaceHolder1_dg_ibtnNext")
 *                     next_button.click()             # <<<<<<<<<<<<<<
 *                except:
 *                     continue
 */
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_next_button, __pyx_n_s_click); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 990, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_12 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
              if (likely(__pyx_t_12)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_4, function);
              }
            }
            __pyx_t_23 = (__pyx_t_12) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_12) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_23)) __PYX_ERR(0, 990, __pyx_L73_error)
            __Pyx_GOTREF(__pyx_t_23);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;

            /* "alacorder/cal.pyx":986
 *                driver.implicitly_wait(0.5)
 *           except:
 *                try:             # <<<<<<<<<<<<<<
 *                     driver.implicitly_wait(0.5)
 *                     time.sleep(0.5)
 */
          }
          __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
          __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
          __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;
          goto __pyx_L80_try_end;
          __pyx_L73_error:;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_23); __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "alacorder/cal.pyx":991
 *                     next_button = driver.find_element(by=By.ID, value = "ContentPlaceHolder1_dg_ibtnNext")
 *                     next_button.click()
 *                except:             # <<<<<<<<<<<<<<
 *                     continue
 *      return pdflinks
 */
          /*except:*/ {
            __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_23, &__pyx_t_4, &__pyx_t_12) < 0) __PYX_ERR(0, 991, __pyx_L75_except_error)
            __Pyx_GOTREF(__pyx_t_23);
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_GOTREF(__pyx_t_12);

            /* "alacorder/cal.pyx":992
 *                     next_button.click()
 *                except:
 *                     continue             # <<<<<<<<<<<<<<
 *      return pdflinks
 * def downloadPDF(driver, url, cID="", uID="", pwd="", window=None):
 */
            goto __pyx_L82_except_continue;
            __pyx_L82_except_continue:;
            __Pyx_DECREF(__pyx_t_23); __pyx_t_23 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            goto __pyx_L79_try_continue;
          }
          __pyx_L75_except_error:;

          /* "alacorder/cal.pyx":986
 *                driver.implicitly_wait(0.5)
 *           except:
 *                try:             # <<<<<<<<<<<<<<
 *                     driver.implicitly_wait(0.5)
 *                     time.sleep(0.5)
 */
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          goto __pyx_L65_except_error;
          __pyx_L79_try_continue:;
          __Pyx_XGIVEREF(__pyx_t_20);
          __Pyx_XGIVEREF(__pyx_t_21);
          __Pyx_XGIVEREF(__pyx_t_22);
          __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_21, __pyx_t_22);
          goto __pyx_L72_except_continue;
          __pyx_L80_try_end:;
        }
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L64_exception_handled;
        __pyx_L72_except_continue:;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        goto __pyx_L69_try_continue;
      }
      __pyx_L65_except_error:;

      /* "alacorder/cal.pyx":981
 *                     pass
 *           driver.implicitly_wait(0.5)
 *           try:             # <<<<<<<<<<<<<<
 *                pager_select = Select(driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$dg$ctl18$ddlPages"))
 *                next_pg = int(pager_select.text) + 1
 */
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      goto __pyx_L1_error;
      __pyx_L69_try_continue:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      goto __pyx_L50_continue;
      __pyx_L64_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_7, __pyx_t_6);
      __pyx_L70_try_end:;
    }

    /* "alacorder/cal.pyx":970
 *      pdflinks = []
 *      i = 0
 *      for i in range(0,pages):             # <<<<<<<<<<<<<<
 *           driver.implicitly_wait(0.5)
 *           hovers = driver.find_elements(By.CLASS_NAME, "menuHover")
 */
    __pyx_L50_continue:;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "alacorder/cal.pyx":993
 *                except:
 *                     continue
 *      return pdflinks             # <<<<<<<<<<<<<<
 * def downloadPDF(driver, url, cID="", uID="", pwd="", window=None):
 *      """
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pdflinks);
  __pyx_r = __pyx_v_pdflinks;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":831
 *      print("Completed query template.")
 *      return query
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Collect PDFs via SJIS Party Search Form from Alacourt.com
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_23);
  __Pyx_AddTraceback("alacorder.cal.party_search", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_party_name_box);
  __Pyx_XDECREF(__pyx_v_ssn_box);
  __Pyx_XDECREF(__pyx_v_date_of_birth_box);
  __Pyx_XDECREF(__pyx_v_party_type_select);
  __Pyx_XDECREF(__pyx_v_pts);
  __Pyx_XDECREF(__pyx_v_county_select);
  __Pyx_XDECREF(__pyx_v_scounty);
  __Pyx_XDECREF(__pyx_v_division_select);
  __Pyx_XDECREF(__pyx_v_sdivision);
  __Pyx_XDECREF(__pyx_v_case_year_select);
  __Pyx_XDECREF(__pyx_v_scase_year);
  __Pyx_XDECREF(__pyx_v_no_records_select);
  __Pyx_XDECREF(__pyx_v_sno_records);
  __Pyx_XDECREF(__pyx_v_filed_before_box);
  __Pyx_XDECREF(__pyx_v_filed_after_box);
  __Pyx_XDECREF(__pyx_v_search_button);
  __Pyx_XDECREF(__pyx_v_page_counter);
  __Pyx_XDECREF(__pyx_v_pages);
  __Pyx_XDECREF(__pyx_v_results_indicator);
  __Pyx_XDECREF(__pyx_v_results_count);
  __Pyx_XDECREF(__pyx_v_pdflinks);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_hovers);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_a);
  __Pyx_XDECREF(__pyx_v_pager_select);
  __Pyx_XDECREF(__pyx_v_next_pg);
  __Pyx_XDECREF(__pyx_v_next_button);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":994
 *                     continue
 *      return pdflinks
 * def downloadPDF(driver, url, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      With sg.WebDriver `driver`, download PDF at `url`.
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_37downloadPDF(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_36downloadPDF[] = "\n     With sg.WebDriver `driver`, download PDF at `url`.\n     \n     Args:\n         driver (WebDriver): Google Chrome selenium.WebDriver() object\n         url (str): URL to Alacourt case detail PDF download\n         cID (str, optional): Customer ID on Alacourt.com\n         uID (str, optional): User ID on Alacourt.com\n         pwd (str, optional): Password on Alacourt.com\n     \n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_37downloadPDF = {"downloadPDF", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_37downloadPDF, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_36downloadPDF};
static PyObject *__pyx_pw_9alacorder_3cal_37downloadPDF(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_driver = 0;
  PyObject *__pyx_v_url = 0;
  PyObject *__pyx_v_cID = 0;
  PyObject *__pyx_v_uID = 0;
  PyObject *__pyx_v_pwd = 0;
  PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("downloadPDF (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_driver,&__pyx_n_s_url,&__pyx_n_s_cID,&__pyx_n_s_uID,&__pyx_n_s_pwd,&__pyx_n_s_window,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[2] = ((PyObject *)__pyx_kp_u__8);
    values[3] = ((PyObject *)__pyx_kp_u__8);
    values[4] = ((PyObject *)__pyx_kp_u__8);
    values[5] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_driver)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_url)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("downloadPDF", 0, 2, 6, 1); __PYX_ERR(0, 994, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cID);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_uID);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pwd);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "downloadPDF") < 0)) __PYX_ERR(0, 994, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_driver = values[0];
    __pyx_v_url = values[1];
    __pyx_v_cID = values[2];
    __pyx_v_uID = values[3];
    __pyx_v_pwd = values[4];
    __pyx_v_window = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("downloadPDF", 0, 2, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 994, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.downloadPDF", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_36downloadPDF(__pyx_self, __pyx_v_driver, __pyx_v_url, __pyx_v_cID, __pyx_v_uID, __pyx_v_pwd, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_36downloadPDF(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_driver, PyObject *__pyx_v_url, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_window) {
  CYTHON_UNUSED PyObject *__pyx_v_a = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("downloadPDF", 0);

  /* "alacorder/cal.pyx":1006
 * 
 *      """
 *      if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx" and cID != "" and uID != "" and pwd != "":             # <<<<<<<<<<<<<<
 *           login(driver,cID=cID,uID=uID,pwd=pwd,window=window)
 *      a = driver.get(url)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_current_url); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_kp_u_https_v2_alacourt_com_frmlogin_a, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1006, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_cID, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1006, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_uID, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1006, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (__Pyx_PyUnicode_Equals(__pyx_v_pwd, __pyx_kp_u__8, Py_NE)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 1006, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "alacorder/cal.pyx":1007
 *      """
 *      if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx" and cID != "" and uID != "" and pwd != "":
 *           login(driver,cID=cID,uID=uID,pwd=pwd,window=window)             # <<<<<<<<<<<<<<
 *      a = driver.get(url)
 *      driver.implicitly_wait(0.5)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_login); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_driver);
    __Pyx_GIVEREF(__pyx_v_driver);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_driver);
    __pyx_t_5 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_cID, __pyx_v_cID) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uID, __pyx_v_uID) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_pwd, __pyx_v_pwd) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_window, __pyx_v_window) < 0) __PYX_ERR(0, 1007, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1007, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":1006
 * 
 *      """
 *      if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx" and cID != "" and uID != "" and pwd != "":             # <<<<<<<<<<<<<<
 *           login(driver,cID=cID,uID=uID,pwd=pwd,window=window)
 *      a = driver.get(url)
 */
  }

  /* "alacorder/cal.pyx":1008
 *      if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx" and cID != "" and uID != "" and pwd != "":
 *           login(driver,cID=cID,uID=uID,pwd=pwd,window=window)
 *      a = driver.get(url)             # <<<<<<<<<<<<<<
 *      driver.implicitly_wait(0.5)
 * def login(driver, cID, uID="", pwd="", path="", window=None):
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_get); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_v_url) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_url);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_a = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "alacorder/cal.pyx":1009
 *           login(driver,cID=cID,uID=uID,pwd=pwd,window=window)
 *      a = driver.get(url)
 *      driver.implicitly_wait(0.5)             # <<<<<<<<<<<<<<
 * def login(driver, cID, uID="", pwd="", path="", window=None):
 *      """Login to Alacourt.com using (driver) and auth (cID, username, pwd) for browser download to directory at (path)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
    }
  }
  __pyx_t_6 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_4, __pyx_float_0_5) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_float_0_5);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1009, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "alacorder/cal.pyx":994
 *                     continue
 *      return pdflinks
 * def downloadPDF(driver, url, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      With sg.WebDriver `driver`, download PDF at `url`.
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.downloadPDF", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_a);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1010
 *      a = driver.get(url)
 *      driver.implicitly_wait(0.5)
 * def login(driver, cID, uID="", pwd="", path="", window=None):             # <<<<<<<<<<<<<<
 *      """Login to Alacourt.com using (driver) and auth (cID, username, pwd) for browser download to directory at (path)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_39login(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_9alacorder_3cal_38login[] = "Login to Alacourt.com using (driver) and auth (cID, username, pwd) for browser download to directory at (path)\n     \n     Args:\n         driver (WebDriver): Google Chrome selenium.WebDriver() object\n         cID (str): Alacourt.com Customer ID\n         uID (str): Alacourt.com User ID\n         pwd (str): Alacourt.com Password\n         path (str, optional): Set browser download path \n     \n     Returns:\n         driver (WebDriver): selenium engine\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_39login = {"login", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_9alacorder_3cal_39login, METH_VARARGS|METH_KEYWORDS, __pyx_doc_9alacorder_3cal_38login};
static PyObject *__pyx_pw_9alacorder_3cal_39login(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_driver = 0;
  PyObject *__pyx_v_cID = 0;
  PyObject *__pyx_v_uID = 0;
  PyObject *__pyx_v_pwd = 0;
  PyObject *__pyx_v_path = 0;
  CYTHON_UNUSED PyObject *__pyx_v_window = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("login (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_driver,&__pyx_n_s_cID,&__pyx_n_s_uID,&__pyx_n_s_pwd,&__pyx_n_s_path,&__pyx_n_s_window,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[2] = ((PyObject *)__pyx_kp_u__8);
    values[3] = ((PyObject *)__pyx_kp_u__8);
    values[4] = ((PyObject *)__pyx_kp_u__8);
    values[5] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_driver)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_cID)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("login", 0, 2, 6, 1); __PYX_ERR(0, 1010, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_uID);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pwd);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_path);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_window);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "login") < 0)) __PYX_ERR(0, 1010, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_driver = values[0];
    __pyx_v_cID = values[1];
    __pyx_v_uID = values[2];
    __pyx_v_pwd = values[3];
    __pyx_v_path = values[4];
    __pyx_v_window = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("login", 0, 2, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 1010, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("alacorder.cal.login", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9alacorder_3cal_38login(__pyx_self, __pyx_v_driver, __pyx_v_cID, __pyx_v_uID, __pyx_v_pwd, __pyx_v_path, __pyx_v_window);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_38login(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_driver, PyObject *__pyx_v_cID, PyObject *__pyx_v_uID, PyObject *__pyx_v_pwd, PyObject *__pyx_v_path, CYTHON_UNUSED PyObject *__pyx_v_window) {
  PyObject *__pyx_v_options = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_login_screen = NULL;
  PyObject *__pyx_v_cID_box = NULL;
  PyObject *__pyx_v_username_box = NULL;
  PyObject *__pyx_v_pwd_box = NULL;
  PyObject *__pyx_v_login_button = NULL;
  PyObject *__pyx_v_continueLogIn = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("login", 0);
  __Pyx_INCREF(__pyx_v_driver);

  /* "alacorder/cal.pyx":1023
 *          driver (WebDriver): selenium engine
 *      """
 *      if driver == None:             # <<<<<<<<<<<<<<
 *           options = webdriver.ChromeOptions()
 *           options.add_experimental_option('prefs', {
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_driver, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1023, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 1023, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "alacorder/cal.pyx":1024
 *      """
 *      if driver == None:
 *           options = webdriver.ChromeOptions()             # <<<<<<<<<<<<<<
 *           options.add_experimental_option('prefs', {
 *                "download.default_directory": path, #Change default directory for downloads
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_webdriver); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_ChromeOptions); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1024, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_options = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":1025
 *      if driver == None:
 *           options = webdriver.ChromeOptions()
 *           options.add_experimental_option('prefs', {             # <<<<<<<<<<<<<<
 *                "download.default_directory": path, #Change default directory for downloads
 *                "download.prompt_for_download": False, #To auto download the file
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_options, __pyx_n_s_add_experimental_option); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1025, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "alacorder/cal.pyx":1026
 *           options = webdriver.ChromeOptions()
 *           options.add_experimental_option('prefs', {
 *                "download.default_directory": path, #Change default directory for downloads             # <<<<<<<<<<<<<<
 *                "download.prompt_for_download": False, #To auto download the file
 *                "download.directory_upgrade": True,
 */
    __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1026, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_download_default_directory, __pyx_v_path) < 0) __PYX_ERR(0, 1026, __pyx_L1_error)

    /* "alacorder/cal.pyx":1027
 *           options.add_experimental_option('prefs', {
 *                "download.default_directory": path, #Change default directory for downloads
 *                "download.prompt_for_download": False, #To auto download the file             # <<<<<<<<<<<<<<
 *                "download.directory_upgrade": True,
 *                "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_download_prompt_for_download, Py_False) < 0) __PYX_ERR(0, 1026, __pyx_L1_error)

    /* "alacorder/cal.pyx":1028
 *                "download.default_directory": path, #Change default directory for downloads
 *                "download.prompt_for_download": False, #To auto download the file
 *                "download.directory_upgrade": True,             # <<<<<<<<<<<<<<
 *                "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 *           })
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_download_directory_upgrade, Py_True) < 0) __PYX_ERR(0, 1026, __pyx_L1_error)

    /* "alacorder/cal.pyx":1029
 *                "download.prompt_for_download": False, #To auto download the file
 *                "download.directory_upgrade": True,
 *                "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome             # <<<<<<<<<<<<<<
 *           })
 *           driver = webdriver.Chrome(options=options)
 */
    if (PyDict_SetItem(__pyx_t_3, __pyx_kp_u_plugins_always_open_pdf_external, Py_True) < 0) __PYX_ERR(0, 1026, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_n_u_prefs, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1025, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_n_u_prefs, __pyx_t_3};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1025, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1025, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__pyx_t_5) {
        __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
      }
      __Pyx_INCREF(__pyx_n_u_prefs);
      __Pyx_GIVEREF(__pyx_n_u_prefs);
      PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_n_u_prefs);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1025, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "alacorder/cal.pyx":1031
 *                "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 *           })
 *           driver = webdriver.Chrome(options=options)             # <<<<<<<<<<<<<<
 * 
 *      print("Connecting to Alacourt...")
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_webdriver); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_Chrome); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_options, __pyx_v_options) < 0) __PYX_ERR(0, 1031, __pyx_L1_error)
    __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_driver, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":1023
 *          driver (WebDriver): selenium engine
 *      """
 *      if driver == None:             # <<<<<<<<<<<<<<
 *           options = webdriver.ChromeOptions()
 *           options.add_experimental_option('prefs', {
 */
  }

  /* "alacorder/cal.pyx":1033
 *           driver = webdriver.Chrome(options=options)
 * 
 *      print("Connecting to Alacourt...")             # <<<<<<<<<<<<<<
 * 
 *      login_screen = driver.get("https://v2.alacourt.com/frmlogin.aspx")
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__107, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":1035
 *      print("Connecting to Alacourt...")
 * 
 *      login_screen = driver.get("https://v2.alacourt.com/frmlogin.aspx")             # <<<<<<<<<<<<<<
 * 
 *      print("Logging in...")
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_kp_u_https_v2_alacourt_com_frmlogin_a) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_kp_u_https_v2_alacourt_com_frmlogin_a);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1035, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_login_screen = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":1037
 *      login_screen = driver.get("https://v2.alacourt.com/frmlogin.aspx")
 * 
 *      print("Logging in...")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__108, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":1039
 *      print("Logging in...")
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 * 
 *      cID_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtCusid")
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1039, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":1041
 *      driver.implicitly_wait(1)
 * 
 *      cID_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtCusid")             # <<<<<<<<<<<<<<
 *      username_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtUserId")
 *      pwd_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtPassword")
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_By); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_NAME); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_by, __pyx_t_3) < 0) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder_txtCusi) < 0) __PYX_ERR(0, 1041, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cID_box = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1042
 * 
 *      cID_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtCusid")
 *      username_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtUserId")             # <<<<<<<<<<<<<<
 *      pwd_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtPassword")
 *      login_button = driver.find_element(by=By.ID, value="ContentPlaceHolder_btLogin")
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_By); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_NAME); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_by, __pyx_t_4) < 0) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder_txtUser) < 0) __PYX_ERR(0, 1042, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_username_box = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":1043
 *      cID_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtCusid")
 *      username_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtUserId")
 *      pwd_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtPassword")             # <<<<<<<<<<<<<<
 *      login_button = driver.find_element(by=By.ID, value="ContentPlaceHolder_btLogin")
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_By); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_NAME); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_by, __pyx_t_7) < 0) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder_txtPass) < 0) __PYX_ERR(0, 1043, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_pwd_box = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "alacorder/cal.pyx":1044
 *      username_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtUserId")
 *      pwd_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$txtPassword")
 *      login_button = driver.find_element(by=By.ID, value="ContentPlaceHolder_btLogin")             # <<<<<<<<<<<<<<
 * 
 *      cID_box.send_keys(cID)
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_By); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_ID); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_by, __pyx_t_3) < 0) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_n_u_ContentPlaceHolder_btLogin) < 0) __PYX_ERR(0, 1044, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_login_button = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1046
 *      login_button = driver.find_element(by=By.ID, value="ContentPlaceHolder_btLogin")
 * 
 *      cID_box.send_keys(cID)             # <<<<<<<<<<<<<<
 *      username_box.send_keys(uID)
 *      pwd_box.send_keys(pwd)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_cID_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_v_cID) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_cID);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1046, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1047
 * 
 *      cID_box.send_keys(cID)
 *      username_box.send_keys(uID)             # <<<<<<<<<<<<<<
 *      pwd_box.send_keys(pwd)
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_username_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_v_uID) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_uID);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1047, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1048
 *      cID_box.send_keys(cID)
 *      username_box.send_keys(uID)
 *      pwd_box.send_keys(pwd)             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_pwd_box, __pyx_n_s_send_keys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_v_pwd) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_pwd);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1050
 *      pwd_box.send_keys(pwd)
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 * 
 *      login_button.click()
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1052
 *      driver.implicitly_wait(1)
 * 
 *      login_button.click()             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_login_button, __pyx_n_s_click); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1054
 *      login_button.click()
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 * 
 *      try:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1056
 *      driver.implicitly_wait(1)
 * 
 *      try:             # <<<<<<<<<<<<<<
 *           continueLogIn = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$btnContinueLogin")
 *           continueLogIn.click()
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_XGOTREF(__pyx_t_10);
    /*try:*/ {

      /* "alacorder/cal.pyx":1057
 * 
 *      try:
 *           continueLogIn = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$btnContinueLogin")             # <<<<<<<<<<<<<<
 *           continueLogIn.click()
 *      except:
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_find_element); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1057, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1057, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_By); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1057, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_NAME); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1057, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_by, __pyx_t_4) < 0) __PYX_ERR(0, 1057, __pyx_L4_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_kp_u_ctl00_ContentPlaceHolder_btnCont) < 0) __PYX_ERR(0, 1057, __pyx_L4_error)
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1057, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_v_continueLogIn = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1058
 *      try:
 *           continueLogIn = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$btnContinueLogin")
 *           continueLogIn.click()             # <<<<<<<<<<<<<<
 *      except:
 *           pass
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_continueLogIn, __pyx_n_s_click); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1058, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1058, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1056
 *      driver.implicitly_wait(1)
 * 
 *      try:             # <<<<<<<<<<<<<<
 *           continueLogIn = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$btnContinueLogin")
 *           continueLogIn.click()
 */
    }
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    goto __pyx_L9_try_end;
    __pyx_L4_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":1059
 *           continueLogIn = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder$btnContinueLogin")
 *           continueLogIn.click()
 *      except:             # <<<<<<<<<<<<<<
 *           pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L5_exception_handled;
    }
    __pyx_L5_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_XGIVEREF(__pyx_t_9);
    __Pyx_XGIVEREF(__pyx_t_10);
    __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
    __pyx_L9_try_end:;
  }

  /* "alacorder/cal.pyx":1063
 * 
 * 
 *      driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")             # <<<<<<<<<<<<<<
 * 
 *      print("Successfully connected and logged into Alacourt!")
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_kp_u_https_v2_alacourt_com_frmIndexSe) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_kp_u_https_v2_alacourt_com_frmIndexSe);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":1065
 *      driver.get("https://v2.alacourt.com/frmIndexSearchForm.aspx")
 * 
 *      print("Successfully connected and logged into Alacourt!")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":1067
 *      print("Successfully connected and logged into Alacourt!")
 * 
 *      driver.implicitly_wait(1)             # <<<<<<<<<<<<<<
 * 
 *      return driver
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_driver, __pyx_n_s_implicitly_wait); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_int_1);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "alacorder/cal.pyx":1069
 *      driver.implicitly_wait(1)
 * 
 *      return driver             # <<<<<<<<<<<<<<
 * def empty_query(path):
 *      """Create empty query worksheet to submit search list for Alacorder to retrieve matching case records from Alacourt.com.
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_driver);
  __pyx_r = __pyx_v_driver;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1010
 *      a = driver.get(url)
 *      driver.implicitly_wait(0.5)
 * def login(driver, cID, uID="", pwd="", path="", window=None):             # <<<<<<<<<<<<<<
 *      """Login to Alacourt.com using (driver) and auth (cID, username, pwd) for browser download to directory at (path)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("alacorder.cal.login", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_options);
  __Pyx_XDECREF(__pyx_v_login_screen);
  __Pyx_XDECREF(__pyx_v_cID_box);
  __Pyx_XDECREF(__pyx_v_username_box);
  __Pyx_XDECREF(__pyx_v_pwd_box);
  __Pyx_XDECREF(__pyx_v_login_button);
  __Pyx_XDECREF(__pyx_v_continueLogIn);
  __Pyx_XDECREF(__pyx_v_driver);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1070
 * 
 *      return driver
 * def empty_query(path):             # <<<<<<<<<<<<<<
 *      """Create empty query worksheet to submit search list for Alacorder to retrieve matching case records from Alacourt.com.
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_41empty_query(PyObject *__pyx_self, PyObject *__pyx_v_path); /*proto*/
static char __pyx_doc_9alacorder_3cal_40empty_query[] = "Create empty query worksheet to submit search list for Alacorder to retrieve matching case records from Alacourt.com. \n     \n     Args:\n         path (str): Desired output path (.xls, .xlsx)\n     \n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_41empty_query = {"empty_query", (PyCFunction)__pyx_pw_9alacorder_3cal_41empty_query, METH_O, __pyx_doc_9alacorder_3cal_40empty_query};
static PyObject *__pyx_pw_9alacorder_3cal_41empty_query(PyObject *__pyx_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("empty_query (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_40empty_query(__pyx_self, ((PyObject *)__pyx_v_path));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_40empty_query(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path) {
  CYTHON_UNUSED int __pyx_v_success;
  PyObject *__pyx_v_empty = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("empty_query", 0);

  /* "alacorder/cal.pyx":1077
 * 
 *      """
 *      success = True             # <<<<<<<<<<<<<<
 *      empty = pl.DataFrame(columns=["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER", "RETRIEVED", "CASES_FOUND"])
 *      print(empty)
 */
  __pyx_v_success = 1;

  /* "alacorder/cal.pyx":1078
 *      """
 *      success = True
 *      empty = pl.DataFrame(columns=["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER", "RETRIEVED", "CASES_FOUND"])             # <<<<<<<<<<<<<<
 *      print(empty)
 *      print(type(empty))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_pl); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DataFrame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyList_New(12); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_u_NAME);
  __Pyx_GIVEREF(__pyx_n_u_NAME);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_u_NAME);
  __Pyx_INCREF(__pyx_n_u_PARTY_TYPE);
  __Pyx_GIVEREF(__pyx_n_u_PARTY_TYPE);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_u_PARTY_TYPE);
  __Pyx_INCREF(__pyx_n_u_SSN);
  __Pyx_GIVEREF(__pyx_n_u_SSN);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_u_SSN);
  __Pyx_INCREF(__pyx_n_u_DOB);
  __Pyx_GIVEREF(__pyx_n_u_DOB);
  PyList_SET_ITEM(__pyx_t_3, 3, __pyx_n_u_DOB);
  __Pyx_INCREF(__pyx_n_u_COUNTY);
  __Pyx_GIVEREF(__pyx_n_u_COUNTY);
  PyList_SET_ITEM(__pyx_t_3, 4, __pyx_n_u_COUNTY);
  __Pyx_INCREF(__pyx_n_u_DIVISION);
  __Pyx_GIVEREF(__pyx_n_u_DIVISION);
  PyList_SET_ITEM(__pyx_t_3, 5, __pyx_n_u_DIVISION);
  __Pyx_INCREF(__pyx_n_u_CASE_YEAR);
  __Pyx_GIVEREF(__pyx_n_u_CASE_YEAR);
  PyList_SET_ITEM(__pyx_t_3, 6, __pyx_n_u_CASE_YEAR);
  __Pyx_INCREF(__pyx_n_u_NO_RECORDS);
  __Pyx_GIVEREF(__pyx_n_u_NO_RECORDS);
  PyList_SET_ITEM(__pyx_t_3, 7, __pyx_n_u_NO_RECORDS);
  __Pyx_INCREF(__pyx_n_u_FILED_BEFORE);
  __Pyx_GIVEREF(__pyx_n_u_FILED_BEFORE);
  PyList_SET_ITEM(__pyx_t_3, 8, __pyx_n_u_FILED_BEFORE);
  __Pyx_INCREF(__pyx_n_u_FILED_AFTER);
  __Pyx_GIVEREF(__pyx_n_u_FILED_AFTER);
  PyList_SET_ITEM(__pyx_t_3, 9, __pyx_n_u_FILED_AFTER);
  __Pyx_INCREF(__pyx_n_u_RETRIEVED);
  __Pyx_GIVEREF(__pyx_n_u_RETRIEVED);
  PyList_SET_ITEM(__pyx_t_3, 10, __pyx_n_u_RETRIEVED);
  __Pyx_INCREF(__pyx_n_u_CASES_FOUND);
  __Pyx_GIVEREF(__pyx_n_u_CASES_FOUND);
  PyList_SET_ITEM(__pyx_t_3, 11, __pyx_n_u_CASES_FOUND);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_columns, __pyx_t_3) < 0) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_empty = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1079
 *      success = True
 *      empty = pl.DataFrame(columns=["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER", "RETRIEVED", "CASES_FOUND"])
 *      print(empty)             # <<<<<<<<<<<<<<
 *      print(type(empty))
 *      print(dir(empty))
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_v_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1079, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1080
 *      empty = pl.DataFrame(columns=["NAME", "PARTY_TYPE", "SSN", "DOB", "COUNTY", "DIVISION", "CASE_YEAR", "NO_RECORDS", "FILED_BEFORE", "FILED_AFTER", "RETRIEVED", "CASES_FOUND"])
 *      print(empty)
 *      print(type(empty))             # <<<<<<<<<<<<<<
 *      print(dir(empty))
 *      return write(empty, sheet_names="query", path=path, overwrite=True)
 */
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, ((PyObject *)Py_TYPE(__pyx_v_empty))); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "alacorder/cal.pyx":1081
 *      print(empty)
 *      print(type(empty))
 *      print(dir(empty))             # <<<<<<<<<<<<<<
 *      return write(empty, sheet_names="query", path=path, overwrite=True)
 * 
 */
  __pyx_t_3 = PyObject_Dir(__pyx_v_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1081, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":1082
 *      print(type(empty))
 *      print(dir(empty))
 *      return write(empty, sheet_names="query", path=path, overwrite=True)             # <<<<<<<<<<<<<<
 * 
 * #   #   #   #           GETTER METHODS         #   #   #   #
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_write); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_empty);
  __Pyx_GIVEREF(__pyx_v_empty);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_empty);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_sheet_names, __pyx_n_u_query) < 0) __PYX_ERR(0, 1082, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_path, __pyx_v_path) < 0) __PYX_ERR(0, 1082, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_overwrite, Py_True) < 0) __PYX_ERR(0, 1082, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1082, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1070
 * 
 *      return driver
 * def empty_query(path):             # <<<<<<<<<<<<<<
 *      """Create empty query worksheet to submit search list for Alacorder to retrieve matching case records from Alacourt.com.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("alacorder.cal.empty_query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_empty);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1086
 * #   #   #   #           GETTER METHODS         #   #   #   #
 * 
 * def getPDFText(path) -> str:             # <<<<<<<<<<<<<<
 *      """
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_43getPDFText(PyObject *__pyx_self, PyObject *__pyx_v_path); /*proto*/
static char __pyx_doc_9alacorder_3cal_42getPDFText[] = "\n     From path, return full text of PDF as string (PyMuPdf engine required!)\n     ";
static PyMethodDef __pyx_mdef_9alacorder_3cal_43getPDFText = {"getPDFText", (PyCFunction)__pyx_pw_9alacorder_3cal_43getPDFText, METH_O, __pyx_doc_9alacorder_3cal_42getPDFText};
static PyObject *__pyx_pw_9alacorder_3cal_43getPDFText(PyObject *__pyx_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPDFText (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_42getPDFText(__pyx_self, ((PyObject *)__pyx_v_path));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9alacorder_3cal_10getPDFText_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "alacorder/cal.pyx":1097
 *      for pg in doc:
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))             # <<<<<<<<<<<<<<
 *           except:
 *                pass
 */

static PyObject *__pyx_pf_9alacorder_3cal_10getPDFText_genexpr(PyObject *__pyx_self) {
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *)__pyx_tp_new_9alacorder_3cal___pyx_scope_struct_1_genexpr(__pyx_ptype_9alacorder_3cal___pyx_scope_struct_1_genexpr, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1097, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *) __pyx_self;
  __Pyx_INCREF(((PyObject *)__pyx_cur_scope->__pyx_outer_scope));
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_outer_scope);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9alacorder_3cal_10getPDFText_2generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_genexpr, __pyx_n_s_getPDFText_locals_genexpr, __pyx_n_s_alacorder_cal); if (unlikely(!gen)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("alacorder.cal.getPDFText.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9alacorder_3cal_10getPDFText_2generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *__pyx_cur_scope = ((struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __pyx_r = PyList_New(0); if (unlikely(!__pyx_r)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_r);
  if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_pg)) { __Pyx_RaiseClosureNameError("pg"); __PYX_ERR(0, 1097, __pyx_L1_error) }
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_cur_scope->__pyx_outer_scope->__pyx_v_pg, __pyx_n_s_get_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_option, __pyx_n_u_blocks) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_empty_tuple, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_2 = __pyx_t_3; __Pyx_INCREF(__pyx_t_2); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1097, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1097, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1097, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 1097, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1097, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_5(__pyx_t_2);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1097, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_x);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_x, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_cur_scope->__pyx_v_x, 4, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_replace); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__110, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(__Pyx_ListComp_Append(__pyx_r, (PyObject*)__pyx_t_3))) __PYX_ERR(0, 1097, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1086
 * #   #   #   #           GETTER METHODS         #   #   #   #
 * 
 * def getPDFText(path) -> str:             # <<<<<<<<<<<<<<
 *      """
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 */

static PyObject *__pyx_pf_9alacorder_3cal_42getPDFText(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path) {
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *__pyx_cur_scope;
  PyObject *__pyx_v_doc = NULL;
  PyObject *__pyx_v_text = NULL;
  PyObject *__pyx_gb_9alacorder_3cal_10getPDFText_2generator = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPDFText", 0);
  __pyx_cur_scope = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *)__pyx_tp_new_9alacorder_3cal___pyx_scope_struct__getPDFText(__pyx_ptype_9alacorder_3cal___pyx_scope_struct__getPDFText, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 1086, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }

  /* "alacorder/cal.pyx":1090
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 *      """
 *      try:             # <<<<<<<<<<<<<<
 *           doc = fitz.open(path)
 *      except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1091
 *      """
 *      try:
 *           doc = fitz.open(path)             # <<<<<<<<<<<<<<
 *      except:
 *           return ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_fitz); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1091, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_open); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1091, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_v_path) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_path);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1091, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_doc = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1090
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 *      """
 *      try:             # <<<<<<<<<<<<<<
 *           doc = fitz.open(path)
 *      except:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":1092
 *      try:
 *           doc = fitz.open(path)
 *      except:             # <<<<<<<<<<<<<<
 *           return ''
 *      text = ''
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getPDFText", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_5) < 0) __PYX_ERR(0, 1092, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1093
 *           doc = fitz.open(path)
 *      except:
 *           return ''             # <<<<<<<<<<<<<<
 *      text = ''
 *      for pg in doc:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1090
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 *      """
 *      try:             # <<<<<<<<<<<<<<
 *           doc = fitz.open(path)
 *      except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "alacorder/cal.pyx":1094
 *      except:
 *           return ''
 *      text = ''             # <<<<<<<<<<<<<<
 *      for pg in doc:
 *           try:
 */
  __Pyx_INCREF(__pyx_kp_u__8);
  __pyx_v_text = __pyx_kp_u__8;

  /* "alacorder/cal.pyx":1095
 *           return ''
 *      text = ''
 *      for pg in doc:             # <<<<<<<<<<<<<<
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))
 */
  if (likely(PyList_CheckExact(__pyx_v_doc)) || PyTuple_CheckExact(__pyx_v_doc)) {
    __pyx_t_5 = __pyx_v_doc; __Pyx_INCREF(__pyx_t_5); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_doc); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1095, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_6); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 1095, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1095, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_7); __Pyx_INCREF(__pyx_t_6); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 1095, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_5, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1095, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_8(__pyx_t_5);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 1095, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_pg);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_pg, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":1096
 *      text = ''
 *      for pg in doc:
 *           try:             # <<<<<<<<<<<<<<
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))
 *           except:
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_1);
      /*try:*/ {

        /* "alacorder/cal.pyx":1097
 *      for pg in doc:
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))             # <<<<<<<<<<<<<<
 *           except:
 *                pass
 */
        __pyx_t_6 = __pyx_pf_9alacorder_3cal_10getPDFText_genexpr(((PyObject*)__pyx_cur_scope)); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1097, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = __Pyx_Generator_Next(__pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1097, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyUnicode_Join(__pyx_kp_u__111, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1097, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_text, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1097, __pyx_L13_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_4);
        __pyx_t_4 = 0;

        /* "alacorder/cal.pyx":1096
 *      text = ''
 *      for pg in doc:
 *           try:             # <<<<<<<<<<<<<<
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))
 *           except:
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L20_try_end;
      __pyx_L13_error:;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "alacorder/cal.pyx":1098
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))
 *           except:             # <<<<<<<<<<<<<<
 *                pass
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()
 */
      /*except:*/ {
        __Pyx_ErrRestore(0,0,0);
        goto __pyx_L14_exception_handled;
      }
      __pyx_L14_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
      __pyx_L20_try_end:;
    }

    /* "alacorder/cal.pyx":1095
 *           return ''
 *      text = ''
 *      for pg in doc:             # <<<<<<<<<<<<<<
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1100
 *           except:
 *                pass
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()             # <<<<<<<<<<<<<<
 *      return text
 * def getName(text):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_10 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
      __pyx_t_10 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_9)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_image, __pyx_kp_u__8, __pyx_v_text};
    __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_10, 3+__pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
    PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_image, __pyx_kp_u__8, __pyx_v_text};
    __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_10, 3+__pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_4);
  } else
  #endif
  {
    __pyx_t_11 = PyTuple_New(3+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u_image);
    __Pyx_GIVEREF(__pyx_kp_u_image);
    PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_image);
    __Pyx_INCREF(__pyx_kp_u__8);
    __Pyx_GIVEREF(__pyx_kp_u__8);
    PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_kp_u__8);
    __Pyx_INCREF(__pyx_v_text);
    __Pyx_GIVEREF(__pyx_v_text);
    PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_10, __pyx_v_text);
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  }
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_9, function);
    }
  }
  __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF_SET(__pyx_v_text, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1101
 *                pass
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()
 *      return text             # <<<<<<<<<<<<<<
 * def getName(text):
 *     try:
 */
  __Pyx_XDECREF(__pyx_r);
  if (!(likely(PyUnicode_CheckExact(__pyx_v_text))||((__pyx_v_text) == Py_None)||((void)PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_text)->tp_name), 0))) __PYX_ERR(0, 1101, __pyx_L1_error)
  __Pyx_INCREF(__pyx_v_text);
  __pyx_r = ((PyObject*)__pyx_v_text);
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1086
 * #   #   #   #           GETTER METHODS         #   #   #   #
 * 
 * def getPDFText(path) -> str:             # <<<<<<<<<<<<<<
 *      """
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getPDFText", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_doc);
  __Pyx_XDECREF(__pyx_v_text);
  __Pyx_XDECREF(__pyx_gb_9alacorder_3cal_10getPDFText_2generator);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1102
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()
 *      return text
 * def getName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_45getName(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_45getName = {"getName", (PyCFunction)__pyx_pw_9alacorder_3cal_45getName, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_45getName(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getName (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_44getName(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_44getName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getName", 0);

  /* "alacorder/cal.pyx":1103
 *      return text
 * def getName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1104
 * def getName(text):
 *     try:
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_sub); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_re); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_search); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = NULL;
      __pyx_t_13 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_13 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100, __pyx_t_10};
        __pyx_t_9 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[3] = {__pyx_t_12, __pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100, __pyx_t_10};
        __pyx_t_9 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_13, 2+__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_14 = PyTuple_New(2+__pyx_t_13); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_14);
        if (__pyx_t_12) {
          __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_12); __pyx_t_12 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100);
        __Pyx_GIVEREF(__pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100);
        PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_13, __pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_13, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_14, NULL); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_group); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      __pyx_t_7 = (__pyx_t_9) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_9, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = NULL;
      __pyx_t_13 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_13 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_kp_u_Case_Number, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_13, 3+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[4] = {__pyx_t_11, __pyx_kp_u_Case_Number, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_13, 3+__pyx_t_13); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_9 = PyTuple_New(3+__pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Case_Number);
        __Pyx_GIVEREF(__pyx_kp_u_Case_Number);
        PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_13, __pyx_kp_u_Case_Number);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_13, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_13, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_9, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1104, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_n_u_C_2) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_n_u_C_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1104, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1103
 *      return text
 * def getName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1105
 *     try:
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAlias(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getName", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1105, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1106
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAlias(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1103
 *      return text
 * def getName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1102
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()
 *      return text
 * def getName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("alacorder.cal.getName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1107
 *     except:
 *         return ''
 * def getAlias(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_47getAlias(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_47getAlias = {"getAlias", (PyCFunction)__pyx_pw_9alacorder_3cal_47getAlias, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_47getAlias(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAlias (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_46getAlias(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_46getAlias(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAlias", 0);

  /* "alacorder/cal.pyx":1108
 *         return ''
 * def getAlias(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1109
 * def getAlias(text):
 *     try:
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_SSN_5_75_Alias, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_SSN_5_75_Alias, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_SSN_5_75_Alias);
        __Pyx_GIVEREF(__pyx_kp_u_SSN_5_75_Alias);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_SSN_5_75_Alias);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u__28, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u__28, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u__28);
        __Pyx_GIVEREF(__pyx_kp_u__28);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u__28);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1109, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1109, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1108
 *         return ''
 * def getAlias(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1110
 *     try:
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDOB(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAlias", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1110, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1111
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDOB(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1108
 *         return ''
 * def getAlias(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1107
 *     except:
 *         return ''
 * def getAlias(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getAlias", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1112
 *     except:
 *         return ''
 * def getDOB(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_49getDOB(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_49getDOB = {"getDOB", (PyCFunction)__pyx_pw_9alacorder_3cal_49getDOB, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_49getDOB(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDOB (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_48getDOB(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_48getDOB(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDOB", 0);

  /* "alacorder/cal.pyx":1113
 *         return ''
 * def getDOB(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1114
 * def getDOB(text):
 *     try:
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_d_2_d_2_d_4_0_5_DOB, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_d_2_d_2_d_4_0_5_DOB, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_d_2_d_2_d_4_0_5_DOB);
        __Pyx_GIVEREF(__pyx_kp_u_d_2_d_2_d_4_0_5_DOB);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_d_2_d_2_d_4_0_5_DOB);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_d, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_d, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_d);
        __Pyx_GIVEREF(__pyx_kp_u_d);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_d);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1114, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1114, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1113
 *         return ''
 * def getDOB(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1115
 *     try:
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getPhone(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDOB", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1115, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1116
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getPhone(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1113
 *         return ''
 * def getDOB(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1112
 *     except:
 *         return ''
 * def getDOB(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getDOB", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1117
 *     except:
 *         return ''
 * def getPhone(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_51getPhone(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_51getPhone = {"getPhone", (PyCFunction)__pyx_pw_9alacorder_3cal_51getPhone, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_51getPhone(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPhone (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_50getPhone(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_50getPhone(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPhone", 0);

  /* "alacorder/cal.pyx":1118
 *         return ''
 * def getPhone(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 *         if len(m) < 7:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1119
 * def getPhone(text):
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()             # <<<<<<<<<<<<<<
 *         if len(m) < 7:
 *             return ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Phone, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Phone, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Phone);
        __Pyx_GIVEREF(__pyx_kp_u_Phone);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Phone);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_9, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_9, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_0_9);
        __Pyx_GIVEREF(__pyx_kp_u_0_9);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_0_9);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1119, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1119, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_m = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1120
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 *         if len(m) < 7:             # <<<<<<<<<<<<<<
 *             return ''
 *         elif m[0:10] == "2050000000":
 */
      __pyx_t_14 = PyObject_Length(__pyx_v_m); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1120, __pyx_L3_error)
      __pyx_t_15 = ((__pyx_t_14 < 7) != 0);
      if (__pyx_t_15) {

        /* "alacorder/cal.pyx":1121
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 *         if len(m) < 7:
 *             return ''             # <<<<<<<<<<<<<<
 *         elif m[0:10] == "2050000000":
 *             return ''
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_kp_u__8);
        __pyx_r = __pyx_kp_u__8;
        goto __pyx_L7_try_return;

        /* "alacorder/cal.pyx":1120
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 *         if len(m) < 7:             # <<<<<<<<<<<<<<
 *             return ''
 *         elif m[0:10] == "2050000000":
 */
      }

      /* "alacorder/cal.pyx":1122
 *         if len(m) < 7:
 *             return ''
 *         elif m[0:10] == "2050000000":             # <<<<<<<<<<<<<<
 *             return ''
 *         elif len(m) > 10:
 */
      __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_m, 0, 10, NULL, NULL, &__pyx_slice__112, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1122, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_15 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_kp_u_2050000000, Py_EQ)); if (unlikely(__pyx_t_15 < 0)) __PYX_ERR(0, 1122, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_15) {

        /* "alacorder/cal.pyx":1123
 *             return ''
 *         elif m[0:10] == "2050000000":
 *             return ''             # <<<<<<<<<<<<<<
 *         elif len(m) > 10:
 *             return m[0:10]
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_kp_u__8);
        __pyx_r = __pyx_kp_u__8;
        goto __pyx_L7_try_return;

        /* "alacorder/cal.pyx":1122
 *         if len(m) < 7:
 *             return ''
 *         elif m[0:10] == "2050000000":             # <<<<<<<<<<<<<<
 *             return ''
 *         elif len(m) > 10:
 */
      }

      /* "alacorder/cal.pyx":1124
 *         elif m[0:10] == "2050000000":
 *             return ''
 *         elif len(m) > 10:             # <<<<<<<<<<<<<<
 *             return m[0:10]
 *     except:
 */
      __pyx_t_14 = PyObject_Length(__pyx_v_m); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1124, __pyx_L3_error)
      __pyx_t_15 = ((__pyx_t_14 > 10) != 0);
      if (__pyx_t_15) {

        /* "alacorder/cal.pyx":1125
 *             return ''
 *         elif len(m) > 10:
 *             return m[0:10]             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_4 = __Pyx_PyObject_GetSlice(__pyx_v_m, 0, 10, NULL, NULL, &__pyx_slice__112, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1125, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L7_try_return;

        /* "alacorder/cal.pyx":1124
 *         elif m[0:10] == "2050000000":
 *             return ''
 *         elif len(m) > 10:             # <<<<<<<<<<<<<<
 *             return m[0:10]
 *     except:
 */
      }

      /* "alacorder/cal.pyx":1118
 *         return ''
 * def getPhone(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 *         if len(m) < 7:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1126
 *         elif len(m) > 10:
 *             return m[0:10]
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getRace(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getPhone", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1126, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1127
 *             return m[0:10]
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getRace(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1118
 *         return ''
 * def getPhone(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 *         if len(m) < 7:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "alacorder/cal.pyx":1117
 *     except:
 *         return ''
 * def getPhone(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getPhone", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1128
 *     except:
 *         return ''
 * def getRace(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_53getRace(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_53getRace = {"getRace", (PyCFunction)__pyx_pw_9alacorder_3cal_53getRace, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_53getRace(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getRace (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_52getRace(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_52getRace(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getRace", 0);

  /* "alacorder/cal.pyx":1129
 *         return ''
 * def getRace(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1130
 * def getRace(text):
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1130, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1130, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1130, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_B_W_H_A_F_M_3, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1130, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_B_W_H_A_F_M_3, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1130, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1130, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_B_W_H_A_F_M_3);
        __Pyx_GIVEREF(__pyx_kp_u_B_W_H_A_F_M_3);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_B_W_H_A_F_M_3);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1130, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1130, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1130, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1129
 *         return ''
 * def getRace(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1131
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSex(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getRace", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1131, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1132
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSex(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1129
 *         return ''
 * def getRace(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1128
 *     except:
 *         return ''
 * def getRace(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getRace", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1133
 *     except:
 *         return ''
 * def getSex(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_55getSex(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_55getSex = {"getSex", (PyCFunction)__pyx_pw_9alacorder_3cal_55getSex, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_55getSex(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSex (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_54getSex(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_54getSex(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSex", 0);

  /* "alacorder/cal.pyx":1134
 *         return ''
 * def getSex(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1135
 * def getSex(text):
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1135, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1135, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1135, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_B_W_H_A_F_M_3, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1135, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_B_W_H_A_F_M_3, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1135, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1135, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_B_W_H_A_F_M_3);
        __Pyx_GIVEREF(__pyx_kp_u_B_W_H_A_F_M_3);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_B_W_H_A_F_M_3);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1135, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1135, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1135, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1134
 *         return ''
 * def getSex(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1136
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAddress1(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSex", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1136, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1137
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAddress1(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1134
 *         return ''
 * def getSex(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1133
 *     except:
 *         return ''
 * def getSex(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getSex", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1138
 *     except:
 *         return ''
 * def getAddress1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_57getAddress1(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_57getAddress1 = {"getAddress1", (PyCFunction)__pyx_pw_9alacorder_3cal_57getAddress1, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_57getAddress1(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAddress1 (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_56getAddress1(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_56getAddress1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAddress1", 0);

  /* "alacorder/cal.pyx":1139
 *         return ''
 * def getAddress1(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1140
 * def getAddress1(text):
 *     try:
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Address_1_Phone, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Address_1_Phone, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Address_1_Phone);
        __Pyx_GIVEREF(__pyx_kp_u_Address_1_Phone);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Address_1_Phone);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Phone_4, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Phone_4, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Phone_4);
        __Pyx_GIVEREF(__pyx_kp_u_Phone_4);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_Phone_4);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1140, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1140, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1139
 *         return ''
 * def getAddress1(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1141
 *     try:
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAddress2(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress1", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1141, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1142
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAddress2(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1139
 *         return ''
 * def getAddress1(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1138
 *     except:
 *         return ''
 * def getAddress1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getAddress1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1143
 *     except:
 *         return ''
 * def getAddress2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_59getAddress2(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_59getAddress2 = {"getAddress2", (PyCFunction)__pyx_pw_9alacorder_3cal_59getAddress2, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_59getAddress2(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAddress2 (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_58getAddress2(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_58getAddress2(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAddress2", 0);

  /* "alacorder/cal.pyx":1144
 *         return ''
 * def getAddress2(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1145
 * def getAddress2(text):
 *     try:
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Address_2, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Address_2, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Address_2);
        __Pyx_GIVEREF(__pyx_kp_u_Address_2);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Address_2);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1145, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Defendant_Information_JID, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Defendant_Information_JID, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Defendant_Information_JID);
        __Pyx_GIVEREF(__pyx_kp_u_Defendant_Information_JID);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_12, __pyx_kp_u_Defendant_Information_JID);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1145, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1144
 *         return ''
 * def getAddress2(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1146
 *     try:
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCity(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress2", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1146, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1147
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCity(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1144
 *         return ''
 * def getAddress2(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1143
 *     except:
 *         return ''
 * def getAddress2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getAddress2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1148
 *     except:
 *         return ''
 * def getCity(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_61getCity(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_61getCity = {"getCity", (PyCFunction)__pyx_pw_9alacorder_3cal_61getCity, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_61getCity(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCity (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_60getCity(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_60getCity(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCity", 0);

  /* "alacorder/cal.pyx":1149
 *         return ''
 * def getCity(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1150
 * def getCity(text):
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1150, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1150, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1150, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_City_State, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1150, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_City_State, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1150, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1150, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_kp_u_City_State);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1150, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1150, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1150, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1149
 *         return ''
 * def getCity(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1151
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getState(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCity", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1151, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1152
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getState(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1149
 *         return ''
 * def getCity(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1148
 *     except:
 *         return ''
 * def getCity(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getCity", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1153
 *     except:
 *         return ''
 * def getState(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_63getState(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_63getState = {"getState", (PyCFunction)__pyx_pw_9alacorder_3cal_63getState, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_63getState(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getState (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_62getState(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_62getState(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getState", 0);

  /* "alacorder/cal.pyx":1154
 *         return ''
 * def getState(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1155
 * def getState(text):
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1155, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1155, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1155, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_City_State, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1155, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_City_State, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1155, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1155, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_kp_u_City_State);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1155, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1155, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1155, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1154
 *         return ''
 * def getState(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1156
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCountry(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getState", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1156, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1157
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCountry(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1154
 *         return ''
 * def getState(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1153
 *     except:
 *         return ''
 * def getState(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getState", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1158
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_65getCountry(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_65getCountry = {"getCountry", (PyCFunction)__pyx_pw_9alacorder_3cal_65getCountry, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_65getCountry(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCountry (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_64getCountry(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_64getCountry(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCountry", 0);

  /* "alacorder/cal.pyx":1159
 *         return ''
 * def getCountry(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1160
 * def getCountry(text):
 *     try:
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_sub); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_re); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_search); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_13 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_kp_u_Country_w, __pyx_t_11};
        __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_12)) {
        PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_kp_u_Country_w, __pyx_t_11};
        __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_12, __pyx_temp+1-__pyx_t_14, 2+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else
      #endif
      {
        __pyx_t_15 = PyTuple_New(2+__pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__pyx_t_13) {
          __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_13); __pyx_t_13 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Country_w);
        __Pyx_GIVEREF(__pyx_kp_u_Country_w);
        PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_14, __pyx_kp_u_Country_w);
        __Pyx_GIVEREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_14, __pyx_t_11);
        __pyx_t_11 = 0;
        __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_15, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      }
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_group); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_12, function);
        }
      }
      __pyx_t_8 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_12, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_12)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_12);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u_Enforcement_Party_Country, __pyx_kp_u__8, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[4] = {__pyx_t_12, __pyx_kp_u_Enforcement_Party_Country, __pyx_kp_u__8, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_12) {
          __Pyx_GIVEREF(__pyx_t_12); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_12); __pyx_t_12 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Enforcement_Party_Country);
        __Pyx_GIVEREF(__pyx_kp_u_Enforcement_Party_Country);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_14, __pyx_kp_u_Enforcement_Party_Country);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_14, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_14, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1160, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_14 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_14 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_kp_u_Country_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_kp_u_Country_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_14, 3+__pyx_t_14); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Country_2);
        __Pyx_GIVEREF(__pyx_kp_u_Country_2);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_14, __pyx_kp_u_Country_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_14, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_14, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1160, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1159
 *         return ''
 * def getCountry(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1161
 *     try:
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getZipCode(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCountry", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1161, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1162
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getZipCode(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1159
 *         return ''
 * def getCountry(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1158
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("alacorder.cal.getCountry", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1163
 *     except:
 *         return ''
 * def getZipCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_67getZipCode(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_67getZipCode = {"getZipCode", (PyCFunction)__pyx_pw_9alacorder_3cal_67getZipCode, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_67getZipCode(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getZipCode (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_66getZipCode(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_66getZipCode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getZipCode", 0);

  /* "alacorder/cal.pyx":1164
 *         return ''
 * def getZipCode(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1165
 * def getZipCode(text):
 *     try:
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Zip_2, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Zip_2, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Zip_2);
        __Pyx_GIVEREF(__pyx_kp_u_Zip_2);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Zip_2);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0000_A_Z, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0000_A_Z, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_0000_A_Z);
        __Pyx_GIVEREF(__pyx_kp_u_0000_A_Z);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_0000_A_Z);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1165, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1165, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1164
 *         return ''
 * def getZipCode(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1166
 *     try:
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAddress(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getZipCode", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1166, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1167
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAddress(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1164
 *         return ''
 * def getZipCode(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1163
 *     except:
 *         return ''
 * def getZipCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getZipCode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1168
 *     except:
 *         return ''
 * def getAddress(text):             # <<<<<<<<<<<<<<
 *     try:
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_69getAddress(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_69getAddress = {"getAddress", (PyCFunction)__pyx_pw_9alacorder_3cal_69getAddress, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_69getAddress(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAddress (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_68getAddress(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_68getAddress(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_street1 = NULL;
  PyObject *__pyx_v_street2 = NULL;
  PyObject *__pyx_v_zipcode = NULL;
  PyObject *__pyx_v_city = NULL;
  PyObject *__pyx_v_state = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  Py_UCS4 __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAddress", 0);

  /* "alacorder/cal.pyx":1169
 *         return ''
 * def getAddress(text):
 *     try:             # <<<<<<<<<<<<<<
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1170
 * def getAddress(text):
 *     try:
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         street1 = ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Address_1_Phone, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Address_1_Phone, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Address_1_Phone);
        __Pyx_GIVEREF(__pyx_kp_u_Address_1_Phone);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Address_1_Phone);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Phone_4, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Phone_4, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Phone_4);
        __Pyx_GIVEREF(__pyx_kp_u_Phone_4);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_Phone_4);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1170, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1170, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_street1 = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1169
 *         return ''
 * def getAddress(text):
 *     try:             # <<<<<<<<<<<<<<
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1171
 *     try:
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         street1 = ''
 *     try:
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1171, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1172
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 *     except:
 *         street1 = ''             # <<<<<<<<<<<<<<
 *     try:
 *         street2 = getAddress2(text).strip()
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_XDECREF_SET(__pyx_v_street1, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L4_exception_handled;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1169
 *         return ''
 * def getAddress(text):
 *     try:             # <<<<<<<<<<<<<<
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "alacorder/cal.pyx":1173
 *     except:
 *         street1 = ''
 *     try:             # <<<<<<<<<<<<<<
 *         street2 = getAddress2(text).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "alacorder/cal.pyx":1174
 *         street1 = ''
 *     try:
 *         street2 = getAddress2(text).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         street2 = ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_getAddress2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1174, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1174, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1174, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1174, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_street2 = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "alacorder/cal.pyx":1173
 *     except:
 *         street1 = ''
 *     try:             # <<<<<<<<<<<<<<
 *         street2 = getAddress2(text).strip()
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1175
 *     try:
 *         street2 = getAddress2(text).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         street2 = ''
 *     try:
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 1175, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1176
 *         street2 = getAddress2(text).strip()
 *     except:
 *         street2 = ''             # <<<<<<<<<<<<<<
 *     try:
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_XDECREF_SET(__pyx_v_street2, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L12_exception_handled;
    }
    __pyx_L13_except_error:;

    /* "alacorder/cal.pyx":1173
 *     except:
 *         street1 = ''
 *     try:             # <<<<<<<<<<<<<<
 *         street2 = getAddress2(text).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L16_try_end:;
  }

  /* "alacorder/cal.pyx":1177
 *     except:
 *         street2 = ''
 *     try:             # <<<<<<<<<<<<<<
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1178
 *         street2 = ''
 *     try:
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         zipcode = ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_re); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_search); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_9 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_13)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Zip_2, __pyx_t_10};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_13, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_13)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Zip_2, __pyx_t_10};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_13, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Zip_2);
        __Pyx_GIVEREF(__pyx_kp_u_Zip_2);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_12, __pyx_kp_u_Zip_2);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_12, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_13, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_6, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_13 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[4] = {__pyx_t_13, __pyx_kp_u_A_Z, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[4] = {__pyx_t_13, __pyx_kp_u_A_Z, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__pyx_t_13) {
          __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_13); __pyx_t_13 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_A_Z);
        __Pyx_GIVEREF(__pyx_kp_u_A_Z);
        PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_12, __pyx_kp_u_A_Z);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1178, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_7 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1178, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_zipcode = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "alacorder/cal.pyx":1177
 *     except:
 *         street2 = ''
 *     try:             # <<<<<<<<<<<<<<
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L24_try_end;
    __pyx_L19_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1179
 *     try:
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         zipcode = ''
 *     try:
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_4) < 0) __PYX_ERR(0, 1179, __pyx_L21_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_4);

      /* "alacorder/cal.pyx":1180
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()
 *     except:
 *         zipcode = ''             # <<<<<<<<<<<<<<
 *     try:
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_XDECREF_SET(__pyx_v_zipcode, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L20_exception_handled;
    }
    __pyx_L21_except_error:;

    /* "alacorder/cal.pyx":1177
 *     except:
 *         street2 = ''
 *     try:             # <<<<<<<<<<<<<<
 *         zipcode = re.sub(r'[A-Z].+','',re.search(r'(Zip: )(.+)',str(text)).group(2)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L20_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L24_try_end:;
  }

  /* "alacorder/cal.pyx":1181
 *     except:
 *         zipcode = ''
 *     try:             # <<<<<<<<<<<<<<
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "alacorder/cal.pyx":1182
 *         zipcode = ''
 *     try:
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         city = ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_13 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_kp_u_City_State, __pyx_t_6};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1182, __pyx_L27_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_13, __pyx_kp_u_City_State, __pyx_t_6};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1182, __pyx_L27_error)
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1182, __pyx_L27_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_13) {
          __Pyx_GIVEREF(__pyx_t_13); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_13); __pyx_t_13 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_kp_u_City_State);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_12, __pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_11, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1182, __pyx_L27_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_8 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_strip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_4 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1182, __pyx_L27_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_city = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1181
 *     except:
 *         zipcode = ''
 *     try:             # <<<<<<<<<<<<<<
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L32_try_end;
    __pyx_L27_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1183
 *     try:
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         city = ''
 *     try:
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_8) < 0) __PYX_ERR(0, 1183, __pyx_L29_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_8);

      /* "alacorder/cal.pyx":1184
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()
 *     except:
 *         city = ''             # <<<<<<<<<<<<<<
 *     try:
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_XDECREF_SET(__pyx_v_city, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L28_exception_handled;
    }
    __pyx_L29_except_error:;

    /* "alacorder/cal.pyx":1181
 *     except:
 *         zipcode = ''
 *     try:             # <<<<<<<<<<<<<<
 *         city = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L28_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L32_try_end:;
  }

  /* "alacorder/cal.pyx":1185
 *     except:
 *         city = ''
 *     try:             # <<<<<<<<<<<<<<
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1186
 *         city = ''
 *     try:
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         state = ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_6 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_kp_u_City_State, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1186, __pyx_L35_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_11)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_kp_u_City_State, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_11, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1186, __pyx_L35_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1186, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_kp_u_City_State);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_City_State);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_13, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1186, __pyx_L35_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_group); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_4, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_11);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_11, function);
        }
      }
      __pyx_t_8 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1186, __pyx_L35_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_v_state = __pyx_t_8;
      __pyx_t_8 = 0;

      /* "alacorder/cal.pyx":1185
 *     except:
 *         city = ''
 *     try:             # <<<<<<<<<<<<<<
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L40_try_end;
    __pyx_L35_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1187
 *     try:
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         state = ''
 *     if len(city)>3:
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAddress", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_11, &__pyx_t_5) < 0) __PYX_ERR(0, 1187, __pyx_L37_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1188
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()
 *     except:
 *         state = ''             # <<<<<<<<<<<<<<
 *     if len(city)>3:
 *         return f"{street1} {street2} {city}, {state} {zipcode}".strip()
 */
      __Pyx_INCREF(__pyx_kp_u__8);
      __Pyx_XDECREF_SET(__pyx_v_state, __pyx_kp_u__8);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L36_exception_handled;
    }
    __pyx_L37_except_error:;

    /* "alacorder/cal.pyx":1185
 *     except:
 *         city = ''
 *     try:             # <<<<<<<<<<<<<<
 *         state = re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L36_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L40_try_end:;
  }

  /* "alacorder/cal.pyx":1189
 *     except:
 *         state = ''
 *     if len(city)>3:             # <<<<<<<<<<<<<<
 *         return f"{street1} {street2} {city}, {state} {zipcode}".strip()
 *     else:
 */
  __pyx_t_14 = PyObject_Length(__pyx_v_city); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1189, __pyx_L1_error)
  __pyx_t_15 = ((__pyx_t_14 > 3) != 0);
  if (__pyx_t_15) {

    /* "alacorder/cal.pyx":1190
 *         state = ''
 *     if len(city)>3:
 *         return f"{street1} {street2} {city}, {state} {zipcode}".strip()             # <<<<<<<<<<<<<<
 *     else:
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_11 = PyTuple_New(9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_14 = 0;
    __pyx_t_16 = 127;
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_street1, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_street2, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_city, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__52);
    __pyx_t_14 += 2;
    __Pyx_GIVEREF(__pyx_kp_u__52);
    PyTuple_SET_ITEM(__pyx_t_11, 5, __pyx_kp_u__52);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_state, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 6, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 7, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_zipcode, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 8, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_11, 9, __pyx_t_14, __pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_strip); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "alacorder/cal.pyx":1189
 *     except:
 *         state = ''
 *     if len(city)>3:             # <<<<<<<<<<<<<<
 *         return f"{street1} {street2} {city}, {state} {zipcode}".strip()
 *     else:
 */
  }

  /* "alacorder/cal.pyx":1192
 *         return f"{street1} {street2} {city}, {state} {zipcode}".strip()
 *     else:
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()             # <<<<<<<<<<<<<<
 * def getChargesRows(text):
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_11 = PyTuple_New(9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_14 = 0;
    __pyx_t_16 = 127;
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_street1, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_street2, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_city, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 5, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_state, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 6, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u__64);
    __pyx_t_14 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__64);
    PyTuple_SET_ITEM(__pyx_t_11, 7, __pyx_kp_u__64);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_v_zipcode, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_16 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_16) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_16;
    __pyx_t_14 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_11, 8, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_11, 9, __pyx_t_14, __pyx_t_16); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_strip); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_11);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_11, function);
      }
    }
    __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1192, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1168
 *     except:
 *         return ''
 * def getAddress(text):             # <<<<<<<<<<<<<<
 *     try:
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getAddress", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_street1);
  __Pyx_XDECREF(__pyx_v_street2);
  __Pyx_XDECREF(__pyx_v_zipcode);
  __Pyx_XDECREF(__pyx_v_city);
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1193
 *     else:
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()
 * def getChargesRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_71getChargesRows(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_71getChargesRows = {"getChargesRows", (PyCFunction)__pyx_pw_9alacorder_3cal_71getChargesRows, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_71getChargesRows(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getChargesRows (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_70getChargesRows(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_70getChargesRows(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getChargesRows", 0);

  /* "alacorder/cal.pyx":1194
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()
 * def getChargesRows(text):
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))             # <<<<<<<<<<<<<<
 *     return m
 * def getFeeSheetRows(text):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_findall); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a);
    __Pyx_GIVEREF(__pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_m = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":1195
 * def getChargesRows(text):
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m             # <<<<<<<<<<<<<<
 * def getFeeSheetRows(text):
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_m);
  __pyx_r = __pyx_v_m;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1193
 *     else:
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()
 * def getChargesRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.getChargesRows", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1196
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 * def getFeeSheetRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_73getFeeSheetRows(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_73getFeeSheetRows = {"getFeeSheetRows", (PyCFunction)__pyx_pw_9alacorder_3cal_73getFeeSheetRows, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_73getFeeSheetRows(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFeeSheetRows (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_72getFeeSheetRows(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_72getFeeSheetRows(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFeeSheetRows", 0);

  /* "alacorder/cal.pyx":1197
 *     return m
 * def getFeeSheetRows(text):
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))             # <<<<<<<<<<<<<<
 *     return m
 * def getTotalRow(text):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_findall); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z);
    __Pyx_GIVEREF(__pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_m = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":1198
 * def getFeeSheetRows(text):
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m             # <<<<<<<<<<<<<<
 * def getTotalRow(text):
 *     try:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_m);
  __pyx_r = __pyx_v_m;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1196
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 * def getFeeSheetRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.getFeeSheetRows", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1199
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 * def getTotalRow(text):             # <<<<<<<<<<<<<<
 *     try:
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_75getTotalRow(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_75getTotalRow = {"getTotalRow", (PyCFunction)__pyx_pw_9alacorder_3cal_75getTotalRow, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_75getTotalRow(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTotalRow (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_74getTotalRow(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_74getTotalRow(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_mmm = NULL;
  PyObject *__pyx_v_mm = NULL;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTotalRow", 0);

  /* "alacorder/cal.pyx":1200
 *     return m
 * def getTotalRow(text):
 *     try:             # <<<<<<<<<<<<<<
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1201
 * def getTotalRow(text):
 *     try:
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()             # <<<<<<<<<<<<<<
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))
 *         m = re.findall(r'\d+\.\d{2}', str(mm))
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1201, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1201, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1201, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Total_n, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1201, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Total_n, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1201, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1201, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Total_n);
        __Pyx_GIVEREF(__pyx_kp_u_Total_n);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Total_n);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1201, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1201, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1201, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_mmm = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1202
 *     try:
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))             # <<<<<<<<<<<<<<
 *         m = re.findall(r'\d+\.\d{2}', str(mm))
 *         return m
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1202, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_sub); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1202, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_mmm); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1202, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_9_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1202, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_9_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1202, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1202, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_0_9_s);
        __Pyx_GIVEREF(__pyx_kp_u_0_9_s);
        PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_9, __pyx_kp_u_0_9_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_9, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_9, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1202, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_mm = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1203
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))
 *         m = re.findall(r'\d+\.\d{2}', str(mm))             # <<<<<<<<<<<<<<
 *         return m
 *     except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1203, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_findall); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1203, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_mm); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1203, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_kp_u_d_d_2_2, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1203, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_7, __pyx_kp_u_d_d_2_2, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1203, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1203, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_d_d_2_2);
        __Pyx_GIVEREF(__pyx_kp_u_d_d_2_2);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_d_d_2_2);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1203, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_m = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1204
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))
 *         m = re.findall(r'\d+\.\d{2}', str(mm))
 *         return m             # <<<<<<<<<<<<<<
 *     except:
 *         return ["0.00","0.00","0.00","0.00"]
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_m);
      __pyx_r = __pyx_v_m;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1200
 *     return m
 * def getTotalRow(text):
 *     try:             # <<<<<<<<<<<<<<
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1205
 *         m = re.findall(r'\d+\.\d{2}', str(mm))
 *         return m
 *     except:             # <<<<<<<<<<<<<<
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTotalRow", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_10) < 0) __PYX_ERR(0, 1205, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_10);

      /* "alacorder/cal.pyx":1206
 *         return m
 *     except:
 *         return ["0.00","0.00","0.00","0.00"]             # <<<<<<<<<<<<<<
 * def getTotalAmtDue(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = PyList_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1206, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_kp_u_0_00_2);
      __Pyx_GIVEREF(__pyx_kp_u_0_00_2);
      PyList_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_0_00_2);
      __Pyx_INCREF(__pyx_kp_u_0_00_2);
      __Pyx_GIVEREF(__pyx_kp_u_0_00_2);
      PyList_SET_ITEM(__pyx_t_5, 1, __pyx_kp_u_0_00_2);
      __Pyx_INCREF(__pyx_kp_u_0_00_2);
      __Pyx_GIVEREF(__pyx_kp_u_0_00_2);
      PyList_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_0_00_2);
      __Pyx_INCREF(__pyx_kp_u_0_00_2);
      __Pyx_GIVEREF(__pyx_kp_u_0_00_2);
      PyList_SET_ITEM(__pyx_t_5, 3, __pyx_kp_u_0_00_2);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1200
 *     return m
 * def getTotalRow(text):
 *     try:             # <<<<<<<<<<<<<<
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 *         mm = re.sub(r'[^0-9|\.|\s|\$]', '', str(mmm))
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1199
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 * def getTotalRow(text):             # <<<<<<<<<<<<<<
 *     try:
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getTotalRow", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mmm);
  __Pyx_XDECREF(__pyx_v_mm);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1207
 *     except:
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_77getTotalAmtDue(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_77getTotalAmtDue = {"getTotalAmtDue", (PyCFunction)__pyx_pw_9alacorder_3cal_77getTotalAmtDue, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_77getTotalAmtDue(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTotalAmtDue (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_76getTotalAmtDue(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_76getTotalAmtDue(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTotalAmtDue", 0);

  /* "alacorder/cal.pyx":1208
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1209
 * def getTotalAmtDue(text):
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))             # <<<<<<<<<<<<<<
 *     except:
 *         return 0.00
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getTotalRow); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1209, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1209, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1209, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_s);
        __Pyx_GIVEREF(__pyx_kp_u_s);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_9, __pyx_kp_u_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_9, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_9, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1209, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1209, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1208
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1210
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 *     except:             # <<<<<<<<<<<<<<
 *         return 0.00
 * def getTotalAmtPaid(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTotalAmtDue", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_8) < 0) __PYX_ERR(0, 1210, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);

      /* "alacorder/cal.pyx":1211
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 *     except:
 *         return 0.00             # <<<<<<<<<<<<<<
 * def getTotalAmtPaid(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_float_0_00);
      __pyx_r = __pyx_float_0_00;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1208
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1207
 *     except:
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.getTotalAmtDue", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1212
 *     except:
 *         return 0.00
 * def getTotalAmtPaid(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_79getTotalAmtPaid(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_79getTotalAmtPaid = {"getTotalAmtPaid", (PyCFunction)__pyx_pw_9alacorder_3cal_79getTotalAmtPaid, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_79getTotalAmtPaid(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTotalAmtPaid (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_78getTotalAmtPaid(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_78getTotalAmtPaid(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTotalAmtPaid", 0);

  /* "alacorder/cal.pyx":1213
 *         return 0.00
 * def getTotalAmtPaid(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1214
 * def getTotalAmtPaid(text):
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))             # <<<<<<<<<<<<<<
 *     except:
 *         return 0.00
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getTotalRow); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_5, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1214, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1214, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1214, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_s);
        __Pyx_GIVEREF(__pyx_kp_u_s);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_9, __pyx_kp_u_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_9, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_9, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1214, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1213
 *         return 0.00
 * def getTotalAmtPaid(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1215
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 *     except:             # <<<<<<<<<<<<<<
 *         return 0.00
 * def getTotalBalance(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTotalAmtPaid", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_8) < 0) __PYX_ERR(0, 1215, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);

      /* "alacorder/cal.pyx":1216
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 *     except:
 *         return 0.00             # <<<<<<<<<<<<<<
 * def getTotalBalance(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_float_0_00);
      __pyx_r = __pyx_float_0_00;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1213
 *         return 0.00
 * def getTotalAmtPaid(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1212
 *     except:
 *         return 0.00
 * def getTotalAmtPaid(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.getTotalAmtPaid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1217
 *     except:
 *         return 0.00
 * def getTotalBalance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_81getTotalBalance(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_81getTotalBalance = {"getTotalBalance", (PyCFunction)__pyx_pw_9alacorder_3cal_81getTotalBalance, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_81getTotalBalance(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTotalBalance (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_80getTotalBalance(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_80getTotalBalance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTotalBalance", 0);

  /* "alacorder/cal.pyx":1218
 *         return 0.00
 * def getTotalBalance(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1219
 * def getTotalBalance(text):
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))             # <<<<<<<<<<<<<<
 *     except:
 *         return 0.00
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1219, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1219, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getTotalRow); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1219, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1219, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_5, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1219, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1219, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1219, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1219, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_s);
        __Pyx_GIVEREF(__pyx_kp_u_s);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_9, __pyx_kp_u_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_9, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_9, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1219, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1219, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1218
 *         return 0.00
 * def getTotalBalance(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1220
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 *     except:             # <<<<<<<<<<<<<<
 *         return 0.00
 * def getTotalAmtHold(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTotalBalance", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_8) < 0) __PYX_ERR(0, 1220, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);

      /* "alacorder/cal.pyx":1221
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 *     except:
 *         return 0.00             # <<<<<<<<<<<<<<
 * def getTotalAmtHold(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_float_0_00);
      __pyx_r = __pyx_float_0_00;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1218
 *         return 0.00
 * def getTotalBalance(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1217
 *     except:
 *         return 0.00
 * def getTotalBalance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.getTotalBalance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1222
 *     except:
 *         return 0.00
 * def getTotalAmtHold(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_83getTotalAmtHold(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_83getTotalAmtHold = {"getTotalAmtHold", (PyCFunction)__pyx_pw_9alacorder_3cal_83getTotalAmtHold, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_83getTotalAmtHold(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTotalAmtHold (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_82getTotalAmtHold(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_82getTotalAmtHold(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTotalAmtHold", 0);

  /* "alacorder/cal.pyx":1223
 *         return 0.00
 * def getTotalAmtHold(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1224
 * def getTotalAmtHold(text):
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))             # <<<<<<<<<<<<<<
 *     except:
 *         return 0.00
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1224, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1224, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getTotalRow); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1224, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1224, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_5, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1224, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1224, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_7};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1224, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1224, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_s);
        __Pyx_GIVEREF(__pyx_kp_u_s);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_9, __pyx_kp_u_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_9, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_9, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_8, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1224, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1224, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1223
 *         return 0.00
 * def getTotalAmtHold(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1225
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 *     except:             # <<<<<<<<<<<<<<
 *         return 0.00
 * def getPaymentToRestore(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTotalAmtHold", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_8) < 0) __PYX_ERR(0, 1225, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);

      /* "alacorder/cal.pyx":1226
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 *     except:
 *         return 0.00             # <<<<<<<<<<<<<<
 * def getPaymentToRestore(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_float_0_00);
      __pyx_r = __pyx_float_0_00;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1223
 *         return 0.00
 * def getTotalAmtHold(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1222
 *     except:
 *         return 0.00
 * def getTotalAmtHold(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.getTotalAmtHold", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1227
 *     except:
 *         return 0.00
 * def getPaymentToRestore(text):             # <<<<<<<<<<<<<<
 *     try:
 *         tbal = getTotalBalance(text)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_85getPaymentToRestore(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_85getPaymentToRestore = {"getPaymentToRestore", (PyCFunction)__pyx_pw_9alacorder_3cal_85getPaymentToRestore, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_85getPaymentToRestore(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPaymentToRestore (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_84getPaymentToRestore(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_84getPaymentToRestore(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_tbal = NULL;
  PyObject *__pyx_v_d999mm = NULL;
  PyObject *__pyx_v_d999m = NULL;
  double __pyx_v_d999;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  double __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPaymentToRestore", 0);

  /* "alacorder/cal.pyx":1228
 *         return 0.00
 * def getPaymentToRestore(text):
 *     try:             # <<<<<<<<<<<<<<
 *         tbal = getTotalBalance(text)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1229
 * def getPaymentToRestore(text):
 *     try:
 *         tbal = getTotalBalance(text)             # <<<<<<<<<<<<<<
 *     except:
 *         return 0.0
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_getTotalBalance); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1229, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_5, __pyx_t_6, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1229, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_tbal = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1228
 *         return 0.00
 * def getPaymentToRestore(text):
 *     try:             # <<<<<<<<<<<<<<
 *         tbal = getTotalBalance(text)
 *     except:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "alacorder/cal.pyx":1230
 *     try:
 *         tbal = getTotalBalance(text)
 *     except:             # <<<<<<<<<<<<<<
 *         return 0.0
 *     try:
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getPaymentToRestore", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6) < 0) __PYX_ERR(0, 1230, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);

      /* "alacorder/cal.pyx":1231
 *         tbal = getTotalBalance(text)
 *     except:
 *         return 0.0             # <<<<<<<<<<<<<<
 *     try:
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_float_0_0);
      __pyx_r = __pyx_float_0_0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1228
 *         return 0.00
 * def getPaymentToRestore(text):
 *     try:             # <<<<<<<<<<<<<<
 *         tbal = getTotalBalance(text)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "alacorder/cal.pyx":1232
 *     except:
 *         return 0.0
 *     try:             # <<<<<<<<<<<<<<
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "alacorder/cal.pyx":1233
 *         return 0.0
 *     try:
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()             # <<<<<<<<<<<<<<
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))
 *         d999 = float(re.sub(r'[\$\s]','',d999m[-1]))
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_re); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1233, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1233, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1233, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_ACTIVE_n_D999_n, __pyx_t_4};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1233, __pyx_L11_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_ACTIVE_n_D999_n, __pyx_t_4};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1233, __pyx_L11_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1233, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_ACTIVE_n_D999_n);
        __Pyx_GIVEREF(__pyx_kp_u_ACTIVE_n_D999_n);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_ACTIVE_n_D999_n);
        __Pyx_GIVEREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1233, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1233, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1233, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_d999mm = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "alacorder/cal.pyx":1234
 *     try:
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))             # <<<<<<<<<<<<<<
 *         d999 = float(re.sub(r'[\$\s]','',d999m[-1]))
 *     except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1234, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_findall); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1234, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_d999mm); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1234, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_d_d_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1234, __pyx_L11_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_d_d_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1234, __pyx_L11_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_4 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1234, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_4);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_d_d_2);
        __Pyx_GIVEREF(__pyx_kp_u_d_d_2);
        PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_9, __pyx_kp_u_d_d_2);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_9, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1234, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_d999m = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "alacorder/cal.pyx":1235
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))
 *         d999 = float(re.sub(r'[\$\s]','',d999m[-1]))             # <<<<<<<<<<<<<<
 *     except:
 *         d999 = 0.0
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1235, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1235, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_d999m, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1235, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1235, __pyx_L11_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
        PyObject *__pyx_temp[4] = {__pyx_t_7, __pyx_kp_u_s, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_9, 3+__pyx_t_9); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1235, __pyx_L11_error)
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(3+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1235, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_7) {
          __Pyx_GIVEREF(__pyx_t_7); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_7); __pyx_t_7 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_s);
        __Pyx_GIVEREF(__pyx_kp_u_s);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_9, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1235, __pyx_L11_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = __Pyx_PyObject_AsDouble(__pyx_t_6); if (unlikely(__pyx_t_11 == ((double)((double)-1)) && PyErr_Occurred())) __PYX_ERR(0, 1235, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_d999 = __pyx_t_11;

      /* "alacorder/cal.pyx":1232
 *     except:
 *         return 0.0
 *     try:             # <<<<<<<<<<<<<<
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1236
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))
 *         d999 = float(re.sub(r'[\$\s]','',d999m[-1]))
 *     except:             # <<<<<<<<<<<<<<
 *         d999 = 0.0
 *     return float(tbal - d999)
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getPaymentToRestore", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_10) < 0) __PYX_ERR(0, 1236, __pyx_L13_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_10);

      /* "alacorder/cal.pyx":1237
 *         d999 = float(re.sub(r'[\$\s]','',d999m[-1]))
 *     except:
 *         d999 = 0.0             # <<<<<<<<<<<<<<
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):
 */
      __pyx_v_d999 = 0.0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L12_exception_handled;
    }
    __pyx_L13_except_error:;

    /* "alacorder/cal.pyx":1232
 *     except:
 *         return 0.0
 *     try:             # <<<<<<<<<<<<<<
 *         d999mm = re.search(r'(ACTIVE[^\n]+D999[^\n]+)',str(text)).group()
 *         d999m = re.findall(r'\$\d+\.\d{2}',str(d999mm))
 */
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L16_try_end:;
  }

  /* "alacorder/cal.pyx":1238
 *     except:
 *         d999 = 0.0
 *     return float(tbal - d999)             # <<<<<<<<<<<<<<
 * def getShortCaseNumber(text):
 *     try:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_10 = PyFloat_FromDouble(__pyx_v_d999); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = PyNumber_Subtract(__pyx_v_tbal, __pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1227
 *     except:
 *         return 0.00
 * def getPaymentToRestore(text):             # <<<<<<<<<<<<<<
 *     try:
 *         tbal = getTotalBalance(text)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getPaymentToRestore", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tbal);
  __Pyx_XDECREF(__pyx_v_d999mm);
  __Pyx_XDECREF(__pyx_v_d999m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1239
 *         d999 = 0.0
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_87getShortCaseNumber(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_87getShortCaseNumber = {"getShortCaseNumber", (PyCFunction)__pyx_pw_9alacorder_3cal_87getShortCaseNumber, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_87getShortCaseNumber(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getShortCaseNumber (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_86getShortCaseNumber(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_86getShortCaseNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getShortCaseNumber", 0);

  /* "alacorder/cal.pyx":1240
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1241
 * def getShortCaseNumber(text):
 *     try:
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1241, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1241, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1241, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_w_2_d_4_d_6_d_2_2, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1241, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_w_2_d_4_d_6_d_2_2, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1241, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1241, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_w_2_d_4_d_6_d_2_2);
        __Pyx_GIVEREF(__pyx_kp_u_w_2_d_4_d_6_d_2_2);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_w_2_d_4_d_6_d_2_2);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1241, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1241, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1241, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1240
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1242
 *     try:
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCounty(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getShortCaseNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1242, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1243
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCounty(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1240
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1239
 *         d999 = 0.0
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getShortCaseNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1244
 *     except:
 *         return ''
 * def getCounty(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_89getCounty(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_89getCounty = {"getCounty", (PyCFunction)__pyx_pw_9alacorder_3cal_89getCounty, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_89getCounty(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCounty (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_88getCounty(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_88getCounty(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCounty", 0);

  /* "alacorder/cal.pyx":1245
 *         return ''
 * def getCounty(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1246
 * def getCounty(text):
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1246, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1246, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1246, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Case_Number_d_d_w_County, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Case_Number_d_d_w_County, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1246, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Case_Number_d_d_w_County);
        __Pyx_GIVEREF(__pyx_kp_u_Case_Number_d_d_w_County);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Case_Number_d_d_w_County);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1246, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1246, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1246, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1245
 *         return ''
 * def getCounty(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1247
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCaseNumber(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCounty", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1247, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1248
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCaseNumber(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1245
 *         return ''
 * def getCounty(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1244
 *     except:
 *         return ''
 * def getCounty(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getCounty", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1249
 *     except:
 *         return ''
 * def getCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_91getCaseNumber(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_91getCaseNumber = {"getCaseNumber", (PyCFunction)__pyx_pw_9alacorder_3cal_91getCaseNumber, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_91getCaseNumber(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCaseNumber (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_90getCaseNumber(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_90getCaseNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCaseNumber", 0);

  /* "alacorder/cal.pyx":1250
 *         return ''
 * def getCaseNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1251
 * def getCaseNumber(text):
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Case_Number_d_d_w_County, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Case_Number_d_d_w_County, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Case_Number_d_d_w_County);
        __Pyx_GIVEREF(__pyx_kp_u_Case_Number_d_d_w_County);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Case_Number_d_d_w_County);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 2, NULL, NULL, &__pyx_slice__113, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyNumber_Add(__pyx_t_7, __pyx_kp_u__63); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_re); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_search); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_w_2_d_4_d_6_d_2_2, __pyx_t_10};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_w_2_d_4_d_6_d_2_2, __pyx_t_10};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_w_2_d_4_d_6_d_2_2);
        __Pyx_GIVEREF(__pyx_kp_u_w_2_d_4_d_6_d_2_2);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_9, __pyx_kp_u_w_2_d_4_d_6_d_2_2);
        __Pyx_GIVEREF(__pyx_t_10);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_9, __pyx_t_10);
        __pyx_t_10 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_11, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1251, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_7 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyNumber_Add(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1251, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1250
 *         return ''
 * def getCaseNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1252
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCaseYear(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCaseNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_7, &__pyx_t_4) < 0) __PYX_ERR(0, 1252, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_4);

      /* "alacorder/cal.pyx":1253
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCaseYear(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1250
 *         return ''
 * def getCaseNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1249
 *     except:
 *         return ''
 * def getCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getCaseNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1254
 *     except:
 *         return ''
 * def getCaseYear(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_93getCaseYear(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_93getCaseYear = {"getCaseYear", (PyCFunction)__pyx_pw_9alacorder_3cal_93getCaseYear, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_93getCaseYear(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCaseYear (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_92getCaseYear(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_92getCaseYear(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCaseYear", 0);

  /* "alacorder/cal.pyx":1255
 *         return ''
 * def getCaseYear(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1256
 * def getCaseYear(text):
 *     try:
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1256, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1256, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1256, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_w_2_d_4_d_6_d_2_3, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1256, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_w_2_d_4_d_6_d_2_3, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1256, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1256, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_w_2_d_4_d_6_d_2_3);
        __Pyx_GIVEREF(__pyx_kp_u_w_2_d_4_d_6_d_2_3);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_w_2_d_4_d_6_d_2_3);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1256, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1256, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1256, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1255
 *         return ''
 * def getCaseYear(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1257
 *     try:
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getLastName(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCaseYear", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1257, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1258
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getLastName(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1255
 *         return ''
 * def getCaseYear(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1254
 *     except:
 *         return ''
 * def getCaseYear(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getCaseYear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1259
 *     except:
 *         return ''
 * def getLastName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[0].strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_95getLastName(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_95getLastName = {"getLastName", (PyCFunction)__pyx_pw_9alacorder_3cal_95getLastName, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_95getLastName(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLastName (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_94getLastName(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_94getLastName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLastName", 0);

  /* "alacorder/cal.pyx":1260
 *         return ''
 * def getLastName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return getName(text).split(" ")[0].strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1261
 * def getLastName(text):
 *     try:
 *         return getName(text).split(" ")[0].strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_6, __pyx_kp_u__64) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__64);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1261, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1260
 *         return ''
 * def getLastName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return getName(text).split(" ")[0].strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1262
 *     try:
 *         return getName(text).split(" ")[0].strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getFirstName(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getLastName", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1262, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1263
 *         return getName(text).split(" ")[0].strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getFirstName(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1260
 *         return ''
 * def getLastName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return getName(text).split(" ")[0].strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1259
 *     except:
 *         return ''
 * def getLastName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[0].strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.getLastName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1264
 *     except:
 *         return ''
 * def getFirstName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[-1].strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_97getFirstName(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_97getFirstName = {"getFirstName", (PyCFunction)__pyx_pw_9alacorder_3cal_97getFirstName, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_97getFirstName(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFirstName (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_96getFirstName(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_96getFirstName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFirstName", 0);

  /* "alacorder/cal.pyx":1265
 *         return ''
 * def getFirstName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return getName(text).split(" ")[-1].strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1266
 * def getFirstName(text):
 *     try:
 *         return getName(text).split(" ")[-1].strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_6, __pyx_kp_u__64) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__64);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_5, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_4 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1266, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1265
 *         return ''
 * def getFirstName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return getName(text).split(" ")[-1].strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1267
 *     try:
 *         return getName(text).split(" ")[-1].strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getMiddleName(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getFirstName", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 1267, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1268
 *         return getName(text).split(" ")[-1].strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getMiddleName(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1265
 *         return ''
 * def getFirstName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return getName(text).split(" ")[-1].strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1264
 *     except:
 *         return ''
 * def getFirstName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[-1].strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("alacorder.cal.getFirstName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1269
 *     except:
 *         return ''
 * def getMiddleName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         if len(getName(text).split(" ")) > 2:
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_99getMiddleName(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_99getMiddleName = {"getMiddleName", (PyCFunction)__pyx_pw_9alacorder_3cal_99getMiddleName, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_99getMiddleName(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getMiddleName (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_98getMiddleName(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_98getMiddleName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getMiddleName", 0);

  /* "alacorder/cal.pyx":1270
 *         return ''
 * def getMiddleName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         if len(getName(text).split(" ")) > 2:
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1271
 * def getMiddleName(text):
 *     try:
 *         if len(getName(text).split(" ")) > 2:             # <<<<<<<<<<<<<<
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()
 *         else:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_getName); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1271, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_7, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_text);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1271, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_split); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1271, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_5, __pyx_kp_u__64) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_kp_u__64);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1271, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_8 = PyObject_Length(__pyx_t_4); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 1271, __pyx_L3_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = ((__pyx_t_8 > 2) != 0);
      if (__pyx_t_9) {

        /* "alacorder/cal.pyx":1272
 *     try:
 *         if len(getName(text).split(" ")) > 2:
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()             # <<<<<<<<<<<<<<
 *         else:
 *             return ''
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_getName); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        __pyx_t_5 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_10, __pyx_v_text) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_v_text);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_split); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_kp_u__64) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__64);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetSlice(__pyx_t_6, 1, -2L, NULL, NULL, &__pyx_slice__114, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = PyUnicode_Join(__pyx_kp_u__64, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
          }
        }
        __pyx_t_4 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1272, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L7_try_return;

        /* "alacorder/cal.pyx":1271
 * def getMiddleName(text):
 *     try:
 *         if len(getName(text).split(" ")) > 2:             # <<<<<<<<<<<<<<
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()
 *         else:
 */
      }

      /* "alacorder/cal.pyx":1274
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()
 *         else:
 *             return ''             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_kp_u__8);
        __pyx_r = __pyx_kp_u__8;
        goto __pyx_L7_try_return;
      }

      /* "alacorder/cal.pyx":1270
 *         return ''
 * def getMiddleName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         if len(getName(text).split(" ")) > 2:
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "alacorder/cal.pyx":1275
 *         else:
 *             return ''
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getRelatedCases(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getMiddleName", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_6) < 0) __PYX_ERR(0, 1275, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_6);

      /* "alacorder/cal.pyx":1276
 *             return ''
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getRelatedCases(text):
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1270
 *         return ''
 * def getMiddleName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         if len(getName(text).split(" ")) > 2:
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1269
 *     except:
 *         return ''
 * def getMiddleName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         if len(getName(text).split(" ")) > 2:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getMiddleName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1277
 *     except:
 *         return ''
 * def getRelatedCases(text):             # <<<<<<<<<<<<<<
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_101getRelatedCases(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_101getRelatedCases = {"getRelatedCases", (PyCFunction)__pyx_pw_9alacorder_3cal_101getRelatedCases, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_101getRelatedCases(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getRelatedCases (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_100getRelatedCases(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_100getRelatedCases(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getRelatedCases", 0);

  /* "alacorder/cal.pyx":1278
 *         return ''
 * def getRelatedCases(text):
 *     return re.findall(r'(\w{2}\d{12})',str(text))             # <<<<<<<<<<<<<<
 * def getFilingDate(text):
 *     try:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_re); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_findall); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 1278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_w_2_d_12, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_u_w_2_d_12, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_u_w_2_d_12);
    __Pyx_GIVEREF(__pyx_kp_u_w_2_d_12);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_u_w_2_d_12);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1278, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "alacorder/cal.pyx":1277
 *     except:
 *         return ''
 * def getRelatedCases(text):             # <<<<<<<<<<<<<<
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("alacorder.cal.getRelatedCases", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1279
 * def getRelatedCases(text):
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_103getFilingDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_103getFilingDate = {"getFilingDate", (PyCFunction)__pyx_pw_9alacorder_3cal_103getFilingDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_103getFilingDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFilingDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_102getFilingDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_102getFilingDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFilingDate", 0);

  /* "alacorder/cal.pyx":1280
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1281
 * def getFilingDate(text):
 *     try:
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_8) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Filing_Date, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Filing_Date, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Filing_Date);
        __Pyx_GIVEREF(__pyx_kp_u_Filing_Date);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_Filing_Date);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1281, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1281, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1280
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1282
 *     try:
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCaseInitiationDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getFilingDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1282, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1283
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCaseInitiationDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1280
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1279
 * def getRelatedCases(text):
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getFilingDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1284
 *     except:
 *         return ''
 * def getCaseInitiationDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_105getCaseInitiationDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_105getCaseInitiationDate = {"getCaseInitiationDate", (PyCFunction)__pyx_pw_9alacorder_3cal_105getCaseInitiationDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_105getCaseInitiationDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCaseInitiationDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_104getCaseInitiationDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_104getCaseInitiationDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCaseInitiationDate", 0);

  /* "alacorder/cal.pyx":1285
 *         return ''
 * def getCaseInitiationDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1286
 * def getCaseInitiationDate(text):
 *     try:
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1286, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_kp_u_Case_Initiation_Date, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_9, __pyx_kp_u_Case_Initiation_Date, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Case_Initiation_Date);
        __Pyx_GIVEREF(__pyx_kp_u_Case_Initiation_Date);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_11, __pyx_kp_u_Case_Initiation_Date);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_11, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1286, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1285
 *         return ''
 * def getCaseInitiationDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1287
 *     try:
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getArrestDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCaseInitiationDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1287, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1288
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getArrestDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1285
 *         return ''
 * def getCaseInitiationDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1284
 *     except:
 *         return ''
 * def getCaseInitiationDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getCaseInitiationDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1289
 *     except:
 *         return ''
 * def getArrestDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_107getArrestDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_107getArrestDate = {"getArrestDate", (PyCFunction)__pyx_pw_9alacorder_3cal_107getArrestDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_107getArrestDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getArrestDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_106getArrestDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_106getArrestDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getArrestDate", 0);

  /* "alacorder/cal.pyx":1290
 *         return ''
 * def getArrestDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1291
 * def getArrestDate(text):
 *     try:
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1291, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1291, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1291, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1291, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1291, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1291, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1291, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1291, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1291, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1290
 *         return ''
 * def getArrestDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1292
 *     try:
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getOffenseDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getArrestDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1292, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1293
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getOffenseDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1290
 *         return ''
 * def getArrestDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1289
 *     except:
 *         return ''
 * def getArrestDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getArrestDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1294
 *     except:
 *         return ''
 * def getOffenseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_109getOffenseDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_109getOffenseDate = {"getOffenseDate", (PyCFunction)__pyx_pw_9alacorder_3cal_109getOffenseDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_109getOffenseDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getOffenseDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_108getOffenseDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_108getOffenseDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getOffenseDate", 0);

  /* "alacorder/cal.pyx":1295
 *         return ''
 * def getOffenseDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1296
 * def getOffenseDate(text):
 *     try:
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1296, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1296, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1296, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1296, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1296, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1296, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1296, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1296, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1296, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1295
 *         return ''
 * def getOffenseDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1297
 *     try:
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getIndictmentDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getOffenseDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1297, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1298
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getIndictmentDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1295
 *         return ''
 * def getOffenseDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1294
 *     except:
 *         return ''
 * def getOffenseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getOffenseDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1299
 *     except:
 *         return ''
 * def getIndictmentDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_111getIndictmentDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_111getIndictmentDate = {"getIndictmentDate", (PyCFunction)__pyx_pw_9alacorder_3cal_111getIndictmentDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_111getIndictmentDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getIndictmentDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_110getIndictmentDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_110getIndictmentDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getIndictmentDate", 0);

  /* "alacorder/cal.pyx":1300
 *         return ''
 * def getIndictmentDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1301
 * def getIndictmentDate(text):
 *     try:
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1301, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1301, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1301, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1301, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1301, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1301, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1301, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1301, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1301, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1300
 *         return ''
 * def getIndictmentDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1302
 *     try:
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getYouthfulDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getIndictmentDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1302, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1303
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getYouthfulDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1300
 *         return ''
 * def getIndictmentDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1299
 *     except:
 *         return ''
 * def getIndictmentDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getIndictmentDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1304
 *     except:
 *         return ''
 * def getYouthfulDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_113getYouthfulDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_113getYouthfulDate = {"getYouthfulDate", (PyCFunction)__pyx_pw_9alacorder_3cal_113getYouthfulDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_113getYouthfulDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getYouthfulDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_112getYouthfulDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_112getYouthfulDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getYouthfulDate", 0);

  /* "alacorder/cal.pyx":1305
 *         return ''
 * def getYouthfulDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1306
 * def getYouthfulDate(text):
 *     try:
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1306, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1306, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1306, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1306, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1306, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1306, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1306, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1306, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1306, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1305
 *         return ''
 * def getYouthfulDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1307
 *     try:
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getRetrieved(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getYouthfulDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1307, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1308
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getRetrieved(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1305
 *         return ''
 * def getYouthfulDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1304
 *     except:
 *         return ''
 * def getYouthfulDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getYouthfulDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1309
 *     except:
 *         return ''
 * def getRetrieved(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_115getRetrieved(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_115getRetrieved = {"getRetrieved", (PyCFunction)__pyx_pw_9alacorder_3cal_115getRetrieved, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_115getRetrieved(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getRetrieved (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_114getRetrieved(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_114getRetrieved(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getRetrieved", 0);

  /* "alacorder/cal.pyx":1310
 *         return ''
 * def getRetrieved(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1311
 * def getRetrieved(text):
 *     try:
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1311, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1311, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1311, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1311, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1311, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1311, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1311, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1311, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1311, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1310
 *         return ''
 * def getRetrieved(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1312
 *     try:
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCourtAction(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getRetrieved", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1312, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1313
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCourtAction(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1310
 *         return ''
 * def getRetrieved(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1309
 *     except:
 *         return ''
 * def getRetrieved(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getRetrieved", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1314
 *     except:
 *         return ''
 * def getCourtAction(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_117getCourtAction(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_117getCourtAction = {"getCourtAction", (PyCFunction)__pyx_pw_9alacorder_3cal_117getCourtAction, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_117getCourtAction(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCourtAction (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_116getCourtAction(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_116getCourtAction(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCourtAction", 0);

  /* "alacorder/cal.pyx":1315
 *         return ''
 * def getCourtAction(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1316
 * def getCourtAction(text):
 *     try:
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1316, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1316, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1316, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1316, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1316, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1316, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W);
        __Pyx_GIVEREF(__pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1316, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1316, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1316, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1315
 *         return ''
 * def getCourtAction(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1317
 *     try:
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCourtActionDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCourtAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1317, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1318
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCourtActionDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1315
 *         return ''
 * def getCourtAction(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1314
 *     except:
 *         return ''
 * def getCourtAction(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getCourtAction", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1319
 *     except:
 *         return ''
 * def getCourtActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_119getCourtActionDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_119getCourtActionDate = {"getCourtActionDate", (PyCFunction)__pyx_pw_9alacorder_3cal_119getCourtActionDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_119getCourtActionDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCourtActionDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_118getCourtActionDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_118getCourtActionDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCourtActionDate", 0);

  /* "alacorder/cal.pyx":1320
 *         return ''
 * def getCourtActionDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1321
 * def getCourtActionDate(text):
 *     try:
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1321, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_search); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1321, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1321, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      __pyx_t_9 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_9 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1321, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[3] = {__pyx_t_8, __pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1321, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1321, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_10);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_10, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1321, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_group); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1321, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_5, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1321, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1320
 *         return ''
 * def getCourtActionDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "alacorder/cal.pyx":1322
 *     try:
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDescription(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCourtActionDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1322, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1323
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDescription(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1320
 *         return ''
 * def getCourtActionDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1319
 *     except:
 *         return ''
 * def getCourtActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("alacorder.cal.getCourtActionDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1324
 *     except:
 *         return ''
 * def getDescription(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_121getDescription(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_121getDescription = {"getDescription", (PyCFunction)__pyx_pw_9alacorder_3cal_121getDescription, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_121getDescription(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDescription (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_120getDescription(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_120getDescription(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDescription", 0);

  /* "alacorder/cal.pyx":1325
 *         return ''
 * def getDescription(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1326
 * def getDescription(text):
 *     try:
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Charge_A_Z_0_9_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1326, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Charge_A_Z_0_9_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1326, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1326, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Charge_A_Z_0_9_s);
        __Pyx_GIVEREF(__pyx_kp_u_Charge_A_Z_0_9_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Charge_A_Z_0_9_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1326, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_C_2) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_C_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1326, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1325
 *         return ''
 * def getDescription(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1327
 *     try:
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getJuryDemand(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDescription", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1327, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1328
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getJuryDemand(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1325
 *         return ''
 * def getDescription(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1324
 *     except:
 *         return ''
 * def getDescription(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getDescription", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1329
 *     except:
 *         return ''
 * def getJuryDemand(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_123getJuryDemand(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_123getJuryDemand = {"getJuryDemand", (PyCFunction)__pyx_pw_9alacorder_3cal_123getJuryDemand, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_123getJuryDemand(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getJuryDemand (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_122getJuryDemand(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_122getJuryDemand(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getJuryDemand", 0);

  /* "alacorder/cal.pyx":1330
 *         return ''
 * def getJuryDemand(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1331
 * def getJuryDemand(text):
 *     try:
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Jury_Demand_A_Z, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1331, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Jury_Demand_A_Z, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1331, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1331, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Jury_Demand_A_Z);
        __Pyx_GIVEREF(__pyx_kp_u_Jury_Demand_A_Z);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Jury_Demand_A_Z);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1331, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1331, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1330
 *         return ''
 * def getJuryDemand(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1332
 *     try:
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getInpatientTreatmentOrdered(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getJuryDemand", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1332, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1333
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getInpatientTreatmentOrdered(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1330
 *         return ''
 * def getJuryDemand(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1329
 *     except:
 *         return ''
 * def getJuryDemand(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getJuryDemand", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1334
 *     except:
 *         return ''
 * def getInpatientTreatmentOrdered(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_125getInpatientTreatmentOrdered(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_125getInpatientTreatmentOrdered = {"getInpatientTreatmentOrdered", (PyCFunction)__pyx_pw_9alacorder_3cal_125getInpatientTreatmentOrdered, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_125getInpatientTreatmentOrdered(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getInpatientTreatmentOrdered (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_124getInpatientTreatmentOrdered(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_124getInpatientTreatmentOrdered(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getInpatientTreatmentOrdered", 0);

  /* "alacorder/cal.pyx":1335
 *         return ''
 * def getInpatientTreatmentOrdered(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1336
 * def getInpatientTreatmentOrdered(text):
 *     try:
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Inpatient_Treatment_Ordered_YES, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1336, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Inpatient_Treatment_Ordered_YES, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1336, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1336, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Inpatient_Treatment_Ordered_YES);
        __Pyx_GIVEREF(__pyx_kp_u_Inpatient_Treatment_Ordered_YES);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Inpatient_Treatment_Ordered_YES);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1336, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1336, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1335
 *         return ''
 * def getInpatientTreatmentOrdered(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1337
 *     try:
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getTrialType(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getInpatientTreatmentOrdered", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1337, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1338
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getTrialType(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1335
 *         return ''
 * def getInpatientTreatmentOrdered(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1334
 *     except:
 *         return ''
 * def getInpatientTreatmentOrdered(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getInpatientTreatmentOrdered", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1339
 *     except:
 *         return ''
 * def getTrialType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_127getTrialType(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_127getTrialType = {"getTrialType", (PyCFunction)__pyx_pw_9alacorder_3cal_127getTrialType, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_127getTrialType(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTrialType (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_126getTrialType(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_126getTrialType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTrialType", 0);

  /* "alacorder/cal.pyx":1340
 *         return ''
 * def getTrialType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1341
 * def getTrialType(text):
 *     try:
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Trial_Type_A_Z, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Trial_Type_A_Z, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Trial_Type_A_Z);
        __Pyx_GIVEREF(__pyx_kp_u_Trial_Type_A_Z);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Trial_Type_A_Z);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_S_N, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_S_N, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_S_N);
        __Pyx_GIVEREF(__pyx_kp_u_S_N);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_S_N);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1341, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1341, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1340
 *         return ''
 * def getTrialType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1342
 *     try:
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getJudge(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTrialType", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1342, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1343
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getJudge(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1340
 *         return ''
 * def getTrialType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1339
 *     except:
 *         return ''
 * def getTrialType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getTrialType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1344
 *     except:
 *         return ''
 * def getJudge(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_129getJudge(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_129getJudge = {"getJudge", (PyCFunction)__pyx_pw_9alacorder_3cal_129getJudge, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_129getJudge(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getJudge (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_128getJudge(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_128getJudge(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getJudge", 0);

  /* "alacorder/cal.pyx":1345
 *         return ''
 * def getJudge(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1346
 * def getJudge(text):
 *     try:
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Judge_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1346, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Judge_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1346, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1346, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Judge_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Judge_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Judge_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1346, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_T) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_T);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1346, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1345
 *         return ''
 * def getJudge(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1347
 *     try:
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getProbationOfficeNumber(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getJudge", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1347, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1348
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getProbationOfficeNumber(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1345
 *         return ''
 * def getJudge(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1344
 *     except:
 *         return ''
 * def getJudge(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getJudge", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1349
 *     except:
 *         return ''
 * def getProbationOfficeNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_131getProbationOfficeNumber(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_131getProbationOfficeNumber = {"getProbationOfficeNumber", (PyCFunction)__pyx_pw_9alacorder_3cal_131getProbationOfficeNumber, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_131getProbationOfficeNumber(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getProbationOfficeNumber (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_130getProbationOfficeNumber(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_130getProbationOfficeNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getProbationOfficeNumber", 0);

  /* "alacorder/cal.pyx":1350
 *         return ''
 * def getProbationOfficeNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1351
 * def getProbationOfficeNumber(text):
 *     try:
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Probation_Office_0_9, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Probation_Office_0_9, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Office_0_9);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Office_0_9);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Probation_Office_0_9);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1351, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_000000_00_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_000000_00_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_0_000000_00_2);
        __Pyx_GIVEREF(__pyx_kp_u_0_000000_00_2);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_12, __pyx_kp_u_0_000000_00_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1351, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1350
 *         return ''
 * def getProbationOfficeNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1352
 *     try:
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDefendantStatus(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getProbationOfficeNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1352, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1353
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDefendantStatus(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1350
 *         return ''
 * def getProbationOfficeNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1349
 *     except:
 *         return ''
 * def getProbationOfficeNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getProbationOfficeNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1354
 *     except:
 *         return ''
 * def getDefendantStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_133getDefendantStatus(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_133getDefendantStatus = {"getDefendantStatus", (PyCFunction)__pyx_pw_9alacorder_3cal_133getDefendantStatus, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_133getDefendantStatus(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDefendantStatus (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_132getDefendantStatus(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_132getDefendantStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDefendantStatus", 0);

  /* "alacorder/cal.pyx":1355
 *         return ''
 * def getDefendantStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1356
 * def getDefendantStatus(text):
 *     try:
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Defendant_Status_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1356, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Defendant_Status_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1356, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1356, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Defendant_Status_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Defendant_Status_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Defendant_Status_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1356, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_J) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_J);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1356, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1355
 *         return ''
 * def getDefendantStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1357
 *     try:
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getArrestingAgencyType(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDefendantStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1357, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1358
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getArrestingAgencyType(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1355
 *         return ''
 * def getDefendantStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1354
 *     except:
 *         return ''
 * def getDefendantStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getDefendantStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1359
 *     except:
 *         return ''
 * def getArrestingAgencyType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_135getArrestingAgencyType(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_135getArrestingAgencyType = {"getArrestingAgencyType", (PyCFunction)__pyx_pw_9alacorder_3cal_135getArrestingAgencyType, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_135getArrestingAgencyType(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getArrestingAgencyType (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_134getArrestingAgencyType(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_134getArrestingAgencyType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getArrestingAgencyType", 0);

  /* "alacorder/cal.pyx":1360
 *         return ''
 * def getArrestingAgencyType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1361
 * def getArrestingAgencyType(text):
 *     try:
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_0_9_Arresting_Agency_Type, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_0_9_Arresting_Agency_Type, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_0_9_Arresting_Agency_Type);
        __Pyx_GIVEREF(__pyx_kp_u_0_9_Arresting_Agency_Type);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_0_9_Arresting_Agency_Type);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n);
        __Pyx_GIVEREF(__pyx_kp_u_n);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_n);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1361, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1361, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1360
 *         return ''
 * def getArrestingAgencyType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1362
 *     try:
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getArrestingOfficer(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getArrestingAgencyType", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1362, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1363
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getArrestingOfficer(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1360
 *         return ''
 * def getArrestingAgencyType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1359
 *     except:
 *         return ''
 * def getArrestingAgencyType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getArrestingAgencyType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1364
 *     except:
 *         return ''
 * def getArrestingOfficer(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_137getArrestingOfficer(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_137getArrestingOfficer = {"getArrestingOfficer", (PyCFunction)__pyx_pw_9alacorder_3cal_137getArrestingOfficer, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_137getArrestingOfficer(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getArrestingOfficer (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_136getArrestingOfficer(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_136getArrestingOfficer(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getArrestingOfficer", 0);

  /* "alacorder/cal.pyx":1365
 *         return ''
 * def getArrestingOfficer(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1366
 * def getArrestingOfficer(text):
 *     try:
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Arresting_Officer_A_Z_s, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1366, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Arresting_Officer_A_Z_s, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1366, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1366, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Arresting_Officer_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Arresting_Officer_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Arresting_Officer_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1366, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_7, __pyx_n_u_S) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_S);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_6, __pyx_n_u_P) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_P);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1366, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1365
 *         return ''
 * def getArrestingOfficer(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1367
 *     try:
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getProbationOfficeName(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getArrestingOfficer", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_10, &__pyx_t_5) < 0) __PYX_ERR(0, 1367, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1368
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getProbationOfficeName(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1365
 *         return ''
 * def getArrestingOfficer(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1364
 *     except:
 *         return ''
 * def getArrestingOfficer(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getArrestingOfficer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1369
 *     except:
 *         return ''
 * def getProbationOfficeName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_139getProbationOfficeName(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_139getProbationOfficeName = {"getProbationOfficeName", (PyCFunction)__pyx_pw_9alacorder_3cal_139getProbationOfficeName, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_139getProbationOfficeName(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getProbationOfficeName (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_138getProbationOfficeName(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_138getProbationOfficeName(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getProbationOfficeName", 0);

  /* "alacorder/cal.pyx":1370
 *         return ''
 * def getProbationOfficeName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1371
 * def getProbationOfficeName(text):
 *     try:
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Probation_Office_Name_A_Z0_9, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1371, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Probation_Office_Name_A_Z0_9, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1371, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1371, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Office_Name_A_Z0_9);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Office_Name_A_Z0_9);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Probation_Office_Name_A_Z0_9);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1371, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1371, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1370
 *         return ''
 * def getProbationOfficeName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1372
 *     try:
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getTrafficCitationNumber(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getProbationOfficeName", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1372, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1373
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getTrafficCitationNumber(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1370
 *         return ''
 * def getProbationOfficeName(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1369
 *     except:
 *         return ''
 * def getProbationOfficeName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getProbationOfficeName", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1374
 *     except:
 *         return ''
 * def getTrafficCitationNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_141getTrafficCitationNumber(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_141getTrafficCitationNumber = {"getTrafficCitationNumber", (PyCFunction)__pyx_pw_9alacorder_3cal_141getTrafficCitationNumber, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_141getTrafficCitationNumber(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTrafficCitationNumber (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_140getTrafficCitationNumber(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_140getTrafficCitationNumber(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTrafficCitationNumber", 0);

  /* "alacorder/cal.pyx":1375
 *         return ''
 * def getTrafficCitationNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1376
 * def getTrafficCitationNumber(text):
 *     try:
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Traffic_Citation_A_Z0_9, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1376, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Traffic_Citation_A_Z0_9, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1376, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1376, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Traffic_Citation_A_Z0_9);
        __Pyx_GIVEREF(__pyx_kp_u_Traffic_Citation_A_Z0_9);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Traffic_Citation_A_Z0_9);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1376, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1376, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1375
 *         return ''
 * def getTrafficCitationNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1377
 *     try:
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getPreviousDUIConvictions(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTrafficCitationNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1377, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1378
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getPreviousDUIConvictions(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1375
 *         return ''
 * def getTrafficCitationNumber(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1374
 *     except:
 *         return ''
 * def getTrafficCitationNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getTrafficCitationNumber", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1379
 *     except:
 *         return ''
 * def getPreviousDUIConvictions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_143getPreviousDUIConvictions(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_143getPreviousDUIConvictions = {"getPreviousDUIConvictions", (PyCFunction)__pyx_pw_9alacorder_3cal_143getPreviousDUIConvictions, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_143getPreviousDUIConvictions(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getPreviousDUIConvictions (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_142getPreviousDUIConvictions(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_142getPreviousDUIConvictions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getPreviousDUIConvictions", 0);

  /* "alacorder/cal.pyx":1380
 *         return ''
 * def getPreviousDUIConvictions(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1381
 * def getPreviousDUIConvictions(text):
 *     try:
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Previous_DUI_Convictions_d_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1381, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Previous_DUI_Convictions_d_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1381, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1381, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Previous_DUI_Convictions_d_3);
        __Pyx_GIVEREF(__pyx_kp_u_Previous_DUI_Convictions_d_3);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Previous_DUI_Convictions_d_3);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1381, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1381, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1380
 *         return ''
 * def getPreviousDUIConvictions(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1382
 *     try:
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCaseInitiationType(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getPreviousDUIConvictions", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1382, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1383
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCaseInitiationType(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1380
 *         return ''
 * def getPreviousDUIConvictions(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1379
 *     except:
 *         return ''
 * def getPreviousDUIConvictions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getPreviousDUIConvictions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1384
 *     except:
 *         return ''
 * def getCaseInitiationType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_145getCaseInitiationType(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_145getCaseInitiationType = {"getCaseInitiationType", (PyCFunction)__pyx_pw_9alacorder_3cal_145getCaseInitiationType, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_145getCaseInitiationType(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCaseInitiationType (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_144getCaseInitiationType(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_144getCaseInitiationType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCaseInitiationType", 0);

  /* "alacorder/cal.pyx":1385
 *         return ''
 * def getCaseInitiationType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1386
 * def getCaseInitiationType(text):
 *     try:
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Case_Initiation_Type_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1386, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Case_Initiation_Type_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1386, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1386, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Case_Initiation_Type_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Case_Initiation_Type_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Case_Initiation_Type_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1386, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_J) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_J);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1386, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1385
 *         return ''
 * def getCaseInitiationType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1387
 *     try:
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDomesticViolence(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCaseInitiationType", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1387, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1388
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDomesticViolence(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1385
 *         return ''
 * def getCaseInitiationType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1384
 *     except:
 *         return ''
 * def getCaseInitiationType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getCaseInitiationType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1389
 *     except:
 *         return ''
 * def getDomesticViolence(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_147getDomesticViolence(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_147getDomesticViolence = {"getDomesticViolence", (PyCFunction)__pyx_pw_9alacorder_3cal_147getDomesticViolence, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_147getDomesticViolence(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDomesticViolence (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_146getDomesticViolence(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_146getDomesticViolence(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDomesticViolence", 0);

  /* "alacorder/cal.pyx":1390
 *         return ''
 * def getDomesticViolence(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1391
 * def getDomesticViolence(text):
 *     try:
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Domestic_Violence_YES_NO, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1391, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Domestic_Violence_YES_NO, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1391, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1391, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Domestic_Violence_YES_NO);
        __Pyx_GIVEREF(__pyx_kp_u_Domestic_Violence_YES_NO);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Domestic_Violence_YES_NO);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1391, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1391, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1390
 *         return ''
 * def getDomesticViolence(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1392
 *     try:
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAgencyORI(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDomesticViolence", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1392, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1393
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAgencyORI(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1390
 *         return ''
 * def getDomesticViolence(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1389
 *     except:
 *         return ''
 * def getDomesticViolence(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getDomesticViolence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1394
 *     except:
 *         return ''
 * def getAgencyORI(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_149getAgencyORI(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_149getAgencyORI = {"getAgencyORI", (PyCFunction)__pyx_pw_9alacorder_3cal_149getAgencyORI, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_149getAgencyORI(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAgencyORI (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_148getAgencyORI(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_148getAgencyORI(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAgencyORI", 0);

  /* "alacorder/cal.pyx":1395
 *         return ''
 * def getAgencyORI(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1396
 * def getAgencyORI(text):
 *     try:
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Agency_ORI_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1396, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Agency_ORI_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1396, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1396, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Agency_ORI_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Agency_ORI_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Agency_ORI_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1396, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_C_2) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_C_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1396, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1395
 *         return ''
 * def getAgencyORI(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1397
 *     try:
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDriverLicenseNo(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAgencyORI", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1397, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1398
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDriverLicenseNo(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1395
 *         return ''
 * def getAgencyORI(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1394
 *     except:
 *         return ''
 * def getAgencyORI(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getAgencyORI", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1399
 *     except:
 *         return ''
 * def getDriverLicenseNo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_151getDriverLicenseNo(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_151getDriverLicenseNo = {"getDriverLicenseNo", (PyCFunction)__pyx_pw_9alacorder_3cal_151getDriverLicenseNo, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_151getDriverLicenseNo(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDriverLicenseNo (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_150getDriverLicenseNo(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_150getDriverLicenseNo(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDriverLicenseNo", 0);

  /* "alacorder/cal.pyx":1400
 *         return ''
 * def getDriverLicenseNo(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 *         if m == "AL":
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1401
 * def getDriverLicenseNo(text):
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *         if m == "AL":
 *             return ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Driver_License_N_A_Z0_9, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1401, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Driver_License_N_A_Z0_9, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1401, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1401, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Driver_License_N_A_Z0_9);
        __Pyx_GIVEREF(__pyx_kp_u_Driver_License_N_A_Z0_9);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Driver_License_N_A_Z0_9);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1401, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1401, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_m = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1402
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 *         if m == "AL":             # <<<<<<<<<<<<<<
 *             return ''
 *         else:
 */
      __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_m, __pyx_n_u_AL, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 1402, __pyx_L3_error)
      if (__pyx_t_12) {

        /* "alacorder/cal.pyx":1403
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 *         if m == "AL":
 *             return ''             # <<<<<<<<<<<<<<
 *         else:
 *             return m
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_kp_u__8);
        __pyx_r = __pyx_kp_u__8;
        goto __pyx_L7_try_return;

        /* "alacorder/cal.pyx":1402
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 *         if m == "AL":             # <<<<<<<<<<<<<<
 *             return ''
 *         else:
 */
      }

      /* "alacorder/cal.pyx":1405
 *             return ''
 *         else:
 *             return m             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_m);
        __pyx_r = __pyx_v_m;
        goto __pyx_L7_try_return;
      }

      /* "alacorder/cal.pyx":1400
 *         return ''
 * def getDriverLicenseNo(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 *         if m == "AL":
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1406
 *         else:
 *             return m
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSSN(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDriverLicenseNo", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1406, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1407
 *             return m
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSSN(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1400
 *         return ''
 * def getDriverLicenseNo(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 *         if m == "AL":
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1399
 *     except:
 *         return ''
 * def getDriverLicenseNo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getDriverLicenseNo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1408
 *     except:
 *         return ''
 * def getSSN(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_153getSSN(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_153getSSN = {"getSSN", (PyCFunction)__pyx_pw_9alacorder_3cal_153getSSN, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_153getSSN(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSSN (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_152getSSN(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_152getSSN(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSSN", 0);

  /* "alacorder/cal.pyx":1409
 *         return ''
 * def getSSN(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1410
 * def getSSN(text):
 *     try:
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1410, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1410, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1410, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4);
        __Pyx_GIVEREF(__pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1410, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1410, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1409
 *         return ''
 * def getSSN(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1411
 *     try:
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getStateID(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSSN", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1411, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1412
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getStateID(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1409
 *         return ''
 * def getSSN(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1408
 *     except:
 *         return ''
 * def getSSN(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getSSN", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1413
 *     except:
 *         return ''
 * def getStateID(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_155getStateID(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_155getStateID = {"getStateID", (PyCFunction)__pyx_pw_9alacorder_3cal_155getStateID, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_155getStateID(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getStateID (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_154getStateID(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_154getStateID(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getStateID", 0);

  /* "alacorder/cal.pyx":1414
 *         return ''
 * def getStateID(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 *         if m == "AL000000000":
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1415
 * def getStateID(text):
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *         if m == "AL000000000":
 *             return ''
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_A_Z0_9_11_State_ID, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1415, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_A_Z0_9_11_State_ID, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1415, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1415, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_A_Z0_9_11_State_ID);
        __Pyx_GIVEREF(__pyx_kp_u_A_Z0_9_11_State_ID);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_A_Z0_9_11_State_ID);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1415, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1415, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_m = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "alacorder/cal.pyx":1416
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 *         if m == "AL000000000":             # <<<<<<<<<<<<<<
 *             return ''
 *         else:
 */
      __pyx_t_12 = (__Pyx_PyUnicode_Equals(__pyx_v_m, __pyx_n_u_AL000000000, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 1416, __pyx_L3_error)
      if (__pyx_t_12) {

        /* "alacorder/cal.pyx":1417
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 *         if m == "AL000000000":
 *             return ''             # <<<<<<<<<<<<<<
 *         else:
 *             return m
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_kp_u__8);
        __pyx_r = __pyx_kp_u__8;
        goto __pyx_L7_try_return;

        /* "alacorder/cal.pyx":1416
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 *         if m == "AL000000000":             # <<<<<<<<<<<<<<
 *             return ''
 *         else:
 */
      }

      /* "alacorder/cal.pyx":1419
 *             return ''
 *         else:
 *             return m             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      /*else*/ {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_m);
        __pyx_r = __pyx_v_m;
        goto __pyx_L7_try_return;
      }

      /* "alacorder/cal.pyx":1414
 *         return ''
 * def getStateID(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 *         if m == "AL000000000":
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1420
 *         else:
 *             return m
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getWeight(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getStateID", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1420, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1421
 *             return m
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getWeight(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1414
 *         return ''
 * def getStateID(text):
 *     try:             # <<<<<<<<<<<<<<
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 *         if m == "AL000000000":
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1413
 *     except:
 *         return ''
 * def getStateID(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getStateID", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1422
 *     except:
 *         return ''
 * def getWeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_157getWeight(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_157getWeight = {"getWeight", (PyCFunction)__pyx_pw_9alacorder_3cal_157getWeight, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_157getWeight(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWeight (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_156getWeight(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_156getWeight(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWeight", 0);

  /* "alacorder/cal.pyx":1423
 *         return ''
 * def getWeight(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1424
 * def getWeight(text):
 *     try:
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Weight_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1424, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Weight_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1424, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1424, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Weight_d);
        __Pyx_GIVEREF(__pyx_kp_u_Weight_d);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Weight_d);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1424, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1424, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1423
 *         return ''
 * def getWeight(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1425
 *     try:
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getHeight(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getWeight", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1425, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1426
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getHeight(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1423
 *         return ''
 * def getWeight(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1422
 *     except:
 *         return ''
 * def getWeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getWeight", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1427
 *     except:
 *         return ''
 * def getHeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_159getHeight(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_159getHeight = {"getHeight", (PyCFunction)__pyx_pw_9alacorder_3cal_159getHeight, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_159getHeight(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getHeight (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_158getHeight(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_158getHeight(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getHeight", 0);

  /* "alacorder/cal.pyx":1428
 *         return ''
 * def getHeight(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1429
 * def getHeight(text):
 *     try:
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Height_d_d_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Height_d_d_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Height_d_d_2);
        __Pyx_GIVEREF(__pyx_kp_u_Height_d_d_2);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Height_d_d_2);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1429, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyNumber_Add(__pyx_t_4, __pyx_kp_u__51); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1429, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1428
 *         return ''
 * def getHeight(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1430
 *     try:
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getEyes(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getHeight", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1430, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1431
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getEyes(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1428
 *         return ''
 * def getHeight(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1427
 *     except:
 *         return ''
 * def getHeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getHeight", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1432
 *     except:
 *         return ''
 * def getEyes(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_161getEyes(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_161getEyes = {"getEyes", (PyCFunction)__pyx_pw_9alacorder_3cal_161getEyes, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_161getEyes(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getEyes (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_160getEyes(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_160getEyes(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getEyes", 0);

  /* "alacorder/cal.pyx":1433
 *         return ''
 * def getEyes(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1434
 * def getEyes(text):
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Eyes_Hair_w_3_w_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1434, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Eyes_Hair_w_3_w_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1434, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1434, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Eyes_Hair_w_3_w_3);
        __Pyx_GIVEREF(__pyx_kp_u_Eyes_Hair_w_3_w_3);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Eyes_Hair_w_3_w_3);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1434, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1434, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1433
 *         return ''
 * def getEyes(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1435
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getHair(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getEyes", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1435, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1436
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getHair(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1433
 *         return ''
 * def getEyes(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1432
 *     except:
 *         return ''
 * def getEyes(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getEyes", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1437
 *     except:
 *         return ''
 * def getHair(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_163getHair(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_163getHair = {"getHair", (PyCFunction)__pyx_pw_9alacorder_3cal_163getHair, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_163getHair(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getHair (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_162getHair(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_162getHair(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getHair", 0);

  /* "alacorder/cal.pyx":1438
 *         return ''
 * def getHair(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1439
 * def getHair(text):
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Eyes_Hair_w_3_w_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1439, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Eyes_Hair_w_3_w_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1439, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1439, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Eyes_Hair_w_3_w_3);
        __Pyx_GIVEREF(__pyx_kp_u_Eyes_Hair_w_3_w_3);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Eyes_Hair_w_3_w_3);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1439, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1439, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1438
 *         return ''
 * def getHair(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1440
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getCountry(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getHair", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1440, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1441
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getCountry(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1438
 *         return ''
 * def getHair(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1437
 *     except:
 *         return ''
 * def getHair(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getHair", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1442
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_165getCountry(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_165getCountry = {"getCountry", (PyCFunction)__pyx_pw_9alacorder_3cal_165getCountry, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_165getCountry(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getCountry (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_164getCountry(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_164getCountry(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getCountry", 0);

  /* "alacorder/cal.pyx":1443
 *         return ''
 * def getCountry(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1444
 * def getCountry(text):
 *     try:
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Country_w, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Country_w, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Country_w);
        __Pyx_GIVEREF(__pyx_kp_u_Country_w);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Country_w);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1444, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Enforcement_Party_Country_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_Enforcement_Party_Country_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Enforcement_Party_Country_2);
        __Pyx_GIVEREF(__pyx_kp_u_Enforcement_Party_Country_2);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_12, __pyx_kp_u_Enforcement_Party_Country_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1444, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1443
 *         return ''
 * def getCountry(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1445
 *     try:
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getWarrantIssuanceDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getCountry", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1445, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1446
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getWarrantIssuanceDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1443
 *         return ''
 * def getCountry(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1442
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getCountry", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1447
 *     except:
 *         return ''
 * def getWarrantIssuanceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_167getWarrantIssuanceDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_167getWarrantIssuanceDate = {"getWarrantIssuanceDate", (PyCFunction)__pyx_pw_9alacorder_3cal_167getWarrantIssuanceDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_167getWarrantIssuanceDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWarrantIssuanceDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_166getWarrantIssuanceDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_166getWarrantIssuanceDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWarrantIssuanceDate", 0);

  /* "alacorder/cal.pyx":1448
 *         return ''
 * def getWarrantIssuanceDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1449
 * def getWarrantIssuanceDate(text):
 *     try:
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1449, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1449, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1449, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc);
        __Pyx_GIVEREF(__pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1449, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1449, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1448
 *         return ''
 * def getWarrantIssuanceDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1450
 *     try:
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getWarrantActionDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getWarrantIssuanceDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1450, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1451
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getWarrantActionDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1448
 *         return ''
 * def getWarrantIssuanceDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1447
 *     except:
 *         return ''
 * def getWarrantIssuanceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getWarrantIssuanceDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1452
 *     except:
 *         return ''
 * def getWarrantActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_169getWarrantActionDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_169getWarrantActionDate = {"getWarrantActionDate", (PyCFunction)__pyx_pw_9alacorder_3cal_169getWarrantActionDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_169getWarrantActionDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWarrantActionDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_168getWarrantActionDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_168getWarrantActionDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWarrantActionDate", 0);

  /* "alacorder/cal.pyx":1453
 *         return ''
 * def getWarrantActionDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1454
 * def getWarrantActionDate(text):
 *     try:
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1454, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1454, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1454, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1454, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1454, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1453
 *         return ''
 * def getWarrantActionDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1455
 *     try:
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getWarrantIssuanceStatus(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getWarrantActionDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1455, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1456
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getWarrantIssuanceStatus(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1453
 *         return ''
 * def getWarrantActionDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1452
 *     except:
 *         return ''
 * def getWarrantActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getWarrantActionDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1457
 *     except:
 *         return ''
 * def getWarrantIssuanceStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_171getWarrantIssuanceStatus(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_171getWarrantIssuanceStatus = {"getWarrantIssuanceStatus", (PyCFunction)__pyx_pw_9alacorder_3cal_171getWarrantIssuanceStatus, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_171getWarrantIssuanceStatus(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWarrantIssuanceStatus (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_170getWarrantIssuanceStatus(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_170getWarrantIssuanceStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWarrantIssuanceStatus", 0);

  /* "alacorder/cal.pyx":1458
 *         return ''
 * def getWarrantIssuanceStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1459
 * def getWarrantIssuanceStatus(text):
 *     try:
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Issuance_Status_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1459, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Issuance_Status_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1459, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1459, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Warrant_Issuance_Status_w);
        __Pyx_GIVEREF(__pyx_kp_u_Warrant_Issuance_Status_w);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Warrant_Issuance_Status_w);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1459, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1459, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1458
 *         return ''
 * def getWarrantIssuanceStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1460
 *     try:
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getWarrantActionStatus(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getWarrantIssuanceStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1460, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1461
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getWarrantActionStatus(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1458
 *         return ''
 * def getWarrantIssuanceStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1457
 *     except:
 *         return ''
 * def getWarrantIssuanceStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getWarrantIssuanceStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1462
 *     except:
 *         return ''
 * def getWarrantActionStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_173getWarrantActionStatus(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_173getWarrantActionStatus = {"getWarrantActionStatus", (PyCFunction)__pyx_pw_9alacorder_3cal_173getWarrantActionStatus, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_173getWarrantActionStatus(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWarrantActionStatus (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_172getWarrantActionStatus(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_172getWarrantActionStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWarrantActionStatus", 0);

  /* "alacorder/cal.pyx":1463
 *         return ''
 * def getWarrantActionStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1464
 * def getWarrantActionStatus(text):
 *     try:
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Action_Status_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1464, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Action_Status_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1464, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1464, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Warrant_Action_Status_w);
        __Pyx_GIVEREF(__pyx_kp_u_Warrant_Action_Status_w);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Warrant_Action_Status_w);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1464, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1464, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1463
 *         return ''
 * def getWarrantActionStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1465
 *     try:
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getWarrantLocationStatus(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getWarrantActionStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1465, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1466
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getWarrantLocationStatus(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1463
 *         return ''
 * def getWarrantActionStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1462
 *     except:
 *         return ''
 * def getWarrantActionStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getWarrantActionStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1467
 *     except:
 *         return ''
 * def getWarrantLocationStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_175getWarrantLocationStatus(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_175getWarrantLocationStatus = {"getWarrantLocationStatus", (PyCFunction)__pyx_pw_9alacorder_3cal_175getWarrantLocationStatus, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_175getWarrantLocationStatus(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getWarrantLocationStatus (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_174getWarrantLocationStatus(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_174getWarrantLocationStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getWarrantLocationStatus", 0);

  /* "alacorder/cal.pyx":1468
 *         return ''
 * def getWarrantLocationStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1469
 * def getWarrantLocationStatus(text):
 *     try:
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Location_Status_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1469, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Warrant_Location_Status_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1469, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1469, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Warrant_Location_Status_w);
        __Pyx_GIVEREF(__pyx_kp_u_Warrant_Location_Status_w);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Warrant_Location_Status_w);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1469, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1469, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1468
 *         return ''
 * def getWarrantLocationStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1470
 *     try:
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getNumberOfWarrants(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getWarrantLocationStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1470, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1471
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getNumberOfWarrants(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1468
 *         return ''
 * def getWarrantLocationStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1467
 *     except:
 *         return ''
 * def getWarrantLocationStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getWarrantLocationStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1472
 *     except:
 *         return ''
 * def getNumberOfWarrants(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_177getNumberOfWarrants(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_177getNumberOfWarrants = {"getNumberOfWarrants", (PyCFunction)__pyx_pw_9alacorder_3cal_177getNumberOfWarrants, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_177getNumberOfWarrants(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumberOfWarrants (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_176getNumberOfWarrants(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_176getNumberOfWarrants(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumberOfWarrants", 0);

  /* "alacorder/cal.pyx":1473
 *         return ''
 * def getNumberOfWarrants(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1474
 * def getNumberOfWarrants(text):
 *     try:
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Number_Of_Warrants_d_3_s_d_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1474, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Number_Of_Warrants_d_3_s_d_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1474, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1474, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Number_Of_Warrants_d_3_s_d_3);
        __Pyx_GIVEREF(__pyx_kp_u_Number_Of_Warrants_d_3_s_d_3);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Number_Of_Warrants_d_3_s_d_3);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1474, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1474, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1473
 *         return ''
 * def getNumberOfWarrants(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1475
 *     try:
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getBondType(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getNumberOfWarrants", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1475, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1476
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getBondType(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1473
 *         return ''
 * def getNumberOfWarrants(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1472
 *     except:
 *         return ''
 * def getNumberOfWarrants(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getNumberOfWarrants", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1477
 *     except:
 *         return ''
 * def getBondType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_179getBondType(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_179getBondType = {"getBondType", (PyCFunction)__pyx_pw_9alacorder_3cal_179getBondType, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_179getBondType(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getBondType (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_178getBondType(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_178getBondType(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getBondType", 0);

  /* "alacorder/cal.pyx":1478
 *         return ''
 * def getBondType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1479
 * def getBondType(text):
 *     try:
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bond_Type_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1479, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bond_Type_w, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1479, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1479, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Bond_Type_w);
        __Pyx_GIVEREF(__pyx_kp_u_Bond_Type_w);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Bond_Type_w);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1479, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1479, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1478
 *         return ''
 * def getBondType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1480
 *     try:
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getBondTypeDesc(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getBondType", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1480, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1481
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getBondTypeDesc(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1478
 *         return ''
 * def getBondType(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1477
 *     except:
 *         return ''
 * def getBondType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getBondType", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1482
 *     except:
 *         return ''
 * def getBondTypeDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_181getBondTypeDesc(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_181getBondTypeDesc = {"getBondTypeDesc", (PyCFunction)__pyx_pw_9alacorder_3cal_181getBondTypeDesc, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_181getBondTypeDesc(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getBondTypeDesc (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_180getBondTypeDesc(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_180getBondTypeDesc(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getBondTypeDesc", 0);

  /* "alacorder/cal.pyx":1483
 *         return ''
 * def getBondTypeDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1484
 * def getBondTypeDesc(text):
 *     try:
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bond_Type_Desc_A_Z_s, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1484, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bond_Type_Desc_A_Z_s, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1484, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1484, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Bond_Type_Desc_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Bond_Type_Desc_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Bond_Type_Desc_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1484, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1484, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1483
 *         return ''
 * def getBondTypeDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1485
 *     try:
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getBondAmt(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getBondTypeDesc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1485, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1486
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getBondAmt(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1483
 *         return ''
 * def getBondTypeDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1482
 *     except:
 *         return ''
 * def getBondTypeDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getBondTypeDesc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1487
 *     except:
 *         return ''
 * def getBondAmt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_183getBondAmt(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_183getBondAmt = {"getBondAmt", (PyCFunction)__pyx_pw_9alacorder_3cal_183getBondAmt, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_183getBondAmt(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getBondAmt (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_182getBondAmt(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_182getBondAmt(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getBondAmt", 0);

  /* "alacorder/cal.pyx":1488
 *         return ''
 * def getBondAmt(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1489
 * def getBondAmt(text):
 *     try:
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_d_Bond_Amount, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_d_Bond_Amount, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_d_Bond_Amount);
        __Pyx_GIVEREF(__pyx_kp_u_d_Bond_Amount);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_d_Bond_Amount);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_9_s_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_0_9_s_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_0_9_s_2);
        __Pyx_GIVEREF(__pyx_kp_u_0_9_s_2);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_12, __pyx_kp_u_0_9_s_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1489, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyNumber_Float(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1489, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1488
 *         return ''
 * def getBondAmt(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1490
 *     try:
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSuretyCode(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getBondAmt", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 1490, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1491
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSuretyCode(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1488
 *         return ''
 * def getBondAmt(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1487
 *     except:
 *         return ''
 * def getBondAmt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getBondAmt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1492
 *     except:
 *         return ''
 * def getSuretyCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_185getSuretyCode(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_185getSuretyCode = {"getSuretyCode", (PyCFunction)__pyx_pw_9alacorder_3cal_185getSuretyCode, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_185getSuretyCode(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSuretyCode (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_184getSuretyCode(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_184getSuretyCode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSuretyCode", 0);

  /* "alacorder/cal.pyx":1493
 *         return ''
 * def getSuretyCode(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1494
 * def getSuretyCode(text):
 *     try:
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Surety_Code_A_Z0_9_4, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1494, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Surety_Code_A_Z0_9_4, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1494, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1494, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Surety_Code_A_Z0_9_4);
        __Pyx_GIVEREF(__pyx_kp_u_Surety_Code_A_Z0_9_4);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Surety_Code_A_Z0_9_4);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1494, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1494, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1493
 *         return ''
 * def getSuretyCode(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1495
 *     try:
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getBondReleaseDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSuretyCode", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1495, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1496
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getBondReleaseDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1493
 *         return ''
 * def getSuretyCode(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1492
 *     except:
 *         return ''
 * def getSuretyCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getSuretyCode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1497
 *     except:
 *         return ''
 * def getBondReleaseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_187getBondReleaseDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_187getBondReleaseDate = {"getBondReleaseDate", (PyCFunction)__pyx_pw_9alacorder_3cal_187getBondReleaseDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_187getBondReleaseDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getBondReleaseDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_186getBondReleaseDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_186getBondReleaseDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getBondReleaseDate", 0);

  /* "alacorder/cal.pyx":1498
 *         return ''
 * def getBondReleaseDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1499
 * def getBondReleaseDate(text):
 *     try:
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1499, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1499, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1499, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1499, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1499, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1498
 *         return ''
 * def getBondReleaseDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1500
 *     try:
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getFailedToAppearDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getBondReleaseDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1500, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1501
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getFailedToAppearDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1498
 *         return ''
 * def getBondReleaseDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1497
 *     except:
 *         return ''
 * def getBondReleaseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getBondReleaseDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1502
 *     except:
 *         return ''
 * def getFailedToAppearDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_189getFailedToAppearDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_189getFailedToAppearDate = {"getFailedToAppearDate", (PyCFunction)__pyx_pw_9alacorder_3cal_189getFailedToAppearDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_189getFailedToAppearDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFailedToAppearDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_188getFailedToAppearDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_188getFailedToAppearDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFailedToAppearDate", 0);

  /* "alacorder/cal.pyx":1503
 *         return ''
 * def getFailedToAppearDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1504
 * def getFailedToAppearDate(text):
 *     try:
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1504, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1504, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1504, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1504, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1504, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1503
 *         return ''
 * def getFailedToAppearDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1505
 *     try:
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getBondsmanProcessIssuance(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getFailedToAppearDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1505, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1506
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getBondsmanProcessIssuance(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1503
 *         return ''
 * def getFailedToAppearDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1502
 *     except:
 *         return ''
 * def getFailedToAppearDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getFailedToAppearDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1507
 *     except:
 *         return ''
 * def getBondsmanProcessIssuance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_191getBondsmanProcessIssuance(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_191getBondsmanProcessIssuance = {"getBondsmanProcessIssuance", (PyCFunction)__pyx_pw_9alacorder_3cal_191getBondsmanProcessIssuance, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_191getBondsmanProcessIssuance(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getBondsmanProcessIssuance (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_190getBondsmanProcessIssuance(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_190getBondsmanProcessIssuance(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getBondsmanProcessIssuance", 0);

  /* "alacorder/cal.pyx":1508
 *         return ''
 * def getBondsmanProcessIssuance(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1509
 * def getBondsmanProcessIssuance(text):
 *     try:
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bondsman_Process_Issuance_n_Bond, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1509, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bondsman_Process_Issuance_n_Bond, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1509, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1509, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Bondsman_Process_Issuance_n_Bond);
        __Pyx_GIVEREF(__pyx_kp_u_Bondsman_Process_Issuance_n_Bond);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Bondsman_Process_Issuance_n_Bond);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1509, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1509, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1508
 *         return ''
 * def getBondsmanProcessIssuance(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1510
 *     try:
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getBondsmanProcessReturn(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getBondsmanProcessIssuance", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1510, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1511
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getBondsmanProcessReturn(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1508
 *         return ''
 * def getBondsmanProcessIssuance(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1507
 *     except:
 *         return ''
 * def getBondsmanProcessIssuance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getBondsmanProcessIssuance", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1512
 *     except:
 *         return ''
 * def getBondsmanProcessReturn(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_193getBondsmanProcessReturn(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_193getBondsmanProcessReturn = {"getBondsmanProcessReturn", (PyCFunction)__pyx_pw_9alacorder_3cal_193getBondsmanProcessReturn, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_193getBondsmanProcessReturn(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getBondsmanProcessReturn (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_192getBondsmanProcessReturn(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_192getBondsmanProcessReturn(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getBondsmanProcessReturn", 0);

  /* "alacorder/cal.pyx":1513
 *         return ''
 * def getBondsmanProcessReturn(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1514
 * def getBondsmanProcessReturn(text):
 *     try:
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bondsman_Process_Return_Number_o, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1514, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Bondsman_Process_Return_Number_o, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1514, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1514, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Bondsman_Process_Return_Number_o);
        __Pyx_GIVEREF(__pyx_kp_u_Bondsman_Process_Return_Number_o);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Bondsman_Process_Return_Number_o);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1514, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1514, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1513
 *         return ''
 * def getBondsmanProcessReturn(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1515
 *     try:
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAppealDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getBondsmanProcessReturn", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1515, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1516
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAppealDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1513
 *         return ''
 * def getBondsmanProcessReturn(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1512
 *     except:
 *         return ''
 * def getBondsmanProcessReturn(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getBondsmanProcessReturn", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1517
 *     except:
 *         return ''
 * def getAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_195getAppealDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_195getAppealDate = {"getAppealDate", (PyCFunction)__pyx_pw_9alacorder_3cal_195getAppealDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_195getAppealDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAppealDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_194getAppealDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_194getAppealDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAppealDate", 0);

  /* "alacorder/cal.pyx":1518
 *         return ''
 * def getAppealDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1519
 * def getAppealDate(text):
 *     try:
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_n_s_d_Appeal_Court, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_n_s_d_Appeal_Court, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_s_d_Appeal_Court);
        __Pyx_GIVEREF(__pyx_kp_u_n_s_d_Appeal_Court);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_n_s_d_Appeal_Court);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1519, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_s);
        __Pyx_GIVEREF(__pyx_kp_u_n_s);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_12, __pyx_kp_u_n_s);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1519, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1518
 *         return ''
 * def getAppealDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1520
 *     try:
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAppealCourt(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAppealDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 1520, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1521
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAppealCourt(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1518
 *         return ''
 * def getAppealDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1517
 *     except:
 *         return ''
 * def getAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getAppealDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1522
 *     except:
 *         return ''
 * def getAppealCourt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_197getAppealCourt(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_197getAppealCourt = {"getAppealCourt", (PyCFunction)__pyx_pw_9alacorder_3cal_197getAppealCourt, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_197getAppealCourt(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAppealCourt (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_196getAppealCourt(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_196getAppealCourt(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAppealCourt", 0);

  /* "alacorder/cal.pyx":1523
 *         return ''
 * def getAppealCourt(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1524
 * def getAppealCourt(text):
 *     try:
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_A_Z_s_Appeal_Case_Number, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1524, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_A_Z_s_Appeal_Case_Number, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1524, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1524, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_A_Z_s_Appeal_Case_Number);
        __Pyx_GIVEREF(__pyx_kp_u_A_Z_s_Appeal_Case_Number);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_A_Z_s_Appeal_Case_Number);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1524, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1524, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1523
 *         return ''
 * def getAppealCourt(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1525
 *     try:
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getOriginOfAppeal(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAppealCourt", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1525, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1526
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getOriginOfAppeal(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1523
 *         return ''
 * def getAppealCourt(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1522
 *     except:
 *         return ''
 * def getAppealCourt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getAppealCourt", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1527
 *     except:
 *         return ''
 * def getOriginOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_199getOriginOfAppeal(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_199getOriginOfAppeal = {"getOriginOfAppeal", (PyCFunction)__pyx_pw_9alacorder_3cal_199getOriginOfAppeal, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_199getOriginOfAppeal(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getOriginOfAppeal (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_198getOriginOfAppeal(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_198getOriginOfAppeal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getOriginOfAppeal", 0);

  /* "alacorder/cal.pyx":1528
 *         return ''
 * def getOriginOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1529
 * def getOriginOfAppeal(text):
 *     try:
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Orgin_Of_Appeal_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1529, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Orgin_Of_Appeal_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1529, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1529, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Orgin_Of_Appeal_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Orgin_Of_Appeal_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Orgin_Of_Appeal_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1529, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_L) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_L);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1529, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1528
 *         return ''
 * def getOriginOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1530
 *     try:
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAppealToDesc(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getOriginOfAppeal", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1530, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1531
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAppealToDesc(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1528
 *         return ''
 * def getOriginOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1527
 *     except:
 *         return ''
 * def getOriginOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getOriginOfAppeal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1532
 *     except:
 *         return ''
 * def getAppealToDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_201getAppealToDesc(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_201getAppealToDesc = {"getAppealToDesc", (PyCFunction)__pyx_pw_9alacorder_3cal_201getAppealToDesc, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_201getAppealToDesc(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAppealToDesc (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_200getAppealToDesc(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_200getAppealToDesc(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAppealToDesc", 0);

  /* "alacorder/cal.pyx":1533
 *         return ''
 * def getAppealToDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1534
 * def getAppealToDesc(text):
 *     try:
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Appeal_To_Desc_A_Z_s, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1534, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Appeal_To_Desc_A_Z_s, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1534, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1534, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Appeal_To_Desc_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Appeal_To_Desc_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Appeal_To_Desc_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1534, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_7, __pyx_n_u_D) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_D);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_6, __pyx_n_u_T) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_n_u_T);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1534, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1533
 *         return ''
 * def getAppealToDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1535
 *     try:
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAppealStatus(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAppealToDesc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_10, &__pyx_t_5) < 0) __PYX_ERR(0, 1535, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1536
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAppealStatus(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1533
 *         return ''
 * def getAppealToDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1532
 *     except:
 *         return ''
 * def getAppealToDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getAppealToDesc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1537
 *     except:
 *         return ''
 * def getAppealStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_203getAppealStatus(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_203getAppealStatus = {"getAppealStatus", (PyCFunction)__pyx_pw_9alacorder_3cal_203getAppealStatus, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_203getAppealStatus(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAppealStatus (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_202getAppealStatus(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_202getAppealStatus(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAppealStatus", 0);

  /* "alacorder/cal.pyx":1538
 *         return ''
 * def getAppealStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1539
 * def getAppealStatus(text):
 *     try:
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Appeal_Status_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1539, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Appeal_Status_A_Z_s, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1539, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1539, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Appeal_Status_A_Z_s);
        __Pyx_GIVEREF(__pyx_kp_u_Appeal_Status_A_Z_s);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Appeal_Status_A_Z_s);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1539, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_rstrip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_6, __pyx_n_u_A) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_n_u_A);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1539, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1538
 *         return ''
 * def getAppealStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1540
 *     try:
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAppealTo(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAppealStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_9, &__pyx_t_5) < 0) __PYX_ERR(0, 1540, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1541
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAppealTo(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1538
 *         return ''
 * def getAppealStatus(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1537
 *     except:
 *         return ''
 * def getAppealStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getAppealStatus", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1542
 *     except:
 *         return ''
 * def getAppealTo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_205getAppealTo(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_205getAppealTo = {"getAppealTo", (PyCFunction)__pyx_pw_9alacorder_3cal_205getAppealTo, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_205getAppealTo(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAppealTo (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_204getAppealTo(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_204getAppealTo(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAppealTo", 0);

  /* "alacorder/cal.pyx":1543
 *         return ''
 * def getAppealTo(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1544
 * def getAppealTo(text):
 *     try:
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Appeal_To_w_Appeal, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1544, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Appeal_To_w_Appeal, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1544, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1544, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Appeal_To_w_Appeal);
        __Pyx_GIVEREF(__pyx_kp_u_Appeal_To_w_Appeal);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Appeal_To_w_Appeal);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1544, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1544, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1543
 *         return ''
 * def getAppealTo(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1545
 *     try:
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getLowerCourtAppealDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAppealTo", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1545, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1546
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getLowerCourtAppealDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1543
 *         return ''
 * def getAppealTo(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1542
 *     except:
 *         return ''
 * def getAppealTo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getAppealTo", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1547
 *     except:
 *         return ''
 * def getLowerCourtAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_207getLowerCourtAppealDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_207getLowerCourtAppealDate = {"getLowerCourtAppealDate", (PyCFunction)__pyx_pw_9alacorder_3cal_207getLowerCourtAppealDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_207getLowerCourtAppealDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLowerCourtAppealDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_206getLowerCourtAppealDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_206getLowerCourtAppealDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLowerCourtAppealDate", 0);

  /* "alacorder/cal.pyx":1548
 *         return ''
 * def getLowerCourtAppealDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1549
 * def getLowerCourtAppealDate(text):
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_s_2);
        __Pyx_GIVEREF(__pyx_kp_u_n_s_2);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_n_s_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1549, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1549, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1548
 *         return ''
 * def getLowerCourtAppealDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1550
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDispositionDateOfAppeal(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getLowerCourtAppealDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1550, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1551
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDispositionDateOfAppeal(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1548
 *         return ''
 * def getLowerCourtAppealDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1547
 *     except:
 *         return ''
 * def getLowerCourtAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getLowerCourtAppealDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1552
 *     except:
 *         return ''
 * def getDispositionDateOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_209getDispositionDateOfAppeal(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_209getDispositionDateOfAppeal = {"getDispositionDateOfAppeal", (PyCFunction)__pyx_pw_9alacorder_3cal_209getDispositionDateOfAppeal, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_209getDispositionDateOfAppeal(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDispositionDateOfAppeal (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_208getDispositionDateOfAppeal(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_208getDispositionDateOfAppeal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDispositionDateOfAppeal", 0);

  /* "alacorder/cal.pyx":1553
 *         return ''
 * def getDispositionDateOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1554
 * def getDispositionDateOfAppeal(text):
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_s_2);
        __Pyx_GIVEREF(__pyx_kp_u_n_s_2);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_n_s_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1554, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1554, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1553
 *         return ''
 * def getDispositionDateOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1555
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getDispositionTypeOfAppeal(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDispositionDateOfAppeal", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1555, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1556
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getDispositionTypeOfAppeal(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1553
 *         return ''
 * def getDispositionDateOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1552
 *     except:
 *         return ''
 * def getDispositionDateOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getDispositionDateOfAppeal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1557
 *     except:
 *         return ''
 * def getDispositionTypeOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_211getDispositionTypeOfAppeal(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_211getDispositionTypeOfAppeal = {"getDispositionTypeOfAppeal", (PyCFunction)__pyx_pw_9alacorder_3cal_211getDispositionTypeOfAppeal, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_211getDispositionTypeOfAppeal(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getDispositionTypeOfAppeal (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_210getDispositionTypeOfAppeal(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_210getDispositionTypeOfAppeal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getDispositionTypeOfAppeal", 0);

  /* "alacorder/cal.pyx":1558
 *         return ''
 * def getDispositionTypeOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1559
 * def getDispositionTypeOfAppeal(text):
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Disposition_Type_Of_Appeal_A_Za, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Disposition_Type_Of_Appeal_A_Za, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Disposition_Type_Of_Appeal_A_Za);
        __Pyx_GIVEREF(__pyx_kp_u_Disposition_Type_Of_Appeal_A_Za);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Disposition_Type_Of_Appeal_A_Za);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_s_2);
        __Pyx_GIVEREF(__pyx_kp_u_n_s_2);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_n_s_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1559, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1559, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1558
 *         return ''
 * def getDispositionTypeOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1560
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getNumberOfSubpoenas(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getDispositionTypeOfAppeal", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1560, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1561
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getNumberOfSubpoenas(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1558
 *         return ''
 * def getDispositionTypeOfAppeal(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1557
 *     except:
 *         return ''
 * def getDispositionTypeOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getDispositionTypeOfAppeal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1562
 *     except:
 *         return ''
 * def getNumberOfSubpoenas(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_213getNumberOfSubpoenas(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_213getNumberOfSubpoenas = {"getNumberOfSubpoenas", (PyCFunction)__pyx_pw_9alacorder_3cal_213getNumberOfSubpoenas, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_213getNumberOfSubpoenas(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumberOfSubpoenas (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_212getNumberOfSubpoenas(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_212getNumberOfSubpoenas(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumberOfSubpoenas", 0);

  /* "alacorder/cal.pyx":1563
 *         return ''
 * def getNumberOfSubpoenas(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1564
 * def getNumberOfSubpoenas(text):
 *     try:
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Number_of_Subponeas_d_3, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_Number_of_Subponeas_d_3, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Number_of_Subponeas_d_3);
        __Pyx_GIVEREF(__pyx_kp_u_Number_of_Subponeas_d_3);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_Number_of_Subponeas_d_3);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_6 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_n_s_2, __pyx_kp_u__8, __pyx_t_6};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_s_2);
        __Pyx_GIVEREF(__pyx_kp_u_n_s_2);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_12, __pyx_kp_u_n_s_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_6);
        PyTuple_SET_ITEM(__pyx_t_8, 2+__pyx_t_12, __pyx_t_6);
        __pyx_t_6 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1564, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1564, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_7;
      __pyx_t_7 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1563
 *         return ''
 * def getNumberOfSubpoenas(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1565
 *     try:
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getAdminUpdatedBy(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getNumberOfSubpoenas", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1565, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1566
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getAdminUpdatedBy(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1563
 *         return ''
 * def getNumberOfSubpoenas(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1562
 *     except:
 *         return ''
 * def getNumberOfSubpoenas(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getNumberOfSubpoenas", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1567
 *     except:
 *         return ''
 * def getAdminUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_215getAdminUpdatedBy(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_215getAdminUpdatedBy = {"getAdminUpdatedBy", (PyCFunction)__pyx_pw_9alacorder_3cal_215getAdminUpdatedBy, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_215getAdminUpdatedBy(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getAdminUpdatedBy (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_214getAdminUpdatedBy(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_214getAdminUpdatedBy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getAdminUpdatedBy", 0);

  /* "alacorder/cal.pyx":1568
 *         return ''
 * def getAdminUpdatedBy(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1569
 * def getAdminUpdatedBy(text):
 *     try:
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Updated_By_w_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1569, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Updated_By_w_3, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1569, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1569, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Updated_By_w_3);
        __Pyx_GIVEREF(__pyx_kp_u_Updated_By_w_3);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Updated_By_w_3);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1569, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1569, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1568
 *         return ''
 * def getAdminUpdatedBy(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1570
 *     try:
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getTransferToAdminDocDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getAdminUpdatedBy", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1570, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1571
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getTransferToAdminDocDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1568
 *         return ''
 * def getAdminUpdatedBy(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1567
 *     except:
 *         return ''
 * def getAdminUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getAdminUpdatedBy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1572
 *     except:
 *         return ''
 * def getTransferToAdminDocDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_217getTransferToAdminDocDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_217getTransferToAdminDocDate = {"getTransferToAdminDocDate", (PyCFunction)__pyx_pw_9alacorder_3cal_217getTransferToAdminDocDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_217getTransferToAdminDocDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTransferToAdminDocDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_216getTransferToAdminDocDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_216getTransferToAdminDocDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTransferToAdminDocDate", 0);

  /* "alacorder/cal.pyx":1573
 *         return ''
 * def getTransferToAdminDocDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1574
 * def getTransferToAdminDocDate(text):
 *     try:
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1574, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1574, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1574, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1574, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1574, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1573
 *         return ''
 * def getTransferToAdminDocDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1575
 *     try:
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getTransferDesc(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTransferToAdminDocDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1575, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1576
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getTransferDesc(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1573
 *         return ''
 * def getTransferToAdminDocDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1572
 *     except:
 *         return ''
 * def getTransferToAdminDocDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getTransferToAdminDocDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1577
 *     except:
 *         return ''
 * def getTransferDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_219getTransferDesc(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_219getTransferDesc = {"getTransferDesc", (PyCFunction)__pyx_pw_9alacorder_3cal_219getTransferDesc, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_219getTransferDesc(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTransferDesc (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_218getTransferDesc(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_218getTransferDesc(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTransferDesc", 0);

  /* "alacorder/cal.pyx":1578
 *         return ''
 * def getTransferDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1579
 * def getTransferDesc(text):
 *     try:
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1579, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1579, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1579, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1579, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1579, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1578
 *         return ''
 * def getTransferDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1580
 *     try:
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getTBNV1(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTransferDesc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1580, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1581
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getTBNV1(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1578
 *         return ''
 * def getTransferDesc(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1577
 *     except:
 *         return ''
 * def getTransferDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getTransferDesc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1582
 *     except:
 *         return ''
 * def getTBNV1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_221getTBNV1(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_221getTBNV1 = {"getTBNV1", (PyCFunction)__pyx_pw_9alacorder_3cal_221getTBNV1, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_221getTBNV1(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTBNV1 (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_220getTBNV1(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_220getTBNV1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTBNV1", 0);

  /* "alacorder/cal.pyx":1583
 *         return ''
 * def getTBNV1(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1584
 * def getTBNV1(text):
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Date_Trial_Began_but_No_Verdict, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1584, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Date_Trial_Began_but_No_Verdict, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1584, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1584, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Date_Trial_Began_but_No_Verdict);
        __Pyx_GIVEREF(__pyx_kp_u_Date_Trial_Began_but_No_Verdict);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Date_Trial_Began_but_No_Verdict);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1584, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1584, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1583
 *         return ''
 * def getTBNV1(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1585
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getTBNV2(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTBNV1", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1585, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1586
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getTBNV2(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1583
 *         return ''
 * def getTBNV1(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1582
 *     except:
 *         return ''
 * def getTBNV1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getTBNV1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1587
 *     except:
 *         return ''
 * def getTBNV2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_223getTBNV2(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_223getTBNV2 = {"getTBNV2", (PyCFunction)__pyx_pw_9alacorder_3cal_223getTBNV2, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_223getTBNV2(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getTBNV2 (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_222getTBNV2(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_222getTBNV2(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getTBNV2", 0);

  /* "alacorder/cal.pyx":1588
 *         return ''
 * def getTBNV2(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1589
 * def getTBNV2(text):
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Date_Trial_Began_but_No_Verdict_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1589, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Date_Trial_Began_but_No_Verdict_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1589, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1589, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Date_Trial_Began_but_No_Verdict_2);
        __Pyx_GIVEREF(__pyx_kp_u_Date_Trial_Began_but_No_Verdict_2);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Date_Trial_Began_but_No_Verdict_2);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1589, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1589, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1588
 *         return ''
 * def getTBNV2(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1590
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentencingRequirementsCompleted(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getTBNV2", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1590, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1591
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentencingRequirementsCompleted(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1588
 *         return ''
 * def getTBNV2(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1587
 *     except:
 *         return ''
 * def getTBNV2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getTBNV2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1592
 *     except:
 *         return ''
 * def getSentencingRequirementsCompleted(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_225getSentencingRequirementsCompleted(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_225getSentencingRequirementsCompleted = {"getSentencingRequirementsCompleted", (PyCFunction)__pyx_pw_9alacorder_3cal_225getSentencingRequirementsCompleted, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_225getSentencingRequirementsCompleted(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentencingRequirementsCompleted (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_224getSentencingRequirementsCompleted(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_224getSentencingRequirementsCompleted(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentencingRequirementsCompleted", 0);

  /* "alacorder/cal.pyx":1593
 *         return ''
 * def getSentencingRequirementsCompleted(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1594
 * def getSentencingRequirementsCompleted(text):
 *     try:
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1594, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1594, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_findall); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1594, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1594, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Requrements_Completed_YES_NO, __pyx_t_7};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Requrements_Completed_YES_NO, __pyx_t_7};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Requrements_Completed_YES_NO);
        __Pyx_GIVEREF(__pyx_kp_u_Requrements_Completed_YES_NO);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Requrements_Completed_YES_NO);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1594, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_n_Requrements_Completed, __pyx_kp_u__8, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_10, 3+__pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_5, __pyx_kp_u_n_Requrements_Completed, __pyx_kp_u__8, __pyx_t_8};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_10, 3+__pyx_t_10); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(3+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_5) {
          __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_5); __pyx_t_5 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_n_Requrements_Completed);
        __Pyx_GIVEREF(__pyx_kp_u_n_Requrements_Completed);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_n_Requrements_Completed);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_11, 2+__pyx_t_10, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1594, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1593
 *         return ''
 * def getSentencingRequirementsCompleted(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1595
 *     try:
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentenceDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentencingRequirementsCompleted", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_11) < 0) __PYX_ERR(0, 1595, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_11);

      /* "alacorder/cal.pyx":1596
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentenceDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1593
 *         return ''
 * def getSentencingRequirementsCompleted(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1592
 *     except:
 *         return ''
 * def getSentencingRequirementsCompleted(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getSentencingRequirementsCompleted", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1597
 *     except:
 *         return ''
 * def getSentenceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_227getSentenceDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_227getSentenceDate = {"getSentenceDate", (PyCFunction)__pyx_pw_9alacorder_3cal_227getSentenceDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_227getSentenceDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentenceDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_226getSentenceDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_226getSentenceDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentenceDate", 0);

  /* "alacorder/cal.pyx":1598
 *         return ''
 * def getSentenceDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1599
 * def getSentenceDate(text):
 *     try:
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1599, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1599, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2);
        __Pyx_GIVEREF(__pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1599, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_2) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_2);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1599, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1598
 *         return ''
 * def getSentenceDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1600
 *     try:
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getProbationPeriod(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentenceDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1600, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1601
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getProbationPeriod(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1598
 *         return ''
 * def getSentenceDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1597
 *     except:
 *         return ''
 * def getSentenceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getSentenceDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1602
 *     except:
 *         return ''
 * def getProbationPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_229getProbationPeriod(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_229getProbationPeriod = {"getProbationPeriod", (PyCFunction)__pyx_pw_9alacorder_3cal_229getProbationPeriod, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_229getProbationPeriod(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getProbationPeriod (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_228getProbationPeriod(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_228getProbationPeriod(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getProbationPeriod", 0);

  /* "alacorder/cal.pyx":1603
 *         return ''
 * def getProbationPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1604
 * def getProbationPeriod(text):
 *     try:
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_search); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Probation_Period, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1604, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Probation_Period, __pyx_t_8};
        __pyx_t_7 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1604, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1604, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Period);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Period);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Probation_Period);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1604, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_group); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_9, __pyx_t_7, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_strip); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_strip); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
        }
      }
      __pyx_t_4 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1604, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1603
 *         return ''
 * def getProbationPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1605
 *     try:
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getLicenseSuspPeriod(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getProbationPeriod", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_9) < 0) __PYX_ERR(0, 1605, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_9);

      /* "alacorder/cal.pyx":1606
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getLicenseSuspPeriod(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1603
 *         return ''
 * def getProbationPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1602
 *     except:
 *         return ''
 * def getProbationPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getProbationPeriod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1607
 *     except:
 *         return ''
 * def getLicenseSuspPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_231getLicenseSuspPeriod(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_231getLicenseSuspPeriod = {"getLicenseSuspPeriod", (PyCFunction)__pyx_pw_9alacorder_3cal_231getLicenseSuspPeriod, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_231getLicenseSuspPeriod(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getLicenseSuspPeriod (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_230getLicenseSuspPeriod(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_230getLicenseSuspPeriod(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getLicenseSuspPeriod", 0);

  /* "alacorder/cal.pyx":1608
 *         return ''
 * def getLicenseSuspPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1609
 * def getLicenseSuspPeriod(text):
 *     try:
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_re); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_sub); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_re); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_search); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_11 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_11)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_11);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_License_Susp_Period, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_11, __pyx_kp_u_License_Susp_Period, __pyx_t_9};
        __pyx_t_8 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_12, 2+__pyx_t_12); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_13 = PyTuple_New(2+__pyx_t_12); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__pyx_t_11) {
          __Pyx_GIVEREF(__pyx_t_11); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_11); __pyx_t_11 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_License_Susp_Period);
        __Pyx_GIVEREF(__pyx_kp_u_License_Susp_Period);
        PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_12, __pyx_kp_u_License_Susp_Period);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_12, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_13, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_group); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_7 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_8, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_strip); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
        }
      }
      __pyx_t_5 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_10);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      __pyx_t_12 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
          __pyx_t_12 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_License_Susp_Period_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
        PyObject *__pyx_temp[4] = {__pyx_t_10, __pyx_kp_u_License_Susp_Period_2, __pyx_kp_u__8, __pyx_t_5};
        __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_12, 3+__pyx_t_12); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else
      #endif
      {
        __pyx_t_7 = PyTuple_New(3+__pyx_t_12); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_License_Susp_Period_2);
        __Pyx_GIVEREF(__pyx_kp_u_License_Susp_Period_2);
        PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_12, __pyx_kp_u_License_Susp_Period_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_12, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_7, 2+__pyx_t_12, __pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1609, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1609, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1608
 *         return ''
 * def getLicenseSuspPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1610
 *     try:
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getJailCreditPeriod(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getLicenseSuspPeriod", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 1610, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);

      /* "alacorder/cal.pyx":1611
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getJailCreditPeriod(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1608
 *         return ''
 * def getLicenseSuspPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1607
 *     except:
 *         return ''
 * def getLicenseSuspPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("alacorder.cal.getLicenseSuspPeriod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1612
 *     except:
 *         return ''
 * def getJailCreditPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_233getJailCreditPeriod(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_233getJailCreditPeriod = {"getJailCreditPeriod", (PyCFunction)__pyx_pw_9alacorder_3cal_233getJailCreditPeriod, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_233getJailCreditPeriod(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getJailCreditPeriod (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_232getJailCreditPeriod(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_232getJailCreditPeriod(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getJailCreditPeriod", 0);

  /* "alacorder/cal.pyx":1613
 *         return ''
 * def getJailCreditPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1614
 * def getJailCreditPeriod(text):
 *     try:
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Jail_Credit_Period, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1614, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Jail_Credit_Period, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1614, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1614, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Jail_Credit_Period);
        __Pyx_GIVEREF(__pyx_kp_u_Jail_Credit_Period);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Jail_Credit_Period);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1614, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = PyUnicode_Join(__pyx_kp_u__8, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1614, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_8;
      __pyx_t_8 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1613
 *         return ''
 * def getJailCreditPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1615
 *     try:
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentenceProvisions(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getJailCreditPeriod", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_4, &__pyx_t_5) < 0) __PYX_ERR(0, 1615, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1616
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentenceProvisions(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1613
 *         return ''
 * def getJailCreditPeriod(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1612
 *     except:
 *         return ''
 * def getJailCreditPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getJailCreditPeriod", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1617
 *     except:
 *         return ''
 * def getSentenceProvisions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_235getSentenceProvisions(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_235getSentenceProvisions = {"getSentenceProvisions", (PyCFunction)__pyx_pw_9alacorder_3cal_235getSentenceProvisions, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_235getSentenceProvisions(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentenceProvisions (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_234getSentenceProvisions(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_234getSentenceProvisions(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentenceProvisions", 0);

  /* "alacorder/cal.pyx":1618
 *         return ''
 * def getSentenceProvisions(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1619
 * def getSentenceProvisions(text):
 *     try:
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_re); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_search); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Sentence_Provisions_Y_N, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1619, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_8)) {
        PyObject *__pyx_temp[3] = {__pyx_t_9, __pyx_kp_u_Sentence_Provisions_Y_N, __pyx_t_7};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_8, __pyx_temp+1-__pyx_t_10, 2+__pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1619, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else
      #endif
      {
        __pyx_t_11 = PyTuple_New(2+__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 1619, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_11);
        if (__pyx_t_9) {
          __Pyx_GIVEREF(__pyx_t_9); PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_9); __pyx_t_9 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Sentence_Provisions_Y_N);
        __Pyx_GIVEREF(__pyx_kp_u_Sentence_Provisions_Y_N);
        PyTuple_SET_ITEM(__pyx_t_11, 0+__pyx_t_10, __pyx_kp_u_Sentence_Provisions_Y_N);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_11, 1+__pyx_t_10, __pyx_t_7);
        __pyx_t_7 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_8, __pyx_t_11, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1619, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_group); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_5 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_6, __pyx_int_1) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_int_1);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1619, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1618
 *         return ''
 * def getSentenceProvisions(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1620
 *     try:
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentenceStartDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentenceProvisions", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_8, &__pyx_t_5) < 0) __PYX_ERR(0, 1620, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1621
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentenceStartDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1618
 *         return ''
 * def getSentenceProvisions(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1617
 *     except:
 *         return ''
 * def getSentenceProvisions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("alacorder.cal.getSentenceProvisions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1622
 *     except:
 *         return ''
 * def getSentenceStartDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_237getSentenceStartDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_237getSentenceStartDate = {"getSentenceStartDate", (PyCFunction)__pyx_pw_9alacorder_3cal_237getSentenceStartDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_237getSentenceStartDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentenceStartDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_236getSentenceStartDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_236getSentenceStartDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentenceStartDate", 0);

  /* "alacorder/cal.pyx":1623
 *         return ''
 * def getSentenceStartDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1624
 * def getSentenceStartDate(text):
 *     try:
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_findall); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Sentence_Start_Date, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Sentence_Start_Date, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Sentence_Start_Date);
        __Pyx_GIVEREF(__pyx_kp_u_Sentence_Start_Date);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Sentence_Start_Date);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1624, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1624, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1623
 *         return ''
 * def getSentenceStartDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1625
 *     try:
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentenceEndDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentenceStartDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1625, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1626
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentenceEndDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1623
 *         return ''
 * def getSentenceStartDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1622
 *     except:
 *         return ''
 * def getSentenceStartDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getSentenceStartDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1627
 *     except:
 *         return ''
 * def getSentenceEndDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_239getSentenceEndDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_239getSentenceEndDate = {"getSentenceEndDate", (PyCFunction)__pyx_pw_9alacorder_3cal_239getSentenceEndDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_239getSentenceEndDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentenceEndDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_238getSentenceEndDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_238getSentenceEndDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentenceEndDate", 0);

  /* "alacorder/cal.pyx":1628
 *         return ''
 * def getSentenceEndDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1629
 * def getSentenceEndDate(text):
 *     try:
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_findall); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Sentence_End_Date, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Sentence_End_Date, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Sentence_End_Date);
        __Pyx_GIVEREF(__pyx_kp_u_Sentence_End_Date);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Sentence_End_Date);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1629, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1629, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1628
 *         return ''
 * def getSentenceEndDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1630
 *     try:
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getProbationBeginDate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentenceEndDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1630, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1631
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getProbationBeginDate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1628
 *         return ''
 * def getSentenceEndDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1627
 *     except:
 *         return ''
 * def getSentenceEndDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getSentenceEndDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1632
 *     except:
 *         return ''
 * def getProbationBeginDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_241getProbationBeginDate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_241getProbationBeginDate = {"getProbationBeginDate", (PyCFunction)__pyx_pw_9alacorder_3cal_241getProbationBeginDate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_241getProbationBeginDate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getProbationBeginDate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_240getProbationBeginDate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_240getProbationBeginDate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getProbationBeginDate", 0);

  /* "alacorder/cal.pyx":1633
 *         return ''
 * def getProbationBeginDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1634
 * def getProbationBeginDate(text):
 *     try:
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_findall); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Probation_Begin_Date, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Probation_Begin_Date, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Begin_Date);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Begin_Date);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Probation_Begin_Date);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1634, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1634, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1633
 *         return ''
 * def getProbationBeginDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1635
 *     try:
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentenceUpdatedBy(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getProbationBeginDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1635, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1636
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentenceUpdatedBy(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1633
 *         return ''
 * def getProbationBeginDate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1632
 *     except:
 *         return ''
 * def getProbationBeginDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getProbationBeginDate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1637
 *     except:
 *         return ''
 * def getSentenceUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_243getSentenceUpdatedBy(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_243getSentenceUpdatedBy = {"getSentenceUpdatedBy", (PyCFunction)__pyx_pw_9alacorder_3cal_243getSentenceUpdatedBy, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_243getSentenceUpdatedBy(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentenceUpdatedBy (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_242getSentenceUpdatedBy(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_242getSentenceUpdatedBy(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentenceUpdatedBy", 0);

  /* "alacorder/cal.pyx":1638
 *         return ''
 * def getSentenceUpdatedBy(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1639
 * def getSentenceUpdatedBy(text):
 *     try:
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_findall); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Updated_By_w_3_2, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Updated_By_w_3_2, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Updated_By_w_3_2);
        __Pyx_GIVEREF(__pyx_kp_u_Updated_By_w_3_2);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Updated_By_w_3_2);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Updated_By, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Updated_By, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Updated_By);
        __Pyx_GIVEREF(__pyx_kp_u_Updated_By);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Updated_By);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1639, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1639, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1638
 *         return ''
 * def getSentenceUpdatedBy(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1640
 *     try:
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getSentenceLastUpdate(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentenceUpdatedBy", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1640, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1641
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getSentenceLastUpdate(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1638
 *         return ''
 * def getSentenceUpdatedBy(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1637
 *     except:
 *         return ''
 * def getSentenceUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getSentenceUpdatedBy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1642
 *     except:
 *         return ''
 * def getSentenceLastUpdate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_245getSentenceLastUpdate(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_245getSentenceLastUpdate = {"getSentenceLastUpdate", (PyCFunction)__pyx_pw_9alacorder_3cal_245getSentenceLastUpdate, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_245getSentenceLastUpdate(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getSentenceLastUpdate (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_244getSentenceLastUpdate(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_244getSentenceLastUpdate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getSentenceLastUpdate", 0);

  /* "alacorder/cal.pyx":1643
 *         return ''
 * def getSentenceLastUpdate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1644
 * def getSentenceLastUpdate(text):
 *     try:
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_findall); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Last_Update, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Last_Update, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Last_Update);
        __Pyx_GIVEREF(__pyx_kp_u_Last_Update);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Last_Update);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1644, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1644, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1643
 *         return ''
 * def getSentenceLastUpdate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1645
 *     try:
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 * def getProbationRevoke(text):
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getSentenceLastUpdate", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1645, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1646
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 * def getProbationRevoke(text):
 *     try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1643
 *         return ''
 * def getSentenceLastUpdate(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1642
 *     except:
 *         return ''
 * def getSentenceLastUpdate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getSentenceLastUpdate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "alacorder/cal.pyx":1647
 *     except:
 *         return ''
 * def getProbationRevoke(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

/* Python wrapper */
static PyObject *__pyx_pw_9alacorder_3cal_247getProbationRevoke(PyObject *__pyx_self, PyObject *__pyx_v_text); /*proto*/
static PyMethodDef __pyx_mdef_9alacorder_3cal_247getProbationRevoke = {"getProbationRevoke", (PyCFunction)__pyx_pw_9alacorder_3cal_247getProbationRevoke, METH_O, 0};
static PyObject *__pyx_pw_9alacorder_3cal_247getProbationRevoke(PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getProbationRevoke (wrapper)", 0);
  __pyx_r = __pyx_pf_9alacorder_3cal_246getProbationRevoke(__pyx_self, ((PyObject *)__pyx_v_text));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9alacorder_3cal_246getProbationRevoke(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_text) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getProbationRevoke", 0);

  /* "alacorder/cal.pyx":1648
 *         return ''
 * def getProbationRevoke(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "alacorder/cal.pyx":1649
 * def getProbationRevoke(text):
 *     try:
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_re); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_sub); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_re); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_findall); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyUnicode_Type)), __pyx_v_text); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_9)) {
        PyObject *__pyx_temp[3] = {__pyx_t_10, __pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d, __pyx_t_8};
        __pyx_t_6 = __Pyx_PyCFunction_FastCall(__pyx_t_9, __pyx_temp+1-__pyx_t_11, 2+__pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(2+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_10) {
          __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_12, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = PyUnicode_Join(__pyx_kp_u__52, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_11 = 0;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_11 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Probation_Revoke_2, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_7)) {
        PyObject *__pyx_temp[4] = {__pyx_t_6, __pyx_kp_u_Probation_Revoke_2, __pyx_kp_u__8, __pyx_t_9};
        __pyx_t_5 = __Pyx_PyCFunction_FastCall(__pyx_t_7, __pyx_temp+1-__pyx_t_11, 3+__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      } else
      #endif
      {
        __pyx_t_12 = PyTuple_New(3+__pyx_t_11); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_u_Probation_Revoke_2);
        __Pyx_GIVEREF(__pyx_kp_u_Probation_Revoke_2);
        PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_kp_u_Probation_Revoke_2);
        __Pyx_INCREF(__pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_kp_u__8);
        PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_kp_u__8);
        __Pyx_GIVEREF(__pyx_t_9);
        PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_9);
        __pyx_t_9 = 0;
        __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_12, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1649, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_strip); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 1649, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L7_try_return;

      /* "alacorder/cal.pyx":1648
 *         return ''
 * def getProbationRevoke(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "alacorder/cal.pyx":1650
 *     try:
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:             # <<<<<<<<<<<<<<
 *         return ''
 */
    /*except:*/ {
      __Pyx_AddTraceback("alacorder.cal.getProbationRevoke", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_7, &__pyx_t_5) < 0) __PYX_ERR(0, 1650, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GOTREF(__pyx_t_5);

      /* "alacorder/cal.pyx":1651
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 *         return ''             # <<<<<<<<<<<<<<
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_kp_u__8);
      __pyx_r = __pyx_kp_u__8;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    __pyx_L5_except_error:;

    /* "alacorder/cal.pyx":1648
 *         return ''
 * def getProbationRevoke(text):
 *     try:             # <<<<<<<<<<<<<<
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 *     except:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
  }

  /* "alacorder/cal.pyx":1647
 *     except:
 *         return ''
 * def getProbationRevoke(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("alacorder.cal.getProbationRevoke", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *__pyx_freelist_9alacorder_3cal___pyx_scope_struct__getPDFText[8];
static int __pyx_freecount_9alacorder_3cal___pyx_scope_struct__getPDFText = 0;

static PyObject *__pyx_tp_new_9alacorder_3cal___pyx_scope_struct__getPDFText(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9alacorder_3cal___pyx_scope_struct__getPDFText > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText)))) {
    o = (PyObject*)__pyx_freelist_9alacorder_3cal___pyx_scope_struct__getPDFText[--__pyx_freecount_9alacorder_3cal___pyx_scope_struct__getPDFText];
    memset(o, 0, sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9alacorder_3cal___pyx_scope_struct__getPDFText(PyObject *o) {
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *p = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pg);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9alacorder_3cal___pyx_scope_struct__getPDFText < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText)))) {
    __pyx_freelist_9alacorder_3cal___pyx_scope_struct__getPDFText[__pyx_freecount_9alacorder_3cal___pyx_scope_struct__getPDFText++] = ((struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9alacorder_3cal___pyx_scope_struct__getPDFText(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *p = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *)o;
  if (p->__pyx_v_pg) {
    e = (*v)(p->__pyx_v_pg, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9alacorder_3cal___pyx_scope_struct__getPDFText(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *p = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText *)o;
  tmp = ((PyObject*)p->__pyx_v_pg);
  p->__pyx_v_pg = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText = {
  PyVarObject_HEAD_INIT(0, 0)
  "alacorder.cal.__pyx_scope_struct__getPDFText", /*tp_name*/
  sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct__getPDFText), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9alacorder_3cal___pyx_scope_struct__getPDFText, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9alacorder_3cal___pyx_scope_struct__getPDFText, /*tp_traverse*/
  __pyx_tp_clear_9alacorder_3cal___pyx_scope_struct__getPDFText, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9alacorder_3cal___pyx_scope_struct__getPDFText, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};

static struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *__pyx_freelist_9alacorder_3cal___pyx_scope_struct_1_genexpr[8];
static int __pyx_freecount_9alacorder_3cal___pyx_scope_struct_1_genexpr = 0;

static PyObject *__pyx_tp_new_9alacorder_3cal___pyx_scope_struct_1_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_9alacorder_3cal___pyx_scope_struct_1_genexpr > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr)))) {
    o = (PyObject*)__pyx_freelist_9alacorder_3cal___pyx_scope_struct_1_genexpr[--__pyx_freecount_9alacorder_3cal___pyx_scope_struct_1_genexpr];
    memset(o, 0, sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9alacorder_3cal___pyx_scope_struct_1_genexpr(PyObject *o) {
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_v_x);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_9alacorder_3cal___pyx_scope_struct_1_genexpr < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr)))) {
    __pyx_freelist_9alacorder_3cal___pyx_scope_struct_1_genexpr[__pyx_freecount_9alacorder_3cal___pyx_scope_struct_1_genexpr++] = ((struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_9alacorder_3cal___pyx_scope_struct_1_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *p = (struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr *)o;
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_v_x) {
    e = (*v)(p->__pyx_v_x, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "alacorder.cal.__pyx_scope_struct_1_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_9alacorder_3cal___pyx_scope_struct_1_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9alacorder_3cal___pyx_scope_struct_1_genexpr, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9alacorder_3cal___pyx_scope_struct_1_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9alacorder_3cal___pyx_scope_struct_1_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
  0, /*tp_print*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
  0, /*tp_pypy_flags*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_cal(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_cal},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "cal",
    __pyx_k_alacorder_on_polars_Dependencie, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_0000_A_Z, __pyx_k_0000_A_Z, sizeof(__pyx_k_0000_A_Z), 0, 1, 0, 0},
  {&__pyx_kp_u_0_00, __pyx_k_0_00, sizeof(__pyx_k_0_00), 0, 1, 0, 0},
  {&__pyx_kp_u_0_000000_00, __pyx_k_0_000000_00, sizeof(__pyx_k_0_000000_00), 0, 1, 0, 0},
  {&__pyx_kp_u_0_000000_00_2, __pyx_k_0_000000_00_2, sizeof(__pyx_k_0_000000_00_2), 0, 1, 0, 0},
  {&__pyx_kp_u_0_00_2, __pyx_k_0_00_2, sizeof(__pyx_k_0_00_2), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9, __pyx_k_0_9, sizeof(__pyx_k_0_9), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9_2, __pyx_k_0_9_2, sizeof(__pyx_k_0_9_2), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9_Arresting_Agency_Type, __pyx_k_0_9_Arresting_Agency_Type, sizeof(__pyx_k_0_9_Arresting_Agency_Type), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9_s, __pyx_k_0_9_s, sizeof(__pyx_k_0_9_s), 0, 1, 0, 0},
  {&__pyx_kp_u_0_9_s_2, __pyx_k_0_9_s_2, sizeof(__pyx_k_0_9_s_2), 0, 1, 0, 0},
  {&__pyx_kp_u_1000, __pyx_k_1000, sizeof(__pyx_k_1000), 0, 1, 0, 0},
  {&__pyx_kp_u_2050000000, __pyx_k_2050000000, sizeof(__pyx_k_2050000000), 0, 1, 0, 0},
  {&__pyx_kp_u_79_2_7, __pyx_k_79_2_7, sizeof(__pyx_k_79_2_7), 0, 1, 0, 0},
  {&__pyx_n_u_A, __pyx_k_A, sizeof(__pyx_k_A), 0, 1, 0, 1},
  {&__pyx_n_u_ACTIVE, __pyx_k_ACTIVE, sizeof(__pyx_k_ACTIVE), 0, 1, 0, 1},
  {&__pyx_kp_u_ACTIVE_n_D999_n, __pyx_k_ACTIVE_n_D999_n, sizeof(__pyx_k_ACTIVE_n_D999_n), 0, 1, 0, 0},
  {&__pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z, __pyx_k_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z, sizeof(__pyx_k_ACTIVE_n_n_ACTIVE_n_n_Total_A_Z), 0, 1, 0, 0},
  {&__pyx_kp_u_ACTIVE_n_n_ACTIVE_n_n_Total_n, __pyx_k_ACTIVE_n_n_ACTIVE_n_n_Total_n, sizeof(__pyx_k_ACTIVE_n_n_ACTIVE_n_n_Total_n), 0, 1, 0, 0},
  {&__pyx_n_u_AL, __pyx_k_AL, sizeof(__pyx_k_AL), 0, 1, 0, 1},
  {&__pyx_n_u_AL000000000, __pyx_k_AL000000000, sizeof(__pyx_k_AL000000000), 0, 1, 0, 1},
  {&__pyx_n_u_ALABAMA, __pyx_k_ALABAMA, sizeof(__pyx_k_ALABAMA), 0, 1, 0, 1},
  {&__pyx_n_u_ALACORDER, __pyx_k_ALACORDER, sizeof(__pyx_k_ALACORDER), 0, 1, 0, 1},
  {&__pyx_n_u_ALA_CUSTOMER_ID, __pyx_k_ALA_CUSTOMER_ID, sizeof(__pyx_k_ALA_CUSTOMER_ID), 0, 1, 0, 1},
  {&__pyx_n_u_ALA_PASSWORD, __pyx_k_ALA_PASSWORD, sizeof(__pyx_k_ALA_PASSWORD), 0, 1, 0, 1},
  {&__pyx_n_u_ALA_USER_ID, __pyx_k_ALA_USER_ID, sizeof(__pyx_k_ALA_USER_ID), 0, 1, 0, 1},
  {&__pyx_kp_u_ALCOHOL_BOND_CONSERVATION_DOCKE, __pyx_k_ALCOHOL_BOND_CONSERVATION_DOCKE, sizeof(__pyx_k_ALCOHOL_BOND_CONSERVATION_DOCKE), 0, 1, 0, 0},
  {&__pyx_n_u_ALInstitutionalServiceNum, __pyx_k_ALInstitutionalServiceNum, sizeof(__pyx_k_ALInstitutionalServiceNum), 0, 1, 0, 1},
  {&__pyx_n_u_ALL, __pyx_k_ALL, sizeof(__pyx_k_ALL), 0, 1, 0, 1},
  {&__pyx_kp_u_AL_Institutional_Service_Num_na, __pyx_k_AL_Institutional_Service_Num_na, sizeof(__pyx_k_AL_Institutional_Service_Num_na), 0, 1, 0, 0},
  {&__pyx_n_u_APPEND, __pyx_k_APPEND, sizeof(__pyx_k_APPEND), 0, 1, 0, 1},
  {&__pyx_n_u_ARCHIVE, __pyx_k_ARCHIVE, sizeof(__pyx_k_ARCHIVE), 0, 1, 0, 1},
  {&__pyx_kp_u_A_ATT_ATTEMPT_S_SOLICIT_CONSP, __pyx_k_A_ATT_ATTEMPT_S_SOLICIT_CONSP, sizeof(__pyx_k_A_ATT_ATTEMPT_S_SOLICIT_CONSP), 0, 1, 0, 0},
  {&__pyx_n_u_A_S_C_DISQ, __pyx_k_A_S_C_DISQ, sizeof(__pyx_k_A_S_C_DISQ), 0, 1, 0, 1},
  {&__pyx_kp_u_A_Z, __pyx_k_A_Z, sizeof(__pyx_k_A_Z), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z0_9_11_State_ID, __pyx_k_A_Z0_9_11_State_ID, sizeof(__pyx_k_A_Z0_9_11_State_ID), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z0_9_3_A_Z0_9_3_A_Z0_9_3_0_1, __pyx_k_A_Z0_9_3_A_Z0_9_3_A_Z0_9_3_0_1, sizeof(__pyx_k_A_Z0_9_3_A_Z0_9_3_A_Z0_9_3_0_1), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A, __pyx_k_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A, sizeof(__pyx_k_A_Z0_9_3_s_0_1_A_Z0_9_3_s_0_1_A), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z0_9_s_n, __pyx_k_A_Z0_9_s_n, sizeof(__pyx_k_A_Z0_9_s_n), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z_2, __pyx_k_A_Z_2, sizeof(__pyx_k_A_Z_2), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z_a_z_A_Za_z_s, __pyx_k_A_Z_a_z_A_Za_z_s, sizeof(__pyx_k_A_Z_a_z_A_Za_z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_A_Z_s_Appeal_Case_Number, __pyx_k_A_Z_s_Appeal_Case_Number, sizeof(__pyx_k_A_Z_s_Appeal_Case_Number), 0, 1, 0, 0},
  {&__pyx_n_u_Address1, __pyx_k_Address1, sizeof(__pyx_k_Address1), 0, 1, 0, 1},
  {&__pyx_n_u_Address2, __pyx_k_Address2, sizeof(__pyx_k_Address2), 0, 1, 0, 1},
  {&__pyx_kp_u_Address_1_Phone, __pyx_k_Address_1_Phone, sizeof(__pyx_k_Address_1_Phone), 0, 1, 0, 0},
  {&__pyx_kp_u_Address_2, __pyx_k_Address_2, sizeof(__pyx_k_Address_2), 0, 1, 0, 0},
  {&__pyx_n_u_AdminFee, __pyx_k_AdminFee, sizeof(__pyx_k_AdminFee), 0, 1, 0, 1},
  {&__pyx_n_u_AdminFee1, __pyx_k_AdminFee1, sizeof(__pyx_k_AdminFee1), 0, 1, 0, 1},
  {&__pyx_n_u_AdminUpdatedBy, __pyx_k_AdminUpdatedBy, sizeof(__pyx_k_AdminUpdatedBy), 0, 1, 0, 1},
  {&__pyx_n_u_AgencyORI, __pyx_k_AgencyORI, sizeof(__pyx_k_AgencyORI), 0, 1, 0, 1},
  {&__pyx_kp_u_Agency_ORI_A_Z_s, __pyx_k_Agency_ORI_A_Z_s, sizeof(__pyx_k_Agency_ORI_A_Z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Alacourt_com_d_d_d_d_d_d_d_d, __pyx_k_Alacourt_com_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Alacourt_com_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_Alias, __pyx_k_Alias, sizeof(__pyx_k_Alias), 0, 1, 0, 1},
  {&__pyx_n_u_AllPagesText, __pyx_k_AllPagesText, sizeof(__pyx_k_AllPagesText), 0, 1, 0, 1},
  {&__pyx_n_u_AmtDue, __pyx_k_AmtDue, sizeof(__pyx_k_AmtDue), 0, 1, 0, 1},
  {&__pyx_n_u_AmtHold, __pyx_k_AmtHold, sizeof(__pyx_k_AmtHold), 0, 1, 0, 1},
  {&__pyx_n_u_AmtHold1, __pyx_k_AmtHold1, sizeof(__pyx_k_AmtHold1), 0, 1, 0, 1},
  {&__pyx_n_u_AmtPaid, __pyx_k_AmtPaid, sizeof(__pyx_k_AmtPaid), 0, 1, 0, 1},
  {&__pyx_n_u_AppealCourt, __pyx_k_AppealCourt, sizeof(__pyx_k_AppealCourt), 0, 1, 0, 1},
  {&__pyx_n_u_AppealDate, __pyx_k_AppealDate, sizeof(__pyx_k_AppealDate), 0, 1, 0, 1},
  {&__pyx_n_u_AppealStatus, __pyx_k_AppealStatus, sizeof(__pyx_k_AppealStatus), 0, 1, 0, 1},
  {&__pyx_n_u_AppealTo, __pyx_k_AppealTo, sizeof(__pyx_k_AppealTo), 0, 1, 0, 1},
  {&__pyx_n_u_AppealToDesc, __pyx_k_AppealToDesc, sizeof(__pyx_k_AppealToDesc), 0, 1, 0, 1},
  {&__pyx_kp_u_Appeal_Status_A_Z_s, __pyx_k_Appeal_Status_A_Z_s, sizeof(__pyx_k_Appeal_Status_A_Z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Appeal_To_Desc_A_Z_s, __pyx_k_Appeal_To_Desc_A_Z_s, sizeof(__pyx_k_Appeal_To_Desc_A_Z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Appeal_To_w_Appeal, __pyx_k_Appeal_To_w_Appeal, sizeof(__pyx_k_Appeal_To_w_Appeal), 0, 1, 0, 0},
  {&__pyx_kp_u_Append_failed_Archive_at_output, __pyx_k_Append_failed_Archive_at_output, sizeof(__pyx_k_Append_failed_Archive_at_output), 0, 1, 0, 0},
  {&__pyx_n_u_ArrestDate, __pyx_k_ArrestDate, sizeof(__pyx_k_ArrestDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Arrest_Date_d_d_d_d_d_d_d_d, __pyx_k_Arrest_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Arrest_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_ArrestingAgencyType, __pyx_k_ArrestingAgencyType, sizeof(__pyx_k_ArrestingAgencyType), 0, 1, 0, 1},
  {&__pyx_n_u_ArrestingOfficer, __pyx_k_ArrestingOfficer, sizeof(__pyx_k_ArrestingOfficer), 0, 1, 0, 1},
  {&__pyx_kp_u_Arresting_Officer_A_Z_s, __pyx_k_Arresting_Officer_A_Z_s, sizeof(__pyx_k_Arresting_Officer_A_Z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_BOUND_GUILTY_PLEA_WAIVED_TO_GJ, __pyx_k_BOUND_GUILTY_PLEA_WAIVED_TO_GJ, sizeof(__pyx_k_BOUND_GUILTY_PLEA_WAIVED_TO_GJ), 0, 1, 0, 0},
  {&__pyx_kp_u_B_W_H_A_F_M, __pyx_k_B_W_H_A_F_M, sizeof(__pyx_k_B_W_H_A_F_M), 0, 1, 0, 0},
  {&__pyx_kp_u_B_W_H_A_F_M_2, __pyx_k_B_W_H_A_F_M_2, sizeof(__pyx_k_B_W_H_A_F_M_2), 0, 1, 0, 0},
  {&__pyx_kp_u_B_W_H_A_F_M_3, __pyx_k_B_W_H_A_F_M_3, sizeof(__pyx_k_B_W_H_A_F_M_3), 0, 1, 0, 0},
  {&__pyx_n_u_Balance, __pyx_k_Balance, sizeof(__pyx_k_Balance), 0, 1, 0, 1},
  {&__pyx_n_u_BondAmt, __pyx_k_BondAmt, sizeof(__pyx_k_BondAmt), 0, 1, 0, 1},
  {&__pyx_n_u_BondCompany, __pyx_k_BondCompany, sizeof(__pyx_k_BondCompany), 0, 1, 0, 1},
  {&__pyx_n_u_BondReleaseDate, __pyx_k_BondReleaseDate, sizeof(__pyx_k_BondReleaseDate), 0, 1, 0, 1},
  {&__pyx_n_u_BondType, __pyx_k_BondType, sizeof(__pyx_k_BondType), 0, 1, 0, 1},
  {&__pyx_n_u_BondTypeDesc, __pyx_k_BondTypeDesc, sizeof(__pyx_k_BondTypeDesc), 0, 1, 0, 1},
  {&__pyx_kp_u_Bond_Company_A_Z0_9, __pyx_k_Bond_Company_A_Z0_9, sizeof(__pyx_k_Bond_Company_A_Z0_9), 0, 1, 0, 0},
  {&__pyx_kp_u_Bond_Type_Desc_A_Z_s, __pyx_k_Bond_Type_Desc_A_Z_s, sizeof(__pyx_k_Bond_Type_Desc_A_Z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Bond_Type_w, __pyx_k_Bond_Type_w, sizeof(__pyx_k_Bond_Type_w), 0, 1, 0, 0},
  {&__pyx_n_u_BondsmanProcessIssuance, __pyx_k_BondsmanProcessIssuance, sizeof(__pyx_k_BondsmanProcessIssuance), 0, 1, 0, 1},
  {&__pyx_n_u_BondsmanProcessReturn, __pyx_k_BondsmanProcessReturn, sizeof(__pyx_k_BondsmanProcessReturn), 0, 1, 0, 1},
  {&__pyx_kp_u_Bondsman_Process_Issuance_n_Bond, __pyx_k_Bondsman_Process_Issuance_n_Bond, sizeof(__pyx_k_Bondsman_Process_Issuance_n_Bond), 0, 1, 0, 0},
  {&__pyx_kp_u_Bondsman_Process_Return_Number_o, __pyx_k_Bondsman_Process_Return_Number_o, sizeof(__pyx_k_Bondsman_Process_Return_Number_o), 0, 1, 0, 0},
  {&__pyx_n_s_By, __pyx_k_By, sizeof(__pyx_k_By), 0, 0, 1, 1},
  {&__pyx_kp_u_C, __pyx_k_C, sizeof(__pyx_k_C), 0, 1, 0, 0},
  {&__pyx_n_u_CASES_FOUND, __pyx_k_CASES_FOUND, sizeof(__pyx_k_CASES_FOUND), 0, 1, 0, 1},
  {&__pyx_n_u_CASE_YEAR, __pyx_k_CASE_YEAR, sizeof(__pyx_k_CASE_YEAR), 0, 1, 0, 1},
  {&__pyx_n_u_CERVDisqCharge, __pyx_k_CERVDisqCharge, sizeof(__pyx_k_CERVDisqCharge), 0, 1, 0, 1},
  {&__pyx_n_u_CERVDisqConviction, __pyx_k_CERVDisqConviction, sizeof(__pyx_k_CERVDisqConviction), 0, 1, 0, 1},
  {&__pyx_n_u_CERV_DISQ_MATCH, __pyx_k_CERV_DISQ_MATCH, sizeof(__pyx_k_CERV_DISQ_MATCH), 0, 1, 0, 1},
  {&__pyx_n_s_CLASS_NAME, __pyx_k_CLASS_NAME, sizeof(__pyx_k_CLASS_NAME), 0, 0, 1, 1},
  {&__pyx_n_u_CLEAN_Phone, __pyx_k_CLEAN_Phone, sizeof(__pyx_k_CLEAN_Phone), 0, 1, 0, 1},
  {&__pyx_kp_u_CM_d_d_CMUR_CAPITAL, __pyx_k_CM_d_d_CMUR_CAPITAL, sizeof(__pyx_k_CM_d_d_CMUR_CAPITAL), 0, 1, 0, 0},
  {&__pyx_kp_u_COMPLETE_AA, __pyx_k_COMPLETE_AA, sizeof(__pyx_k_COMPLETE_AA), 0, 1, 0, 0},
  {&__pyx_kp_u_COMPLETE_MA, __pyx_k_COMPLETE_MA, sizeof(__pyx_k_COMPLETE_MA), 0, 1, 0, 0},
  {&__pyx_kp_u_COMPLETE_SQ, __pyx_k_COMPLETE_SQ, sizeof(__pyx_k_COMPLETE_SQ), 0, 1, 0, 0},
  {&__pyx_kp_u_COMPLETE_TB, __pyx_k_COMPLETE_TB, sizeof(__pyx_k_COMPLETE_TB), 0, 1, 0, 0},
  {&__pyx_n_s_CONTEXT_SETTINGS, __pyx_k_CONTEXT_SETTINGS, sizeof(__pyx_k_CONTEXT_SETTINGS), 0, 0, 1, 1},
  {&__pyx_n_u_CONVICTED, __pyx_k_CONVICTED, sizeof(__pyx_k_CONVICTED), 0, 1, 0, 1},
  {&__pyx_n_u_COUNT, __pyx_k_COUNT, sizeof(__pyx_k_COUNT), 0, 1, 0, 1},
  {&__pyx_n_u_COUNTY, __pyx_k_COUNTY, sizeof(__pyx_k_COUNTY), 0, 1, 0, 1},
  {&__pyx_n_u_C_2, __pyx_k_C_2, sizeof(__pyx_k_C_2), 0, 1, 0, 1},
  {&__pyx_n_u_CaseInitiationDate, __pyx_k_CaseInitiationDate, sizeof(__pyx_k_CaseInitiationDate), 0, 1, 0, 1},
  {&__pyx_n_u_CaseInitiationType, __pyx_k_CaseInitiationType, sizeof(__pyx_k_CaseInitiationType), 0, 1, 0, 1},
  {&__pyx_n_u_CaseNumber, __pyx_k_CaseNumber, sizeof(__pyx_k_CaseNumber), 0, 1, 0, 1},
  {&__pyx_kp_u_Case_Initiation_Date, __pyx_k_Case_Initiation_Date, sizeof(__pyx_k_Case_Initiation_Date), 0, 1, 0, 0},
  {&__pyx_kp_u_Case_Initiation_Date_d_d_d_d_d_d, __pyx_k_Case_Initiation_Date_d_d_d_d_d_d, sizeof(__pyx_k_Case_Initiation_Date_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Case_Initiation_Type_A_Z_s, __pyx_k_Case_Initiation_Type_A_Z_s, sizeof(__pyx_k_Case_Initiation_Type_A_Z_s), 0, 1, 0, 0},
  {&__pyx_kp_u_Case_Number, __pyx_k_Case_Number, sizeof(__pyx_k_Case_Number), 0, 1, 0, 0},
  {&__pyx_kp_u_Case_Number_d_d_w_County, __pyx_k_Case_Number_d_d_w_County, sizeof(__pyx_k_Case_Number_d_d_w_County), 0, 1, 0, 0},
  {&__pyx_n_u_Category, __pyx_k_Category, sizeof(__pyx_k_Category), 0, 1, 0, 1},
  {&__pyx_kp_u_Charge_A_Z_0_9_s, __pyx_k_Charge_A_Z_0_9_s, sizeof(__pyx_k_Charge_A_Z_0_9_s), 0, 1, 0, 0},
  {&__pyx_n_u_Charges, __pyx_k_Charges, sizeof(__pyx_k_Charges), 0, 1, 0, 1},
  {&__pyx_n_s_Chrome, __pyx_k_Chrome, sizeof(__pyx_k_Chrome), 0, 0, 1, 1},
  {&__pyx_n_s_ChromeOptions, __pyx_k_ChromeOptions, sizeof(__pyx_k_ChromeOptions), 0, 0, 1, 1},
  {&__pyx_n_u_Cite, __pyx_k_Cite, sizeof(__pyx_k_Cite), 0, 1, 0, 1},
  {&__pyx_n_u_City, __pyx_k_City, sizeof(__pyx_k_City), 0, 1, 0, 1},
  {&__pyx_kp_u_City_State, __pyx_k_City_State, sizeof(__pyx_k_City_State), 0, 1, 0, 0},
  {&__pyx_n_u_Code, __pyx_k_Code, sizeof(__pyx_k_Code), 0, 1, 0, 1},
  {&__pyx_kp_u_Completed_query_template, __pyx_k_Completed_query_template, sizeof(__pyx_k_Completed_query_template), 0, 1, 0, 0},
  {&__pyx_n_s_Config, __pyx_k_Config, sizeof(__pyx_k_Config), 0, 0, 1, 1},
  {&__pyx_kp_u_Connecting_to_Alacourt, __pyx_k_Connecting_to_Alacourt, sizeof(__pyx_k_Connecting_to_Alacourt), 0, 1, 0, 0},
  {&__pyx_n_u_ContentPlaceHolder1_dg_ibtnNext, __pyx_k_ContentPlaceHolder1_dg_ibtnNext, sizeof(__pyx_k_ContentPlaceHolder1_dg_ibtnNext), 0, 1, 0, 1},
  {&__pyx_n_u_ContentPlaceHolder1_dg_tcPageXof, __pyx_k_ContentPlaceHolder1_dg_tcPageXof, sizeof(__pyx_k_ContentPlaceHolder1_dg_tcPageXof), 0, 1, 0, 1},
  {&__pyx_n_u_ContentPlaceHolder1_lblResultCou, __pyx_k_ContentPlaceHolder1_lblResultCou, sizeof(__pyx_k_ContentPlaceHolder1_lblResultCou), 0, 1, 0, 1},
  {&__pyx_n_u_ContentPlaceHolder_btLogin, __pyx_k_ContentPlaceHolder_btLogin, sizeof(__pyx_k_ContentPlaceHolder_btLogin), 0, 1, 0, 1},
  {&__pyx_n_u_Conviction, __pyx_k_Conviction, sizeof(__pyx_k_Conviction), 0, 1, 0, 1},
  {&__pyx_kp_u_Could_not_find_column_Path_in_ar, __pyx_k_Could_not_find_column_Path_in_ar, sizeof(__pyx_k_Could_not_find_column_Path_in_ar), 0, 1, 0, 0},
  {&__pyx_kp_u_Could_not_find_column_Timestamp, __pyx_k_Could_not_find_column_Timestamp, sizeof(__pyx_k_Could_not_find_column_Timestamp), 0, 1, 0, 0},
  {&__pyx_kp_u_Could_not_write_to_output_path_b, __pyx_k_Could_not_write_to_output_path_b, sizeof(__pyx_k_Could_not_write_to_output_path_b), 0, 1, 0, 0},
  {&__pyx_n_u_Country, __pyx_k_Country, sizeof(__pyx_k_Country), 0, 1, 0, 1},
  {&__pyx_kp_u_Country_2, __pyx_k_Country_2, sizeof(__pyx_k_Country_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Country_w, __pyx_k_Country_w, sizeof(__pyx_k_Country_w), 0, 1, 0, 0},
  {&__pyx_n_u_County, __pyx_k_County, sizeof(__pyx_k_County), 0, 1, 0, 1},
  {&__pyx_kp_u_County_d_2, __pyx_k_County_d_2, sizeof(__pyx_k_County_d_2), 0, 1, 0, 0},
  {&__pyx_n_u_CourtAction, __pyx_k_CourtAction, sizeof(__pyx_k_CourtAction), 0, 1, 0, 1},
  {&__pyx_n_u_CourtActionDate, __pyx_k_CourtActionDate, sizeof(__pyx_k_CourtActionDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Court_Action_BOUND_GUILTY_PLEA_W, __pyx_k_Court_Action_BOUND_GUILTY_PLEA_W, sizeof(__pyx_k_Court_Action_BOUND_GUILTY_PLEA_W), 0, 1, 0, 0},
  {&__pyx_kp_u_Court_Action_Date_d_d_d_d_d_d_d, __pyx_k_Court_Action_Date_d_d_d_d_d_d_d, sizeof(__pyx_k_Court_Action_Date_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_D, __pyx_k_D, sizeof(__pyx_k_D), 0, 1, 0, 1},
  {&__pyx_n_u_D999, __pyx_k_D999, sizeof(__pyx_k_D999), 0, 1, 0, 1},
  {&__pyx_n_u_DEBUG, __pyx_k_DEBUG, sizeof(__pyx_k_DEBUG), 0, 1, 0, 1},
  {&__pyx_n_u_DIVISION, __pyx_k_DIVISION, sizeof(__pyx_k_DIVISION), 0, 1, 0, 1},
  {&__pyx_n_u_DLRAW, __pyx_k_DLRAW, sizeof(__pyx_k_DLRAW), 0, 1, 0, 1},
  {&__pyx_n_u_DOB, __pyx_k_DOB, sizeof(__pyx_k_DOB), 0, 1, 0, 1},
  {&__pyx_n_s_DataFrame, __pyx_k_DataFrame, sizeof(__pyx_k_DataFrame), 0, 0, 1, 1},
  {&__pyx_kp_u_Date_Trial_Began_but_No_Verdict, __pyx_k_Date_Trial_Began_but_No_Verdict, sizeof(__pyx_k_Date_Trial_Began_but_No_Verdict), 0, 1, 0, 0},
  {&__pyx_kp_u_Date_Trial_Began_but_No_Verdict_2, __pyx_k_Date_Trial_Began_but_No_Verdict_2, sizeof(__pyx_k_Date_Trial_Began_but_No_Verdict_2), 0, 1, 0, 0},
  {&__pyx_n_u_DefendantStatus, __pyx_k_DefendantStatus, sizeof(__pyx_k_DefendantStatus), 0, 1, 0, 1},
  {&__pyx_kp_u_Defendant_Information_JID, __pyx_k_Defendant_Information_JID, sizeof(__pyx_k_Defendant_Information_JID), 0, 1, 0, 0},
  {&__pyx_kp_u_Defendant_Status_A_Z_s, __pyx_k_Defendant_Status_A_Z_s, sizeof(__pyx_k_Defendant_Status_A_Z_s), 0, 1, 0, 0},
  {&__pyx_n_u_Defendants, __pyx_k_Defendants, sizeof(__pyx_k_Defendants), 0, 1, 0, 1},
  {&__pyx_n_u_Description, __pyx_k_Description, sizeof(__pyx_k_Description), 0, 1, 0, 1},
  {&__pyx_n_u_Disposition, __pyx_k_Disposition, sizeof(__pyx_k_Disposition), 0, 1, 0, 1},
  {&__pyx_n_u_DispositionDateOfAppeal, __pyx_k_DispositionDateOfAppeal, sizeof(__pyx_k_DispositionDateOfAppeal), 0, 1, 0, 1},
  {&__pyx_n_u_DispositionTypeOfAppeal, __pyx_k_DispositionTypeOfAppeal, sizeof(__pyx_k_DispositionTypeOfAppeal), 0, 1, 0, 1},
  {&__pyx_kp_u_Disposition_Date_Of_Appeal_d_d_d, __pyx_k_Disposition_Date_Of_Appeal_d_d_d, sizeof(__pyx_k_Disposition_Date_Of_Appeal_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Disposition_Type_Of_Appeal_A_Za, __pyx_k_Disposition_Type_Of_Appeal_A_Za, sizeof(__pyx_k_Disposition_Type_Of_Appeal_A_Za), 0, 1, 0, 0},
  {&__pyx_n_u_DomesticViolence, __pyx_k_DomesticViolence, sizeof(__pyx_k_DomesticViolence), 0, 1, 0, 1},
  {&__pyx_kp_u_Domestic_Violence_YES_NO, __pyx_k_Domestic_Violence_YES_NO, sizeof(__pyx_k_Domestic_Violence_YES_NO), 0, 1, 0, 0},
  {&__pyx_n_u_DriverLicenseNo, __pyx_k_DriverLicenseNo, sizeof(__pyx_k_DriverLicenseNo), 0, 1, 0, 1},
  {&__pyx_kp_u_Driver_License_N_A_Z0_9, __pyx_k_Driver_License_N_A_Z0_9, sizeof(__pyx_k_Driver_License_N_A_Z0_9), 0, 1, 0, 0},
  {&__pyx_n_u_EXISTING_OUTPUT, __pyx_k_EXISTING_OUTPUT, sizeof(__pyx_k_EXISTING_OUTPUT), 0, 1, 0, 1},
  {&__pyx_kp_u_Enforcement_Party, __pyx_k_Enforcement_Party, sizeof(__pyx_k_Enforcement_Party), 0, 1, 0, 0},
  {&__pyx_kp_u_Enforcement_Party_Country, __pyx_k_Enforcement_Party_Country, sizeof(__pyx_k_Enforcement_Party_Country), 0, 1, 0, 0},
  {&__pyx_kp_u_Enforcement_Party_Country_2, __pyx_k_Enforcement_Party_Country_2, sizeof(__pyx_k_Enforcement_Party_Country_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Extracting_case_info, __pyx_k_Extracting_case_info, sizeof(__pyx_k_Extracting_case_info), 0, 1, 0, 0},
  {&__pyx_kp_u_Extracting_charges, __pyx_k_Extracting_charges, sizeof(__pyx_k_Extracting_charges), 0, 1, 0, 0},
  {&__pyx_kp_u_Extracting_fee_sheets, __pyx_k_Extracting_fee_sheets, sizeof(__pyx_k_Extracting_fee_sheets), 0, 1, 0, 0},
  {&__pyx_kp_u_Extracting_text, __pyx_k_Extracting_text, sizeof(__pyx_k_Extracting_text), 0, 1, 0, 0},
  {&__pyx_n_u_Eyes, __pyx_k_Eyes, sizeof(__pyx_k_Eyes), 0, 1, 0, 1},
  {&__pyx_kp_u_Eyes_Hair_w_3_w_3, __pyx_k_Eyes_Hair_w_3_w_3, sizeof(__pyx_k_Eyes_Hair_w_3_w_3), 0, 1, 0, 0},
  {&__pyx_n_u_FEE_SEP, __pyx_k_FEE_SEP, sizeof(__pyx_k_FEE_SEP), 0, 1, 0, 1},
  {&__pyx_n_u_FELONY, __pyx_k_FELONY, sizeof(__pyx_k_FELONY), 0, 1, 0, 1},
  {&__pyx_n_u_FETCH, __pyx_k_FETCH, sizeof(__pyx_k_FETCH), 0, 1, 0, 1},
  {&__pyx_n_u_FETCH_MAX, __pyx_k_FETCH_MAX, sizeof(__pyx_k_FETCH_MAX), 0, 1, 0, 1},
  {&__pyx_n_u_FETCH_SKIP, __pyx_k_FETCH_SKIP, sizeof(__pyx_k_FETCH_SKIP), 0, 1, 0, 1},
  {&__pyx_n_u_FILED_AFTER, __pyx_k_FILED_AFTER, sizeof(__pyx_k_FILED_AFTER), 0, 1, 0, 1},
  {&__pyx_n_u_FILED_BEFORE, __pyx_k_FILED_BEFORE, sizeof(__pyx_k_FILED_BEFORE), 0, 1, 0, 1},
  {&__pyx_n_u_FOUND, __pyx_k_FOUND, sizeof(__pyx_k_FOUND), 0, 1, 0, 1},
  {&__pyx_n_u_FailedToAppearDate, __pyx_k_FailedToAppearDate, sizeof(__pyx_k_FailedToAppearDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Failed_to_Appear_Date_d_d_d_d_d, __pyx_k_Failed_to_Appear_Date_d_d_d_d_d, sizeof(__pyx_k_Failed_to_Appear_Date_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Failed_to_determine_input_type, __pyx_k_Failed_to_determine_input_type, sizeof(__pyx_k_Failed_to_determine_input_type), 0, 1, 0, 0},
  {&__pyx_n_u_FeeStatus, __pyx_k_FeeStatus, sizeof(__pyx_k_FeeStatus), 0, 1, 0, 1},
  {&__pyx_n_u_FeeStatus1, __pyx_k_FeeStatus1, sizeof(__pyx_k_FeeStatus1), 0, 1, 0, 1},
  {&__pyx_n_u_FeeStatus2, __pyx_k_FeeStatus2, sizeof(__pyx_k_FeeStatus2), 0, 1, 0, 1},
  {&__pyx_n_u_Fees, __pyx_k_Fees, sizeof(__pyx_k_Fees), 0, 1, 0, 1},
  {&__pyx_n_u_Felony, __pyx_k_Felony, sizeof(__pyx_k_Felony), 0, 1, 0, 1},
  {&__pyx_n_u_Filing, __pyx_k_Filing, sizeof(__pyx_k_Filing), 0, 1, 0, 1},
  {&__pyx_n_u_FilingDate, __pyx_k_FilingDate, sizeof(__pyx_k_FilingDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Filing_Date, __pyx_k_Filing_Date, sizeof(__pyx_k_Filing_Date), 0, 1, 0, 0},
  {&__pyx_kp_u_Filing_Date_d_d_d_d_d_d_d_d, __pyx_k_Filing_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Filing_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_s_Float64, __pyx_k_Float64, sizeof(__pyx_k_Float64), 0, 0, 1, 1},
  {&__pyx_kp_u_Found, __pyx_k_Found, sizeof(__pyx_k_Found), 0, 1, 0, 0},
  {&__pyx_kp_u_Found_no_results, __pyx_k_Found_no_results, sizeof(__pyx_k_Found_no_results), 0, 1, 0, 0},
  {&__pyx_kp_u_GUILTY_PLEA, __pyx_k_GUILTY_PLEA, sizeof(__pyx_k_GUILTY_PLEA), 0, 1, 0, 0},
  {&__pyx_n_u_GUILTY_PLEA_2, __pyx_k_GUILTY_PLEA_2, sizeof(__pyx_k_GUILTY_PLEA_2), 0, 1, 0, 1},
  {&__pyx_n_u_Hair, __pyx_k_Hair, sizeof(__pyx_k_Hair), 0, 1, 0, 1},
  {&__pyx_n_u_Height, __pyx_k_Height, sizeof(__pyx_k_Height), 0, 1, 0, 1},
  {&__pyx_kp_u_Height_d_d_2, __pyx_k_Height_d_d_2, sizeof(__pyx_k_Height_d_d_2), 0, 1, 0, 0},
  {&__pyx_n_s_ID, __pyx_k_ID, sizeof(__pyx_k_ID), 0, 0, 1, 1},
  {&__pyx_n_u_INPUTS, __pyx_k_INPUTS, sizeof(__pyx_k_INPUTS), 0, 1, 0, 1},
  {&__pyx_n_u_INPUT_TYPE, __pyx_k_INPUT_TYPE, sizeof(__pyx_k_INPUT_TYPE), 0, 1, 0, 1},
  {&__pyx_n_u_IndictmentDate, __pyx_k_IndictmentDate, sizeof(__pyx_k_IndictmentDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Indictment_Date_d_d_d_d_d_d_d_d, __pyx_k_Indictment_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Indictment_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_InpatientTreatmentOrdered, __pyx_k_InpatientTreatmentOrdered, sizeof(__pyx_k_InpatientTreatmentOrdered), 0, 1, 0, 1},
  {&__pyx_kp_u_Inpatient_Treatment_Ordered_YES, __pyx_k_Inpatient_Treatment_Ordered_YES, sizeof(__pyx_k_Inpatient_Treatment_Ordered_YES), 0, 1, 0, 0},
  {&__pyx_n_s_Int64, __pyx_k_Int64, sizeof(__pyx_k_Int64), 0, 0, 1, 1},
  {&__pyx_n_u_J, __pyx_k_J, sizeof(__pyx_k_J), 0, 1, 0, 1},
  {&__pyx_kp_u_JID_w_3_Hardship_Defendant_Infor, __pyx_k_JID_w_3_Hardship_Defendant_Infor, sizeof(__pyx_k_JID_w_3_Hardship_Defendant_Infor), 0, 1, 0, 0},
  {&__pyx_n_u_JailCreditPeriod, __pyx_k_JailCreditPeriod, sizeof(__pyx_k_JailCreditPeriod), 0, 1, 0, 1},
  {&__pyx_kp_u_Jail_Credit_Period, __pyx_k_Jail_Credit_Period, sizeof(__pyx_k_Jail_Credit_Period), 0, 1, 0, 0},
  {&__pyx_kp_u_Jail_Credit_Period_2, __pyx_k_Jail_Credit_Period_2, sizeof(__pyx_k_Jail_Credit_Period_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Job_not_specified_Select_a_mode, __pyx_k_Job_not_specified_Select_a_mode, sizeof(__pyx_k_Job_not_specified_Select_a_mode), 0, 1, 0, 0},
  {&__pyx_n_u_Judge, __pyx_k_Judge, sizeof(__pyx_k_Judge), 0, 1, 0, 1},
  {&__pyx_kp_u_Judge_A_Z_s, __pyx_k_Judge_A_Z_s, sizeof(__pyx_k_Judge_A_Z_s), 0, 1, 0, 0},
  {&__pyx_n_u_JuryDemand, __pyx_k_JuryDemand, sizeof(__pyx_k_JuryDemand), 0, 1, 0, 1},
  {&__pyx_kp_u_Jury_Demand_A_Z, __pyx_k_Jury_Demand_A_Z, sizeof(__pyx_k_Jury_Demand_A_Z), 0, 1, 0, 0},
  {&__pyx_n_u_L, __pyx_k_L, sizeof(__pyx_k_L), 0, 1, 0, 1},
  {&__pyx_kp_u_Last_Update, __pyx_k_Last_Update, sizeof(__pyx_k_Last_Update), 0, 1, 0, 0},
  {&__pyx_kp_u_Last_Update_d_d_d_d_d_d_d_d, __pyx_k_Last_Update_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Last_Update_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_LicenseSuspPeriod, __pyx_k_LicenseSuspPeriod, sizeof(__pyx_k_LicenseSuspPeriod), 0, 1, 0, 1},
  {&__pyx_kp_u_License_Susp_Period, __pyx_k_License_Susp_Period, sizeof(__pyx_k_License_Susp_Period), 0, 1, 0, 0},
  {&__pyx_kp_u_License_Susp_Period_2, __pyx_k_License_Susp_Period_2, sizeof(__pyx_k_License_Susp_Period_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Logging_in, __pyx_k_Logging_in, sizeof(__pyx_k_Logging_in), 0, 1, 0, 0},
  {&__pyx_n_u_LowerCourtAppealDate, __pyx_k_LowerCourtAppealDate, sizeof(__pyx_k_LowerCourtAppealDate), 0, 1, 0, 1},
  {&__pyx_kp_u_LowerCourt_Appeal_Date_d_d_d_d_d, __pyx_k_LowerCourt_Appeal_Date_d_d_d_d_d, sizeof(__pyx_k_LowerCourt_Appeal_Date_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_MISDEMEANOR, __pyx_k_MISDEMEANOR, sizeof(__pyx_k_MISDEMEANOR), 0, 1, 0, 1},
  {&__pyx_n_s_NAME, __pyx_k_NAME, sizeof(__pyx_k_NAME), 0, 0, 1, 1},
  {&__pyx_n_u_NAME, __pyx_k_NAME, sizeof(__pyx_k_NAME), 0, 1, 0, 1},
  {&__pyx_n_u_NEEDTEXT, __pyx_k_NEEDTEXT, sizeof(__pyx_k_NEEDTEXT), 0, 1, 0, 1},
  {&__pyx_n_u_NO_PROMPT, __pyx_k_NO_PROMPT, sizeof(__pyx_k_NO_PROMPT), 0, 1, 0, 1},
  {&__pyx_n_u_NO_RECORDS, __pyx_k_NO_RECORDS, sizeof(__pyx_k_NO_RECORDS), 0, 1, 0, 1},
  {&__pyx_n_u_NO_UPDATE, __pyx_k_NO_UPDATE, sizeof(__pyx_k_NO_UPDATE), 0, 1, 0, 1},
  {&__pyx_n_u_NO_WRITE, __pyx_k_NO_WRITE, sizeof(__pyx_k_NO_WRITE), 0, 1, 0, 1},
  {&__pyx_n_u_Name, __pyx_k_Name, sizeof(__pyx_k_Name), 0, 1, 0, 1},
  {&__pyx_n_s_NoSuchElementException, __pyx_k_NoSuchElementException, sizeof(__pyx_k_NoSuchElementException), 0, 0, 1, 1},
  {&__pyx_kp_u_NoSuchElementException_on_alac_p, __pyx_k_NoSuchElementException_on_alac_p, sizeof(__pyx_k_NoSuchElementException_on_alac_p), 0, 1, 0, 0},
  {&__pyx_n_u_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 1, 0, 1},
  {&__pyx_n_u_Num, __pyx_k_Num, sizeof(__pyx_k_Num), 0, 1, 0, 1},
  {&__pyx_n_u_NumberOfSubpoenas, __pyx_k_NumberOfSubpoenas, sizeof(__pyx_k_NumberOfSubpoenas), 0, 1, 0, 1},
  {&__pyx_n_u_NumberOfWarrants, __pyx_k_NumberOfWarrants, sizeof(__pyx_k_NumberOfWarrants), 0, 1, 0, 1},
  {&__pyx_kp_u_Number_Of_Warrants_d_3_s_d_3, __pyx_k_Number_Of_Warrants_d_3_s_d_3, sizeof(__pyx_k_Number_Of_Warrants_d_3_s_d_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Number_of_Subponeas_d_3, __pyx_k_Number_of_Subponeas_d_3, sizeof(__pyx_k_Number_of_Subponeas_d_3), 0, 1, 0, 0},
  {&__pyx_kp_u_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A, __pyx_k_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A, sizeof(__pyx_k_OSUA_EGUA_MAN1_MAN2_MANS_ASS1_A), 0, 1, 0, 0},
  {&__pyx_n_u_OUTPUT_EXT, __pyx_k_OUTPUT_EXT, sizeof(__pyx_k_OUTPUT_EXT), 0, 1, 0, 1},
  {&__pyx_n_u_OUTPUT_PATH, __pyx_k_OUTPUT_PATH, sizeof(__pyx_k_OUTPUT_PATH), 0, 1, 0, 1},
  {&__pyx_n_u_OVERWRITE, __pyx_k_OVERWRITE, sizeof(__pyx_k_OVERWRITE), 0, 1, 0, 1},
  {&__pyx_n_u_OffenseDate, __pyx_k_OffenseDate, sizeof(__pyx_k_OffenseDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Offense_Date_d_d_d_d_d_d_d_d, __pyx_k_Offense_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Offense_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_s_Options, __pyx_k_Options, sizeof(__pyx_k_Options), 0, 0, 1, 1},
  {&__pyx_kp_u_Orgin_Of_Appeal_A_Z_s, __pyx_k_Orgin_Of_Appeal_A_Z_s, sizeof(__pyx_k_Orgin_Of_Appeal_A_Z_s), 0, 1, 0, 0},
  {&__pyx_n_u_OriginOfAppeal, __pyx_k_OriginOfAppeal, sizeof(__pyx_k_OriginOfAppeal), 0, 1, 0, 1},
  {&__pyx_n_u_P, __pyx_k_P, sizeof(__pyx_k_P), 0, 1, 0, 1},
  {&__pyx_n_u_PARDON_DISQ_MATCH, __pyx_k_PARDON_DISQ_MATCH, sizeof(__pyx_k_PARDON_DISQ_MATCH), 0, 1, 0, 1},
  {&__pyx_n_u_PARTY_TYPE, __pyx_k_PARTY_TYPE, sizeof(__pyx_k_PARTY_TYPE), 0, 1, 0, 1},
  {&__pyx_n_u_PDF, __pyx_k_PDF, sizeof(__pyx_k_PDF), 0, 1, 0, 1},
  {&__pyx_n_u_PERM_DISQ_MATCH, __pyx_k_PERM_DISQ_MATCH, sizeof(__pyx_k_PERM_DISQ_MATCH), 0, 1, 0, 1},
  {&__pyx_n_u_PROBATIONOFFICENUMBERRAW, __pyx_k_PROBATIONOFFICENUMBERRAW, sizeof(__pyx_k_PROBATIONOFFICENUMBERRAW), 0, 1, 0, 1},
  {&__pyx_n_u_PROGRESS, __pyx_k_PROGRESS, sizeof(__pyx_k_PROGRESS), 0, 1, 0, 1},
  {&__pyx_kp_u_PROGRESS_TEXT, __pyx_k_PROGRESS_TEXT, sizeof(__pyx_k_PROGRESS_TEXT), 0, 1, 0, 0},
  {&__pyx_kp_u_PROGRESS_TEXT_TOTAL, __pyx_k_PROGRESS_TEXT_TOTAL, sizeof(__pyx_k_PROGRESS_TEXT_TOTAL), 0, 1, 0, 0},
  {&__pyx_n_u_PROGRESS_TOTAL, __pyx_k_PROGRESS_TOTAL, sizeof(__pyx_k_PROGRESS_TOTAL), 0, 1, 0, 1},
  {&__pyx_n_u_PardonDisqCharge, __pyx_k_PardonDisqCharge, sizeof(__pyx_k_PardonDisqCharge), 0, 1, 0, 1},
  {&__pyx_n_u_PardonDisqConviction, __pyx_k_PardonDisqConviction, sizeof(__pyx_k_PardonDisqConviction), 0, 1, 0, 1},
  {&__pyx_kp_u_Parsing_charges, __pyx_k_Parsing_charges, sizeof(__pyx_k_Parsing_charges), 0, 1, 0, 0},
  {&__pyx_kp_u_Parsing_fees_tables, __pyx_k_Parsing_fees_tables, sizeof(__pyx_k_Parsing_fees_tables), 0, 1, 0, 0},
  {&__pyx_n_u_Path, __pyx_k_Path, sizeof(__pyx_k_Path), 0, 1, 0, 1},
  {&__pyx_n_u_Payee, __pyx_k_Payee, sizeof(__pyx_k_Payee), 0, 1, 0, 1},
  {&__pyx_n_u_Payee1, __pyx_k_Payee1, sizeof(__pyx_k_Payee1), 0, 1, 0, 1},
  {&__pyx_n_u_Payee2, __pyx_k_Payee2, sizeof(__pyx_k_Payee2), 0, 1, 0, 1},
  {&__pyx_n_u_PaymentToRestore, __pyx_k_PaymentToRestore, sizeof(__pyx_k_PaymentToRestore), 0, 1, 0, 1},
  {&__pyx_n_u_Payor, __pyx_k_Payor, sizeof(__pyx_k_Payor), 0, 1, 0, 1},
  {&__pyx_n_u_Payor1, __pyx_k_Payor1, sizeof(__pyx_k_Payor1), 0, 1, 0, 1},
  {&__pyx_n_u_Payor2, __pyx_k_Payor2, sizeof(__pyx_k_Payor2), 0, 1, 0, 1},
  {&__pyx_n_u_PermanentDisqCharge, __pyx_k_PermanentDisqCharge, sizeof(__pyx_k_PermanentDisqCharge), 0, 1, 0, 1},
  {&__pyx_n_u_PermanentDisqConviction, __pyx_k_PermanentDisqConviction, sizeof(__pyx_k_PermanentDisqConviction), 0, 1, 0, 1},
  {&__pyx_kp_u_Phone, __pyx_k_Phone, sizeof(__pyx_k_Phone), 0, 1, 0, 0},
  {&__pyx_kp_u_Phone_2, __pyx_k_Phone_2, sizeof(__pyx_k_Phone_2), 0, 1, 0, 0},
  {&__pyx_n_u_Phone_3, __pyx_k_Phone_3, sizeof(__pyx_k_Phone_3), 0, 1, 0, 1},
  {&__pyx_kp_u_Phone_4, __pyx_k_Phone_4, sizeof(__pyx_k_Phone_4), 0, 1, 0, 0},
  {&__pyx_n_u_Plaintiffs, __pyx_k_Plaintiffs, sizeof(__pyx_k_Plaintiffs), 0, 1, 0, 1},
  {&__pyx_n_u_PreviousDUIConvictions, __pyx_k_PreviousDUIConvictions, sizeof(__pyx_k_PreviousDUIConvictions), 0, 1, 0, 1},
  {&__pyx_kp_u_Previous_DUI_Convictions_d_3, __pyx_k_Previous_DUI_Convictions_d_3, sizeof(__pyx_k_Previous_DUI_Convictions_d_3), 0, 1, 0, 0},
  {&__pyx_n_u_ProbationBeginDate, __pyx_k_ProbationBeginDate, sizeof(__pyx_k_ProbationBeginDate), 0, 1, 0, 1},
  {&__pyx_n_u_ProbationOfficeName, __pyx_k_ProbationOfficeName, sizeof(__pyx_k_ProbationOfficeName), 0, 1, 0, 1},
  {&__pyx_n_u_ProbationPeriod, __pyx_k_ProbationPeriod, sizeof(__pyx_k_ProbationPeriod), 0, 1, 0, 1},
  {&__pyx_n_u_ProbationRevoke, __pyx_k_ProbationRevoke, sizeof(__pyx_k_ProbationRevoke), 0, 1, 0, 1},
  {&__pyx_kp_u_Probation_Begin_Date, __pyx_k_Probation_Begin_Date, sizeof(__pyx_k_Probation_Begin_Date), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Begin_Date_d_d_d_d_d_d, __pyx_k_Probation_Begin_Date_d_d_d_d_d_d, sizeof(__pyx_k_Probation_Begin_Date_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Office_0_9, __pyx_k_Probation_Office_0_9, sizeof(__pyx_k_Probation_Office_0_9), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Office_Name_A_Z0_9, __pyx_k_Probation_Office_Name_A_Z0_9, sizeof(__pyx_k_Probation_Office_Name_A_Z0_9), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Period, __pyx_k_Probation_Period, sizeof(__pyx_k_Probation_Period), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Revoke, __pyx_k_Probation_Revoke, sizeof(__pyx_k_Probation_Revoke), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Revoke_2, __pyx_k_Probation_Revoke_2, sizeof(__pyx_k_Probation_Revoke_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Probation_Revoke_d_d_d_d_d_d_d_d, __pyx_k_Probation_Revoke_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Probation_Revoke_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_QUERY_COMPLETE, __pyx_k_QUERY_COMPLETE, sizeof(__pyx_k_QUERY_COMPLETE), 0, 1, 0, 1},
  {&__pyx_n_u_QUEUE, __pyx_k_QUEUE, sizeof(__pyx_k_QUEUE), 0, 1, 0, 1},
  {&__pyx_kp_u_R0_9_d_3, __pyx_k_R0_9_d_3, sizeof(__pyx_k_R0_9_d_3), 0, 1, 0, 0},
  {&__pyx_kp_u_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S, __pyx_k_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S, sizeof(__pyx_k_RAP1_RAP2_SOD1_SOD2_STSA_SXA1_S), 0, 1, 0, 0},
  {&__pyx_n_u_RAWHEIGHT, __pyx_k_RAWHEIGHT, sizeof(__pyx_k_RAWHEIGHT), 0, 1, 0, 1},
  {&__pyx_n_u_RETRIEVED, __pyx_k_RETRIEVED, sizeof(__pyx_k_RETRIEVED), 0, 1, 0, 1},
  {&__pyx_n_u_RE_Charges, __pyx_k_RE_Charges, sizeof(__pyx_k_RE_Charges), 0, 1, 0, 1},
  {&__pyx_n_u_RE_Fees, __pyx_k_RE_Fees, sizeof(__pyx_k_RE_Fees), 0, 1, 0, 1},
  {&__pyx_n_u_RE_Phone, __pyx_k_RE_Phone, sizeof(__pyx_k_RE_Phone), 0, 1, 0, 1},
  {&__pyx_n_u_Race, __pyx_k_Race, sizeof(__pyx_k_Race), 0, 1, 0, 1},
  {&__pyx_n_u_RelatedCases, __pyx_k_RelatedCases, sizeof(__pyx_k_RelatedCases), 0, 1, 0, 1},
  {&__pyx_kp_u_Release_Date_d_d_d_d_d_d_d_d, __pyx_k_Release_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Release_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Requrements_Completed_YES_NO, __pyx_k_Requrements_Completed_YES_NO, sizeof(__pyx_k_Requrements_Completed_YES_NO), 0, 1, 0, 0},
  {&__pyx_n_u_Retrieved, __pyx_k_Retrieved, sizeof(__pyx_k_Retrieved), 0, 1, 0, 1},
  {&__pyx_n_u_S, __pyx_k_S, sizeof(__pyx_k_S), 0, 1, 0, 1},
  {&__pyx_n_u_SEG_2, __pyx_k_SEG_2, sizeof(__pyx_k_SEG_2), 0, 1, 0, 1},
  {&__pyx_n_u_SHORTCASENO, __pyx_k_SHORTCASENO, sizeof(__pyx_k_SHORTCASENO), 0, 1, 0, 1},
  {&__pyx_n_u_SHORTCOUNTY, __pyx_k_SHORTCOUNTY, sizeof(__pyx_k_SHORTCOUNTY), 0, 1, 0, 1},
  {&__pyx_n_u_SIDRAW, __pyx_k_SIDRAW, sizeof(__pyx_k_SIDRAW), 0, 1, 0, 1},
  {&__pyx_n_u_SPACE_SEP, __pyx_k_SPACE_SEP, sizeof(__pyx_k_SPACE_SEP), 0, 1, 0, 1},
  {&__pyx_n_u_SSN, __pyx_k_SSN, sizeof(__pyx_k_SSN), 0, 1, 0, 1},
  {&__pyx_kp_u_SSN_5_75_Alias, __pyx_k_SSN_5_75_Alias, sizeof(__pyx_k_SSN_5_75_Alias), 0, 1, 0, 0},
  {&__pyx_kp_u_SSN_X_d_3_X_d_2_X_d_4, __pyx_k_SSN_X_d_3_X_d_2_X_d_4, sizeof(__pyx_k_SSN_X_d_3_X_d_2_X_d_4), 0, 1, 0, 0},
  {&__pyx_n_u_SUPPORT_ARCHIVE, __pyx_k_SUPPORT_ARCHIVE, sizeof(__pyx_k_SUPPORT_ARCHIVE), 0, 1, 0, 1},
  {&__pyx_n_u_SUPPORT_MULTITABLE, __pyx_k_SUPPORT_MULTITABLE, sizeof(__pyx_k_SUPPORT_MULTITABLE), 0, 1, 0, 1},
  {&__pyx_n_u_SUPPORT_SINGLETABLE, __pyx_k_SUPPORT_SINGLETABLE, sizeof(__pyx_k_SUPPORT_SINGLETABLE), 0, 1, 0, 1},
  {&__pyx_kp_u_S_N, __pyx_k_S_N, sizeof(__pyx_k_S_N), 0, 1, 0, 0},
  {&__pyx_kp_u_Search_Results, __pyx_k_Search_Results, sizeof(__pyx_k_Search_Results), 0, 1, 0, 0},
  {&__pyx_n_s_Select, __pyx_k_Select, sizeof(__pyx_k_Select), 0, 0, 1, 1},
  {&__pyx_n_u_SentenceDate, __pyx_k_SentenceDate, sizeof(__pyx_k_SentenceDate), 0, 1, 0, 1},
  {&__pyx_n_u_SentenceEndDate, __pyx_k_SentenceEndDate, sizeof(__pyx_k_SentenceEndDate), 0, 1, 0, 1},
  {&__pyx_n_u_SentenceLastUpdate, __pyx_k_SentenceLastUpdate, sizeof(__pyx_k_SentenceLastUpdate), 0, 1, 0, 1},
  {&__pyx_n_u_SentenceProvisions, __pyx_k_SentenceProvisions, sizeof(__pyx_k_SentenceProvisions), 0, 1, 0, 1},
  {&__pyx_n_u_SentenceStartDate, __pyx_k_SentenceStartDate, sizeof(__pyx_k_SentenceStartDate), 0, 1, 0, 1},
  {&__pyx_n_u_SentenceUpdatedBy, __pyx_k_SentenceUpdatedBy, sizeof(__pyx_k_SentenceUpdatedBy), 0, 1, 0, 1},
  {&__pyx_kp_u_Sentence_Date, __pyx_k_Sentence_Date, sizeof(__pyx_k_Sentence_Date), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d, __pyx_k_Sentence_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Sentence_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_Date_d_d_d_d_d_d_d_d_2, __pyx_k_Sentence_Date_d_d_d_d_d_d_d_d_2, sizeof(__pyx_k_Sentence_Date_d_d_d_d_d_d_d_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_End_Date, __pyx_k_Sentence_End_Date, sizeof(__pyx_k_Sentence_End_Date), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_End_Date_d_d_d_d_d_d_d, __pyx_k_Sentence_End_Date_d_d_d_d_d_d_d, sizeof(__pyx_k_Sentence_End_Date_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_Provisions, __pyx_k_Sentence_Provisions, sizeof(__pyx_k_Sentence_Provisions), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_Provisions_Y_N, __pyx_k_Sentence_Provisions_Y_N, sizeof(__pyx_k_Sentence_Provisions_Y_N), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_Start_Date, __pyx_k_Sentence_Start_Date, sizeof(__pyx_k_Sentence_Start_Date), 0, 1, 0, 0},
  {&__pyx_kp_u_Sentence_Start_Date_d_d_d_d_d_d, __pyx_k_Sentence_Start_Date_d_d_d_d_d_d, sizeof(__pyx_k_Sentence_Start_Date_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_SentencingRequirementsCompleted, __pyx_k_SentencingRequirementsCompleted, sizeof(__pyx_k_SentencingRequirementsCompleted), 0, 1, 0, 1},
  {&__pyx_n_s_Series, __pyx_k_Series, sizeof(__pyx_k_Series), 0, 0, 1, 1},
  {&__pyx_n_u_Sex, __pyx_k_Sex, sizeof(__pyx_k_Sex), 0, 1, 0, 1},
  {&__pyx_kp_u_Single_table_export_choice_requi, __pyx_k_Single_table_export_choice_requi, sizeof(__pyx_k_Single_table_export_choice_requi), 0, 1, 0, 0},
  {&__pyx_n_u_Sort, __pyx_k_Sort, sizeof(__pyx_k_Sort), 0, 1, 0, 1},
  {&__pyx_n_u_Split, __pyx_k_Split, sizeof(__pyx_k_Split), 0, 1, 0, 1},
  {&__pyx_kp_u_Starting_browser_Do_not_close_wh, __pyx_k_Starting_browser_Do_not_close_wh, sizeof(__pyx_k_Starting_browser_Do_not_close_wh), 0, 1, 0, 0},
  {&__pyx_n_u_State, __pyx_k_State, sizeof(__pyx_k_State), 0, 1, 0, 1},
  {&__pyx_n_u_StateID, __pyx_k_StateID, sizeof(__pyx_k_StateID), 0, 1, 0, 1},
  {&__pyx_n_u_StreetAddress, __pyx_k_StreetAddress, sizeof(__pyx_k_StreetAddress), 0, 1, 0, 1},
  {&__pyx_kp_u_Submitted_party_search_form, __pyx_k_Submitted_party_search_form, sizeof(__pyx_k_Submitted_party_search_form), 0, 1, 0, 0},
  {&__pyx_kp_u_Successfully_configured, __pyx_k_Successfully_configured, sizeof(__pyx_k_Successfully_configured), 0, 1, 0, 0},
  {&__pyx_kp_u_Successfully_connected_and_logge, __pyx_k_Successfully_connected_and_logge, sizeof(__pyx_k_Successfully_connected_and_logge), 0, 1, 0, 0},
  {&__pyx_n_u_SuretyCode, __pyx_k_SuretyCode, sizeof(__pyx_k_SuretyCode), 0, 1, 0, 1},
  {&__pyx_kp_u_Surety_Code_A_Z0_9_4, __pyx_k_Surety_Code_A_Z0_9_4, sizeof(__pyx_k_Surety_Code_A_Z0_9_4), 0, 1, 0, 0},
  {&__pyx_n_u_T, __pyx_k_T, sizeof(__pyx_k_T), 0, 1, 0, 1},
  {&__pyx_n_u_TABLE, __pyx_k_TABLE, sizeof(__pyx_k_TABLE), 0, 1, 0, 1},
  {&__pyx_n_u_TBNV1, __pyx_k_TBNV1, sizeof(__pyx_k_TBNV1), 0, 1, 0, 1},
  {&__pyx_n_u_TBNV2, __pyx_k_TBNV2, sizeof(__pyx_k_TBNV2), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP, __pyx_k_TEMP, sizeof(__pyx_k_TEMP), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_CASE_YEAR, __pyx_k_TEMP_CASE_YEAR, sizeof(__pyx_k_TEMP_CASE_YEAR), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_COUNTY, __pyx_k_TEMP_COUNTY, sizeof(__pyx_k_TEMP_COUNTY), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_DIVISION, __pyx_k_TEMP_DIVISION, sizeof(__pyx_k_TEMP_DIVISION), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_DOB, __pyx_k_TEMP_DOB, sizeof(__pyx_k_TEMP_DOB), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_FILED_AFTER, __pyx_k_TEMP_FILED_AFTER, sizeof(__pyx_k_TEMP_FILED_AFTER), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_FILED_BEFORE, __pyx_k_TEMP_FILED_BEFORE, sizeof(__pyx_k_TEMP_FILED_BEFORE), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_NAME, __pyx_k_TEMP_NAME, sizeof(__pyx_k_TEMP_NAME), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_NO_RECORDS, __pyx_k_TEMP_NO_RECORDS, sizeof(__pyx_k_TEMP_NO_RECORDS), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_PARTY_TYPE, __pyx_k_TEMP_PARTY_TYPE, sizeof(__pyx_k_TEMP_PARTY_TYPE), 0, 1, 0, 1},
  {&__pyx_n_u_TEMP_SSN, __pyx_k_TEMP_SSN, sizeof(__pyx_k_TEMP_SSN), 0, 1, 0, 1},
  {&__pyx_n_u_TOTALS, __pyx_k_TOTALS, sizeof(__pyx_k_TOTALS), 0, 1, 0, 1},
  {&__pyx_kp_u_TRAFFIC_MISDEMEANOR, __pyx_k_TRAFFIC_MISDEMEANOR, sizeof(__pyx_k_TRAFFIC_MISDEMEANOR), 0, 1, 0, 0},
  {&__pyx_kp_u_TRAFFIC_MISDEMEANOR_BOND_FELONY, __pyx_k_TRAFFIC_MISDEMEANOR_BOND_FELONY, sizeof(__pyx_k_TRAFFIC_MISDEMEANOR_BOND_FELONY), 0, 1, 0, 0},
  {&__pyx_n_u_Timestamp, __pyx_k_Timestamp, sizeof(__pyx_k_Timestamp), 0, 1, 0, 1},
  {&__pyx_n_u_Total, __pyx_k_Total, sizeof(__pyx_k_Total), 0, 1, 0, 1},
  {&__pyx_n_u_TotalAmtDue, __pyx_k_TotalAmtDue, sizeof(__pyx_k_TotalAmtDue), 0, 1, 0, 1},
  {&__pyx_n_u_TotalAmtHold, __pyx_k_TotalAmtHold, sizeof(__pyx_k_TotalAmtHold), 0, 1, 0, 1},
  {&__pyx_n_u_TotalAmtPaid, __pyx_k_TotalAmtPaid, sizeof(__pyx_k_TotalAmtPaid), 0, 1, 0, 1},
  {&__pyx_n_u_TotalBalance, __pyx_k_TotalBalance, sizeof(__pyx_k_TotalBalance), 0, 1, 0, 1},
  {&__pyx_kp_u_Total_2, __pyx_k_Total_2, sizeof(__pyx_k_Total_2), 0, 1, 0, 0},
  {&__pyx_kp_u_Total_n, __pyx_k_Total_n, sizeof(__pyx_k_Total_n), 0, 1, 0, 0},
  {&__pyx_n_u_TrafficCitationNumber, __pyx_k_TrafficCitationNumber, sizeof(__pyx_k_TrafficCitationNumber), 0, 1, 0, 1},
  {&__pyx_kp_u_Traffic_Citation_A_Z0_9, __pyx_k_Traffic_Citation_A_Z0_9, sizeof(__pyx_k_Traffic_Citation_A_Z0_9), 0, 1, 0, 0},
  {&__pyx_n_u_TransferDesc, __pyx_k_TransferDesc, sizeof(__pyx_k_TransferDesc), 0, 1, 0, 1},
  {&__pyx_n_u_TransferToAdminDocDate, __pyx_k_TransferToAdminDocDate, sizeof(__pyx_k_TransferToAdminDocDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Transfer_Desc, __pyx_k_Transfer_Desc, sizeof(__pyx_k_Transfer_Desc), 0, 1, 0, 0},
  {&__pyx_kp_u_Transfer_Desc_A_Z_s_0_15_d_d_d_d, __pyx_k_Transfer_Desc_A_Z_s_0_15_d_d_d_d, sizeof(__pyx_k_Transfer_Desc_A_Z_s_0_15_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Transfer_to_Admin_Doc_Date_d_d_d, __pyx_k_Transfer_to_Admin_Doc_Date_d_d_d, sizeof(__pyx_k_Transfer_to_Admin_Doc_Date_d_d_d), 0, 1, 0, 0},
  {&__pyx_n_u_TrialType, __pyx_k_TrialType, sizeof(__pyx_k_TrialType), 0, 1, 0, 1},
  {&__pyx_kp_u_Trial_Type_A_Z, __pyx_k_Trial_Type_A_Z, sizeof(__pyx_k_Trial_Type_A_Z), 0, 1, 0, 0},
  {&__pyx_kp_u_Try_again_with_at_least_one_vali, __pyx_k_Try_again_with_at_least_one_vali, sizeof(__pyx_k_Try_again_with_at_least_one_vali), 0, 1, 0, 0},
  {&__pyx_n_u_TypeDescription, __pyx_k_TypeDescription, sizeof(__pyx_k_TypeDescription), 0, 1, 0, 1},
  {&__pyx_n_u_UTF8_FULL_CONDENSED, __pyx_k_UTF8_FULL_CONDENSED, sizeof(__pyx_k_UTF8_FULL_CONDENSED), 0, 1, 0, 1},
  {&__pyx_kp_u_Updated_By, __pyx_k_Updated_By, sizeof(__pyx_k_Updated_By), 0, 1, 0, 0},
  {&__pyx_kp_u_Updated_By_w_3, __pyx_k_Updated_By_w_3, sizeof(__pyx_k_Updated_By_w_3), 0, 1, 0, 0},
  {&__pyx_kp_u_Updated_By_w_3_2, __pyx_k_Updated_By_w_3_2, sizeof(__pyx_k_Updated_By_w_3_2), 0, 1, 0, 0},
  {&__pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100, __pyx_k_VS_V_VS_V_VS_VS_1_A_Z_s_10_100, sizeof(__pyx_k_VS_V_VS_V_VS_VS_1_A_Z_s_10_100), 0, 1, 0, 0},
  {&__pyx_n_u_WINDOW, __pyx_k_WINDOW, sizeof(__pyx_k_WINDOW), 0, 1, 0, 1},
  {&__pyx_n_u_WarrantActionDate, __pyx_k_WarrantActionDate, sizeof(__pyx_k_WarrantActionDate), 0, 1, 0, 1},
  {&__pyx_n_u_WarrantActionStatus, __pyx_k_WarrantActionStatus, sizeof(__pyx_k_WarrantActionStatus), 0, 1, 0, 1},
  {&__pyx_n_u_WarrantIssuanceDate, __pyx_k_WarrantIssuanceDate, sizeof(__pyx_k_WarrantIssuanceDate), 0, 1, 0, 1},
  {&__pyx_n_u_WarrantIssuanceStatus, __pyx_k_WarrantIssuanceStatus, sizeof(__pyx_k_WarrantIssuanceStatus), 0, 1, 0, 1},
  {&__pyx_n_u_WarrantLocationStatus, __pyx_k_WarrantLocationStatus, sizeof(__pyx_k_WarrantLocationStatus), 0, 1, 0, 1},
  {&__pyx_kp_u_Warrant_Action_Date_d_d_d_d_d_d, __pyx_k_Warrant_Action_Date_d_d_d_d_d_d, sizeof(__pyx_k_Warrant_Action_Date_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Warrant_Action_Status_w, __pyx_k_Warrant_Action_Status_w, sizeof(__pyx_k_Warrant_Action_Status_w), 0, 1, 0, 0},
  {&__pyx_kp_u_Warrant_Issuance_Status_w, __pyx_k_Warrant_Issuance_Status_w, sizeof(__pyx_k_Warrant_Issuance_Status_w), 0, 1, 0, 0},
  {&__pyx_kp_u_Warrant_Location_Status_w, __pyx_k_Warrant_Location_Status_w, sizeof(__pyx_k_Warrant_Location_Status_w), 0, 1, 0, 0},
  {&__pyx_n_u_Weight, __pyx_k_Weight, sizeof(__pyx_k_Weight), 0, 1, 0, 1},
  {&__pyx_kp_u_Weight_d, __pyx_k_Weight_d, sizeof(__pyx_k_Weight_d), 0, 1, 0, 0},
  {&__pyx_n_s_Workbook, __pyx_k_Workbook, sizeof(__pyx_k_Workbook), 0, 0, 1, 1},
  {&__pyx_kp_u_Writing_to_export, __pyx_k_Writing_to_export, sizeof(__pyx_k_Writing_to_export), 0, 1, 0, 0},
  {&__pyx_n_u_Y, __pyx_k_Y, sizeof(__pyx_k_Y), 0, 1, 0, 1},
  {&__pyx_n_u_YouthfulDate, __pyx_k_YouthfulDate, sizeof(__pyx_k_YouthfulDate), 0, 1, 0, 1},
  {&__pyx_kp_u_Youthful_Date_d_d_d_d_d_d_d_d, __pyx_k_Youthful_Date_d_d_d_d_d_d_d_d, sizeof(__pyx_k_Youthful_Date_d_d_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_Zip, __pyx_k_Zip, sizeof(__pyx_k_Zip), 0, 1, 0, 0},
  {&__pyx_n_u_ZipCode, __pyx_k_ZipCode, sizeof(__pyx_k_ZipCode), 0, 1, 0, 1},
  {&__pyx_kp_u_Zip_2, __pyx_k_Zip_2, sizeof(__pyx_k_Zip_2), 0, 1, 0, 0},
  {&__pyx_kp_u__109, __pyx_k__109, sizeof(__pyx_k__109), 0, 1, 0, 0},
  {&__pyx_kp_u__111, __pyx_k__111, sizeof(__pyx_k__111), 0, 1, 0, 0},
  {&__pyx_kp_u__115, __pyx_k__115, sizeof(__pyx_k__115), 0, 1, 0, 0},
  {&__pyx_kp_u__28, __pyx_k__28, sizeof(__pyx_k__28), 0, 1, 0, 0},
  {&__pyx_kp_u__42, __pyx_k__42, sizeof(__pyx_k__42), 0, 1, 0, 0},
  {&__pyx_kp_u__51, __pyx_k__51, sizeof(__pyx_k__51), 0, 1, 0, 0},
  {&__pyx_kp_u__52, __pyx_k__52, sizeof(__pyx_k__52), 0, 1, 0, 0},
  {&__pyx_kp_u__63, __pyx_k__63, sizeof(__pyx_k__63), 0, 1, 0, 0},
  {&__pyx_kp_u__64, __pyx_k__64, sizeof(__pyx_k__64), 0, 1, 0, 0},
  {&__pyx_kp_u__69, __pyx_k__69, sizeof(__pyx_k__69), 0, 1, 0, 0},
  {&__pyx_kp_u__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 1, 0, 0},
  {&__pyx_kp_u__82, __pyx_k__82, sizeof(__pyx_k__82), 0, 1, 0, 0},
  {&__pyx_kp_u__85, __pyx_k__85, sizeof(__pyx_k__85), 0, 1, 0, 0},
  {&__pyx_kp_u__88, __pyx_k__88, sizeof(__pyx_k__88), 0, 1, 0, 0},
  {&__pyx_kp_u__90, __pyx_k__90, sizeof(__pyx_k__90), 0, 1, 0, 0},
  {&__pyx_n_u__92, __pyx_k__92, sizeof(__pyx_k__92), 0, 1, 0, 1},
  {&__pyx_kp_u__96, __pyx_k__96, sizeof(__pyx_k__96), 0, 1, 0, 0},
  {&__pyx_kp_u__97, __pyx_k__97, sizeof(__pyx_k__97), 0, 1, 0, 0},
  {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
  {&__pyx_n_s_ac, __pyx_k_ac, sizeof(__pyx_k_ac), 0, 0, 1, 1},
  {&__pyx_n_s_add_experimental_option, __pyx_k_add_experimental_option, sizeof(__pyx_k_add_experimental_option), 0, 0, 1, 1},
  {&__pyx_n_s_af, __pyx_k_af, sizeof(__pyx_k_af), 0, 0, 1, 1},
  {&__pyx_n_s_agg, __pyx_k_agg, sizeof(__pyx_k_agg), 0, 0, 1, 1},
  {&__pyx_kp_u_alac_1004, __pyx_k_alac_1004, sizeof(__pyx_k_alac_1004), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_1026, __pyx_k_alac_1026, sizeof(__pyx_k_alac_1026), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_1040, __pyx_k_alac_1040, sizeof(__pyx_k_alac_1040), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_899, __pyx_k_alac_899, sizeof(__pyx_k_alac_899), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_931, __pyx_k_alac_931, sizeof(__pyx_k_alac_931), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_945, __pyx_k_alac_945, sizeof(__pyx_k_alac_945), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_965, __pyx_k_alac_965, sizeof(__pyx_k_alac_965), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_989, __pyx_k_alac_989, sizeof(__pyx_k_alac_989), 0, 1, 0, 0},
  {&__pyx_kp_u_alac_994, __pyx_k_alac_994, sizeof(__pyx_k_alac_994), 0, 1, 0, 0},
  {&__pyx_n_s_alacorder_cal, __pyx_k_alacorder_cal, sizeof(__pyx_k_alacorder_cal), 0, 0, 1, 1},
  {&__pyx_n_s_alias, __pyx_k_alias, sizeof(__pyx_k_alias), 0, 0, 1, 1},
  {&__pyx_n_u_all, __pyx_k_all, sizeof(__pyx_k_all), 0, 1, 0, 1},
  {&__pyx_n_s_all_charges, __pyx_k_all_charges, sizeof(__pyx_k_all_charges), 0, 0, 1, 1},
  {&__pyx_n_s_all_fees, __pyx_k_all_fees, sizeof(__pyx_k_all_fees), 0, 0, 1, 1},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_append_archive, __pyx_k_append_archive, sizeof(__pyx_k_append_archive), 0, 0, 1, 1},
  {&__pyx_n_s_apply, __pyx_k_apply, sizeof(__pyx_k_apply), 0, 0, 1, 1},
  {&__pyx_n_s_aptxt, __pyx_k_aptxt, sizeof(__pyx_k_aptxt), 0, 0, 1, 1},
  {&__pyx_n_s_ar, __pyx_k_ar, sizeof(__pyx_k_ar), 0, 0, 1, 1},
  {&__pyx_n_s_archive, __pyx_k_archive, sizeof(__pyx_k_archive), 0, 0, 1, 1},
  {&__pyx_n_u_archive, __pyx_k_archive, sizeof(__pyx_k_archive), 0, 1, 0, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_arr, __pyx_k_arr, sizeof(__pyx_k_arr), 0, 0, 1, 1},
  {&__pyx_n_s_autofit, __pyx_k_autofit, sizeof(__pyx_k_autofit), 0, 0, 1, 1},
  {&__pyx_n_u_blocks, __pyx_k_blocks, sizeof(__pyx_k_blocks), 0, 1, 0, 1},
  {&__pyx_n_u_brotli, __pyx_k_brotli, sizeof(__pyx_k_brotli), 0, 1, 0, 1},
  {&__pyx_n_s_by, __pyx_k_by, sizeof(__pyx_k_by), 0, 0, 1, 1},
  {&__pyx_n_s_cID, __pyx_k_cID, sizeof(__pyx_k_cID), 0, 0, 1, 1},
  {&__pyx_n_s_cID_box, __pyx_k_cID_box, sizeof(__pyx_k_cID_box), 0, 0, 1, 1},
  {&__pyx_n_s_ca, __pyx_k_ca, sizeof(__pyx_k_ca), 0, 0, 1, 1},
  {&__pyx_kp_s_cal_pyx, __pyx_k_cal_pyx, sizeof(__pyx_k_cal_pyx), 0, 0, 1, 0},
  {&__pyx_n_s_case_year, __pyx_k_case_year, sizeof(__pyx_k_case_year), 0, 0, 1, 1},
  {&__pyx_n_s_case_year_select, __pyx_k_case_year_select, sizeof(__pyx_k_case_year_select), 0, 0, 1, 1},
  {&__pyx_n_s_cases, __pyx_k_cases, sizeof(__pyx_k_cases), 0, 0, 1, 1},
  {&__pyx_n_u_cases, __pyx_k_cases, sizeof(__pyx_k_cases), 0, 1, 0, 1},
  {&__pyx_n_s_cast, __pyx_k_cast, sizeof(__pyx_k_cast), 0, 0, 1, 1},
  {&__pyx_n_s_cf, __pyx_k_cf, sizeof(__pyx_k_cf), 0, 0, 1, 1},
  {&__pyx_n_s_ch, __pyx_k_ch, sizeof(__pyx_k_ch), 0, 0, 1, 1},
  {&__pyx_n_s_charges, __pyx_k_charges, sizeof(__pyx_k_charges), 0, 0, 1, 1},
  {&__pyx_n_u_charges, __pyx_k_charges, sizeof(__pyx_k_charges), 0, 1, 0, 1},
  {&__pyx_n_s_city, __pyx_k_city, sizeof(__pyx_k_city), 0, 0, 1, 1},
  {&__pyx_n_s_clean_ch_list, __pyx_k_clean_ch_list, sizeof(__pyx_k_clean_ch_list), 0, 0, 1, 1},
  {&__pyx_n_s_clean_fs_list, __pyx_k_clean_fs_list, sizeof(__pyx_k_clean_fs_list), 0, 0, 1, 1},
  {&__pyx_n_s_click, __pyx_k_click, sizeof(__pyx_k_click), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_col, __pyx_k_col, sizeof(__pyx_k_col), 0, 0, 1, 1},
  {&__pyx_n_s_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 0, 1, 1},
  {&__pyx_n_s_common, __pyx_k_common, sizeof(__pyx_k_common), 0, 0, 1, 1},
  {&__pyx_n_s_compression, __pyx_k_compression, sizeof(__pyx_k_compression), 0, 0, 1, 1},
  {&__pyx_n_s_concat, __pyx_k_concat, sizeof(__pyx_k_concat), 0, 0, 1, 1},
  {&__pyx_n_s_concat_str, __pyx_k_concat_str, sizeof(__pyx_k_concat_str), 0, 0, 1, 1},
  {&__pyx_n_s_conf, __pyx_k_conf, sizeof(__pyx_k_conf), 0, 0, 1, 1},
  {&__pyx_n_s_contains, __pyx_k_contains, sizeof(__pyx_k_contains), 0, 0, 1, 1},
  {&__pyx_n_s_continueLogIn, __pyx_k_continueLogIn, sizeof(__pyx_k_continueLogIn), 0, 0, 1, 1},
  {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
  {&__pyx_n_s_county, __pyx_k_county, sizeof(__pyx_k_county), 0, 0, 1, 1},
  {&__pyx_n_s_county_select, __pyx_k_county_select, sizeof(__pyx_k_county_select), 0, 0, 1, 1},
  {&__pyx_kp_u_csv, __pyx_k_csv, sizeof(__pyx_k_csv), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_UcddlD, __pyx_k_ctl00_ContentPlaceHolder1_UcddlD, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_UcddlD), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_ddlCas, __pyx_k_ctl00_ContentPlaceHolder1_ddlCas, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_ddlCas), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_ddlCou, __pyx_k_ctl00_ContentPlaceHolder1_ddlCou, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_ddlCou), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_ddlNum, __pyx_k_ctl00_ContentPlaceHolder1_ddlNum, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_ddlNum), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_dg_ctl, __pyx_k_ctl00_ContentPlaceHolder1_dg_ctl, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_dg_ctl), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_rdlPar, __pyx_k_ctl00_ContentPlaceHolder1_rdlPar, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_rdlPar), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_txtDOB, __pyx_k_ctl00_ContentPlaceHolder1_txtDOB, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_txtDOB), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_txtFro, __pyx_k_ctl00_ContentPlaceHolder1_txtFro, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_txtFro), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_txtNam, __pyx_k_ctl00_ContentPlaceHolder1_txtNam, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_txtNam), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_txtSSN, __pyx_k_ctl00_ContentPlaceHolder1_txtSSN, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_txtSSN), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder1_txtTo, __pyx_k_ctl00_ContentPlaceHolder1_txtTo, sizeof(__pyx_k_ctl00_ContentPlaceHolder1_txtTo), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder_btnCont, __pyx_k_ctl00_ContentPlaceHolder_btnCont, sizeof(__pyx_k_ctl00_ContentPlaceHolder_btnCont), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder_txtCusi, __pyx_k_ctl00_ContentPlaceHolder_txtCusi, sizeof(__pyx_k_ctl00_ContentPlaceHolder_txtCusi), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder_txtPass, __pyx_k_ctl00_ContentPlaceHolder_txtPass, sizeof(__pyx_k_ctl00_ContentPlaceHolder_txtPass), 0, 1, 0, 0},
  {&__pyx_kp_u_ctl00_ContentPlaceHolder_txtUser, __pyx_k_ctl00_ContentPlaceHolder_txtUser, sizeof(__pyx_k_ctl00_ContentPlaceHolder_txtUser), 0, 1, 0, 0},
  {&__pyx_n_s_current_url, __pyx_k_current_url, sizeof(__pyx_k_current_url), 0, 0, 1, 1},
  {&__pyx_kp_u_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 1, 0, 0},
  {&__pyx_n_s_d999, __pyx_k_d999, sizeof(__pyx_k_d999), 0, 0, 1, 1},
  {&__pyx_n_s_d999m, __pyx_k_d999m, sizeof(__pyx_k_d999m), 0, 0, 1, 1},
  {&__pyx_n_s_d999mm, __pyx_k_d999mm, sizeof(__pyx_k_d999mm), 0, 0, 1, 1},
  {&__pyx_kp_u_d_1_2, __pyx_k_d_1_2, sizeof(__pyx_k_d_1_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_1_2_d_d_d_d_d_d, __pyx_k_d_1_2_d_d_d_d_d_d, sizeof(__pyx_k_d_1_2_d_d_d_d_d_d), 0, 1, 0, 0},
  {&__pyx_kp_u_d_2_d_2_d_4_0_5_DOB, __pyx_k_d_2_d_2_d_4_0_5_DOB, sizeof(__pyx_k_d_2_d_2_d_4_0_5_DOB), 0, 1, 0, 0},
  {&__pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10, __pyx_k_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10, sizeof(__pyx_k_d_3_s_1_A_Z0_9_4_1_200_3_3_3_10), 0, 1, 0, 0},
  {&__pyx_kp_u_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a, __pyx_k_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a, sizeof(__pyx_k_d_3_s_1_A_Z0_9_4_1_200_3_3_3_a), 0, 1, 0, 0},
  {&__pyx_kp_u_d_Bond_Amount, __pyx_k_d_Bond_Amount, sizeof(__pyx_k_d_Bond_Amount), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_2, __pyx_k_d_d_2, sizeof(__pyx_k_d_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_2_2, __pyx_k_d_d_2_2, sizeof(__pyx_k_d_d_2_2), 0, 1, 0, 0},
  {&__pyx_kp_u_d_d_d_d_d_d_d_d_Warrant_Issuanc, __pyx_k_d_d_d_d_d_d_d_d_Warrant_Issuanc, sizeof(__pyx_k_d_d_d_d_d_d_d_d_Warrant_Issuanc), 0, 1, 0, 0},
  {&__pyx_n_s_dataframe, __pyx_k_dataframe, sizeof(__pyx_k_dataframe), 0, 0, 1, 1},
  {&__pyx_n_s_date_of_birth_box, __pyx_k_date_of_birth_box, sizeof(__pyx_k_date_of_birth_box), 0, 0, 1, 1},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_u_defendants, __pyx_k_defendants, sizeof(__pyx_k_defendants), 0, 1, 0, 1},
  {&__pyx_n_s_df, __pyx_k_df, sizeof(__pyx_k_df), 0, 0, 1, 1},
  {&__pyx_n_u_directory, __pyx_k_directory, sizeof(__pyx_k_directory), 0, 1, 0, 1},
  {&__pyx_n_s_dirpath, __pyx_k_dirpath, sizeof(__pyx_k_dirpath), 0, 0, 1, 1},
  {&__pyx_n_s_division, __pyx_k_division, sizeof(__pyx_k_division), 0, 0, 1, 1},
  {&__pyx_n_s_division_select, __pyx_k_division_select, sizeof(__pyx_k_division_select), 0, 0, 1, 1},
  {&__pyx_n_s_dlog, __pyx_k_dlog, sizeof(__pyx_k_dlog), 0, 0, 1, 1},
  {&__pyx_n_s_dob, __pyx_k_dob, sizeof(__pyx_k_dob), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_downloadPDF, __pyx_k_downloadPDF, sizeof(__pyx_k_downloadPDF), 0, 0, 1, 1},
  {&__pyx_kp_u_download_default_directory, __pyx_k_download_default_directory, sizeof(__pyx_k_download_default_directory), 0, 1, 0, 0},
  {&__pyx_kp_u_download_directory_upgrade, __pyx_k_download_directory_upgrade, sizeof(__pyx_k_download_directory_upgrade), 0, 1, 0, 0},
  {&__pyx_kp_u_download_prompt_for_download, __pyx_k_download_prompt_for_download, sizeof(__pyx_k_download_prompt_for_download), 0, 1, 0, 0},
  {&__pyx_n_s_driver, __pyx_k_driver, sizeof(__pyx_k_driver), 0, 0, 1, 1},
  {&__pyx_n_s_drop, __pyx_k_drop, sizeof(__pyx_k_drop), 0, 0, 1, 1},
  {&__pyx_n_s_drop_in_place, __pyx_k_drop_in_place, sizeof(__pyx_k_drop_in_place), 0, 0, 1, 1},
  {&__pyx_n_s_drop_nulls, __pyx_k_drop_nulls, sizeof(__pyx_k_drop_nulls), 0, 0, 1, 1},
  {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
  {&__pyx_n_s_empty_query, __pyx_k_empty_query, sizeof(__pyx_k_empty_query), 0, 0, 1, 1},
  {&__pyx_n_s_enter, __pyx_k_enter, sizeof(__pyx_k_enter), 0, 0, 1, 1},
  {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
  {&__pyx_n_s_exceptions, __pyx_k_exceptions, sizeof(__pyx_k_exceptions), 0, 0, 1, 1},
  {&__pyx_n_s_existing_output, __pyx_k_existing_output, sizeof(__pyx_k_existing_output), 0, 0, 1, 1},
  {&__pyx_n_s_exit, __pyx_k_exit, sizeof(__pyx_k_exit), 0, 0, 1, 1},
  {&__pyx_n_s_explode, __pyx_k_explode, sizeof(__pyx_k_explode), 0, 0, 1, 1},
  {&__pyx_n_s_ext, __pyx_k_ext, sizeof(__pyx_k_ext), 0, 0, 1, 1},
  {&__pyx_n_s_extract, __pyx_k_extract, sizeof(__pyx_k_extract), 0, 0, 1, 1},
  {&__pyx_n_s_extract_all, __pyx_k_extract_all, sizeof(__pyx_k_extract_all), 0, 0, 1, 1},
  {&__pyx_n_s_fees, __pyx_k_fees, sizeof(__pyx_k_fees), 0, 0, 1, 1},
  {&__pyx_n_u_fees, __pyx_k_fees, sizeof(__pyx_k_fees), 0, 1, 0, 1},
  {&__pyx_n_s_fetch, __pyx_k_fetch, sizeof(__pyx_k_fetch), 0, 0, 1, 1},
  {&__pyx_n_s_filed_after, __pyx_k_filed_after, sizeof(__pyx_k_filed_after), 0, 0, 1, 1},
  {&__pyx_n_s_filed_after_box, __pyx_k_filed_after_box, sizeof(__pyx_k_filed_after_box), 0, 0, 1, 1},
  {&__pyx_n_s_filed_before, __pyx_k_filed_before, sizeof(__pyx_k_filed_before), 0, 0, 1, 1},
  {&__pyx_n_s_filed_before_box, __pyx_k_filed_before_box, sizeof(__pyx_k_filed_before_box), 0, 0, 1, 1},
  {&__pyx_n_s_fill_null, __pyx_k_fill_null, sizeof(__pyx_k_fill_null), 0, 0, 1, 1},
  {&__pyx_n_s_filterwarnings, __pyx_k_filterwarnings, sizeof(__pyx_k_filterwarnings), 0, 0, 1, 1},
  {&__pyx_n_s_find_element, __pyx_k_find_element, sizeof(__pyx_k_find_element), 0, 0, 1, 1},
  {&__pyx_n_s_find_elements, __pyx_k_find_elements, sizeof(__pyx_k_find_elements), 0, 0, 1, 1},
  {&__pyx_n_s_findall, __pyx_k_findall, sizeof(__pyx_k_findall), 0, 0, 1, 1},
  {&__pyx_n_s_fitz, __pyx_k_fitz, sizeof(__pyx_k_fitz), 0, 0, 1, 1},
  {&__pyx_n_s_float_precision, __pyx_k_float_precision, sizeof(__pyx_k_float_precision), 0, 0, 1, 1},
  {&__pyx_n_s_fname, __pyx_k_fname, sizeof(__pyx_k_fname), 0, 0, 1, 1},
  {&__pyx_n_s_force, __pyx_k_force, sizeof(__pyx_k_force), 0, 0, 1, 1},
  {&__pyx_n_s_found, __pyx_k_found, sizeof(__pyx_k_found), 0, 0, 1, 1},
  {&__pyx_n_s_frame, __pyx_k_frame, sizeof(__pyx_k_frame), 0, 0, 1, 1},
  {&__pyx_n_u_frmIndexSearchForm, __pyx_k_frmIndexSearchForm, sizeof(__pyx_k_frmIndexSearchForm), 0, 1, 0, 1},
  {&__pyx_n_s_fs, __pyx_k_fs, sizeof(__pyx_k_fs), 0, 0, 1, 1},
  {&__pyx_n_s_fshort_name, __pyx_k_fshort_name, sizeof(__pyx_k_fshort_name), 0, 0, 1, 1},
  {&__pyx_n_s_ft, __pyx_k_ft, sizeof(__pyx_k_ft), 0, 0, 1, 1},
  {&__pyx_n_s_genexpr, __pyx_k_genexpr, sizeof(__pyx_k_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_getAddress, __pyx_k_getAddress, sizeof(__pyx_k_getAddress), 0, 0, 1, 1},
  {&__pyx_n_s_getAddress1, __pyx_k_getAddress1, sizeof(__pyx_k_getAddress1), 0, 0, 1, 1},
  {&__pyx_n_s_getAddress2, __pyx_k_getAddress2, sizeof(__pyx_k_getAddress2), 0, 0, 1, 1},
  {&__pyx_n_s_getAdminUpdatedBy, __pyx_k_getAdminUpdatedBy, sizeof(__pyx_k_getAdminUpdatedBy), 0, 0, 1, 1},
  {&__pyx_n_s_getAgencyORI, __pyx_k_getAgencyORI, sizeof(__pyx_k_getAgencyORI), 0, 0, 1, 1},
  {&__pyx_n_s_getAlias, __pyx_k_getAlias, sizeof(__pyx_k_getAlias), 0, 0, 1, 1},
  {&__pyx_n_s_getAppealCourt, __pyx_k_getAppealCourt, sizeof(__pyx_k_getAppealCourt), 0, 0, 1, 1},
  {&__pyx_n_s_getAppealDate, __pyx_k_getAppealDate, sizeof(__pyx_k_getAppealDate), 0, 0, 1, 1},
  {&__pyx_n_s_getAppealStatus, __pyx_k_getAppealStatus, sizeof(__pyx_k_getAppealStatus), 0, 0, 1, 1},
  {&__pyx_n_s_getAppealTo, __pyx_k_getAppealTo, sizeof(__pyx_k_getAppealTo), 0, 0, 1, 1},
  {&__pyx_n_s_getAppealToDesc, __pyx_k_getAppealToDesc, sizeof(__pyx_k_getAppealToDesc), 0, 0, 1, 1},
  {&__pyx_n_s_getArrestDate, __pyx_k_getArrestDate, sizeof(__pyx_k_getArrestDate), 0, 0, 1, 1},
  {&__pyx_n_s_getArrestingAgencyType, __pyx_k_getArrestingAgencyType, sizeof(__pyx_k_getArrestingAgencyType), 0, 0, 1, 1},
  {&__pyx_n_s_getArrestingOfficer, __pyx_k_getArrestingOfficer, sizeof(__pyx_k_getArrestingOfficer), 0, 0, 1, 1},
  {&__pyx_n_s_getBondAmt, __pyx_k_getBondAmt, sizeof(__pyx_k_getBondAmt), 0, 0, 1, 1},
  {&__pyx_n_s_getBondReleaseDate, __pyx_k_getBondReleaseDate, sizeof(__pyx_k_getBondReleaseDate), 0, 0, 1, 1},
  {&__pyx_n_s_getBondType, __pyx_k_getBondType, sizeof(__pyx_k_getBondType), 0, 0, 1, 1},
  {&__pyx_n_s_getBondTypeDesc, __pyx_k_getBondTypeDesc, sizeof(__pyx_k_getBondTypeDesc), 0, 0, 1, 1},
  {&__pyx_n_s_getBondsmanProcessIssuance, __pyx_k_getBondsmanProcessIssuance, sizeof(__pyx_k_getBondsmanProcessIssuance), 0, 0, 1, 1},
  {&__pyx_n_s_getBondsmanProcessReturn, __pyx_k_getBondsmanProcessReturn, sizeof(__pyx_k_getBondsmanProcessReturn), 0, 0, 1, 1},
  {&__pyx_n_s_getCaseInitiationDate, __pyx_k_getCaseInitiationDate, sizeof(__pyx_k_getCaseInitiationDate), 0, 0, 1, 1},
  {&__pyx_n_s_getCaseInitiationType, __pyx_k_getCaseInitiationType, sizeof(__pyx_k_getCaseInitiationType), 0, 0, 1, 1},
  {&__pyx_n_s_getCaseNumber, __pyx_k_getCaseNumber, sizeof(__pyx_k_getCaseNumber), 0, 0, 1, 1},
  {&__pyx_n_s_getCaseYear, __pyx_k_getCaseYear, sizeof(__pyx_k_getCaseYear), 0, 0, 1, 1},
  {&__pyx_n_s_getChargesRows, __pyx_k_getChargesRows, sizeof(__pyx_k_getChargesRows), 0, 0, 1, 1},
  {&__pyx_n_s_getCity, __pyx_k_getCity, sizeof(__pyx_k_getCity), 0, 0, 1, 1},
  {&__pyx_n_s_getCountry, __pyx_k_getCountry, sizeof(__pyx_k_getCountry), 0, 0, 1, 1},
  {&__pyx_n_s_getCounty, __pyx_k_getCounty, sizeof(__pyx_k_getCounty), 0, 0, 1, 1},
  {&__pyx_n_s_getCourtAction, __pyx_k_getCourtAction, sizeof(__pyx_k_getCourtAction), 0, 0, 1, 1},
  {&__pyx_n_s_getCourtActionDate, __pyx_k_getCourtActionDate, sizeof(__pyx_k_getCourtActionDate), 0, 0, 1, 1},
  {&__pyx_n_s_getDOB, __pyx_k_getDOB, sizeof(__pyx_k_getDOB), 0, 0, 1, 1},
  {&__pyx_n_s_getDefendantStatus, __pyx_k_getDefendantStatus, sizeof(__pyx_k_getDefendantStatus), 0, 0, 1, 1},
  {&__pyx_n_s_getDescription, __pyx_k_getDescription, sizeof(__pyx_k_getDescription), 0, 0, 1, 1},
  {&__pyx_n_s_getDispositionDateOfAppeal, __pyx_k_getDispositionDateOfAppeal, sizeof(__pyx_k_getDispositionDateOfAppeal), 0, 0, 1, 1},
  {&__pyx_n_s_getDispositionTypeOfAppeal, __pyx_k_getDispositionTypeOfAppeal, sizeof(__pyx_k_getDispositionTypeOfAppeal), 0, 0, 1, 1},
  {&__pyx_n_s_getDomesticViolence, __pyx_k_getDomesticViolence, sizeof(__pyx_k_getDomesticViolence), 0, 0, 1, 1},
  {&__pyx_n_s_getDriverLicenseNo, __pyx_k_getDriverLicenseNo, sizeof(__pyx_k_getDriverLicenseNo), 0, 0, 1, 1},
  {&__pyx_n_s_getEyes, __pyx_k_getEyes, sizeof(__pyx_k_getEyes), 0, 0, 1, 1},
  {&__pyx_n_s_getFailedToAppearDate, __pyx_k_getFailedToAppearDate, sizeof(__pyx_k_getFailedToAppearDate), 0, 0, 1, 1},
  {&__pyx_n_s_getFeeSheetRows, __pyx_k_getFeeSheetRows, sizeof(__pyx_k_getFeeSheetRows), 0, 0, 1, 1},
  {&__pyx_n_s_getFilingDate, __pyx_k_getFilingDate, sizeof(__pyx_k_getFilingDate), 0, 0, 1, 1},
  {&__pyx_n_s_getFirstName, __pyx_k_getFirstName, sizeof(__pyx_k_getFirstName), 0, 0, 1, 1},
  {&__pyx_n_s_getHair, __pyx_k_getHair, sizeof(__pyx_k_getHair), 0, 0, 1, 1},
  {&__pyx_n_s_getHeight, __pyx_k_getHeight, sizeof(__pyx_k_getHeight), 0, 0, 1, 1},
  {&__pyx_n_s_getIndictmentDate, __pyx_k_getIndictmentDate, sizeof(__pyx_k_getIndictmentDate), 0, 0, 1, 1},
  {&__pyx_n_s_getInpatientTreatmentOrdered, __pyx_k_getInpatientTreatmentOrdered, sizeof(__pyx_k_getInpatientTreatmentOrdered), 0, 0, 1, 1},
  {&__pyx_n_s_getJailCreditPeriod, __pyx_k_getJailCreditPeriod, sizeof(__pyx_k_getJailCreditPeriod), 0, 0, 1, 1},
  {&__pyx_n_s_getJudge, __pyx_k_getJudge, sizeof(__pyx_k_getJudge), 0, 0, 1, 1},
  {&__pyx_n_s_getJuryDemand, __pyx_k_getJuryDemand, sizeof(__pyx_k_getJuryDemand), 0, 0, 1, 1},
  {&__pyx_n_s_getLastName, __pyx_k_getLastName, sizeof(__pyx_k_getLastName), 0, 0, 1, 1},
  {&__pyx_n_s_getLicenseSuspPeriod, __pyx_k_getLicenseSuspPeriod, sizeof(__pyx_k_getLicenseSuspPeriod), 0, 0, 1, 1},
  {&__pyx_n_s_getLowerCourtAppealDate, __pyx_k_getLowerCourtAppealDate, sizeof(__pyx_k_getLowerCourtAppealDate), 0, 0, 1, 1},
  {&__pyx_n_s_getMiddleName, __pyx_k_getMiddleName, sizeof(__pyx_k_getMiddleName), 0, 0, 1, 1},
  {&__pyx_n_s_getName, __pyx_k_getName, sizeof(__pyx_k_getName), 0, 0, 1, 1},
  {&__pyx_n_s_getNumberOfSubpoenas, __pyx_k_getNumberOfSubpoenas, sizeof(__pyx_k_getNumberOfSubpoenas), 0, 0, 1, 1},
  {&__pyx_n_s_getNumberOfWarrants, __pyx_k_getNumberOfWarrants, sizeof(__pyx_k_getNumberOfWarrants), 0, 0, 1, 1},
  {&__pyx_n_s_getOffenseDate, __pyx_k_getOffenseDate, sizeof(__pyx_k_getOffenseDate), 0, 0, 1, 1},
  {&__pyx_n_s_getOriginOfAppeal, __pyx_k_getOriginOfAppeal, sizeof(__pyx_k_getOriginOfAppeal), 0, 0, 1, 1},
  {&__pyx_n_s_getPDFText, __pyx_k_getPDFText, sizeof(__pyx_k_getPDFText), 0, 0, 1, 1},
  {&__pyx_n_s_getPDFText_locals_genexpr, __pyx_k_getPDFText_locals_genexpr, sizeof(__pyx_k_getPDFText_locals_genexpr), 0, 0, 1, 1},
  {&__pyx_n_s_getPaymentToRestore, __pyx_k_getPaymentToRestore, sizeof(__pyx_k_getPaymentToRestore), 0, 0, 1, 1},
  {&__pyx_n_s_getPhone, __pyx_k_getPhone, sizeof(__pyx_k_getPhone), 0, 0, 1, 1},
  {&__pyx_n_s_getPreviousDUIConvictions, __pyx_k_getPreviousDUIConvictions, sizeof(__pyx_k_getPreviousDUIConvictions), 0, 0, 1, 1},
  {&__pyx_n_s_getProbationBeginDate, __pyx_k_getProbationBeginDate, sizeof(__pyx_k_getProbationBeginDate), 0, 0, 1, 1},
  {&__pyx_n_s_getProbationOfficeName, __pyx_k_getProbationOfficeName, sizeof(__pyx_k_getProbationOfficeName), 0, 0, 1, 1},
  {&__pyx_n_s_getProbationOfficeNumber, __pyx_k_getProbationOfficeNumber, sizeof(__pyx_k_getProbationOfficeNumber), 0, 0, 1, 1},
  {&__pyx_n_s_getProbationPeriod, __pyx_k_getProbationPeriod, sizeof(__pyx_k_getProbationPeriod), 0, 0, 1, 1},
  {&__pyx_n_s_getProbationRevoke, __pyx_k_getProbationRevoke, sizeof(__pyx_k_getProbationRevoke), 0, 0, 1, 1},
  {&__pyx_n_s_getRace, __pyx_k_getRace, sizeof(__pyx_k_getRace), 0, 0, 1, 1},
  {&__pyx_n_s_getRelatedCases, __pyx_k_getRelatedCases, sizeof(__pyx_k_getRelatedCases), 0, 0, 1, 1},
  {&__pyx_n_s_getRetrieved, __pyx_k_getRetrieved, sizeof(__pyx_k_getRetrieved), 0, 0, 1, 1},
  {&__pyx_n_s_getSSN, __pyx_k_getSSN, sizeof(__pyx_k_getSSN), 0, 0, 1, 1},
  {&__pyx_n_s_getSentenceDate, __pyx_k_getSentenceDate, sizeof(__pyx_k_getSentenceDate), 0, 0, 1, 1},
  {&__pyx_n_s_getSentenceEndDate, __pyx_k_getSentenceEndDate, sizeof(__pyx_k_getSentenceEndDate), 0, 0, 1, 1},
  {&__pyx_n_s_getSentenceLastUpdate, __pyx_k_getSentenceLastUpdate, sizeof(__pyx_k_getSentenceLastUpdate), 0, 0, 1, 1},
  {&__pyx_n_s_getSentenceProvisions, __pyx_k_getSentenceProvisions, sizeof(__pyx_k_getSentenceProvisions), 0, 0, 1, 1},
  {&__pyx_n_s_getSentenceStartDate, __pyx_k_getSentenceStartDate, sizeof(__pyx_k_getSentenceStartDate), 0, 0, 1, 1},
  {&__pyx_n_s_getSentenceUpdatedBy, __pyx_k_getSentenceUpdatedBy, sizeof(__pyx_k_getSentenceUpdatedBy), 0, 0, 1, 1},
  {&__pyx_n_s_getSentencingRequirementsComplet, __pyx_k_getSentencingRequirementsComplet, sizeof(__pyx_k_getSentencingRequirementsComplet), 0, 0, 1, 1},
  {&__pyx_n_s_getSex, __pyx_k_getSex, sizeof(__pyx_k_getSex), 0, 0, 1, 1},
  {&__pyx_n_s_getShortCaseNumber, __pyx_k_getShortCaseNumber, sizeof(__pyx_k_getShortCaseNumber), 0, 0, 1, 1},
  {&__pyx_n_s_getState, __pyx_k_getState, sizeof(__pyx_k_getState), 0, 0, 1, 1},
  {&__pyx_n_s_getStateID, __pyx_k_getStateID, sizeof(__pyx_k_getStateID), 0, 0, 1, 1},
  {&__pyx_n_s_getSuretyCode, __pyx_k_getSuretyCode, sizeof(__pyx_k_getSuretyCode), 0, 0, 1, 1},
  {&__pyx_n_s_getTBNV1, __pyx_k_getTBNV1, sizeof(__pyx_k_getTBNV1), 0, 0, 1, 1},
  {&__pyx_n_s_getTBNV2, __pyx_k_getTBNV2, sizeof(__pyx_k_getTBNV2), 0, 0, 1, 1},
  {&__pyx_n_s_getTotalAmtDue, __pyx_k_getTotalAmtDue, sizeof(__pyx_k_getTotalAmtDue), 0, 0, 1, 1},
  {&__pyx_n_s_getTotalAmtHold, __pyx_k_getTotalAmtHold, sizeof(__pyx_k_getTotalAmtHold), 0, 0, 1, 1},
  {&__pyx_n_s_getTotalAmtPaid, __pyx_k_getTotalAmtPaid, sizeof(__pyx_k_getTotalAmtPaid), 0, 0, 1, 1},
  {&__pyx_n_s_getTotalBalance, __pyx_k_getTotalBalance, sizeof(__pyx_k_getTotalBalance), 0, 0, 1, 1},
  {&__pyx_n_s_getTotalRow, __pyx_k_getTotalRow, sizeof(__pyx_k_getTotalRow), 0, 0, 1, 1},
  {&__pyx_n_s_getTrafficCitationNumber, __pyx_k_getTrafficCitationNumber, sizeof(__pyx_k_getTrafficCitationNumber), 0, 0, 1, 1},
  {&__pyx_n_s_getTransferDesc, __pyx_k_getTransferDesc, sizeof(__pyx_k_getTransferDesc), 0, 0, 1, 1},
  {&__pyx_n_s_getTransferToAdminDocDate, __pyx_k_getTransferToAdminDocDate, sizeof(__pyx_k_getTransferToAdminDocDate), 0, 0, 1, 1},
  {&__pyx_n_s_getTrialType, __pyx_k_getTrialType, sizeof(__pyx_k_getTrialType), 0, 0, 1, 1},
  {&__pyx_n_s_getWarrantActionDate, __pyx_k_getWarrantActionDate, sizeof(__pyx_k_getWarrantActionDate), 0, 0, 1, 1},
  {&__pyx_n_s_getWarrantActionStatus, __pyx_k_getWarrantActionStatus, sizeof(__pyx_k_getWarrantActionStatus), 0, 0, 1, 1},
  {&__pyx_n_s_getWarrantIssuanceDate, __pyx_k_getWarrantIssuanceDate, sizeof(__pyx_k_getWarrantIssuanceDate), 0, 0, 1, 1},
  {&__pyx_n_s_getWarrantIssuanceStatus, __pyx_k_getWarrantIssuanceStatus, sizeof(__pyx_k_getWarrantIssuanceStatus), 0, 0, 1, 1},
  {&__pyx_n_s_getWarrantLocationStatus, __pyx_k_getWarrantLocationStatus, sizeof(__pyx_k_getWarrantLocationStatus), 0, 0, 1, 1},
  {&__pyx_n_s_getWeight, __pyx_k_getWeight, sizeof(__pyx_k_getWeight), 0, 0, 1, 1},
  {&__pyx_n_s_getYouthfulDate, __pyx_k_getYouthfulDate, sizeof(__pyx_k_getYouthfulDate), 0, 0, 1, 1},
  {&__pyx_n_s_getZipCode, __pyx_k_getZipCode, sizeof(__pyx_k_getZipCode), 0, 0, 1, 1},
  {&__pyx_n_s_get_attribute, __pyx_k_get_attribute, sizeof(__pyx_k_get_attribute), 0, 0, 1, 1},
  {&__pyx_n_s_get_text, __pyx_k_get_text, sizeof(__pyx_k_get_text), 0, 0, 1, 1},
  {&__pyx_n_s_glob, __pyx_k_glob, sizeof(__pyx_k_glob), 0, 0, 1, 1},
  {&__pyx_n_s_good, __pyx_k_good, sizeof(__pyx_k_good), 0, 0, 1, 1},
  {&__pyx_n_s_goodquery, __pyx_k_goodquery, sizeof(__pyx_k_goodquery), 0, 0, 1, 1},
  {&__pyx_n_s_group, __pyx_k_group, sizeof(__pyx_k_group), 0, 0, 1, 1},
  {&__pyx_n_s_group_index, __pyx_k_group_index, sizeof(__pyx_k_group_index), 0, 0, 1, 1},
  {&__pyx_n_s_groupby, __pyx_k_groupby, sizeof(__pyx_k_groupby), 0, 0, 1, 1},
  {&__pyx_kp_u_h, __pyx_k_h, sizeof(__pyx_k_h), 0, 1, 0, 0},
  {&__pyx_n_s_has_window, __pyx_k_has_window, sizeof(__pyx_k_has_window), 0, 0, 1, 1},
  {&__pyx_kp_u_help, __pyx_k_help, sizeof(__pyx_k_help), 0, 1, 0, 0},
  {&__pyx_n_s_help_option_names, __pyx_k_help_option_names, sizeof(__pyx_k_help_option_names), 0, 0, 1, 1},
  {&__pyx_n_s_hovers, __pyx_k_hovers, sizeof(__pyx_k_hovers), 0, 0, 1, 1},
  {&__pyx_n_s_how, __pyx_k_how, sizeof(__pyx_k_how), 0, 0, 1, 1},
  {&__pyx_n_u_href, __pyx_k_href, sizeof(__pyx_k_href), 0, 1, 0, 1},
  {&__pyx_kp_u_https_v2_alacourt_com_frmIndexSe, __pyx_k_https_v2_alacourt_com_frmIndexSe, sizeof(__pyx_k_https_v2_alacourt_com_frmIndexSe), 0, 1, 0, 0},
  {&__pyx_kp_u_https_v2_alacourt_com_frmIndexSe_2, __pyx_k_https_v2_alacourt_com_frmIndexSe_2, sizeof(__pyx_k_https_v2_alacourt_com_frmIndexSe_2), 0, 1, 0, 0},
  {&__pyx_kp_u_https_v2_alacourt_com_frmlogin_a, __pyx_k_https_v2_alacourt_com_frmlogin_a, sizeof(__pyx_k_https_v2_alacourt_com_frmlogin_a), 0, 1, 0, 0},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_u_ignore, __pyx_k_ignore, sizeof(__pyx_k_ignore), 0, 1, 0, 1},
  {&__pyx_kp_u_image, __pyx_k_image, sizeof(__pyx_k_image), 0, 1, 0, 0},
  {&__pyx_n_s_implicitly_wait, __pyx_k_implicitly_wait, sizeof(__pyx_k_implicitly_wait), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_inarc, __pyx_k_inarc, sizeof(__pyx_k_inarc), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_inpath, __pyx_k_inpath, sizeof(__pyx_k_inpath), 0, 0, 1, 1},
  {&__pyx_n_s_inputs, __pyx_k_inputs, sizeof(__pyx_k_inputs), 0, 0, 1, 1},
  {&__pyx_n_s_inspect, __pyx_k_inspect, sizeof(__pyx_k_inspect), 0, 0, 1, 1},
  {&__pyx_n_s_is_full_text, __pyx_k_is_full_text, sizeof(__pyx_k_is_full_text), 0, 0, 1, 1},
  {&__pyx_n_s_is_not, __pyx_k_is_not, sizeof(__pyx_k_is_not), 0, 0, 1, 1},
  {&__pyx_n_s_isdir, __pyx_k_isdir, sizeof(__pyx_k_isdir), 0, 0, 1, 1},
  {&__pyx_n_s_isfile, __pyx_k_isfile, sizeof(__pyx_k_isfile), 0, 0, 1, 1},
  {&__pyx_n_s_itype, __pyx_k_itype, sizeof(__pyx_k_itype), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_kp_u_json, __pyx_k_json, sizeof(__pyx_k_json), 0, 1, 0, 0},
  {&__pyx_n_u_left, __pyx_k_left, sizeof(__pyx_k_left), 0, 1, 0, 1},
  {&__pyx_n_s_lit, __pyx_k_lit, sizeof(__pyx_k_lit), 0, 0, 1, 1},
  {&__pyx_n_s_literal, __pyx_k_literal, sizeof(__pyx_k_literal), 0, 0, 1, 1},
  {&__pyx_n_s_login, __pyx_k_login, sizeof(__pyx_k_login), 0, 0, 1, 1},
  {&__pyx_n_s_login_button, __pyx_k_login_button, sizeof(__pyx_k_login_button), 0, 0, 1, 1},
  {&__pyx_n_s_login_screen, __pyx_k_login_screen, sizeof(__pyx_k_login_screen), 0, 0, 1, 1},
  {&__pyx_n_s_long_version, __pyx_k_long_version, sizeof(__pyx_k_long_version), 0, 0, 1, 1},
  {&__pyx_n_s_m, __pyx_k_m, sizeof(__pyx_k_m), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_math, __pyx_k_math, sizeof(__pyx_k_math), 0, 0, 1, 1},
  {&__pyx_n_u_menuHover, __pyx_k_menuHover, sizeof(__pyx_k_menuHover), 0, 1, 0, 1},
  {&__pyx_n_s_mm, __pyx_k_mm, sizeof(__pyx_k_mm), 0, 0, 1, 1},
  {&__pyx_n_s_mmm, __pyx_k_mmm, sizeof(__pyx_k_mmm), 0, 0, 1, 1},
  {&__pyx_n_s_multi, __pyx_k_multi, sizeof(__pyx_k_multi), 0, 0, 1, 1},
  {&__pyx_n_u_multi, __pyx_k_multi, sizeof(__pyx_k_multi), 0, 1, 0, 1},
  {&__pyx_n_u_multitable, __pyx_k_multitable, sizeof(__pyx_k_multitable), 0, 1, 0, 1},
  {&__pyx_kp_u_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 1, 0, 0},
  {&__pyx_kp_u_n_Requrements_Completed, __pyx_k_n_Requrements_Completed, sizeof(__pyx_k_n_Requrements_Completed), 0, 1, 0, 0},
  {&__pyx_n_s_n_chars, __pyx_k_n_chars, sizeof(__pyx_k_n_chars), 0, 0, 1, 1},
  {&__pyx_kp_u_n_s, __pyx_k_n_s, sizeof(__pyx_k_n_s), 0, 1, 0, 0},
  {&__pyx_kp_u_n_s_2, __pyx_k_n_s_2, sizeof(__pyx_k_n_s_2), 0, 1, 0, 0},
  {&__pyx_kp_u_n_s_d_Appeal_Court, __pyx_k_n_s_d_Appeal_Court, sizeof(__pyx_k_n_s_d_Appeal_Court), 0, 1, 0, 0},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_named, __pyx_k_named, sizeof(__pyx_k_named), 0, 0, 1, 1},
  {&__pyx_n_s_next_button, __pyx_k_next_button, sizeof(__pyx_k_next_button), 0, 0, 1, 1},
  {&__pyx_n_s_next_pg, __pyx_k_next_pg, sizeof(__pyx_k_next_pg), 0, 0, 1, 1},
  {&__pyx_n_s_no_prompt, __pyx_k_no_prompt, sizeof(__pyx_k_no_prompt), 0, 0, 1, 1},
  {&__pyx_n_s_no_records_select, __pyx_k_no_records_select, sizeof(__pyx_k_no_records_select), 0, 0, 1, 1},
  {&__pyx_n_s_no_update, __pyx_k_no_update, sizeof(__pyx_k_no_update), 0, 0, 1, 1},
  {&__pyx_n_s_no_write, __pyx_k_no_write, sizeof(__pyx_k_no_write), 0, 0, 1, 1},
  {&__pyx_n_u_none, __pyx_k_none, sizeof(__pyx_k_none), 0, 1, 0, 1},
  {&__pyx_n_s_now, __pyx_k_now, sizeof(__pyx_k_now), 0, 0, 1, 1},
  {&__pyx_kp_u_null, __pyx_k_null, sizeof(__pyx_k_null), 0, 1, 0, 0},
  {&__pyx_n_u_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 1, 0, 1},
  {&__pyx_n_s_old_archive, __pyx_k_old_archive, sizeof(__pyx_k_old_archive), 0, 0, 1, 1},
  {&__pyx_n_s_on, __pyx_k_on, sizeof(__pyx_k_on), 0, 0, 1, 1},
  {&__pyx_n_s_open, __pyx_k_open, sizeof(__pyx_k_open), 0, 0, 1, 1},
  {&__pyx_n_s_opt, __pyx_k_opt, sizeof(__pyx_k_opt), 0, 0, 1, 1},
  {&__pyx_n_s_option, __pyx_k_option, sizeof(__pyx_k_option), 0, 0, 1, 1},
  {&__pyx_n_s_options, __pyx_k_options, sizeof(__pyx_k_options), 0, 0, 1, 1},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_otherwise, __pyx_k_otherwise, sizeof(__pyx_k_otherwise), 0, 0, 1, 1},
  {&__pyx_n_s_out, __pyx_k_out, sizeof(__pyx_k_out), 0, 0, 1, 1},
  {&__pyx_n_s_outarc, __pyx_k_outarc, sizeof(__pyx_k_outarc), 0, 0, 1, 1},
  {&__pyx_n_s_outpath, __pyx_k_outpath, sizeof(__pyx_k_outpath), 0, 0, 1, 1},
  {&__pyx_n_s_outputext, __pyx_k_outputext, sizeof(__pyx_k_outputext), 0, 0, 1, 1},
  {&__pyx_n_s_outputs, __pyx_k_outputs, sizeof(__pyx_k_outputs), 0, 0, 1, 1},
  {&__pyx_n_s_overwrite, __pyx_k_overwrite, sizeof(__pyx_k_overwrite), 0, 0, 1, 1},
  {&__pyx_n_s_page_counter, __pyx_k_page_counter, sizeof(__pyx_k_page_counter), 0, 0, 1, 1},
  {&__pyx_n_s_pager_select, __pyx_k_pager_select, sizeof(__pyx_k_pager_select), 0, 0, 1, 1},
  {&__pyx_n_s_pages, __pyx_k_pages, sizeof(__pyx_k_pages), 0, 0, 1, 1},
  {&__pyx_kp_u_parquet, __pyx_k_parquet, sizeof(__pyx_k_parquet), 0, 1, 0, 0},
  {&__pyx_n_s_party_name_box, __pyx_k_party_name_box, sizeof(__pyx_k_party_name_box), 0, 0, 1, 1},
  {&__pyx_n_s_party_search, __pyx_k_party_search, sizeof(__pyx_k_party_search), 0, 0, 1, 1},
  {&__pyx_n_s_party_type, __pyx_k_party_type, sizeof(__pyx_k_party_type), 0, 0, 1, 1},
  {&__pyx_n_s_party_type_select, __pyx_k_party_type_select, sizeof(__pyx_k_party_type_select), 0, 0, 1, 1},
  {&__pyx_n_u_partymountain, __pyx_k_partymountain, sizeof(__pyx_k_partymountain), 0, 1, 0, 1},
  {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
  {&__pyx_kp_u_pdf, __pyx_k_pdf, sizeof(__pyx_k_pdf), 0, 1, 0, 0},
  {&__pyx_n_s_pdflinks, __pyx_k_pdflinks, sizeof(__pyx_k_pdflinks), 0, 0, 1, 1},
  {&__pyx_n_s_pg, __pyx_k_pg, sizeof(__pyx_k_pg), 0, 0, 1, 1},
  {&__pyx_n_s_pl, __pyx_k_pl, sizeof(__pyx_k_pl), 0, 0, 1, 1},
  {&__pyx_n_u_plaintiffs, __pyx_k_plaintiffs, sizeof(__pyx_k_plaintiffs), 0, 1, 0, 1},
  {&__pyx_n_s_platform, __pyx_k_platform, sizeof(__pyx_k_platform), 0, 0, 1, 1},
  {&__pyx_kp_u_plugins_always_open_pdf_external, __pyx_k_plugins_always_open_pdf_external, sizeof(__pyx_k_plugins_always_open_pdf_external), 0, 1, 0, 0},
  {&__pyx_n_s_polars, __pyx_k_polars, sizeof(__pyx_k_polars), 0, 0, 1, 1},
  {&__pyx_n_s_pp, __pyx_k_pp, sizeof(__pyx_k_pp), 0, 0, 1, 1},
  {&__pyx_n_u_prefs, __pyx_k_prefs, sizeof(__pyx_k_prefs), 0, 1, 0, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_s_pscols, __pyx_k_pscols, sizeof(__pyx_k_pscols), 0, 0, 1, 1},
  {&__pyx_n_s_pts, __pyx_k_pts, sizeof(__pyx_k_pts), 0, 0, 1, 1},
  {&__pyx_n_s_pwd, __pyx_k_pwd, sizeof(__pyx_k_pwd), 0, 0, 1, 1},
  {&__pyx_n_s_pwd_box, __pyx_k_pwd_box, sizeof(__pyx_k_pwd_box), 0, 0, 1, 1},
  {&__pyx_n_s_qmax, __pyx_k_qmax, sizeof(__pyx_k_qmax), 0, 0, 1, 1},
  {&__pyx_n_s_qs, __pyx_k_qs, sizeof(__pyx_k_qs), 0, 0, 1, 1},
  {&__pyx_n_s_qskip, __pyx_k_qskip, sizeof(__pyx_k_qskip), 0, 0, 1, 1},
  {&__pyx_kp_u_queries_found_in_input_query_fi, __pyx_k_queries_found_in_input_query_fi, sizeof(__pyx_k_queries_found_in_input_query_fi), 0, 1, 0, 0},
  {&__pyx_n_s_query, __pyx_k_query, sizeof(__pyx_k_query), 0, 0, 1, 1},
  {&__pyx_n_u_query, __pyx_k_query, sizeof(__pyx_k_query), 0, 1, 0, 1},
  {&__pyx_n_s_querypath, __pyx_k_querypath, sizeof(__pyx_k_querypath), 0, 0, 1, 1},
  {&__pyx_n_s_queue, __pyx_k_queue, sizeof(__pyx_k_queue), 0, 0, 1, 1},
  {&__pyx_n_s_qwrite, __pyx_k_qwrite, sizeof(__pyx_k_qwrite), 0, 0, 1, 1},
  {&__pyx_n_s_r, __pyx_k_r, sizeof(__pyx_k_r), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_re, __pyx_k_re, sizeof(__pyx_k_re), 0, 0, 1, 1},
  {&__pyx_n_s_read, __pyx_k_read, sizeof(__pyx_k_read), 0, 0, 1, 1},
  {&__pyx_n_s_read_csv, __pyx_k_read_csv, sizeof(__pyx_k_read_csv), 0, 0, 1, 1},
  {&__pyx_n_s_read_excel, __pyx_k_read_excel, sizeof(__pyx_k_read_excel), 0, 0, 1, 1},
  {&__pyx_n_s_read_json, __pyx_k_read_json, sizeof(__pyx_k_read_json), 0, 0, 1, 1},
  {&__pyx_n_s_read_parquet, __pyx_k_read_parquet, sizeof(__pyx_k_read_parquet), 0, 0, 1, 1},
  {&__pyx_n_s_read_query, __pyx_k_read_query, sizeof(__pyx_k_read_query), 0, 0, 1, 1},
  {&__pyx_kp_u_records_returned, __pyx_k_records_returned, sizeof(__pyx_k_records_returned), 0, 1, 0, 0},
  {&__pyx_kp_u_records_returned_2, __pyx_k_records_returned_2, sizeof(__pyx_k_records_returned_2), 0, 1, 0, 0},
  {&__pyx_n_s_recursive, __pyx_k_recursive, sizeof(__pyx_k_recursive), 0, 0, 1, 1},
  {&__pyx_n_s_replace, __pyx_k_replace, sizeof(__pyx_k_replace), 0, 0, 1, 1},
  {&__pyx_n_s_replace_all, __pyx_k_replace_all, sizeof(__pyx_k_replace_all), 0, 0, 1, 1},
  {&__pyx_n_s_results, __pyx_k_results, sizeof(__pyx_k_results), 0, 0, 1, 1},
  {&__pyx_n_s_results_count, __pyx_k_results_count, sizeof(__pyx_k_results_count), 0, 0, 1, 1},
  {&__pyx_kp_u_results_fetching_URLs_and_downl, __pyx_k_results_fetching_URLs_and_downl, sizeof(__pyx_k_results_fetching_URLs_and_downl), 0, 1, 0, 0},
  {&__pyx_n_s_results_indicator, __pyx_k_results_indicator, sizeof(__pyx_k_results_indicator), 0, 0, 1, 1},
  {&__pyx_n_s_rich, __pyx_k_rich, sizeof(__pyx_k_rich), 0, 0, 1, 1},
  {&__pyx_n_s_rows, __pyx_k_rows, sizeof(__pyx_k_rows), 0, 0, 1, 1},
  {&__pyx_n_s_rsplit, __pyx_k_rsplit, sizeof(__pyx_k_rsplit), 0, 0, 1, 1},
  {&__pyx_n_s_rstrip, __pyx_k_rstrip, sizeof(__pyx_k_rstrip), 0, 0, 1, 1},
  {&__pyx_kp_u_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 1, 0, 0},
  {&__pyx_kp_u_s_d_d_2, __pyx_k_s_d_d_2, sizeof(__pyx_k_s_d_d_2), 0, 1, 0, 0},
  {&__pyx_n_s_scase_year, __pyx_k_scase_year, sizeof(__pyx_k_scase_year), 0, 0, 1, 1},
  {&__pyx_n_s_scounty, __pyx_k_scounty, sizeof(__pyx_k_scounty), 0, 0, 1, 1},
  {&__pyx_n_s_sdivision, __pyx_k_sdivision, sizeof(__pyx_k_sdivision), 0, 0, 1, 1},
  {&__pyx_n_s_search, __pyx_k_search, sizeof(__pyx_k_search), 0, 0, 1, 1},
  {&__pyx_n_u_searchButton, __pyx_k_searchButton, sizeof(__pyx_k_searchButton), 0, 1, 0, 1},
  {&__pyx_n_s_search_button, __pyx_k_search_button, sizeof(__pyx_k_search_button), 0, 0, 1, 1},
  {&__pyx_n_s_select, __pyx_k_select, sizeof(__pyx_k_select), 0, 0, 1, 1},
  {&__pyx_n_s_select_by_visible_text, __pyx_k_select_by_visible_text, sizeof(__pyx_k_select_by_visible_text), 0, 0, 1, 1},
  {&__pyx_n_s_selenium, __pyx_k_selenium, sizeof(__pyx_k_selenium), 0, 0, 1, 1},
  {&__pyx_n_s_selenium_webdriver_chrome_option, __pyx_k_selenium_webdriver_chrome_option, sizeof(__pyx_k_selenium_webdriver_chrome_option), 0, 0, 1, 1},
  {&__pyx_n_s_selenium_webdriver_common_by, __pyx_k_selenium_webdriver_common_by, sizeof(__pyx_k_selenium_webdriver_common_by), 0, 0, 1, 1},
  {&__pyx_n_s_selenium_webdriver_support_ui, __pyx_k_selenium_webdriver_support_ui, sizeof(__pyx_k_selenium_webdriver_support_ui), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_send_keys, __pyx_k_send_keys, sizeof(__pyx_k_send_keys), 0, 0, 1, 1},
  {&__pyx_n_s_series, __pyx_k_series, sizeof(__pyx_k_series), 0, 0, 1, 1},
  {&__pyx_n_s_set, __pyx_k_set, sizeof(__pyx_k_set), 0, 0, 1, 1},
  {&__pyx_n_s_set_fmt_str_lengths, __pyx_k_set_fmt_str_lengths, sizeof(__pyx_k_set_fmt_str_lengths), 0, 0, 1, 1},
  {&__pyx_n_s_set_tbl_cols, __pyx_k_set_tbl_cols, sizeof(__pyx_k_set_tbl_cols), 0, 0, 1, 1},
  {&__pyx_n_s_set_tbl_formatting, __pyx_k_set_tbl_formatting, sizeof(__pyx_k_set_tbl_formatting), 0, 0, 1, 1},
  {&__pyx_n_s_set_tbl_rows, __pyx_k_set_tbl_rows, sizeof(__pyx_k_set_tbl_rows), 0, 0, 1, 1},
  {&__pyx_n_s_set_verbose, __pyx_k_set_verbose, sizeof(__pyx_k_set_verbose), 0, 0, 1, 1},
  {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
  {&__pyx_n_s_sheet_names, __pyx_k_sheet_names, sizeof(__pyx_k_sheet_names), 0, 0, 1, 1},
  {&__pyx_n_s_sleep, __pyx_k_sleep, sizeof(__pyx_k_sleep), 0, 0, 1, 1},
  {&__pyx_n_s_slice, __pyx_k_slice, sizeof(__pyx_k_slice), 0, 0, 1, 1},
  {&__pyx_n_u_snappy, __pyx_k_snappy, sizeof(__pyx_k_snappy), 0, 1, 0, 1},
  {&__pyx_n_s_sno_records, __pyx_k_sno_records, sizeof(__pyx_k_sno_records), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_split_cases, __pyx_k_split_cases, sizeof(__pyx_k_split_cases), 0, 0, 1, 1},
  {&__pyx_n_s_split_charges, __pyx_k_split_charges, sizeof(__pyx_k_split_charges), 0, 0, 1, 1},
  {&__pyx_n_s_split_charges_locals_lambda, __pyx_k_split_charges_locals_lambda, sizeof(__pyx_k_split_charges_locals_lambda), 0, 0, 1, 1},
  {&__pyx_n_s_split_fees, __pyx_k_split_fees, sizeof(__pyx_k_split_fees), 0, 0, 1, 1},
  {&__pyx_n_s_splitext, __pyx_k_splitext, sizeof(__pyx_k_splitext), 0, 0, 1, 1},
  {&__pyx_n_s_ssn, __pyx_k_ssn, sizeof(__pyx_k_ssn), 0, 0, 1, 1},
  {&__pyx_n_s_ssn_box, __pyx_k_ssn_box, sizeof(__pyx_k_ssn_box), 0, 0, 1, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_n_s_street1, __pyx_k_street1, sizeof(__pyx_k_street1), 0, 0, 1, 1},
  {&__pyx_n_s_street2, __pyx_k_street2, sizeof(__pyx_k_street2), 0, 0, 1, 1},
  {&__pyx_n_s_strict, __pyx_k_strict, sizeof(__pyx_k_strict), 0, 0, 1, 1},
  {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
  {&__pyx_n_s_sub, __pyx_k_sub, sizeof(__pyx_k_sub), 0, 0, 1, 1},
  {&__pyx_n_s_success, __pyx_k_success, sizeof(__pyx_k_success), 0, 0, 1, 1},
  {&__pyx_n_s_support_archive, __pyx_k_support_archive, sizeof(__pyx_k_support_archive), 0, 0, 1, 1},
  {&__pyx_n_s_support_multitable, __pyx_k_support_multitable, sizeof(__pyx_k_support_multitable), 0, 0, 1, 1},
  {&__pyx_n_s_support_singletable, __pyx_k_support_singletable, sizeof(__pyx_k_support_singletable), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_table, __pyx_k_table, sizeof(__pyx_k_table), 0, 0, 1, 1},
  {&__pyx_n_s_tables, __pyx_k_tables, sizeof(__pyx_k_tables), 0, 0, 1, 1},
  {&__pyx_n_s_tbal, __pyx_k_tbal, sizeof(__pyx_k_tbal), 0, 0, 1, 1},
  {&__pyx_n_s_tempcols, __pyx_k_tempcols, sizeof(__pyx_k_tempcols), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_text, __pyx_k_text, sizeof(__pyx_k_text), 0, 0, 1, 1},
  {&__pyx_n_s_then, __pyx_k_then, sizeof(__pyx_k_then), 0, 0, 1, 1},
  {&__pyx_n_s_threading, __pyx_k_threading, sizeof(__pyx_k_threading), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
  {&__pyx_n_s_tqdm, __pyx_k_tqdm, sizeof(__pyx_k_tqdm), 0, 0, 1, 1},
  {&__pyx_n_s_tracebacklimit, __pyx_k_tracebacklimit, sizeof(__pyx_k_tracebacklimit), 0, 0, 1, 1},
  {&__pyx_kp_u_txt, __pyx_k_txt, sizeof(__pyx_k_txt), 0, 1, 0, 0},
  {&__pyx_n_s_uID, __pyx_k_uID, sizeof(__pyx_k_uID), 0, 0, 1, 1},
  {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
  {&__pyx_n_s_url, __pyx_k_url, sizeof(__pyx_k_url), 0, 0, 1, 1},
  {&__pyx_n_s_username_box, __pyx_k_username_box, sizeof(__pyx_k_username_box), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_version, __pyx_k_version, sizeof(__pyx_k_version), 0, 0, 1, 1},
  {&__pyx_kp_u_w_2_d_12, __pyx_k_w_2_d_12, sizeof(__pyx_k_w_2_d_12), 0, 1, 0, 0},
  {&__pyx_kp_u_w_2_d_4_d_6_d_2, __pyx_k_w_2_d_4_d_6_d_2, sizeof(__pyx_k_w_2_d_4_d_6_d_2), 0, 1, 0, 0},
  {&__pyx_kp_u_w_2_d_4_d_6_d_2_2, __pyx_k_w_2_d_4_d_6_d_2_2, sizeof(__pyx_k_w_2_d_4_d_6_d_2_2), 0, 1, 0, 0},
  {&__pyx_kp_u_w_2_d_4_d_6_d_2_3, __pyx_k_w_2_d_4_d_6_d_2_3, sizeof(__pyx_k_w_2_d_4_d_6_d_2_3), 0, 1, 0, 0},
  {&__pyx_n_s_warnings, __pyx_k_warnings, sizeof(__pyx_k_warnings), 0, 0, 1, 1},
  {&__pyx_n_s_webdriver, __pyx_k_webdriver, sizeof(__pyx_k_webdriver), 0, 0, 1, 1},
  {&__pyx_n_s_when, __pyx_k_when, sizeof(__pyx_k_when), 0, 0, 1, 1},
  {&__pyx_n_s_window, __pyx_k_window, sizeof(__pyx_k_window), 0, 0, 1, 1},
  {&__pyx_n_s_with_columns, __pyx_k_with_columns, sizeof(__pyx_k_with_columns), 0, 0, 1, 1},
  {&__pyx_n_s_workbook, __pyx_k_workbook, sizeof(__pyx_k_workbook), 0, 0, 1, 1},
  {&__pyx_n_s_worksheet, __pyx_k_worksheet, sizeof(__pyx_k_worksheet), 0, 0, 1, 1},
  {&__pyx_n_s_write, __pyx_k_write, sizeof(__pyx_k_write), 0, 0, 1, 1},
  {&__pyx_n_s_write_csv, __pyx_k_write_csv, sizeof(__pyx_k_write_csv), 0, 0, 1, 1},
  {&__pyx_n_s_write_event_value, __pyx_k_write_event_value, sizeof(__pyx_k_write_event_value), 0, 0, 1, 1},
  {&__pyx_n_s_write_excel, __pyx_k_write_excel, sizeof(__pyx_k_write_excel), 0, 0, 1, 1},
  {&__pyx_n_s_write_json, __pyx_k_write_json, sizeof(__pyx_k_write_json), 0, 0, 1, 1},
  {&__pyx_n_s_write_parquet, __pyx_k_write_parquet, sizeof(__pyx_k_write_parquet), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_kp_u_xls, __pyx_k_xls, sizeof(__pyx_k_xls), 0, 1, 0, 0},
  {&__pyx_kp_u_xlsx, __pyx_k_xlsx, sizeof(__pyx_k_xlsx), 0, 1, 0, 0},
  {&__pyx_n_s_xlsxwriter, __pyx_k_xlsxwriter, sizeof(__pyx_k_xlsxwriter), 0, 0, 1, 1},
  {&__pyx_kp_u_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 1, 0, 0},
  {&__pyx_n_s_zipcode, __pyx_k_zipcode, sizeof(__pyx_k_zipcode), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 36, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(0, 315, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 970, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "alacorder/cal.pyx":36
 *      """
 *      df = read(cf, window)
 *      print("Extracting case info...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])
 *      print("Parsing charges...")
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_u_Extracting_case_info); if (unlikely(!__pyx_tuple_)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "alacorder/cal.pyx":38
 *      print("Extracting case info...")
 *      ca, ac, af = split_cases(df, debug=cf['DEBUG'])
 *      print("Parsing charges...")             # <<<<<<<<<<<<<<
 *      ch = split_charges(ac, debug=cf['DEBUG'])
 *      print("Parsing fees tables...")
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_u_Parsing_charges); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(0, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "alacorder/cal.pyx":40
 *      print("Parsing charges...")
 *      ch = split_charges(ac, debug=cf['DEBUG'])
 *      print("Parsing fees tables...")             # <<<<<<<<<<<<<<
 *      fs = split_fees(af, debug=cf['DEBUG'])
 *      if not cf['NO_WRITE']:
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_Parsing_fees_tables); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "alacorder/cal.pyx":43
 *      fs = split_fees(af, debug=cf['DEBUG'])
 *      if not cf['NO_WRITE']:
 *           print("Writing to export...")             # <<<<<<<<<<<<<<
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 *      if window:
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_u_Writing_to_export); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "alacorder/cal.pyx":46
 *      write([ca, ch, fs], sheet_names=["cases","charges","fees"], cf=cf)
 *      if window:
 *           window.write_event_value("COMPLETE-TB",True)             # <<<<<<<<<<<<<<
 *      return ca, ch, fs
 * def cases(cf, window=None, debug=False):
 */
  __pyx_tuple__5 = PyTuple_Pack(2, __pyx_kp_u_COMPLETE_TB, Py_True); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "alacorder/cal.pyx":66
 *      """
 *      df = read(cf, window)
 *      print("Extracting charges...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df)
 *      print("Parsing charges...")
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_u_Extracting_charges); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "alacorder/cal.pyx":81
 *      """
 *      df = read(cf, window)
 *      print("Extracting fee sheets...")             # <<<<<<<<<<<<<<
 *      ca, ac, af = split_cases(df)
 *      print("Parsing fees tables...")
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_u_Extracting_fee_sheets); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "alacorder/cal.pyx":133
 *           return ca, ch, fs
 *      else:
 *           print("Job not specified. Select a mode and reconfigure to start.")             # <<<<<<<<<<<<<<
 *           return None
 * def archive(cf, window=None, debug=False):
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_Job_not_specified_Select_a_mode); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "alacorder/cal.pyx":142
 *      write(a, cf=cf)
 *      if window:
 *           window.write_event_value("COMPLETE-MA",True)             # <<<<<<<<<<<<<<
 *      return a
 * 
 */
  __pyx_tuple__10 = PyTuple_Pack(2, __pyx_kp_u_COMPLETE_MA, Py_True); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(0, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "alacorder/cal.pyx":206
 *      assert force or outputext in (".xls",".xlsx",".csv",".parquet",".zip",".json","none","directory")
 *      if support_multitable == False and archive == False and fetch == False and table not in ("cases","charges","fees"):
 *           raise Exception("Single table export choice required! (cases, charges, fees)")             # <<<<<<<<<<<<<<
 *      if archive and append and existing_output and not no_write:
 *           try:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Single_table_export_choice_requi); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "alacorder/cal.pyx":211
 *                old_archive = read(outputs)
 *           except:
 *                print("Append failed! Archive at output path could not be read.")             # <<<<<<<<<<<<<<
 * 
 *      ## DIRECTORY INPUTS
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Append_failed_Archive_at_output); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "alacorder/cal.pyx":244
 *           itype = "object"
 *      else:
 *           raise Exception("Failed to determine input type.")             # <<<<<<<<<<<<<<
 * 
 *      if count == 0:
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_u_Failed_to_determine_input_type); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "alacorder/cal.pyx":287
 *      }
 *      dlog(debug, out)
 *      print("Successfully configured.")             # <<<<<<<<<<<<<<
 *      if now:
 *           return init(out, window=window, debug=debug)
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Successfully_configured); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(0, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "alacorder/cal.pyx":312
 *                queue = cf['QUEUE']
 *                aptxt = []
 *                print("Extracting text...")             # <<<<<<<<<<<<<<
 *                if window:
 *                     window.write_event_value("PROGRESS_TOTAL",len(queue))
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_u_Extracting_text); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "alacorder/cal.pyx":391
 *           return outputs
 *      elif not cf['OVERWRITE'] and os.path.isfile(cf['OUTPUT_PATH']):
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")             # <<<<<<<<<<<<<<
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_Could_not_write_to_output_path_b); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "alacorder/cal.pyx":393
 *           raise Exception("Could not write to output path because overwrite mode is not enabled.")
 *      elif cf['OUTPUT_EXT'] in (".xlsx",".xls"):
 *            with xlsxwriter.Workbook(cf['OUTPUT_PATH']) as workbook:             # <<<<<<<<<<<<<<
 *                  if not isinstance(outputs, list):
 *                     outputs = [outputs]
 */
  __pyx_tuple__18 = PyTuple_Pack(3, Py_None, Py_None, Py_None); if (unlikely(!__pyx_tuple__18)) __PYX_ERR(0, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "alacorder/cal.pyx":434
 *      assert os.path.isfile(inpath) and os.path.isfile(outpath)
 *      try:
 *           inarc = read(inpath).select("AllPagesText","Path","Timestamp")             # <<<<<<<<<<<<<<
 *           outarc = read(outpath).select("AllPagesText","Path","Timestamp")
 *      except:
 */
  __pyx_tuple__19 = PyTuple_Pack(3, __pyx_n_u_AllPagesText, __pyx_n_u_Path, __pyx_n_u_Timestamp); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "alacorder/cal.pyx":438
 *      except:
 *           try:
 *                print("Could not find column Timestamp in archive.")             # <<<<<<<<<<<<<<
 *                inarc = read(inpath).select("AllPagesText","Path")
 *                outarc = read(outpath).select("AllPagesText","Path")
 */
  __pyx_tuple__20 = PyTuple_Pack(1, __pyx_kp_u_Could_not_find_column_Timestamp); if (unlikely(!__pyx_tuple__20)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__20);
  __Pyx_GIVEREF(__pyx_tuple__20);

  /* "alacorder/cal.pyx":439
 *           try:
 *                print("Could not find column Timestamp in archive.")
 *                inarc = read(inpath).select("AllPagesText","Path")             # <<<<<<<<<<<<<<
 *                outarc = read(outpath).select("AllPagesText","Path")
 *           except:
 */
  __pyx_tuple__21 = PyTuple_Pack(2, __pyx_n_u_AllPagesText, __pyx_n_u_Path); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "alacorder/cal.pyx":442
 *                outarc = read(outpath).select("AllPagesText","Path")
 *           except:
 *                print("Could not find column Path in archive.")             # <<<<<<<<<<<<<<
 *                inarc = read(inpath).select("AllPagesText")
 *                outarc = read(outpath).select("AllPagesText")
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_u_Could_not_find_column_Path_in_ar); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "alacorder/cal.pyx":448
 *      out = pl.concat([inarc, outarc])
 *      if window:
 *                window.write_event_value("COMPLETE-AA",True)             # <<<<<<<<<<<<<<
 *      write(conf, out)
 *      return out
 */
  __pyx_tuple__23 = PyTuple_Pack(2, __pyx_kp_u_COMPLETE_AA, Py_True); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "alacorder/cal.pyx":456
 * def split_cases(df, debug=False):
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_u_VS_V_VS_V_VS_VS_1_A_Z_s_10_100); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_tuple__25 = PyTuple_Pack(2, __pyx_kp_u_Case_Number, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);
  __pyx_tuple__26 = PyTuple_Pack(2, __pyx_kp_u_C, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "alacorder/cal.pyx":457
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_SSN_5_75_Alias); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_tuple__29 = PyTuple_Pack(2, __pyx_kp_u__28, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "alacorder/cal.pyx":458
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 *           pl.col("AllPagesText").str.extract(r'(?:SSN)(.{5,75})(?:Alias)', group_index=1).str.replace_all(":","",literal=True).str.strip().alias("Alias"),
 *           pl.col("AllPagesText").str.extract(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', group_index=1).str.replace_all(r'[^\d/]','').str.strip().alias("DOB"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_u_d_2_d_2_d_4_0_5_DOB); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_tuple__31 = PyTuple_Pack(2, __pyx_kp_u_d, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__31)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__31);
  __Pyx_GIVEREF(__pyx_tuple__31);

  /* "alacorder/cal.pyx":461
 *           pl.col("AllPagesText").str.extract(r'(\w{2}\-\d{4}\-\d{6}\.\d{2})').alias("SHORTCASENO"),
 *           pl.col("AllPagesText").str.extract(r'(?:County: )(\d{2})').alias("SHORTCOUNTY"),
 *           pl.col("AllPagesText").str.extract(r'(Phone: )(.+)', group_index=2).str.replace_all(r'[^0-9]','').str.slice(0,10).alias("RE_Phone"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_u_Phone); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);
  __pyx_tuple__33 = PyTuple_Pack(2, __pyx_kp_u_0_9, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_tuple__34 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_10); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "alacorder/cal.pyx":464
 *           pl.col("AllPagesText").str.extract(r'(B|W|H|A)/(?:F|M)').alias("Race"),
 *           pl.col("AllPagesText").str.extract(r'(?:B|W|H|A)/(F|M)').alias("Sex"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_kp_u_Address_1_Phone); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);
  __pyx_tuple__36 = PyTuple_Pack(2, __pyx_kp_u_Phone_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "alacorder/cal.pyx":466
 *           pl.col("AllPagesText").str.extract(r'(?:Address 1:)(.+)(?:Phone)*?', group_index=1).str.replace(r'(Phone.+)','').str.strip().alias("Address1"),
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_kp_u_Zip); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);
  __pyx_tuple__38 = PyTuple_Pack(2, __pyx_kp_u_A_Z, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "alacorder/cal.pyx":467
 *           pl.col("AllPagesText").str.extract(r'(?:Address 2:)(.+)').str.strip().alias("Address2"),
 *           pl.col("AllPagesText").str.extract(r'(?:Zip: )(.+)',group_index=1).str.replace_all(r'[A-Z].+','').alias("ZipCode"),
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=1).alias("City"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(?:City: )(.*)(?:State: )(.*)', group_index=2).alias("State"),
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_kp_u_City_State); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "alacorder/cal.pyx":471
 *           pl.col("AllPagesText").str.extract_all(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}.{10,75})').alias("RE_Charges"),
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),
 */
  __pyx_tuple__40 = PyTuple_Pack(2, __pyx_kp_u_0_9_s, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__40)) __PYX_ERR(0, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__40);
  __Pyx_GIVEREF(__pyx_tuple__40);

  /* "alacorder/cal.pyx":472
 *           pl.col("AllPagesText").str.extract_all(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^\n]*)').alias('RE_Fees'),
 *           pl.col("AllPagesText").str.extract(r'(Total:.+\$[^\n]*)').str.replace_all(r'[^0-9|\.|\s|\$]', "").str.extract_all(r'\s\$\d+\.\d{2}').alias("TOTALS"),
 *           pl.col("AllPagesText").str.extract(r'(ACTIVE[^\n]+D999[^\n]+)').str.extract_all(r'\$\d+\.\d{2}').arr.get(-1).str.replace(r'[\$\s]','').cast(pl.Float64, strict=False).alias("D999"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(\w{2}\d{12})').arr.join("/").alias("RelatedCases"),
 *           pl.col("AllPagesText").str.extract(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)').alias("FilingDate"),
 */
  __pyx_tuple__41 = PyTuple_Pack(2, __pyx_kp_u_s, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "alacorder/cal.pyx":487
 *           pl.col("AllPagesText").str.extract(r'Jury Demand: ([A-Z]+)').str.strip().alias("JuryDemand"),
 *           pl.col("AllPagesText").str.extract(r'Inpatient Treatment Ordered: ([YES|NO]?)').str.strip().alias("InpatientTreatmentOrdered"),
 *           pl.col("AllPagesText").str.extract(r'Trial Type: ([A-Z]+)').str.replace(r'[S|N]$','').str.strip().alias("TrialType"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Case Number: (\d\d-\w+) County:').str.strip().alias("County"),
 *           pl.col("AllPagesText").str.extract(r'Judge: ([A-Z\-\.\s]+)').str.rstrip("T").str.strip().alias("Judge"),
 */
  __pyx_tuple__43 = PyTuple_Pack(2, __pyx_kp_u_S_N, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "alacorder/cal.pyx":492
 *           pl.col("AllPagesText").str.extract(r'Probation Office \#: ([0-9\-]+)').alias("PROBATIONOFFICENUMBERRAW"),
 *           pl.col("AllPagesText").str.extract(r'Defendant Status: ([A-Z\s]+)').str.rstrip("J").str.strip().alias("DefendantStatus"),
 *           pl.col("AllPagesText").str.extract(r'([^0-9]+) Arresting Agency Type:').str.replace(r'\n','').str.strip().alias("ArrestingAgencyType"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Arresting Officer: ([A-Z\s]+)').str.rstrip("S").str.rstrip("P").str.strip().alias("ArrestingOfficer"),
 *           pl.col("AllPagesText").str.extract(r'Probation Office Name: ([A-Z0-9]+)').alias("ProbationOfficeName"),
 */
  __pyx_tuple__44 = PyTuple_Pack(2, __pyx_kp_u_n, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__44)) __PYX_ERR(0, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "alacorder/cal.pyx":505
 *           pl.col("AllPagesText").str.extract(r'Weight: (\d+)').cast(pl.Int64, strict=False).alias("Weight"),
 *           pl.col("AllPagesText").str.extract(r"Height : (\d'\d{2})").alias("RAWHEIGHT"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),
 */
  __pyx_tuple__45 = PyTuple_Pack(1, __pyx_kp_u_Eyes_Hair_w_3_w_3); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "alacorder/cal.pyx":507
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=1).alias("Eyes"),
 *           pl.col("AllPagesText").str.extract(r'Eyes/Hair: (\w{3})/(\w{3})', group_index=2).alias("Hair"),
 *           pl.col("AllPagesText").str.extract(r'Country: (\w*+)').str.replace(r'(Enforcement|Party)','').str.strip().alias("Country"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:').str.strip().alias("WarrantIssuanceDate"),
 *           pl.col("AllPagesText").str.extract(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("WarrantActionDate"),
 */
  __pyx_tuple__46 = PyTuple_Pack(2, __pyx_kp_u_Enforcement_Party, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);

  /* "alacorder/cal.pyx":516
 *           pl.col("AllPagesText").str.extract(r'Bond Type: (\w)').str.strip().alias("BondType"),
 *           pl.col("AllPagesText").str.extract(r'Bond Type Desc: ([A-Z\s]+)').str.strip().alias("BondTypeDesc"),
 *           pl.col("AllPagesText").str.extract(r'([\d\.]+) Bond Amount:').str.replace_all(r'[^0-9\.\s]','').cast(pl.Float64,strict=False).alias("BondAmt"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Bond Company: ([A-Z0-9]+)').str.rstrip("S").str.strip().alias("BondCompany"),
 *           pl.col("AllPagesText").str.extract(r'Surety Code: ([A-Z0-9]{4})').str.strip().alias("SuretyCode"),
 */
  __pyx_tuple__47 = PyTuple_Pack(2, __pyx_kp_u_0_9_s_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__47)) __PYX_ERR(0, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "alacorder/cal.pyx":523
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:').str.strip().alias("BondsmanProcessIssuance"),
 *           pl.col("AllPagesText").str.extract(r'Bondsman Process Return: (.*?) Number of Subponeas').str.strip().alias("BondsmanProcessReturn"),
 *           pl.col("AllPagesText").str.extract(r'([\n\s/\d]*?) Appeal Court:').str.replace_all(r'[\n\s]','').str.strip().alias("AppealDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'([A-Z\-\s]+) Appeal Case Number').str.strip().alias("AppealCourt"),
 *           pl.col("AllPagesText").str.extract(r'Orgin Of Appeal: ([A-Z\-\s]+)').str.rstrip("L").str.strip().alias("OriginOfAppeal"),
 */
  __pyx_tuple__48 = PyTuple_Pack(2, __pyx_kp_u_n_s, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);

  /* "alacorder/cal.pyx":529
 *           pl.col("AllPagesText").str.extract(r'Appeal Status: ([A-Z\-\s]+)').str.rstrip("A").str.strip().alias("AppealStatus"),
 *           pl.col("AllPagesText").str.extract(r'Appeal To: (\w?) Appeal').str.strip().alias("AppealTo"),
 *           pl.col("AllPagesText").str.extract(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("LowerCourtAppealDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionDateOfAppeal"),
 *           pl.col("AllPagesText").str.extract(r'Disposition Type Of Appeal: [^A-Za-z]+').str.replace_all(r'[\n\s:\-]','').str.strip().alias("DispositionTypeOfAppeal"),
 */
  __pyx_tuple__49 = PyTuple_Pack(2, __pyx_kp_u_n_s_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__49)) __PYX_ERR(0, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "alacorder/cal.pyx":535
 *           pl.col("AllPagesText").str.extract(r'Updated By: (\w{3})').str.strip().alias("AdminUpdatedBy"),
 *           pl.col("AllPagesText").str.extract(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)').str.strip().alias("TransferToAdminDocDate"),
 *           pl.col("AllPagesText").str.extract(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)').str.replace_all(r'(Transfer Desc:)','').str.strip().alias("TransferDesc"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)').str.strip().alias("TBNV1"),
 *           pl.col("AllPagesText").str.extract(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)').str.strip().alias("TBNV2")])
 */
  __pyx_tuple__50 = PyTuple_Pack(2, __pyx_kp_u_Transfer_Desc, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 535, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "alacorder/cal.pyx":540
 *      cases.with_columns([
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 */
  __pyx_tuple__53 = PyTuple_Pack(2, __pyx_kp_u_n_Requrements_Completed, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__53)) __PYX_ERR(0, 540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "alacorder/cal.pyx":541
 *           pl.concat_str([pl.col("RAWHEIGHT"), pl.lit('"')]).alias("Height"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Requrements Completed: )([YES|NO]?)').arr.join(", ").str.replace_all(r'[\n:]|Requrements Completed','').str.strip().alias("SentencingRequirementsCompleted"),
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 */
  __pyx_tuple__54 = PyTuple_Pack(2, __pyx_kp_u_Sentence_Date, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__54)) __PYX_ERR(0, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "alacorder/cal.pyx":543
 *           pl.col("AllPagesText").str.extract_all(r'(?:Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Date: )','').str.strip().alias("SentenceDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 */
  __pyx_tuple__55 = PyTuple_Pack(2, __pyx_kp_u_License_Susp_Period_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__55)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);

  /* "alacorder/cal.pyx":544
 *           pl.col("AllPagesText").str.extract_all(r'Probation Period: ([^\.]+)').arr.join(", ").str.strip().alias("ProbationPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 */
  __pyx_tuple__56 = PyTuple_Pack(2, __pyx_kp_u_Jail_Credit_Period_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__56)) __PYX_ERR(0, 544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__56);
  __Pyx_GIVEREF(__pyx_tuple__56);

  /* "alacorder/cal.pyx":545
 *           pl.col("AllPagesText").str.extract_all(r'License Susp Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(License Susp Period:)','').str.strip().alias("LicenseSuspPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 */
  __pyx_tuple__57 = PyTuple_Pack(2, __pyx_kp_u_Sentence_Provisions, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__57)) __PYX_ERR(0, 545, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "alacorder/cal.pyx":546
 *           pl.col("AllPagesText").str.extract_all(r'Jail Credit Period: ([^\.]+)').arr.join(", ").str.replace_all(r'(Jail Credit Period:)','').str.strip().alias("JailCreditPeriod"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 */
  __pyx_tuple__58 = PyTuple_Pack(2, __pyx_kp_u_Sentence_Start_Date, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__58)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "alacorder/cal.pyx":547
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Provisions: ([Y|N]?)').arr.join(", ").str.replace_all(r'(Sentence Provisions:)','').str.strip().alias("SentenceProvisions"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 */
  __pyx_tuple__59 = PyTuple_Pack(2, __pyx_kp_u_Sentence_End_Date, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "alacorder/cal.pyx":548
 *           pl.col("AllPagesText").str.extract_all(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence Start Date:)','').str.strip().alias("SentenceStartDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),
 */
  __pyx_tuple__60 = PyTuple_Pack(2, __pyx_kp_u_Probation_Begin_Date, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__60)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__60);
  __Pyx_GIVEREF(__pyx_tuple__60);

  /* "alacorder/cal.pyx":549
 *           pl.col("AllPagesText").str.extract_all(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Sentence End Date:)','').str.strip().alias("SentenceEndDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'(Probation Begin Date:)','').str.strip().alias("ProbationBeginDate"),
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),             # <<<<<<<<<<<<<<
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'Probation Revoke: ','').str.strip().alias("ProbationRevoke")])
 */
  __pyx_tuple__61 = PyTuple_Pack(2, __pyx_kp_u_Updated_By, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__61)) __PYX_ERR(0, 549, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "alacorder/cal.pyx":551
 *           pl.col("AllPagesText").str.extract_all(r'Updated By: (\w{3}?)').arr.join(", ").str.replace_all(r'(Updated By:)','').str.strip().alias("SentenceUpdatedBy"),
 *           pl.col("AllPagesText").str.extract_all(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.strip().alias("SentenceLastUpdate"),
 *           pl.col("AllPagesText").str.extract_all(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)').arr.join(", ").str.replace_all(r'Probation Revoke: ','').str.strip().alias("ProbationRevoke")])             # <<<<<<<<<<<<<<
 * 
 *      dlog(debug, [cases.columns, cases.shape, "alac 899"])
 */
  __pyx_tuple__62 = PyTuple_Pack(2, __pyx_kp_u_Probation_Revoke, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__62)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);

  /* "alacorder/cal.pyx":559
 *           pl.col("RE_Phone").str.replace_all(r'[^0-9]','').alias("CLEAN_Phone"),
 *           pl.concat_str([pl.col("SHORTCOUNTY"),pl.lit("-"),pl.col("SHORTCASENO")]).alias("CaseNumber"),
 *           pl.concat_str([pl.col("Address1"), pl.lit(" "), pl.col("Address2")]).str.replace_all(r'JID: \w{3} Hardship.*|Defendant Information.*','').str.strip().alias("StreetAddress"),             # <<<<<<<<<<<<<<
 *           pl.col("Name"),
 *           pl.when(pl.col("PROBATIONOFFICENUMBERRAW")=="0-000000-00").then(pl.lit('')).otherwise(pl.col("PROBATIONOFFICENUMBERRAW")).alias("ProbationOfficeName"),
 */
  __pyx_tuple__65 = PyTuple_Pack(2, __pyx_kp_u_JID_w_3_Hardship_Defendant_Infor, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__65)) __PYX_ERR(0, 559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "alacorder/cal.pyx":564
 *           pl.when(pl.col("DLRAW")=="AL").then(pl.lit('')).otherwise(pl.col("DLRAW")).alias("DriverLicenseNo"),
 *           pl.when(pl.col("SIDRAW")=="AL000000000").then(pl.lit('')).otherwise(pl.col("SIDRAW")).alias("StateID"),
 *           pl.col("TOTALS").arr.get(0).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtDue"),             # <<<<<<<<<<<<<<
 *           pl.col("TOTALS").arr.get(1).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalAmtPaid"),
 *           pl.col("TOTALS").arr.get(2).str.replace_all(r'[^0-9\.]','').cast(pl.Float64, strict=False).alias("TotalBalance"),
 */
  __pyx_tuple__66 = PyTuple_Pack(2, __pyx_kp_u_0_9_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__66)) __PYX_ERR(0, 564, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "alacorder/cal.pyx":576
 *      all_charges = cases.explode("RE_Charges").select([
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Charges").str.replace_all(r'[A-Z][a-z][A-Za-z\s\$]+.+','').str.strip().alias("Charges")])             # <<<<<<<<<<<<<<
 *      cases.drop_in_place("RE_Charges")
 * 
 */
  __pyx_tuple__67 = PyTuple_Pack(2, __pyx_kp_u_A_Z_a_z_A_Za_z_s, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__67)) __PYX_ERR(0, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "alacorder/cal.pyx":583
 *      all_fees = cases.explode("RE_Fees").select([
 *           pl.col("CaseNumber"),
 *           pl.col("RE_Fees").str.replace_all(r"[^A-Z0-9|\.|\s|\$|\n]"," ").str.strip().alias("Fees")])             # <<<<<<<<<<<<<<
 *      cases.drop_in_place("RE_Fees")
 * 
 */
  __pyx_tuple__68 = PyTuple_Pack(2, __pyx_kp_u_A_Z0_9_s_n, __pyx_kp_u__64); if (unlikely(!__pyx_tuple__68)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "alacorder/cal.pyx":593
 *      cases = cases.join(clean_ch_list, on="CaseNumber", how="left")
 *      cases = cases.join(clean_fs_list, on="CaseNumber", how="left")
 *      cases = cases.with_columns(pl.col("Charges").arr.join("; ").str.replace_all(r'(null;?)',''))             # <<<<<<<<<<<<<<
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.fill_null('')
 */
  __pyx_tuple__70 = PyTuple_Pack(2, __pyx_kp_u_null, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__70)) __PYX_ERR(0, 593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "alacorder/cal.pyx":596
 *      cases = cases.with_columns(pl.col("Fees").arr.join("; ").str.replace_all(r'(null;?)',''))
 *      cases = cases.fill_null('')
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')             # <<<<<<<<<<<<<<
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):
 */
  __pyx_tuple__71 = PyTuple_Pack(70, __pyx_n_u_Retrieved, __pyx_n_u_CaseNumber, __pyx_n_u_Name, __pyx_n_u_DOB, __pyx_n_u_Race, __pyx_n_u_Sex, __pyx_n_u_Description, __pyx_n_u_CourtAction, __pyx_n_u_CourtActionDate, __pyx_n_u_TotalAmtDue, __pyx_n_u_TotalAmtPaid, __pyx_n_u_TotalBalance, __pyx_n_u_TotalAmtHold, __pyx_n_u_PaymentToRestore, __pyx_n_u_Phone_3, __pyx_n_u_StreetAddress, __pyx_n_u_City, __pyx_n_u_State, __pyx_n_u_ZipCode, __pyx_n_u_County, __pyx_n_u_Country, __pyx_n_u_Alias, __pyx_n_u_SSN, __pyx_n_u_Weight, __pyx_n_u_Eyes, __pyx_n_u_Hair, __pyx_n_u_FilingDate, __pyx_n_u_CaseInitiationDate, __pyx_n_u_ArrestDate, __pyx_n_u_OffenseDate, __pyx_n_u_IndictmentDate, __pyx_n_u_JuryDemand, __pyx_n_u_InpatientTreatmentOrdered, __pyx_n_u_TrialType, __pyx_n_u_Judge, __pyx_n_u_DefendantStatus, __pyx_n_u_ArrestingAgencyType, __pyx_n_u_ArrestingOfficer, __pyx_n_u_ProbationOfficeName, __pyx_n_u_PreviousDUIConvictions, __pyx_n_u_CaseInitiationType, __pyx_n_u_DomesticViolence, __pyx_n_u_AgencyORI, __pyx_n_u_WarrantIssuanceDate, __pyx_n_u_WarrantActionDate, __pyx_n_u_WarrantIssuanceStatus, __pyx_n_u_WarrantActionStatus, __pyx_n_u_WarrantLocationStatus, __pyx_n_u_NumberOfWarrants, __pyx_n_u_BondType, __pyx_n_u_BondTypeDesc, __pyx_n_u_BondAmt, __pyx_n_u_BondCompany, __pyx_n_u_SuretyCode, __pyx_n_u_BondReleaseDate, __pyx_n_u_FailedToAppearDate, __pyx_n_u_BondsmanProcessIssuance, __pyx_n_u_AppealDate, __pyx_n_u_AppealCourt, __pyx_n_u_OriginOfAppeal, __pyx_n_u_AppealToDesc, __pyx_n_u_AppealStatus, __pyx_n_u_AppealTo, __pyx_n_u_NumberOfSubpoenas, __pyx_n_u_AdminUpdatedBy, __pyx_n_u_TransferDesc, __pyx_n_u_TBNV1, __pyx_n_u_TBNV2, __pyx_n_u_DriverLicenseNo, __pyx_n_u_StateID); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(0, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);

  /* "alacorder/cal.pyx":601
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 *           pl.col("Charges").str.slice(0,3).alias("Num"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 */
  __pyx_tuple__72 = PyTuple_Pack(2, __pyx_int_0, __pyx_int_3); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(0, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "alacorder/cal.pyx":602
 *      charges = df.with_columns([
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 *           pl.col("Charges").str.slice(4,4).alias("Code"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 */
  __pyx_tuple__73 = PyTuple_Pack(2, __pyx_int_4, __pyx_int_4); if (unlikely(!__pyx_tuple__73)) __PYX_ERR(0, 602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);

  /* "alacorder/cal.pyx":603
 *           pl.col("Charges").str.slice(0,3).alias("Num"),
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 */
  __pyx_tuple__74 = PyTuple_Pack(2, __pyx_int_9, __pyx_int_1); if (unlikely(!__pyx_tuple__74)) __PYX_ERR(0, 603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__74);
  __Pyx_GIVEREF(__pyx_tuple__74);

  /* "alacorder/cal.pyx":604
 *           pl.col("Charges").str.slice(4,4).alias("Code"),
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),
 */
  __pyx_tuple__75 = PyTuple_Pack(1, __pyx_kp_u_d_1_2_d_d_d_d_d_d); if (unlikely(!__pyx_tuple__75)) __PYX_ERR(0, 604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);

  /* "alacorder/cal.pyx":605
 *           pl.col("Charges").str.slice(9,1).alias("Sort"), # 0-9: disposition A-Z: filing else: None
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")
 */
  __pyx_tuple__76 = PyTuple_Pack(1, __pyx_kp_u_A_Z0_9_3_A_Z0_9_3_A_Z0_9_3_0_1); if (unlikely(!__pyx_tuple__76)) __PYX_ERR(0, 605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__76);
  __Pyx_GIVEREF(__pyx_tuple__76);

  /* "alacorder/cal.pyx":606
 *           pl.col("Charges").str.extract(r'(\d{1,2}/\d\d/\d\d\d\d)', group_index=1).alias("CourtActionDate"),
 *           pl.col("Charges").str.extract(r'[A-Z0-9]{3}-[A-Z0-9]{3}-[A-Z0-9]{3}\({0,1}[A-Z]{0,1}\){0,1}\.{0,1}\d{0,1}',group_index=0).alias("Cite"),
 *           pl.col("Charges").str.extract(r'(BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', group_index=1).alias("CourtAction"),             # <<<<<<<<<<<<<<
 *           pl.col("Charges").apply(lambda x: re.split(r'[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\s{0,1}-[A-Z0-9]{3}\({0,1}?[A-Z]{0,1}?\){0,1}?\.{0,1}?\d{0,1}?',str(x))).alias("Split")
 *           ])
 */
  __pyx_tuple__77 = PyTuple_Pack(1, __pyx_kp_u_BOUND_GUILTY_PLEA_WAIVED_TO_GJ); if (unlikely(!__pyx_tuple__77)) __PYX_ERR(0, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);

  /* "alacorder/cal.pyx":622
 *      dlog(debug, [charges.columns, charges.shape, "alac 965"])
 *      charges = charges.with_columns([
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),             # <<<<<<<<<<<<<<
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),
 */
  __pyx_tuple__78 = PyTuple_Pack(1, __pyx_kp_u_TRAFFIC_MISDEMEANOR_BOND_FELONY); if (unlikely(!__pyx_tuple__78)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__78);
  __Pyx_GIVEREF(__pyx_tuple__78);
  __pyx_tuple__79 = PyTuple_Pack(2, __pyx_kp_u_TRAFFIC_MISDEMEANOR, __pyx_n_u_MISDEMEANOR); if (unlikely(!__pyx_tuple__79)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);

  /* "alacorder/cal.pyx":623
 *      charges = charges.with_columns([
 *           pl.col("SEG_2").str.extract(r'(TRAFFIC MISDEMEANOR|BOND|FELONY|MISDEMEANOR|OTHER|TRAFFIC|VIOLATION)', group_index=1).str.replace("TRAFFIC MISDEMEANOR","MISDEMEANOR").alias("TypeDescription"),
 *           pl.col("SEG_2").str.extract(r'(ALCOHOL|BOND|CONSERVATION|DOCKET|DRUG|GOVERNMENT|HEALTH|MUNICIPAL|OTHER|PERSONAL|PROPERTY|SEX|TRAFFIC)', group_index=1).alias("Category"),             # <<<<<<<<<<<<<<
 *           pl.col("Description").str.contains(r'(A ATT|ATTEMPT|S SOLICIT|CONSP)').is_not().alias("A_S_C_DISQ"),
 *           pl.col("Code").str.contains('(OSUA|EGUA|MAN1|MAN2|MANS|ASS1|ASS2|KID1|KID2|HUT1|HUT2|BUR1|BUR2|TOP1|TOP2|TPCS|TPCD|TPC1|TET2|TOD2|ROB1|ROB2|ROB3|FOR1|FOR2|FR2D|MIOB|TRAK|TRAG|VDRU|VDRY|TRAO|TRFT|TRMA|TROP|CHAB|WABC|ACHA|ACAL)').alias("CERV_DISQ_MATCH"),
 */
  __pyx_tuple__80 = PyTuple_Pack(1, __pyx_kp_u_ALCOHOL_BOND_CONSERVATION_DOCKE); if (unlikely(!__pyx_tuple__80)) __PYX_ERR(0, 623, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__80);
  __Pyx_GIVEREF(__pyx_tuple__80);

  /* "alacorder/cal.pyx":641
 *           ])
 * 
 *      charges = charges.select("Num","Code","Description","TypeDescription","Category","CourtAction","CourtActionDate","Conviction","Felony","CERVDisqCharge","CERVDisqConviction","PardonDisqCharge","PardonDisqConviction","PermanentDisqCharge","PermanentDisqConviction")             # <<<<<<<<<<<<<<
 * 
 *      dlog(debug, [charges.columns, charges.shape, "alac 989"])
 */
  __pyx_tuple__81 = PyTuple_Pack(15, __pyx_n_u_Num, __pyx_n_u_Code, __pyx_n_u_Description, __pyx_n_u_TypeDescription, __pyx_n_u_Category, __pyx_n_u_CourtAction, __pyx_n_u_CourtActionDate, __pyx_n_u_Conviction, __pyx_n_u_Felony, __pyx_n_u_CERVDisqCharge, __pyx_n_u_CERVDisqConviction, __pyx_n_u_PardonDisqCharge, __pyx_n_u_PardonDisqConviction, __pyx_n_u_PermanentDisqCharge, __pyx_n_u_PermanentDisqConviction); if (unlikely(!__pyx_tuple__81)) __PYX_ERR(0, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);

  /* "alacorder/cal.pyx":654
 *      df = df.select([
 *           pl.col("CaseNumber"),
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),             # <<<<<<<<<<<<<<
 *           pl.col("Fees").str.strip().str.replace(" ","").str.extract_all(r'\s\$\d+\.\d{2}').alias("FEE_SEP")
 *           ])
 */
  __pyx_tuple__83 = PyTuple_Pack(2, __pyx_kp_u_d_1_2, __pyx_kp_u__82); if (unlikely(!__pyx_tuple__83)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);

  /* "alacorder/cal.pyx":655
 *           pl.col("CaseNumber"),
 *           pl.col("Fees").str.replace(r'(?:\$\d{1,2})( )','\2').str.split(" ").alias("SPACE_SEP"),
 *           pl.col("Fees").str.strip().str.replace(" ","").str.extract_all(r'\s\$\d+\.\d{2}').alias("FEE_SEP")             # <<<<<<<<<<<<<<
 *           ])
 *      dlog(debug, [df.columns, df.shape, "alac 1004"])
 */
  __pyx_tuple__84 = PyTuple_Pack(2, __pyx_kp_u__64, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__84)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__84);
  __Pyx_GIVEREF(__pyx_tuple__84);

  /* "alacorder/cal.pyx":662
 *           pl.col("SPACE_SEP").arr.get(0).alias("AdminFee1"), # good
 *           pl.col("SPACE_SEP").arr.get(1).alias("FeeStatus1"), # good
 *           pl.col("FEE_SEP").arr.get(0).str.replace(r'\$','').alias("AmtDue"), # good             # <<<<<<<<<<<<<<
 *           pl.col("FEE_SEP").arr.get(1).str.replace(r'\$','').alias("AmtPaid"), # good
 *           pl.col("FEE_SEP").arr.get(-1).str.replace(r'\$','').alias("AmtHold1"),
 */
  __pyx_tuple__86 = PyTuple_Pack(2, __pyx_kp_u__85, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__86)) __PYX_ERR(0, 662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__86);
  __Pyx_GIVEREF(__pyx_tuple__86);

  /* "alacorder/cal.pyx":677
 *           pl.when(pl.col("Payor2").str.contains(r"[^R0-9]\d{3}").is_not()).then(pl.col("Payor2")).otherwise(pl.col("Payee2")).alias("Payee1"),
 *           pl.when(pl.col("AdminFee1")=="Total:").then(pl.lit(None)).otherwise(pl.col("FeeStatus1")).alias("FeeStatus2"),
 *           pl.when(pl.col("AmtHold1")=="L").then("$0.00").otherwise(pl.col("AmtHold1").str.replace_all(r'[A-Z]|\$','')).alias("AmtHold")             # <<<<<<<<<<<<<<
 *           ])
 *      dlog(debug, [out.columns, out.shape, "alac 1026"])
 */
  __pyx_tuple__87 = PyTuple_Pack(2, __pyx_kp_u_A_Z_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__87)) __PYX_ERR(0, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);

  /* "alacorder/cal.pyx":684
 *           pl.col("Total"),
 *           pl.col("AdminFee"),
 *           pl.when(pl.col("FeeStatus2").str.contains("$", literal=True)).then(pl.lit(None)).otherwise(pl.col("FeeStatus2")).alias("FeeStatus"),             # <<<<<<<<<<<<<<
 *           pl.col("Code"),
 *           pl.when(pl.col("AdminFee1")!="ACTIVE").then('').otherwise(pl.col("Payor1")).alias("Payor"),
 */
  __pyx_tuple__89 = PyTuple_Pack(1, __pyx_kp_u__88); if (unlikely(!__pyx_tuple__89)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);

  /* "alacorder/cal.pyx":724
 * 
 *     # add missing progress cols
 *     for col in ("RETRIEVED","CASES_FOUND","QUERY_COMPLETE"):             # <<<<<<<<<<<<<<
 *         if col not in query.columns:
 *             query = query.with_columns(pl.lit('').alias(col))
 */
  __pyx_tuple__91 = PyTuple_Pack(3, __pyx_n_u_RETRIEVED, __pyx_n_u_CASES_FOUND, __pyx_n_u_QUERY_COMPLETE); if (unlikely(!__pyx_tuple__91)) __PYX_ERR(0, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);

  /* "alacorder/cal.pyx":731
 *     goodquery = False
 *     for col in query.columns:
 *         if col.upper().strip().replace(' ','_') in pscols:             # <<<<<<<<<<<<<<
 *             query = query.with_columns([pl.col(col).alias(f"TEMP_{col.upper().strip().replace(' ','_')}")])
 *             goodquery = True
 */
  __pyx_tuple__93 = PyTuple_Pack(2, __pyx_kp_u__64, __pyx_n_u__92); if (unlikely(!__pyx_tuple__93)) __PYX_ERR(0, 731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);

  /* "alacorder/cal.pyx":744
 *         return query
 *     else:
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")             # <<<<<<<<<<<<<<
 *         return None
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):
 */
  __pyx_tuple__94 = PyTuple_Pack(1, __pyx_kp_u_Try_again_with_at_least_one_vali); if (unlikely(!__pyx_tuple__94)) __PYX_ERR(0, 744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__94);
  __Pyx_GIVEREF(__pyx_tuple__94);

  /* "alacorder/cal.pyx":789
 *           "plugins.always_open_pdf_externally": True #It will not display PDF directly in chrome
 *      })
 *      print("Starting browser... Do not close while in progress!")             # <<<<<<<<<<<<<<
 *      driver = webdriver.Chrome(options=opt)
 *      login(driver, cID=cID, uID=uID, pwd=pwd, window=window)
 */
  __pyx_tuple__95 = PyTuple_Pack(1, __pyx_kp_u_Starting_browser_Do_not_close_wh); if (unlikely(!__pyx_tuple__95)) __PYX_ERR(0, 789, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);

  /* "alacorder/cal.pyx":804
 *             print(f"#{i}/{query.shape[0]} {query[i, 'TEMP_NAME']}) ({len(results)} records returned)")
 *             if window != None:
 *                 window.write_event_value('PROGRESS-TEXT', 0)             # <<<<<<<<<<<<<<
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)
 *                 for i, url in enumerate(results):
 */
  __pyx_tuple__98 = PyTuple_Pack(2, __pyx_kp_u_PROGRESS_TEXT, __pyx_int_0); if (unlikely(!__pyx_tuple__98)) __PYX_ERR(0, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__98);
  __Pyx_GIVEREF(__pyx_tuple__98);

  /* "alacorder/cal.pyx":805
 *             if window != None:
 *                 window.write_event_value('PROGRESS-TEXT', 0)
 *                 window.write_event_value('PROGRESS-TEXT-TOTAL', 100)             # <<<<<<<<<<<<<<
 *                 for i, url in enumerate(results):
 *                     window.write_event_value('PROGRESS-TEXT', i+1)
 */
  __pyx_tuple__99 = PyTuple_Pack(2, __pyx_kp_u_PROGRESS_TEXT_TOTAL, __pyx_int_100); if (unlikely(!__pyx_tuple__99)) __PYX_ERR(0, 805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);

  /* "alacorder/cal.pyx":816
 *             query[i,'QUERY_COMPLETE'] = "Y"
 *             if not no_update:
 *                 qwrite = query.drop("TEMP_NAME", "TEMP_PARTY_TYPE", "TEMP_SSN", "TEMP_DOB", "TEMP_COUNTY", "TEMP_DIVISION", "TEMP_CASE_YEAR", "TEMP_NO_RECORDS", "TEMP_FILED_BEFORE", "TEMP_FILED_AFTER")             # <<<<<<<<<<<<<<
 *                 write(qwrite, path=cf['INPUTS'], overwrite=True)
 *         else:
 */
  __pyx_tuple__100 = PyTuple_Pack(10, __pyx_n_u_TEMP_NAME, __pyx_n_u_TEMP_PARTY_TYPE, __pyx_n_u_TEMP_SSN, __pyx_n_u_TEMP_DOB, __pyx_n_u_TEMP_COUNTY, __pyx_n_u_TEMP_DIVISION, __pyx_n_u_TEMP_CASE_YEAR, __pyx_n_u_TEMP_NO_RECORDS, __pyx_n_u_TEMP_FILED_BEFORE, __pyx_n_u_TEMP_FILED_AFTER); if (unlikely(!__pyx_tuple__100)) __PYX_ERR(0, 816, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__100);
  __Pyx_GIVEREF(__pyx_tuple__100);

  /* "alacorder/cal.pyx":829
 *      if window != None:
 *         window.write_event_value('COMPLETE-SQ',time.time())
 *      print("Completed query template.")             # <<<<<<<<<<<<<<
 *      return query
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):
 */
  __pyx_tuple__101 = PyTuple_Pack(1, __pyx_kp_u_Completed_query_template); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "alacorder/cal.pyx":882
 *      except selenium.common.exceptions.NoSuchElementException:
 *           if debug:
 *                print("""NoSuchElementException on alac.py 2173: party_name_box = driver.find_element(by=By.NAME, value="ctl00$ContentPlaceHolder1$txtName")""")             # <<<<<<<<<<<<<<
 *           if driver.current_url == "https://v2.alacourt.com/frmlogin.aspx":
 *                time.sleep(10)
 */
  __pyx_tuple__102 = PyTuple_Pack(1, __pyx_kp_u_NoSuchElementException_on_alac_p); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(0, 882, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "alacorder/cal.pyx":888
 *                driver.implicitly_wait(1)
 *           driver.get("https:v2.alacourt.com/frmIndexSearchForm.aspx")
 *           print("Successfully connected and logged into Alacourt!")             # <<<<<<<<<<<<<<
 * 
 *      # field search
 */
  __pyx_tuple__103 = PyTuple_Pack(1, __pyx_kp_u_Successfully_connected_and_logge); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(0, 888, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);

  /* "alacorder/cal.pyx":944
 * 
 *      if debug:
 *           print("Submitted party search form...")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_tuple__104 = PyTuple_Pack(1, __pyx_kp_u_Submitted_party_search_form); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(0, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "alacorder/cal.pyx":959
 *      try:
 *           results_indicator = driver.find_element(by=By.ID, value="ContentPlaceHolder1_lblResultCount")
 *           results_count = int(results_indicator.text.replace("Search Results: ","").replace(" records returned.","").strip())             # <<<<<<<<<<<<<<
 *      except:
 *           pass
 */
  __pyx_tuple__105 = PyTuple_Pack(2, __pyx_kp_u_Search_Results, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);
  __pyx_tuple__106 = PyTuple_Pack(2, __pyx_kp_u_records_returned_2, __pyx_kp_u__8); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(0, 959, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "alacorder/cal.pyx":1033
 *           driver = webdriver.Chrome(options=options)
 * 
 *      print("Connecting to Alacourt...")             # <<<<<<<<<<<<<<
 * 
 *      login_screen = driver.get("https://v2.alacourt.com/frmlogin.aspx")
 */
  __pyx_tuple__107 = PyTuple_Pack(1, __pyx_kp_u_Connecting_to_Alacourt); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(0, 1033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "alacorder/cal.pyx":1037
 *      login_screen = driver.get("https://v2.alacourt.com/frmlogin.aspx")
 * 
 *      print("Logging in...")             # <<<<<<<<<<<<<<
 * 
 *      driver.implicitly_wait(1)
 */
  __pyx_tuple__108 = PyTuple_Pack(1, __pyx_kp_u_Logging_in); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(0, 1037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "alacorder/cal.pyx":1097
 *      for pg in doc:
 *           try:
 *                text += ' \n '.join(x[4].replace("\n"," ") for x in pg.get_text(option='blocks'))             # <<<<<<<<<<<<<<
 *           except:
 *                pass
 */
  __pyx_tuple__110 = PyTuple_Pack(2, __pyx_kp_u__109, __pyx_kp_u__64); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(0, 1097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "alacorder/cal.pyx":1122
 *         if len(m) < 7:
 *             return ''
 *         elif m[0:10] == "2050000000":             # <<<<<<<<<<<<<<
 *             return ''
 *         elif len(m) > 10:
 */
  __pyx_slice__112 = PySlice_New(__pyx_int_0, __pyx_int_10, Py_None); if (unlikely(!__pyx_slice__112)) __PYX_ERR(0, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__112);
  __Pyx_GIVEREF(__pyx_slice__112);

  /* "alacorder/cal.pyx":1251
 * def getCaseNumber(text):
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()             # <<<<<<<<<<<<<<
 *     except:
 *         return ''
 */
  __pyx_slice__113 = PySlice_New(__pyx_int_0, __pyx_int_2, Py_None); if (unlikely(!__pyx_slice__113)) __PYX_ERR(0, 1251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__113);
  __Pyx_GIVEREF(__pyx_slice__113);

  /* "alacorder/cal.pyx":1272
 *     try:
 *         if len(getName(text).split(" ")) > 2:
 *             return " ".join(getName(text).split(" ")[1:-2]).strip()             # <<<<<<<<<<<<<<
 *         else:
 *             return ''
 */
  __pyx_slice__114 = PySlice_New(__pyx_int_1, __pyx_int_neg_2, Py_None); if (unlikely(!__pyx_slice__114)) __PYX_ERR(0, 1272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__114);
  __Pyx_GIVEREF(__pyx_slice__114);

  /* "alacorder/cal.pyx":21
 * from selenium.webdriver.chrome.options import Options
 * fname = f"{name} {version}"
 * fshort_name = f"{name} {version.rsplit('.')[0]}"             # <<<<<<<<<<<<<<
 * warnings.filterwarnings('ignore')
 * pl.Config.set_tbl_rows(100)
 */
  __pyx_tuple__116 = PyTuple_Pack(1, __pyx_kp_u__115); if (unlikely(!__pyx_tuple__116)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__116);
  __Pyx_GIVEREF(__pyx_tuple__116);

  /* "alacorder/cal.pyx":22
 * fname = f"{name} {version}"
 * fshort_name = f"{name} {version.rsplit('.')[0]}"
 * warnings.filterwarnings('ignore')             # <<<<<<<<<<<<<<
 * pl.Config.set_tbl_rows(100)
 * pl.Config.set_fmt_str_lengths(100)
 */
  __pyx_tuple__117 = PyTuple_Pack(1, __pyx_n_u_ignore); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);

  /* "alacorder/cal.pyx":23
 * fshort_name = f"{name} {version.rsplit('.')[0]}"
 * warnings.filterwarnings('ignore')
 * pl.Config.set_tbl_rows(100)             # <<<<<<<<<<<<<<
 * pl.Config.set_fmt_str_lengths(100)
 * pl.Config.set_tbl_cols(10)
 */
  __pyx_tuple__118 = PyTuple_Pack(1, __pyx_int_100); if (unlikely(!__pyx_tuple__118)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__118);
  __Pyx_GIVEREF(__pyx_tuple__118);

  /* "alacorder/cal.pyx":25
 * pl.Config.set_tbl_rows(100)
 * pl.Config.set_fmt_str_lengths(100)
 * pl.Config.set_tbl_cols(10)             # <<<<<<<<<<<<<<
 * pl.Config.set_tbl_formatting('UTF8_FULL_CONDENSED')
 * CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 */
  __pyx_tuple__119 = PyTuple_Pack(1, __pyx_int_10); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);

  /* "alacorder/cal.pyx":26
 * pl.Config.set_fmt_str_lengths(100)
 * pl.Config.set_tbl_cols(10)
 * pl.Config.set_tbl_formatting('UTF8_FULL_CONDENSED')             # <<<<<<<<<<<<<<
 * CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 * 
 */
  __pyx_tuple__120 = PyTuple_Pack(1, __pyx_n_u_UTF8_FULL_CONDENSED); if (unlikely(!__pyx_tuple__120)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__120);
  __Pyx_GIVEREF(__pyx_tuple__120);

  /* "alacorder/cal.pyx":31
 * #   #   #   #           TASK STARTERS           #   #   #   #
 * 
 * def multi(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start multitable collection using configuration object `cf`.
 */
  __pyx_tuple__121 = PyTuple_Pack(9, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug, __pyx_n_s_df, __pyx_n_s_ca, __pyx_n_s_ac, __pyx_n_s_af, __pyx_n_s_ch, __pyx_n_s_fs); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);
  __pyx_codeobj__122 = (PyObject*)__Pyx_PyCode_New(3, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_multi, 31, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__122)) __PYX_ERR(0, 31, __pyx_L1_error)

  /* "alacorder/cal.pyx":48
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs
 * def cases(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start cases table collection using configuration object `cf`.
 */
  __pyx_tuple__123 = PyTuple_Pack(7, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug, __pyx_n_s_df, __pyx_n_s_ca, __pyx_n_s_ac, __pyx_n_s_af); if (unlikely(!__pyx_tuple__123)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__123);
  __Pyx_GIVEREF(__pyx_tuple__123);
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(3, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__123, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_cases, 48, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(0, 48, __pyx_L1_error)

  /* "alacorder/cal.pyx":61
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca
 * def charges(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start charges table collection using configuration object `cf`.
 */
  __pyx_tuple__125 = PyTuple_Pack(8, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug, __pyx_n_s_df, __pyx_n_s_ca, __pyx_n_s_ac, __pyx_n_s_af, __pyx_n_s_ch); if (unlikely(!__pyx_tuple__125)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__125);
  __Pyx_GIVEREF(__pyx_tuple__125);
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(3, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__125, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_charges, 61, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(0, 61, __pyx_L1_error)

  /* "alacorder/cal.pyx":76
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch
 * def fees(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start fee sheet collection using configuration object `cf`.
 */
  __pyx_tuple__127 = PyTuple_Pack(8, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug, __pyx_n_s_df, __pyx_n_s_ca, __pyx_n_s_ac, __pyx_n_s_af, __pyx_n_s_fs); if (unlikely(!__pyx_tuple__127)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__127);
  __Pyx_GIVEREF(__pyx_tuple__127);
  __pyx_codeobj__128 = (PyObject*)__Pyx_PyCode_New(3, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__127, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_fees, 76, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__128)) __PYX_ERR(0, 76, __pyx_L1_error)

  /* "alacorder/cal.pyx":91
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs
 * def tables(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *     """
 *     Start Alacorder table export using configuration object `cf`.
 */
  __pyx_tuple__129 = PyTuple_Pack(3, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug); if (unlikely(!__pyx_tuple__129)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__129);
  __Pyx_GIVEREF(__pyx_tuple__129);
  __pyx_codeobj__130 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__129, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_tables, 91, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__130)) __PYX_ERR(0, 91, __pyx_L1_error)

  /* "alacorder/cal.pyx":103
 *     """
 *     return init(cf, window=window)
 * def init(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start Alacorder using configuration object `cf`.
 */
  __pyx_tuple__131 = PyTuple_Pack(8, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug, __pyx_n_s_ft, __pyx_n_s_ar, __pyx_n_s_ch, __pyx_n_s_ca, __pyx_n_s_fs); if (unlikely(!__pyx_tuple__131)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__131);
  __Pyx_GIVEREF(__pyx_tuple__131);
  __pyx_codeobj__132 = (PyObject*)__Pyx_PyCode_New(3, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__131, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_init, 103, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__132)) __PYX_ERR(0, 103, __pyx_L1_error)

  /* "alacorder/cal.pyx":135
 *           print("Job not specified. Select a mode and reconfigure to start.")
 *           return None
 * def archive(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Write a full text archive from inputs using configuration `cf`.
 */
  __pyx_tuple__133 = PyTuple_Pack(4, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_debug, __pyx_n_s_a); if (unlikely(!__pyx_tuple__133)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__133);
  __Pyx_GIVEREF(__pyx_tuple__133);
  __pyx_codeobj__134 = (PyObject*)__Pyx_PyCode_New(3, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__133, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_archive, 135, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__134)) __PYX_ERR(0, 135, __pyx_L1_error)

  /* "alacorder/cal.pyx":147
 * #   #   #   #         CONFIGURATION & I/O        #   #   #   #
 * 
 * def set(inputs, outputs=None, count=0, table='', archive=False, no_prompt=True, debug=False, overwrite=False, no_write=False, fetch=False, cID='', uID='', pwd='', qmax=0, qskip=0, append=False, window=None, force=False, no_update=False, now=False):             # <<<<<<<<<<<<<<
 *      """
 *      Check inputs and outputs and return a configuration object for Alacorder table parser functions to receive as parameter and complete task, or set `now = True` to run upon set() call.
 */
  __pyx_tuple__135 = PyTuple_Pack(32, __pyx_n_s_inputs, __pyx_n_s_outputs, __pyx_n_s_count, __pyx_n_s_table, __pyx_n_s_archive, __pyx_n_s_no_prompt, __pyx_n_s_debug, __pyx_n_s_overwrite, __pyx_n_s_no_write, __pyx_n_s_fetch, __pyx_n_s_cID, __pyx_n_s_uID, __pyx_n_s_pwd, __pyx_n_s_qmax, __pyx_n_s_qskip, __pyx_n_s_append, __pyx_n_s_window, __pyx_n_s_force, __pyx_n_s_no_update, __pyx_n_s_now, __pyx_n_s_good, __pyx_n_s_found, __pyx_n_s_outputext, __pyx_n_s_existing_output, __pyx_n_s_support_multitable, __pyx_n_s_support_singletable, __pyx_n_s_support_archive, __pyx_n_s_old_archive, __pyx_n_s_queue, __pyx_n_s_is_full_text, __pyx_n_s_itype, __pyx_n_s_out); if (unlikely(!__pyx_tuple__135)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__135);
  __Pyx_GIVEREF(__pyx_tuple__135);
  __pyx_codeobj__136 = (PyObject*)__Pyx_PyCode_New(20, 0, 32, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__135, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_set, 147, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__136)) __PYX_ERR(0, 147, __pyx_L1_error)

  /* "alacorder/cal.pyx":291
 *           return init(out, window=window, debug=debug)
 *      return out
 * def dlog(cf=None, text=""):             # <<<<<<<<<<<<<<
 *      if cf == None or cf == False:
 *           return None
 */
  __pyx_tuple__137 = PyTuple_Pack(2, __pyx_n_s_cf, __pyx_n_s_text); if (unlikely(!__pyx_tuple__137)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__137);
  __Pyx_GIVEREF(__pyx_tuple__137);
  __pyx_codeobj__138 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__137, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_dlog, 291, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__138)) __PYX_ERR(0, 291, __pyx_L1_error)

  /* "alacorder/cal.pyx":302
 *           else:
 *                return None
 * def read(cf='', window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Read `cf` input PDF directory or case text archive into memory.
 */
  __pyx_tuple__139 = PyTuple_Pack(8, __pyx_n_s_cf, __pyx_n_s_window, __pyx_n_s_queue, __pyx_n_s_aptxt, __pyx_n_s_i, __pyx_n_s_pp, __pyx_n_s_archive, __pyx_n_s_ext); if (unlikely(!__pyx_tuple__139)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__139);
  __Pyx_GIVEREF(__pyx_tuple__139);
  __pyx_codeobj__140 = (PyObject*)__Pyx_PyCode_New(2, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__139, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_read, 302, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__140)) __PYX_ERR(0, 302, __pyx_L1_error)

  /* "alacorder/cal.pyx":363
 *           return None
 * 
 * def write(outputs, sheet_names=[], cf=None, path=None, overwrite=False):             # <<<<<<<<<<<<<<
 *      """Write `outputs` to output path at `cf` in accordance with configuration settings.
 * 
 */
  __pyx_tuple__141 = PyTuple_Pack(8, __pyx_n_s_outputs, __pyx_n_s_sheet_names, __pyx_n_s_cf, __pyx_n_s_path, __pyx_n_s_overwrite, __pyx_n_s_workbook, __pyx_n_s_i, __pyx_n_s_x); if (unlikely(!__pyx_tuple__141)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__141);
  __Pyx_GIVEREF(__pyx_tuple__141);
  __pyx_codeobj__142 = (PyObject*)__Pyx_PyCode_New(5, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__141, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_write, 363, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__142)) __PYX_ERR(0, 363, __pyx_L1_error)

  /* "alacorder/cal.pyx":415
 *           pass
 *      return outputs
 * def append_archive(inpath='', outpath='', conf=None, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Append the contents of one archive to another.
 */
  __pyx_tuple__143 = PyTuple_Pack(7, __pyx_n_s_inpath, __pyx_n_s_outpath, __pyx_n_s_conf, __pyx_n_s_window, __pyx_n_s_inarc, __pyx_n_s_outarc, __pyx_n_s_out); if (unlikely(!__pyx_tuple__143)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__143);
  __Pyx_GIVEREF(__pyx_tuple__143);
  __pyx_codeobj__144 = (PyObject*)__Pyx_PyCode_New(4, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__143, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_append_archive, 415, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__144)) __PYX_ERR(0, 415, __pyx_L1_error)

  /* "alacorder/cal.pyx":454
 * #   #   #   #           TABLE PARSERS           #   #   #   #
 * 
 * def split_cases(df, debug=False):             # <<<<<<<<<<<<<<
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 */
  __pyx_tuple__145 = PyTuple_Pack(7, __pyx_n_s_df, __pyx_n_s_debug, __pyx_n_s_cases, __pyx_n_s_all_charges, __pyx_n_s_all_fees, __pyx_n_s_clean_ch_list, __pyx_n_s_clean_fs_list); if (unlikely(!__pyx_tuple__145)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__145);
  __Pyx_GIVEREF(__pyx_tuple__145);
  __pyx_codeobj__146 = (PyObject*)__Pyx_PyCode_New(2, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__145, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_split_cases, 454, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__146)) __PYX_ERR(0, 454, __pyx_L1_error)

  /* "alacorder/cal.pyx":598
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):             # <<<<<<<<<<<<<<
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 */
  __pyx_tuple__147 = PyTuple_Pack(3, __pyx_n_s_df, __pyx_n_s_debug, __pyx_n_s_charges); if (unlikely(!__pyx_tuple__147)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__147);
  __Pyx_GIVEREF(__pyx_tuple__147);
  __pyx_codeobj__148 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__147, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_split_charges, 598, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__148)) __PYX_ERR(0, 598, __pyx_L1_error)

  /* "alacorder/cal.pyx":651
 * 
 *      return charges
 * def split_fees(df, debug=False):             # <<<<<<<<<<<<<<
 *      df = df.select([
 *           pl.col("CaseNumber"),
 */
  __pyx_tuple__149 = PyTuple_Pack(3, __pyx_n_s_df, __pyx_n_s_debug, __pyx_n_s_out); if (unlikely(!__pyx_tuple__149)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__149);
  __Pyx_GIVEREF(__pyx_tuple__149);
  __pyx_codeobj__150 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__149, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_split_fees, 651, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__150)) __PYX_ERR(0, 651, __pyx_L1_error)

  /* "alacorder/cal.pyx":699
 * #   #   #   #         FETCH (PDF SCRAPER)       #   #   #   #
 * 
 * def read_query(path, qmax=0, qskip=0, window=None):             # <<<<<<<<<<<<<<
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)
 */
  __pyx_tuple__151 = PyTuple_Pack(10, __pyx_n_s_path, __pyx_n_s_qmax, __pyx_n_s_qskip, __pyx_n_s_window, __pyx_n_s_query, __pyx_n_s_qs, __pyx_n_s_pscols, __pyx_n_s_tempcols, __pyx_n_s_col, __pyx_n_s_goodquery); if (unlikely(!__pyx_tuple__151)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__151);
  __Pyx_GIVEREF(__pyx_tuple__151);
  __pyx_codeobj__152 = (PyObject*)__Pyx_PyCode_New(4, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__151, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_read_query, 699, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__152)) __PYX_ERR(0, 699, __pyx_L1_error)

  /* "alacorder/cal.pyx":746
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")
 *         return None
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Fetch cases from Alacourt.com with input query spreadsheet headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE.
 */
  __pyx_tuple__153 = PyTuple_Pack(19, __pyx_n_s_querypath, __pyx_n_s_dirpath, __pyx_n_s_cID, __pyx_n_s_uID, __pyx_n_s_pwd, __pyx_n_s_qmax, __pyx_n_s_qskip, __pyx_n_s_cf, __pyx_n_s_no_update, __pyx_n_s_debug, __pyx_n_s_window, __pyx_n_s_query, __pyx_n_s_opt, __pyx_n_s_driver, __pyx_n_s_i, __pyx_n_s_r, __pyx_n_s_results, __pyx_n_s_url, __pyx_n_s_qwrite); if (unlikely(!__pyx_tuple__153)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__153);
  __Pyx_GIVEREF(__pyx_tuple__153);
  __pyx_codeobj__154 = (PyObject*)__Pyx_PyCode_New(11, 0, 19, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__153, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_fetch, 746, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__154)) __PYX_ERR(0, 746, __pyx_L1_error)

  /* "alacorder/cal.pyx":831
 *      print("Completed query template.")
 *      return query
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Collect PDFs via SJIS Party Search Form from Alacourt.com
 */
  __pyx_tuple__155 = PyTuple_Pack(44, __pyx_n_s_driver, __pyx_n_s_name, __pyx_n_s_party_type, __pyx_n_s_ssn, __pyx_n_s_dob, __pyx_n_s_county, __pyx_n_s_division, __pyx_n_s_case_year, __pyx_n_s_filed_before, __pyx_n_s_filed_after, __pyx_n_s_debug, __pyx_n_s_cID, __pyx_n_s_uID, __pyx_n_s_pwd, __pyx_n_s_window, __pyx_n_s_has_window, __pyx_n_s_party_name_box, __pyx_n_s_ssn_box, __pyx_n_s_date_of_birth_box, __pyx_n_s_party_type_select, __pyx_n_s_pts, __pyx_n_s_county_select, __pyx_n_s_scounty, __pyx_n_s_division_select, __pyx_n_s_sdivision, __pyx_n_s_case_year_select, __pyx_n_s_scase_year, __pyx_n_s_no_records_select, __pyx_n_s_sno_records, __pyx_n_s_filed_before_box, __pyx_n_s_filed_after_box, __pyx_n_s_search_button, __pyx_n_s_page_counter, __pyx_n_s_pages, __pyx_n_s_results_indicator, __pyx_n_s_results_count, __pyx_n_s_pdflinks, __pyx_n_s_i, __pyx_n_s_hovers, __pyx_n_s_x, __pyx_n_s_a, __pyx_n_s_pager_select, __pyx_n_s_next_pg, __pyx_n_s_next_button); if (unlikely(!__pyx_tuple__155)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__155);
  __Pyx_GIVEREF(__pyx_tuple__155);
  __pyx_codeobj__156 = (PyObject*)__Pyx_PyCode_New(15, 0, 44, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__155, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_party_search, 831, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__156)) __PYX_ERR(0, 831, __pyx_L1_error)

  /* "alacorder/cal.pyx":994
 *                     continue
 *      return pdflinks
 * def downloadPDF(driver, url, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      With sg.WebDriver `driver`, download PDF at `url`.
 */
  __pyx_tuple__157 = PyTuple_Pack(7, __pyx_n_s_driver, __pyx_n_s_url, __pyx_n_s_cID, __pyx_n_s_uID, __pyx_n_s_pwd, __pyx_n_s_window, __pyx_n_s_a); if (unlikely(!__pyx_tuple__157)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__157);
  __Pyx_GIVEREF(__pyx_tuple__157);
  __pyx_codeobj__158 = (PyObject*)__Pyx_PyCode_New(6, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__157, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_downloadPDF, 994, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__158)) __PYX_ERR(0, 994, __pyx_L1_error)

  /* "alacorder/cal.pyx":1010
 *      a = driver.get(url)
 *      driver.implicitly_wait(0.5)
 * def login(driver, cID, uID="", pwd="", path="", window=None):             # <<<<<<<<<<<<<<
 *      """Login to Alacourt.com using (driver) and auth (cID, username, pwd) for browser download to directory at (path)
 * 
 */
  __pyx_tuple__159 = PyTuple_Pack(13, __pyx_n_s_driver, __pyx_n_s_cID, __pyx_n_s_uID, __pyx_n_s_pwd, __pyx_n_s_path, __pyx_n_s_window, __pyx_n_s_options, __pyx_n_s_login_screen, __pyx_n_s_cID_box, __pyx_n_s_username_box, __pyx_n_s_pwd_box, __pyx_n_s_login_button, __pyx_n_s_continueLogIn); if (unlikely(!__pyx_tuple__159)) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__159);
  __Pyx_GIVEREF(__pyx_tuple__159);
  __pyx_codeobj__160 = (PyObject*)__Pyx_PyCode_New(6, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__159, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_login, 1010, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__160)) __PYX_ERR(0, 1010, __pyx_L1_error)

  /* "alacorder/cal.pyx":1070
 * 
 *      return driver
 * def empty_query(path):             # <<<<<<<<<<<<<<
 *      """Create empty query worksheet to submit search list for Alacorder to retrieve matching case records from Alacourt.com.
 * 
 */
  __pyx_tuple__161 = PyTuple_Pack(3, __pyx_n_s_path, __pyx_n_s_success, __pyx_n_s_empty); if (unlikely(!__pyx_tuple__161)) __PYX_ERR(0, 1070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__161);
  __Pyx_GIVEREF(__pyx_tuple__161);
  __pyx_codeobj__162 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__161, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_empty_query, 1070, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__162)) __PYX_ERR(0, 1070, __pyx_L1_error)

  /* "alacorder/cal.pyx":1086
 * #   #   #   #           GETTER METHODS         #   #   #   #
 * 
 * def getPDFText(path) -> str:             # <<<<<<<<<<<<<<
 *      """
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 */
  __pyx_tuple__163 = PyTuple_Pack(6, __pyx_n_s_path, __pyx_n_s_doc, __pyx_n_s_text, __pyx_n_s_pg, __pyx_n_s_genexpr, __pyx_n_s_genexpr); if (unlikely(!__pyx_tuple__163)) __PYX_ERR(0, 1086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__163);
  __Pyx_GIVEREF(__pyx_tuple__163);
  __pyx_codeobj__164 = (PyObject*)__Pyx_PyCode_New(1, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__163, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getPDFText, 1086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__164)) __PYX_ERR(0, 1086, __pyx_L1_error)

  /* "alacorder/cal.pyx":1102
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()
 *      return text
 * def getName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 */
  __pyx_tuple__165 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);
  __pyx_codeobj__166 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__165, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getName, 1102, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__166)) __PYX_ERR(0, 1102, __pyx_L1_error)

  /* "alacorder/cal.pyx":1107
 *     except:
 *         return ''
 * def getAlias(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 */
  __pyx_tuple__167 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__167)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__167);
  __Pyx_GIVEREF(__pyx_tuple__167);
  __pyx_codeobj__168 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__167, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAlias, 1107, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__168)) __PYX_ERR(0, 1107, __pyx_L1_error)

  /* "alacorder/cal.pyx":1112
 *     except:
 *         return ''
 * def getDOB(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 */
  __pyx_tuple__169 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__169)) __PYX_ERR(0, 1112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__169);
  __Pyx_GIVEREF(__pyx_tuple__169);
  __pyx_codeobj__170 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__169, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDOB, 1112, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__170)) __PYX_ERR(0, 1112, __pyx_L1_error)

  /* "alacorder/cal.pyx":1117
 *     except:
 *         return ''
 * def getPhone(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 */
  __pyx_tuple__171 = PyTuple_Pack(2, __pyx_n_s_text, __pyx_n_s_m); if (unlikely(!__pyx_tuple__171)) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__171);
  __Pyx_GIVEREF(__pyx_tuple__171);
  __pyx_codeobj__172 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__171, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getPhone, 1117, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__172)) __PYX_ERR(0, 1117, __pyx_L1_error)

  /* "alacorder/cal.pyx":1128
 *     except:
 *         return ''
 * def getRace(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 */
  __pyx_tuple__173 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__173)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__173);
  __Pyx_GIVEREF(__pyx_tuple__173);
  __pyx_codeobj__174 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__173, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getRace, 1128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__174)) __PYX_ERR(0, 1128, __pyx_L1_error)

  /* "alacorder/cal.pyx":1133
 *     except:
 *         return ''
 * def getSex(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 */
  __pyx_tuple__175 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);
  __pyx_codeobj__176 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSex, 1133, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__176)) __PYX_ERR(0, 1133, __pyx_L1_error)

  /* "alacorder/cal.pyx":1138
 *     except:
 *         return ''
 * def getAddress1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 */
  __pyx_tuple__177 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__177)) __PYX_ERR(0, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__177);
  __Pyx_GIVEREF(__pyx_tuple__177);
  __pyx_codeobj__178 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__177, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAddress1, 1138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__178)) __PYX_ERR(0, 1138, __pyx_L1_error)

  /* "alacorder/cal.pyx":1143
 *     except:
 *         return ''
 * def getAddress2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 */
  __pyx_tuple__179 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__179)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__179);
  __Pyx_GIVEREF(__pyx_tuple__179);
  __pyx_codeobj__180 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__179, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAddress2, 1143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__180)) __PYX_ERR(0, 1143, __pyx_L1_error)

  /* "alacorder/cal.pyx":1148
 *     except:
 *         return ''
 * def getCity(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 */
  __pyx_tuple__181 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__181)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__181);
  __Pyx_GIVEREF(__pyx_tuple__181);
  __pyx_codeobj__182 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__181, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCity, 1148, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__182)) __PYX_ERR(0, 1148, __pyx_L1_error)

  /* "alacorder/cal.pyx":1153
 *     except:
 *         return ''
 * def getState(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 */
  __pyx_tuple__183 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__183)) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__183);
  __Pyx_GIVEREF(__pyx_tuple__183);
  __pyx_codeobj__184 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__183, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getState, 1153, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__184)) __PYX_ERR(0, 1153, __pyx_L1_error)

  /* "alacorder/cal.pyx":1158
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 */
  __pyx_tuple__185 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);
  __pyx_codeobj__186 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCountry, 1158, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__186)) __PYX_ERR(0, 1158, __pyx_L1_error)

  /* "alacorder/cal.pyx":1163
 *     except:
 *         return ''
 * def getZipCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 */
  __pyx_tuple__187 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);
  __pyx_codeobj__188 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__187, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getZipCode, 1163, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__188)) __PYX_ERR(0, 1163, __pyx_L1_error)

  /* "alacorder/cal.pyx":1168
 *     except:
 *         return ''
 * def getAddress(text):             # <<<<<<<<<<<<<<
 *     try:
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 */
  __pyx_tuple__189 = PyTuple_Pack(6, __pyx_n_s_text, __pyx_n_s_street1, __pyx_n_s_street2, __pyx_n_s_zipcode, __pyx_n_s_city, __pyx_n_s_state); if (unlikely(!__pyx_tuple__189)) __PYX_ERR(0, 1168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__189);
  __Pyx_GIVEREF(__pyx_tuple__189);
  __pyx_codeobj__190 = (PyObject*)__Pyx_PyCode_New(1, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__189, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAddress, 1168, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__190)) __PYX_ERR(0, 1168, __pyx_L1_error)

  /* "alacorder/cal.pyx":1193
 *     else:
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()
 * def getChargesRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 */
  __pyx_tuple__191 = PyTuple_Pack(2, __pyx_n_s_text, __pyx_n_s_m); if (unlikely(!__pyx_tuple__191)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__191);
  __Pyx_GIVEREF(__pyx_tuple__191);
  __pyx_codeobj__192 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__191, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getChargesRows, 1193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__192)) __PYX_ERR(0, 1193, __pyx_L1_error)

  /* "alacorder/cal.pyx":1196
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 * def getFeeSheetRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 */
  __pyx_tuple__193 = PyTuple_Pack(2, __pyx_n_s_text, __pyx_n_s_m); if (unlikely(!__pyx_tuple__193)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__193);
  __Pyx_GIVEREF(__pyx_tuple__193);
  __pyx_codeobj__194 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__193, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getFeeSheetRows, 1196, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__194)) __PYX_ERR(0, 1196, __pyx_L1_error)

  /* "alacorder/cal.pyx":1199
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 * def getTotalRow(text):             # <<<<<<<<<<<<<<
 *     try:
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 */
  __pyx_tuple__195 = PyTuple_Pack(4, __pyx_n_s_text, __pyx_n_s_mmm, __pyx_n_s_mm, __pyx_n_s_m); if (unlikely(!__pyx_tuple__195)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__195);
  __Pyx_GIVEREF(__pyx_tuple__195);
  __pyx_codeobj__196 = (PyObject*)__Pyx_PyCode_New(1, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__195, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTotalRow, 1199, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__196)) __PYX_ERR(0, 1199, __pyx_L1_error)

  /* "alacorder/cal.pyx":1207
 *     except:
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 */
  __pyx_tuple__197 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(0, 1207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);
  __pyx_codeobj__198 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTotalAmtDue, 1207, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__198)) __PYX_ERR(0, 1207, __pyx_L1_error)

  /* "alacorder/cal.pyx":1212
 *     except:
 *         return 0.00
 * def getTotalAmtPaid(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 */
  __pyx_tuple__199 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);
  __pyx_codeobj__200 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__199, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTotalAmtPaid, 1212, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__200)) __PYX_ERR(0, 1212, __pyx_L1_error)

  /* "alacorder/cal.pyx":1217
 *     except:
 *         return 0.00
 * def getTotalBalance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 */
  __pyx_tuple__201 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__201)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__201);
  __Pyx_GIVEREF(__pyx_tuple__201);
  __pyx_codeobj__202 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__201, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTotalBalance, 1217, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__202)) __PYX_ERR(0, 1217, __pyx_L1_error)

  /* "alacorder/cal.pyx":1222
 *     except:
 *         return 0.00
 * def getTotalAmtHold(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 */
  __pyx_tuple__203 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__203)) __PYX_ERR(0, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__203);
  __Pyx_GIVEREF(__pyx_tuple__203);
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__203, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTotalAmtHold, 1222, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(0, 1222, __pyx_L1_error)

  /* "alacorder/cal.pyx":1227
 *     except:
 *         return 0.00
 * def getPaymentToRestore(text):             # <<<<<<<<<<<<<<
 *     try:
 *         tbal = getTotalBalance(text)
 */
  __pyx_tuple__205 = PyTuple_Pack(5, __pyx_n_s_text, __pyx_n_s_tbal, __pyx_n_s_d999mm, __pyx_n_s_d999m, __pyx_n_s_d999); if (unlikely(!__pyx_tuple__205)) __PYX_ERR(0, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__205);
  __Pyx_GIVEREF(__pyx_tuple__205);
  __pyx_codeobj__206 = (PyObject*)__Pyx_PyCode_New(1, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__205, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getPaymentToRestore, 1227, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__206)) __PYX_ERR(0, 1227, __pyx_L1_error)

  /* "alacorder/cal.pyx":1239
 *         d999 = 0.0
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */
  __pyx_tuple__207 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__207)) __PYX_ERR(0, 1239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__207);
  __Pyx_GIVEREF(__pyx_tuple__207);
  __pyx_codeobj__208 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__207, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getShortCaseNumber, 1239, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__208)) __PYX_ERR(0, 1239, __pyx_L1_error)

  /* "alacorder/cal.pyx":1244
 *     except:
 *         return ''
 * def getCounty(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 */
  __pyx_tuple__209 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__209)) __PYX_ERR(0, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__209);
  __Pyx_GIVEREF(__pyx_tuple__209);
  __pyx_codeobj__210 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__209, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCounty, 1244, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__210)) __PYX_ERR(0, 1244, __pyx_L1_error)

  /* "alacorder/cal.pyx":1249
 *     except:
 *         return ''
 * def getCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */
  __pyx_tuple__211 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__211)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__211);
  __Pyx_GIVEREF(__pyx_tuple__211);
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__211, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCaseNumber, 1249, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(0, 1249, __pyx_L1_error)

  /* "alacorder/cal.pyx":1254
 *     except:
 *         return ''
 * def getCaseYear(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 */
  __pyx_tuple__213 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__213)) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__213);
  __Pyx_GIVEREF(__pyx_tuple__213);
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__213, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCaseYear, 1254, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(0, 1254, __pyx_L1_error)

  /* "alacorder/cal.pyx":1259
 *     except:
 *         return ''
 * def getLastName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[0].strip()
 */
  __pyx_tuple__215 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__215)) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__215);
  __Pyx_GIVEREF(__pyx_tuple__215);
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__215, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getLastName, 1259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(0, 1259, __pyx_L1_error)

  /* "alacorder/cal.pyx":1264
 *     except:
 *         return ''
 * def getFirstName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[-1].strip()
 */
  __pyx_tuple__217 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__217)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__217);
  __Pyx_GIVEREF(__pyx_tuple__217);
  __pyx_codeobj__218 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__217, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getFirstName, 1264, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__218)) __PYX_ERR(0, 1264, __pyx_L1_error)

  /* "alacorder/cal.pyx":1269
 *     except:
 *         return ''
 * def getMiddleName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         if len(getName(text).split(" ")) > 2:
 */
  __pyx_tuple__219 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__219)) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__219);
  __Pyx_GIVEREF(__pyx_tuple__219);
  __pyx_codeobj__220 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__219, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getMiddleName, 1269, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__220)) __PYX_ERR(0, 1269, __pyx_L1_error)

  /* "alacorder/cal.pyx":1277
 *     except:
 *         return ''
 * def getRelatedCases(text):             # <<<<<<<<<<<<<<
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 */
  __pyx_tuple__221 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__221)) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__221);
  __Pyx_GIVEREF(__pyx_tuple__221);
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__221, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getRelatedCases, 1277, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(0, 1277, __pyx_L1_error)

  /* "alacorder/cal.pyx":1279
 * def getRelatedCases(text):
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 */
  __pyx_tuple__223 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__223)) __PYX_ERR(0, 1279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__223);
  __Pyx_GIVEREF(__pyx_tuple__223);
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__223, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getFilingDate, 1279, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(0, 1279, __pyx_L1_error)

  /* "alacorder/cal.pyx":1284
 *     except:
 *         return ''
 * def getCaseInitiationDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 */
  __pyx_tuple__225 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__225)) __PYX_ERR(0, 1284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__225);
  __Pyx_GIVEREF(__pyx_tuple__225);
  __pyx_codeobj__226 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__225, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCaseInitiationDate, 1284, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__226)) __PYX_ERR(0, 1284, __pyx_L1_error)

  /* "alacorder/cal.pyx":1289
 *     except:
 *         return ''
 * def getArrestDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_tuple__227 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__227)) __PYX_ERR(0, 1289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__227);
  __Pyx_GIVEREF(__pyx_tuple__227);
  __pyx_codeobj__228 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__227, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getArrestDate, 1289, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__228)) __PYX_ERR(0, 1289, __pyx_L1_error)

  /* "alacorder/cal.pyx":1294
 *     except:
 *         return ''
 * def getOffenseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_tuple__229 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__229)) __PYX_ERR(0, 1294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__229);
  __Pyx_GIVEREF(__pyx_tuple__229);
  __pyx_codeobj__230 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__229, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getOffenseDate, 1294, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__230)) __PYX_ERR(0, 1294, __pyx_L1_error)

  /* "alacorder/cal.pyx":1299
 *     except:
 *         return ''
 * def getIndictmentDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_tuple__231 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__231)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__231);
  __Pyx_GIVEREF(__pyx_tuple__231);
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__231, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getIndictmentDate, 1299, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(0, 1299, __pyx_L1_error)

  /* "alacorder/cal.pyx":1304
 *     except:
 *         return ''
 * def getYouthfulDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_tuple__233 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__233)) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__233);
  __Pyx_GIVEREF(__pyx_tuple__233);
  __pyx_codeobj__234 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__233, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getYouthfulDate, 1304, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__234)) __PYX_ERR(0, 1304, __pyx_L1_error)

  /* "alacorder/cal.pyx":1309
 *     except:
 *         return ''
 * def getRetrieved(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_tuple__235 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__235)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__235);
  __Pyx_GIVEREF(__pyx_tuple__235);
  __pyx_codeobj__236 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__235, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getRetrieved, 1309, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__236)) __PYX_ERR(0, 1309, __pyx_L1_error)

  /* "alacorder/cal.pyx":1314
 *     except:
 *         return ''
 * def getCourtAction(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 */
  __pyx_tuple__237 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__237)) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__237);
  __Pyx_GIVEREF(__pyx_tuple__237);
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__237, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCourtAction, 1314, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(0, 1314, __pyx_L1_error)

  /* "alacorder/cal.pyx":1319
 *     except:
 *         return ''
 * def getCourtActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 */
  __pyx_tuple__239 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__239)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__239);
  __Pyx_GIVEREF(__pyx_tuple__239);
  __pyx_codeobj__240 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__239, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCourtActionDate, 1319, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__240)) __PYX_ERR(0, 1319, __pyx_L1_error)

  /* "alacorder/cal.pyx":1324
 *     except:
 *         return ''
 * def getDescription(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 */
  __pyx_tuple__241 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__241)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__241);
  __Pyx_GIVEREF(__pyx_tuple__241);
  __pyx_codeobj__242 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__241, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDescription, 1324, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__242)) __PYX_ERR(0, 1324, __pyx_L1_error)

  /* "alacorder/cal.pyx":1329
 *     except:
 *         return ''
 * def getJuryDemand(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 */
  __pyx_tuple__243 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__243)) __PYX_ERR(0, 1329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__243);
  __Pyx_GIVEREF(__pyx_tuple__243);
  __pyx_codeobj__244 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__243, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getJuryDemand, 1329, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__244)) __PYX_ERR(0, 1329, __pyx_L1_error)

  /* "alacorder/cal.pyx":1334
 *     except:
 *         return ''
 * def getInpatientTreatmentOrdered(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 */
  __pyx_tuple__245 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__245)) __PYX_ERR(0, 1334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__245);
  __Pyx_GIVEREF(__pyx_tuple__245);
  __pyx_codeobj__246 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__245, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getInpatientTreatmentOrdered, 1334, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__246)) __PYX_ERR(0, 1334, __pyx_L1_error)

  /* "alacorder/cal.pyx":1339
 *     except:
 *         return ''
 * def getTrialType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 */
  __pyx_tuple__247 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__247)) __PYX_ERR(0, 1339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__247);
  __Pyx_GIVEREF(__pyx_tuple__247);
  __pyx_codeobj__248 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__247, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTrialType, 1339, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__248)) __PYX_ERR(0, 1339, __pyx_L1_error)

  /* "alacorder/cal.pyx":1344
 *     except:
 *         return ''
 * def getJudge(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 */
  __pyx_tuple__249 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__249)) __PYX_ERR(0, 1344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__249);
  __Pyx_GIVEREF(__pyx_tuple__249);
  __pyx_codeobj__250 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__249, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getJudge, 1344, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__250)) __PYX_ERR(0, 1344, __pyx_L1_error)

  /* "alacorder/cal.pyx":1349
 *     except:
 *         return ''
 * def getProbationOfficeNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 */
  __pyx_tuple__251 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__251)) __PYX_ERR(0, 1349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__251);
  __Pyx_GIVEREF(__pyx_tuple__251);
  __pyx_codeobj__252 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__251, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getProbationOfficeNumber, 1349, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__252)) __PYX_ERR(0, 1349, __pyx_L1_error)

  /* "alacorder/cal.pyx":1354
 *     except:
 *         return ''
 * def getDefendantStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */
  __pyx_tuple__253 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__253)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__253);
  __Pyx_GIVEREF(__pyx_tuple__253);
  __pyx_codeobj__254 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__253, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDefendantStatus, 1354, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__254)) __PYX_ERR(0, 1354, __pyx_L1_error)

  /* "alacorder/cal.pyx":1359
 *     except:
 *         return ''
 * def getArrestingAgencyType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 */
  __pyx_tuple__255 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__255)) __PYX_ERR(0, 1359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__255);
  __Pyx_GIVEREF(__pyx_tuple__255);
  __pyx_codeobj__256 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__255, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getArrestingAgencyType, 1359, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__256)) __PYX_ERR(0, 1359, __pyx_L1_error)

  /* "alacorder/cal.pyx":1364
 *     except:
 *         return ''
 * def getArrestingOfficer(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 */
  __pyx_tuple__257 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__257)) __PYX_ERR(0, 1364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__257);
  __Pyx_GIVEREF(__pyx_tuple__257);
  __pyx_codeobj__258 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__257, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getArrestingOfficer, 1364, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__258)) __PYX_ERR(0, 1364, __pyx_L1_error)

  /* "alacorder/cal.pyx":1369
 *     except:
 *         return ''
 * def getProbationOfficeName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 */
  __pyx_tuple__259 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__259)) __PYX_ERR(0, 1369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__259);
  __Pyx_GIVEREF(__pyx_tuple__259);
  __pyx_codeobj__260 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__259, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getProbationOfficeName, 1369, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__260)) __PYX_ERR(0, 1369, __pyx_L1_error)

  /* "alacorder/cal.pyx":1374
 *     except:
 *         return ''
 * def getTrafficCitationNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 */
  __pyx_tuple__261 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__261)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__261);
  __Pyx_GIVEREF(__pyx_tuple__261);
  __pyx_codeobj__262 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__261, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTrafficCitationNumber, 1374, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__262)) __PYX_ERR(0, 1374, __pyx_L1_error)

  /* "alacorder/cal.pyx":1379
 *     except:
 *         return ''
 * def getPreviousDUIConvictions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 */
  __pyx_tuple__263 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__263)) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__263);
  __Pyx_GIVEREF(__pyx_tuple__263);
  __pyx_codeobj__264 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__263, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getPreviousDUIConvictions, 1379, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__264)) __PYX_ERR(0, 1379, __pyx_L1_error)

  /* "alacorder/cal.pyx":1384
 *     except:
 *         return ''
 * def getCaseInitiationType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */
  __pyx_tuple__265 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__265)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__265);
  __Pyx_GIVEREF(__pyx_tuple__265);
  __pyx_codeobj__266 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__265, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCaseInitiationType, 1384, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__266)) __PYX_ERR(0, 1384, __pyx_L1_error)

  /* "alacorder/cal.pyx":1389
 *     except:
 *         return ''
 * def getDomesticViolence(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 */
  __pyx_tuple__267 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__267)) __PYX_ERR(0, 1389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__267);
  __Pyx_GIVEREF(__pyx_tuple__267);
  __pyx_codeobj__268 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__267, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDomesticViolence, 1389, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__268)) __PYX_ERR(0, 1389, __pyx_L1_error)

  /* "alacorder/cal.pyx":1394
 *     except:
 *         return ''
 * def getAgencyORI(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 */
  __pyx_tuple__269 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__269)) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__269);
  __Pyx_GIVEREF(__pyx_tuple__269);
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__269, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAgencyORI, 1394, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(0, 1394, __pyx_L1_error)

  /* "alacorder/cal.pyx":1399
 *     except:
 *         return ''
 * def getDriverLicenseNo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 */
  __pyx_tuple__271 = PyTuple_Pack(2, __pyx_n_s_text, __pyx_n_s_m); if (unlikely(!__pyx_tuple__271)) __PYX_ERR(0, 1399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__271);
  __Pyx_GIVEREF(__pyx_tuple__271);
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__271, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDriverLicenseNo, 1399, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(0, 1399, __pyx_L1_error)

  /* "alacorder/cal.pyx":1408
 *     except:
 *         return ''
 * def getSSN(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 */
  __pyx_tuple__273 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__273)) __PYX_ERR(0, 1408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__273);
  __Pyx_GIVEREF(__pyx_tuple__273);
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__273, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSSN, 1408, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(0, 1408, __pyx_L1_error)

  /* "alacorder/cal.pyx":1413
 *     except:
 *         return ''
 * def getStateID(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 */
  __pyx_tuple__275 = PyTuple_Pack(2, __pyx_n_s_text, __pyx_n_s_m); if (unlikely(!__pyx_tuple__275)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__275);
  __Pyx_GIVEREF(__pyx_tuple__275);
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__275, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getStateID, 1413, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(0, 1413, __pyx_L1_error)

  /* "alacorder/cal.pyx":1422
 *     except:
 *         return ''
 * def getWeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 */
  __pyx_tuple__277 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__277)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__277);
  __Pyx_GIVEREF(__pyx_tuple__277);
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__277, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getWeight, 1422, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(0, 1422, __pyx_L1_error)

  /* "alacorder/cal.pyx":1427
 *     except:
 *         return ''
 * def getHeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 */
  __pyx_tuple__279 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__279)) __PYX_ERR(0, 1427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__279);
  __Pyx_GIVEREF(__pyx_tuple__279);
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__279, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getHeight, 1427, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(0, 1427, __pyx_L1_error)

  /* "alacorder/cal.pyx":1432
 *     except:
 *         return ''
 * def getEyes(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 */
  __pyx_tuple__281 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__281)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__281);
  __Pyx_GIVEREF(__pyx_tuple__281);
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__281, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getEyes, 1432, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(0, 1432, __pyx_L1_error)

  /* "alacorder/cal.pyx":1437
 *     except:
 *         return ''
 * def getHair(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 */
  __pyx_tuple__283 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__283)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__283);
  __Pyx_GIVEREF(__pyx_tuple__283);
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__283, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getHair, 1437, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(0, 1437, __pyx_L1_error)

  /* "alacorder/cal.pyx":1442
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 */
  __pyx_tuple__285 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__285)) __PYX_ERR(0, 1442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__285);
  __Pyx_GIVEREF(__pyx_tuple__285);
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__285, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getCountry, 1442, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(0, 1442, __pyx_L1_error)

  /* "alacorder/cal.pyx":1447
 *     except:
 *         return ''
 * def getWarrantIssuanceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 */
  __pyx_tuple__287 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__287)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__287);
  __Pyx_GIVEREF(__pyx_tuple__287);
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__287, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getWarrantIssuanceDate, 1447, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(0, 1447, __pyx_L1_error)

  /* "alacorder/cal.pyx":1452
 *     except:
 *         return ''
 * def getWarrantActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_tuple__289 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__289)) __PYX_ERR(0, 1452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__289);
  __Pyx_GIVEREF(__pyx_tuple__289);
  __pyx_codeobj__290 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__289, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getWarrantActionDate, 1452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__290)) __PYX_ERR(0, 1452, __pyx_L1_error)

  /* "alacorder/cal.pyx":1457
 *     except:
 *         return ''
 * def getWarrantIssuanceStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 */
  __pyx_tuple__291 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__291)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__291);
  __Pyx_GIVEREF(__pyx_tuple__291);
  __pyx_codeobj__292 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__291, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getWarrantIssuanceStatus, 1457, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__292)) __PYX_ERR(0, 1457, __pyx_L1_error)

  /* "alacorder/cal.pyx":1462
 *     except:
 *         return ''
 * def getWarrantActionStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 */
  __pyx_tuple__293 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__293)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__293);
  __Pyx_GIVEREF(__pyx_tuple__293);
  __pyx_codeobj__294 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__293, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getWarrantActionStatus, 1462, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__294)) __PYX_ERR(0, 1462, __pyx_L1_error)

  /* "alacorder/cal.pyx":1467
 *     except:
 *         return ''
 * def getWarrantLocationStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 */
  __pyx_tuple__295 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__295)) __PYX_ERR(0, 1467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__295);
  __Pyx_GIVEREF(__pyx_tuple__295);
  __pyx_codeobj__296 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__295, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getWarrantLocationStatus, 1467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__296)) __PYX_ERR(0, 1467, __pyx_L1_error)

  /* "alacorder/cal.pyx":1472
 *     except:
 *         return ''
 * def getNumberOfWarrants(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 */
  __pyx_tuple__297 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__297)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__297);
  __Pyx_GIVEREF(__pyx_tuple__297);
  __pyx_codeobj__298 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__297, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getNumberOfWarrants, 1472, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__298)) __PYX_ERR(0, 1472, __pyx_L1_error)

  /* "alacorder/cal.pyx":1477
 *     except:
 *         return ''
 * def getBondType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 */
  __pyx_tuple__299 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__299)) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__299);
  __Pyx_GIVEREF(__pyx_tuple__299);
  __pyx_codeobj__300 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__299, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getBondType, 1477, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__300)) __PYX_ERR(0, 1477, __pyx_L1_error)

  /* "alacorder/cal.pyx":1482
 *     except:
 *         return ''
 * def getBondTypeDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 */
  __pyx_tuple__301 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__301)) __PYX_ERR(0, 1482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__301);
  __Pyx_GIVEREF(__pyx_tuple__301);
  __pyx_codeobj__302 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__301, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getBondTypeDesc, 1482, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__302)) __PYX_ERR(0, 1482, __pyx_L1_error)

  /* "alacorder/cal.pyx":1487
 *     except:
 *         return ''
 * def getBondAmt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 */
  __pyx_tuple__303 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__303)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__303);
  __Pyx_GIVEREF(__pyx_tuple__303);
  __pyx_codeobj__304 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__303, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getBondAmt, 1487, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__304)) __PYX_ERR(0, 1487, __pyx_L1_error)

  /* "alacorder/cal.pyx":1492
 *     except:
 *         return ''
 * def getSuretyCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 */
  __pyx_tuple__305 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__305)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__305);
  __Pyx_GIVEREF(__pyx_tuple__305);
  __pyx_codeobj__306 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__305, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSuretyCode, 1492, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__306)) __PYX_ERR(0, 1492, __pyx_L1_error)

  /* "alacorder/cal.pyx":1497
 *     except:
 *         return ''
 * def getBondReleaseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_tuple__307 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__307)) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__307);
  __Pyx_GIVEREF(__pyx_tuple__307);
  __pyx_codeobj__308 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__307, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getBondReleaseDate, 1497, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__308)) __PYX_ERR(0, 1497, __pyx_L1_error)

  /* "alacorder/cal.pyx":1502
 *     except:
 *         return ''
 * def getFailedToAppearDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_tuple__309 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__309)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__309);
  __Pyx_GIVEREF(__pyx_tuple__309);
  __pyx_codeobj__310 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__309, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getFailedToAppearDate, 1502, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__310)) __PYX_ERR(0, 1502, __pyx_L1_error)

  /* "alacorder/cal.pyx":1507
 *     except:
 *         return ''
 * def getBondsmanProcessIssuance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 */
  __pyx_tuple__311 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__311)) __PYX_ERR(0, 1507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__311);
  __Pyx_GIVEREF(__pyx_tuple__311);
  __pyx_codeobj__312 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__311, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getBondsmanProcessIssuance, 1507, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__312)) __PYX_ERR(0, 1507, __pyx_L1_error)

  /* "alacorder/cal.pyx":1512
 *     except:
 *         return ''
 * def getBondsmanProcessReturn(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 */
  __pyx_tuple__313 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__313)) __PYX_ERR(0, 1512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__313);
  __Pyx_GIVEREF(__pyx_tuple__313);
  __pyx_codeobj__314 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__313, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getBondsmanProcessReturn, 1512, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__314)) __PYX_ERR(0, 1512, __pyx_L1_error)

  /* "alacorder/cal.pyx":1517
 *     except:
 *         return ''
 * def getAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 */
  __pyx_tuple__315 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__315)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__315);
  __Pyx_GIVEREF(__pyx_tuple__315);
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__315, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAppealDate, 1517, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(0, 1517, __pyx_L1_error)

  /* "alacorder/cal.pyx":1522
 *     except:
 *         return ''
 * def getAppealCourt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 */
  __pyx_tuple__317 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__317)) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__317);
  __Pyx_GIVEREF(__pyx_tuple__317);
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__317, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAppealCourt, 1522, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(0, 1522, __pyx_L1_error)

  /* "alacorder/cal.pyx":1527
 *     except:
 *         return ''
 * def getOriginOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 */
  __pyx_tuple__319 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__319)) __PYX_ERR(0, 1527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__319);
  __Pyx_GIVEREF(__pyx_tuple__319);
  __pyx_codeobj__320 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__319, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getOriginOfAppeal, 1527, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__320)) __PYX_ERR(0, 1527, __pyx_L1_error)

  /* "alacorder/cal.pyx":1532
 *     except:
 *         return ''
 * def getAppealToDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 */
  __pyx_tuple__321 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__321)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__321);
  __Pyx_GIVEREF(__pyx_tuple__321);
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__321, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAppealToDesc, 1532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(0, 1532, __pyx_L1_error)

  /* "alacorder/cal.pyx":1537
 *     except:
 *         return ''
 * def getAppealStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 */
  __pyx_tuple__323 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__323)) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__323);
  __Pyx_GIVEREF(__pyx_tuple__323);
  __pyx_codeobj__324 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__323, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAppealStatus, 1537, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__324)) __PYX_ERR(0, 1537, __pyx_L1_error)

  /* "alacorder/cal.pyx":1542
 *     except:
 *         return ''
 * def getAppealTo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 */
  __pyx_tuple__325 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__325)) __PYX_ERR(0, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__325);
  __Pyx_GIVEREF(__pyx_tuple__325);
  __pyx_codeobj__326 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__325, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAppealTo, 1542, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__326)) __PYX_ERR(0, 1542, __pyx_L1_error)

  /* "alacorder/cal.pyx":1547
 *     except:
 *         return ''
 * def getLowerCourtAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */
  __pyx_tuple__327 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__327)) __PYX_ERR(0, 1547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__327);
  __Pyx_GIVEREF(__pyx_tuple__327);
  __pyx_codeobj__328 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__327, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getLowerCourtAppealDate, 1547, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__328)) __PYX_ERR(0, 1547, __pyx_L1_error)

  /* "alacorder/cal.pyx":1552
 *     except:
 *         return ''
 * def getDispositionDateOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */
  __pyx_tuple__329 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__329)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__329);
  __Pyx_GIVEREF(__pyx_tuple__329);
  __pyx_codeobj__330 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__329, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDispositionDateOfAppeal, 1552, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__330)) __PYX_ERR(0, 1552, __pyx_L1_error)

  /* "alacorder/cal.pyx":1557
 *     except:
 *         return ''
 * def getDispositionTypeOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 */
  __pyx_tuple__331 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__331)) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__331);
  __Pyx_GIVEREF(__pyx_tuple__331);
  __pyx_codeobj__332 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__331, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getDispositionTypeOfAppeal, 1557, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__332)) __PYX_ERR(0, 1557, __pyx_L1_error)

  /* "alacorder/cal.pyx":1562
 *     except:
 *         return ''
 * def getNumberOfSubpoenas(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 */
  __pyx_tuple__333 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__333)) __PYX_ERR(0, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__333);
  __Pyx_GIVEREF(__pyx_tuple__333);
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__333, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getNumberOfSubpoenas, 1562, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(0, 1562, __pyx_L1_error)

  /* "alacorder/cal.pyx":1567
 *     except:
 *         return ''
 * def getAdminUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 */
  __pyx_tuple__335 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__335)) __PYX_ERR(0, 1567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__335);
  __Pyx_GIVEREF(__pyx_tuple__335);
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__335, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getAdminUpdatedBy, 1567, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(0, 1567, __pyx_L1_error)

  /* "alacorder/cal.pyx":1572
 *     except:
 *         return ''
 * def getTransferToAdminDocDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_tuple__337 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__337)) __PYX_ERR(0, 1572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__337);
  __Pyx_GIVEREF(__pyx_tuple__337);
  __pyx_codeobj__338 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__337, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTransferToAdminDocDate, 1572, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__338)) __PYX_ERR(0, 1572, __pyx_L1_error)

  /* "alacorder/cal.pyx":1577
 *     except:
 *         return ''
 * def getTransferDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_tuple__339 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__339)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__339);
  __Pyx_GIVEREF(__pyx_tuple__339);
  __pyx_codeobj__340 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__339, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTransferDesc, 1577, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__340)) __PYX_ERR(0, 1577, __pyx_L1_error)

  /* "alacorder/cal.pyx":1582
 *     except:
 *         return ''
 * def getTBNV1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 */
  __pyx_tuple__341 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__341)) __PYX_ERR(0, 1582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__341);
  __Pyx_GIVEREF(__pyx_tuple__341);
  __pyx_codeobj__342 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__341, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTBNV1, 1582, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__342)) __PYX_ERR(0, 1582, __pyx_L1_error)

  /* "alacorder/cal.pyx":1587
 *     except:
 *         return ''
 * def getTBNV2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 */
  __pyx_tuple__343 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__343)) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__343);
  __Pyx_GIVEREF(__pyx_tuple__343);
  __pyx_codeobj__344 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__343, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getTBNV2, 1587, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__344)) __PYX_ERR(0, 1587, __pyx_L1_error)

  /* "alacorder/cal.pyx":1592
 *     except:
 *         return ''
 * def getSentencingRequirementsCompleted(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 */
  __pyx_tuple__345 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__345)) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__345);
  __Pyx_GIVEREF(__pyx_tuple__345);
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__345, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentencingRequirementsComplet, 1592, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(0, 1592, __pyx_L1_error)

  /* "alacorder/cal.pyx":1597
 *     except:
 *         return ''
 * def getSentenceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 */
  __pyx_tuple__347 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__347)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__347);
  __Pyx_GIVEREF(__pyx_tuple__347);
  __pyx_codeobj__348 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__347, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentenceDate, 1597, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__348)) __PYX_ERR(0, 1597, __pyx_L1_error)

  /* "alacorder/cal.pyx":1602
 *     except:
 *         return ''
 * def getProbationPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 */
  __pyx_tuple__349 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__349)) __PYX_ERR(0, 1602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__349);
  __Pyx_GIVEREF(__pyx_tuple__349);
  __pyx_codeobj__350 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__349, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getProbationPeriod, 1602, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__350)) __PYX_ERR(0, 1602, __pyx_L1_error)

  /* "alacorder/cal.pyx":1607
 *     except:
 *         return ''
 * def getLicenseSuspPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 */
  __pyx_tuple__351 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__351)) __PYX_ERR(0, 1607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__351);
  __Pyx_GIVEREF(__pyx_tuple__351);
  __pyx_codeobj__352 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__351, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getLicenseSuspPeriod, 1607, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__352)) __PYX_ERR(0, 1607, __pyx_L1_error)

  /* "alacorder/cal.pyx":1612
 *     except:
 *         return ''
 * def getJailCreditPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 */
  __pyx_tuple__353 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__353)) __PYX_ERR(0, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__353);
  __Pyx_GIVEREF(__pyx_tuple__353);
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__353, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getJailCreditPeriod, 1612, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(0, 1612, __pyx_L1_error)

  /* "alacorder/cal.pyx":1617
 *     except:
 *         return ''
 * def getSentenceProvisions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 */
  __pyx_tuple__355 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__355)) __PYX_ERR(0, 1617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__355);
  __Pyx_GIVEREF(__pyx_tuple__355);
  __pyx_codeobj__356 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__355, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentenceProvisions, 1617, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__356)) __PYX_ERR(0, 1617, __pyx_L1_error)

  /* "alacorder/cal.pyx":1622
 *     except:
 *         return ''
 * def getSentenceStartDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_tuple__357 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__357)) __PYX_ERR(0, 1622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__357);
  __Pyx_GIVEREF(__pyx_tuple__357);
  __pyx_codeobj__358 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__357, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentenceStartDate, 1622, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__358)) __PYX_ERR(0, 1622, __pyx_L1_error)

  /* "alacorder/cal.pyx":1627
 *     except:
 *         return ''
 * def getSentenceEndDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_tuple__359 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__359)) __PYX_ERR(0, 1627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__359);
  __Pyx_GIVEREF(__pyx_tuple__359);
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__359, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentenceEndDate, 1627, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(0, 1627, __pyx_L1_error)

  /* "alacorder/cal.pyx":1632
 *     except:
 *         return ''
 * def getProbationBeginDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_tuple__361 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__361)) __PYX_ERR(0, 1632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__361);
  __Pyx_GIVEREF(__pyx_tuple__361);
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__361, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getProbationBeginDate, 1632, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(0, 1632, __pyx_L1_error)

  /* "alacorder/cal.pyx":1637
 *     except:
 *         return ''
 * def getSentenceUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 */
  __pyx_tuple__363 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__363)) __PYX_ERR(0, 1637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__363);
  __Pyx_GIVEREF(__pyx_tuple__363);
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__363, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentenceUpdatedBy, 1637, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(0, 1637, __pyx_L1_error)

  /* "alacorder/cal.pyx":1642
 *     except:
 *         return ''
 * def getSentenceLastUpdate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_tuple__365 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__365)) __PYX_ERR(0, 1642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__365);
  __Pyx_GIVEREF(__pyx_tuple__365);
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__365, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getSentenceLastUpdate, 1642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(0, 1642, __pyx_L1_error)

  /* "alacorder/cal.pyx":1647
 *     except:
 *         return ''
 * def getProbationRevoke(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_tuple__367 = PyTuple_Pack(1, __pyx_n_s_text); if (unlikely(!__pyx_tuple__367)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__367);
  __Pyx_GIVEREF(__pyx_tuple__367);
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__367, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_cal_pyx, __pyx_n_s_getProbationRevoke, 1647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_0 = PyFloat_FromDouble(0.0); if (unlikely(!__pyx_float_0_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_5 = PyFloat_FromDouble(0.5); if (unlikely(!__pyx_float_0_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_float_0_00 = PyFloat_FromDouble(0.00); if (unlikely(!__pyx_float_0_00)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_9 = PyInt_FromLong(9); if (unlikely(!__pyx_int_9)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_10 = PyInt_FromLong(10); if (unlikely(!__pyx_int_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_19 = PyInt_FromLong(19); if (unlikely(!__pyx_int_19)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_2 = PyInt_FromLong(-2); if (unlikely(!__pyx_int_neg_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText) < 0) __PYX_ERR(0, 1086, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText.tp_dictoffset && __pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_9alacorder_3cal___pyx_scope_struct__getPDFText = &__pyx_type_9alacorder_3cal___pyx_scope_struct__getPDFText;
  if (PyType_Ready(&__pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr) < 0) __PYX_ERR(0, 1097, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr.tp_dictoffset && __pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_9alacorder_3cal___pyx_scope_struct_1_genexpr = &__pyx_type_9alacorder_3cal___pyx_scope_struct_1_genexpr;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initcal(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initcal(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_cal(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_cal(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_cal(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'cal' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_cal(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("cal", __pyx_methods, __pyx_k_alacorder_on_polars_Dependencie, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_alacorder__cal) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "alacorder.cal")) {
      if (unlikely(PyDict_SetItemString(modules, "alacorder.cal", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "alacorder/cal.pyx":10
 * """
 * 
 * name = "ALACORDER"             # <<<<<<<<<<<<<<
 * version = "79.2.8"
 * long_version = "partymountain"
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_name, __pyx_n_u_ALACORDER) < 0) __PYX_ERR(0, 10, __pyx_L1_error)

  /* "alacorder/cal.pyx":11
 * 
 * name = "ALACORDER"
 * version = "79.2.8"             # <<<<<<<<<<<<<<
 * long_version = "partymountain"
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_version, __pyx_kp_u_79_2_7) < 0) __PYX_ERR(0, 11, __pyx_L1_error)

  /* "alacorder/cal.pyx":12
 * name = "ALACORDER"
 * version = "79.2.8"
 * long_version = "partymountain"             # <<<<<<<<<<<<<<
 * 
 * import click, fitz, os, sys, time, glob, inspect, math, re, warnings, xlsxwriter, threading, platform, tqdm, selenium
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_long_version, __pyx_n_u_partymountain) < 0) __PYX_ERR(0, 12, __pyx_L1_error)

  /* "alacorder/cal.pyx":14
 * long_version = "partymountain"
 * 
 * import click, fitz, os, sys, time, glob, inspect, math, re, warnings, xlsxwriter, threading, platform, tqdm, selenium             # <<<<<<<<<<<<<<
 * import polars as pl
 * from selenium import webdriver
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_click, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_click, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_fitz, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_fitz, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_os, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_time, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_time, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_glob, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_glob, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_patch_inspect(__Pyx_Import(__pyx_n_s_inspect, 0, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_inspect, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_math, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_math, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_re, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_re, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_warnings, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_warnings, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_xlsxwriter, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_xlsxwriter, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_threading, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_threading, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_platform, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_platform, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_tqdm, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tqdm, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_selenium, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_selenium, __pyx_t_1) < 0) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":15
 * 
 * import click, fitz, os, sys, time, glob, inspect, math, re, warnings, xlsxwriter, threading, platform, tqdm, selenium
 * import polars as pl             # <<<<<<<<<<<<<<
 * from selenium import webdriver
 * from selenium.webdriver.common.by import By
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_polars, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pl, __pyx_t_1) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":16
 * import click, fitz, os, sys, time, glob, inspect, math, re, warnings, xlsxwriter, threading, platform, tqdm, selenium
 * import polars as pl
 * from selenium import webdriver             # <<<<<<<<<<<<<<
 * from selenium.webdriver.common.by import By
 * from selenium.webdriver.support.ui import Select
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_webdriver);
  __Pyx_GIVEREF(__pyx_n_s_webdriver);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_webdriver);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_selenium, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_webdriver); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_webdriver, __pyx_t_1) < 0) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":17
 * import polars as pl
 * from selenium import webdriver
 * from selenium.webdriver.common.by import By             # <<<<<<<<<<<<<<
 * from selenium.webdriver.support.ui import Select
 * from selenium.webdriver.chrome.options import Options
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_By);
  __Pyx_GIVEREF(__pyx_n_s_By);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_By);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_selenium_webdriver_common_by, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_By); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_By, __pyx_t_2) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":18
 * from selenium import webdriver
 * from selenium.webdriver.common.by import By
 * from selenium.webdriver.support.ui import Select             # <<<<<<<<<<<<<<
 * from selenium.webdriver.chrome.options import Options
 * fname = f"{name} {version}"
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_Select);
  __Pyx_GIVEREF(__pyx_n_s_Select);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_Select);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_selenium_webdriver_support_ui, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_Select); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Select, __pyx_t_1) < 0) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":19
 * from selenium.webdriver.common.by import By
 * from selenium.webdriver.support.ui import Select
 * from selenium.webdriver.chrome.options import Options             # <<<<<<<<<<<<<<
 * fname = f"{name} {version}"
 * fshort_name = f"{name} {version.rsplit('.')[0]}"
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_Options);
  __Pyx_GIVEREF(__pyx_n_s_Options);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_Options);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_selenium_webdriver_chrome_option, __pyx_t_2, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_Options); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_Options, __pyx_t_2) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "alacorder/cal.pyx":20
 * from selenium.webdriver.support.ui import Select
 * from selenium.webdriver.chrome.options import Options
 * fname = f"{name} {version}"             # <<<<<<<<<<<<<<
 * fshort_name = f"{name} {version.rsplit('.')[0]}"
 * warnings.filterwarnings('ignore')
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_2, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__64);
  __pyx_t_3 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__64);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__64);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_version); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_fname, __pyx_t_2) < 0) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":21
 * from selenium.webdriver.chrome.options import Options
 * fname = f"{name} {version}"
 * fshort_name = f"{name} {version.rsplit('.')[0]}"             # <<<<<<<<<<<<<<
 * warnings.filterwarnings('ignore')
 * pl.Config.set_tbl_rows(100)
 */
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__64);
  __pyx_t_3 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__64);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u__64);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_version); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_rsplit); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_tuple__116, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_5, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_2, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_fshort_name, __pyx_t_5) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":22
 * fname = f"{name} {version}"
 * fshort_name = f"{name} {version.rsplit('.')[0]}"
 * warnings.filterwarnings('ignore')             # <<<<<<<<<<<<<<
 * pl.Config.set_tbl_rows(100)
 * pl.Config.set_fmt_str_lengths(100)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_warnings); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_filterwarnings); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__117, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":23
 * fshort_name = f"{name} {version.rsplit('.')[0]}"
 * warnings.filterwarnings('ignore')
 * pl.Config.set_tbl_rows(100)             # <<<<<<<<<<<<<<
 * pl.Config.set_fmt_str_lengths(100)
 * pl.Config.set_tbl_cols(10)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Config); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_tbl_rows); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__118, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":24
 * warnings.filterwarnings('ignore')
 * pl.Config.set_tbl_rows(100)
 * pl.Config.set_fmt_str_lengths(100)             # <<<<<<<<<<<<<<
 * pl.Config.set_tbl_cols(10)
 * pl.Config.set_tbl_formatting('UTF8_FULL_CONDENSED')
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Config); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_set_fmt_str_lengths); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__118, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":25
 * pl.Config.set_tbl_rows(100)
 * pl.Config.set_fmt_str_lengths(100)
 * pl.Config.set_tbl_cols(10)             # <<<<<<<<<<<<<<
 * pl.Config.set_tbl_formatting('UTF8_FULL_CONDENSED')
 * CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pl); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Config); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_set_tbl_cols); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_tuple__119, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "alacorder/cal.pyx":26
 * pl.Config.set_fmt_str_lengths(100)
 * pl.Config.set_tbl_cols(10)
 * pl.Config.set_tbl_formatting('UTF8_FULL_CONDENSED')             # <<<<<<<<<<<<<<
 * CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_pl); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Config); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_set_tbl_formatting); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_tuple__120, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":27
 * pl.Config.set_tbl_cols(10)
 * pl.Config.set_tbl_formatting('UTF8_FULL_CONDENSED')
 * CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])             # <<<<<<<<<<<<<<
 * 
 * #   #   #   #           TASK STARTERS           #   #   #   #
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_kp_u_h);
  __Pyx_GIVEREF(__pyx_kp_u_h);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_h);
  __Pyx_INCREF(__pyx_kp_u_help);
  __Pyx_GIVEREF(__pyx_kp_u_help);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_kp_u_help);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_help_option_names, __pyx_t_2) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CONTEXT_SETTINGS, __pyx_t_5) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":31
 * #   #   #   #           TASK STARTERS           #   #   #   #
 * 
 * def multi(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start multitable collection using configuration object `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_1multi, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_multi, __pyx_t_5) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":48
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca, ch, fs
 * def cases(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start cases table collection using configuration object `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_3cases, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_cases, __pyx_t_5) < 0) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":61
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ca
 * def charges(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start charges table collection using configuration object `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_5charges, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_charges, __pyx_t_5) < 0) __PYX_ERR(0, 61, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":76
 *           window.write_event_value("COMPLETE-TB",True)
 *      return ch
 * def fees(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start fee sheet collection using configuration object `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_7fees, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_fees, __pyx_t_5) < 0) __PYX_ERR(0, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":91
 *           window.write_event_value("COMPLETE-TB",True)
 *      return fs
 * def tables(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *     """
 *     Start Alacorder table export using configuration object `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_9tables, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tables, __pyx_t_5) < 0) __PYX_ERR(0, 91, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":103
 *     """
 *     return init(cf, window=window)
 * def init(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Start Alacorder using configuration object `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_11init, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_init, __pyx_t_5) < 0) __PYX_ERR(0, 103, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":135
 *           print("Job not specified. Select a mode and reconfigure to start.")
 *           return None
 * def archive(cf, window=None, debug=False):             # <<<<<<<<<<<<<<
 *      """
 *      Write a full text archive from inputs using configuration `cf`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_13archive, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_archive, __pyx_t_5) < 0) __PYX_ERR(0, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":147
 * #   #   #   #         CONFIGURATION & I/O        #   #   #   #
 * 
 * def set(inputs, outputs=None, count=0, table='', archive=False, no_prompt=True, debug=False, overwrite=False, no_write=False, fetch=False, cID='', uID='', pwd='', qmax=0, qskip=0, append=False, window=None, force=False, no_update=False, now=False):             # <<<<<<<<<<<<<<
 *      """
 *      Check inputs and outputs and return a configuration object for Alacorder table parser functions to receive as parameter and complete task, or set `now = True` to run upon set() call.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_15set, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set, __pyx_t_5) < 0) __PYX_ERR(0, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":291
 *           return init(out, window=window, debug=debug)
 *      return out
 * def dlog(cf=None, text=""):             # <<<<<<<<<<<<<<
 *      if cf == None or cf == False:
 *           return None
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_17dlog, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_dlog, __pyx_t_5) < 0) __PYX_ERR(0, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":302
 *           else:
 *                return None
 * def read(cf='', window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Read `cf` input PDF directory or case text archive into memory.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_19read, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_read, __pyx_t_5) < 0) __PYX_ERR(0, 302, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":363
 *           return None
 * 
 * def write(outputs, sheet_names=[], cf=None, path=None, overwrite=False):             # <<<<<<<<<<<<<<
 *      """Write `outputs` to output path at `cf` in accordance with configuration settings.
 * 
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_k__16 = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_21write, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_write, __pyx_t_5) < 0) __PYX_ERR(0, 363, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":415
 *           pass
 *      return outputs
 * def append_archive(inpath='', outpath='', conf=None, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Append the contents of one archive to another.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_23append_archive, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_append_archive, __pyx_t_5) < 0) __PYX_ERR(0, 415, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":454
 * #   #   #   #           TABLE PARSERS           #   #   #   #
 * 
 * def split_cases(df, debug=False):             # <<<<<<<<<<<<<<
 *      cases = df.with_columns([
 *           pl.col("AllPagesText").str.extract(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*',group_index=1).str.replace_all("Case Number:","",literal=True).str.replace(r'C$','').str.strip().alias("Name"),
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_25split_cases, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_split_cases, __pyx_t_5) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":598
 *      cases = cases.select("Retrieved","CaseNumber","Name","DOB","Race","Sex","Description","CourtAction","CourtActionDate","TotalAmtDue","TotalAmtPaid","TotalBalance","TotalAmtHold","PaymentToRestore","Phone", "StreetAddress","City","State","ZipCode",'County',"Country","Alias", 'SSN','Weight','Eyes','Hair',"FilingDate","CaseInitiationDate","ArrestDate","OffenseDate","IndictmentDate","JuryDemand","InpatientTreatmentOrdered","TrialType","Judge","DefendantStatus","ArrestingAgencyType",'ArrestingOfficer','ProbationOfficeName','PreviousDUIConvictions','CaseInitiationType','DomesticViolence','AgencyORI','WarrantIssuanceDate', 'WarrantActionDate', 'WarrantIssuanceStatus', 'WarrantActionStatus', 'WarrantLocationStatus', 'NumberOfWarrants', 'BondType', 'BondTypeDesc', 'BondAmt', 'BondCompany', 'SuretyCode', 'BondReleaseDate', 'FailedToAppearDate', 'BondsmanProcessIssuance', 'AppealDate', 'AppealCourt', 'OriginOfAppeal', 'AppealToDesc', 'AppealStatus', 'AppealTo', 'NumberOfSubpoenas', 'AdminUpdatedBy', 'TransferDesc', 'TBNV1', 'TBNV2','DriverLicenseNo','StateID')
 *      return cases, all_charges, all_fees
 * def split_charges(df, debug=False):             # <<<<<<<<<<<<<<
 *      dlog(debug, [df.columns, df.shape, "alac 945"])
 *      charges = df.with_columns([
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_27split_charges, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_split_charges, __pyx_t_5) < 0) __PYX_ERR(0, 598, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":651
 * 
 *      return charges
 * def split_fees(df, debug=False):             # <<<<<<<<<<<<<<
 *      df = df.select([
 *           pl.col("CaseNumber"),
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_29split_fees, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_split_fees, __pyx_t_5) < 0) __PYX_ERR(0, 651, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":699
 * #   #   #   #         FETCH (PDF SCRAPER)       #   #   #   #
 * 
 * def read_query(path, qmax=0, qskip=0, window=None):             # <<<<<<<<<<<<<<
 *     if os.path.splitext(path)[1] in (".xlsx",".xls"):
 *         query = pl.read_excel(path)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_31read_query, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_read_query, __pyx_t_5) < 0) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":746
 *         print("Try again with at least one valid column header: [NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, NO_RECORDS, FILED_BEFORE, FILED_AFTER, RETRIEVED, CASES_FOUND, QUERY_COMPLETE]")
 *         return None
 * def fetch(querypath='', dirpath='', cID='', uID='', pwd='', qmax=0, qskip=0, cf=None, no_update=False, debug=False, window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Fetch cases from Alacourt.com with input query spreadsheet headers NAME, PARTY_TYPE, SSN, DOB, COUNTY, DIVISION, CASE_YEAR, and FILED_BEFORE.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_33fetch, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_fetch, __pyx_t_5) < 0) __PYX_ERR(0, 746, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":831
 *      print("Completed query template.")
 *      return query
 * def party_search(driver, name = "", party_type = "", ssn="", dob="", county="", division="", case_year="", filed_before="", filed_after="", debug=False, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      Collect PDFs via SJIS Party Search Form from Alacourt.com
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_35party_search, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_party_search, __pyx_t_5) < 0) __PYX_ERR(0, 831, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":994
 *                     continue
 *      return pdflinks
 * def downloadPDF(driver, url, cID="", uID="", pwd="", window=None):             # <<<<<<<<<<<<<<
 *      """
 *      With sg.WebDriver `driver`, download PDF at `url`.
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_37downloadPDF, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_downloadPDF, __pyx_t_5) < 0) __PYX_ERR(0, 994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1010
 *      a = driver.get(url)
 *      driver.implicitly_wait(0.5)
 * def login(driver, cID, uID="", pwd="", path="", window=None):             # <<<<<<<<<<<<<<
 *      """Login to Alacourt.com using (driver) and auth (cID, username, pwd) for browser download to directory at (path)
 * 
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_39login, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_login, __pyx_t_5) < 0) __PYX_ERR(0, 1010, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1070
 * 
 *      return driver
 * def empty_query(path):             # <<<<<<<<<<<<<<
 *      """Create empty query worksheet to submit search list for Alacorder to retrieve matching case records from Alacourt.com.
 * 
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_41empty_query, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1070, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_empty_query, __pyx_t_5) < 0) __PYX_ERR(0, 1070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1086
 * #   #   #   #           GETTER METHODS         #   #   #   #
 * 
 * def getPDFText(path) -> str:             # <<<<<<<<<<<<<<
 *      """
 *      From path, return full text of PDF as string (PyMuPdf engine required!)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_43getPDFText, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getPDFText, __pyx_t_5) < 0) __PYX_ERR(0, 1086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1102
 *      text = re.sub(r'(<image\:.+?>)','', text).strip()
 *      return text
 * def getName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Number:','',re.search(r'(?:VS\.|V\.| VS | V | VS: |-VS-{1})([A-Z\s]{10,100})(Case Number)*', str(text)).group(1)).rstrip("C").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_45getName, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getName, __pyx_t_5) < 0) __PYX_ERR(0, 1102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1107
 *     except:
 *         return ''
 * def getAlias(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r':','',re.search(r'(?:SSN)(.{5,75})(?:Alias)', str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_47getAlias, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAlias, __pyx_t_5) < 0) __PYX_ERR(0, 1107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1112
 *     except:
 *         return ''
 * def getDOB(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[^\d/]','',re.search(r'(\d{2}/\d{2}/\d{4})(?:.{0,5}DOB:)', str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_49getDOB, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDOB, __pyx_t_5) < 0) __PYX_ERR(0, 1112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1117
 *     except:
 *         return ''
 * def getPhone(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.sub(r'[^0-9]','',re.search(r'(Phone: )(.+)', str(text)).group(2)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_51getPhone, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getPhone, __pyx_t_5) < 0) __PYX_ERR(0, 1117, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1128
 *     except:
 *         return ''
 * def getRace(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_53getRace, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getRace, __pyx_t_5) < 0) __PYX_ERR(0, 1128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1133
 *     except:
 *         return ''
 * def getSex(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(B|W|H|A)/(F|M)', str(text)).group(2)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_55getSex, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSex, __pyx_t_5) < 0) __PYX_ERR(0, 1133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1138
 *     except:
 *         return ''
 * def getAddress1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?', str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_57getAddress1, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAddress1, __pyx_t_5) < 0) __PYX_ERR(0, 1138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1143
 *     except:
 *         return ''
 * def getAddress2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Defendant Information|JID:.+','',re.search(r'(?:Address 2:)(.+)', str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_59getAddress2, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAddress2, __pyx_t_5) < 0) __PYX_ERR(0, 1143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1148
 *     except:
 *         return ''
 * def getCity(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_61getCity, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCity, __pyx_t_5) < 0) __PYX_ERR(0, 1148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1153
 *     except:
 *         return ''
 * def getState(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(?:City: )(.*)(?:State: )(.*)', str(text)).group(2)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_63getState, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getState, __pyx_t_5) < 0) __PYX_ERR(0, 1153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1158
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Country:','',re.sub(r'(Enforcement|Party|Country)','',re.search(r'Country: (\w*+)', str(text)).group()).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_65getCountry, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCountry, __pyx_t_5) < 0) __PYX_ERR(0, 1158, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1163
 *     except:
 *         return ''
 * def getZipCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'-0000$|[A-Z].+','',re.search(r'(Zip: )(.+)', str(text)).group(2)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_67getZipCode, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getZipCode, __pyx_t_5) < 0) __PYX_ERR(0, 1163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1168
 *     except:
 *         return ''
 * def getAddress(text):             # <<<<<<<<<<<<<<
 *     try:
 *         street1 = re.sub(r'Phone.+','',re.search(r'(?:Address 1:)(.+)(?:Phone)*?',str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_69getAddress, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAddress, __pyx_t_5) < 0) __PYX_ERR(0, 1168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1193
 *     else:
 *         return f"{street1} {street2} {city} {state} {zipcode}".strip()
 * def getChargesRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_71getChargesRows, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getChargesRows, __pyx_t_5) < 0) __PYX_ERR(0, 1193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1196
 *     m = re.findall(r'(\d{3}\s{1}[A-Z0-9]{4}.{1,200}?.{3}-.{3}-.{3}[^a-z\n]{10,75})', str(text))
 *     return m
 * def getFeeSheetRows(text):             # <<<<<<<<<<<<<<
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_73getFeeSheetRows, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getFeeSheetRows, __pyx_t_5) < 0) __PYX_ERR(0, 1196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1199
 *     m = re.findall(r'(ACTIVE [^\(\n]+\$[^\(\n]+ACTIVE[^\(\n]+[^\n]|Total:.+\$[^A-Za-z\n]*)', str(text))
 *     return m
 * def getTotalRow(text):             # <<<<<<<<<<<<<<
 *     try:
 *         mmm = re.search(r'(Total:.+\$[^\n]*)', str(text)).group()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_75getTotalRow, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTotalRow, __pyx_t_5) < 0) __PYX_ERR(0, 1199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1207
 *     except:
 *         return ["0.00","0.00","0.00","0.00"]
 * def getTotalAmtDue(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[0]))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_77getTotalAmtDue, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTotalAmtDue, __pyx_t_5) < 0) __PYX_ERR(0, 1207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1212
 *     except:
 *         return 0.00
 * def getTotalAmtPaid(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[1]))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_79getTotalAmtPaid, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTotalAmtPaid, __pyx_t_5) < 0) __PYX_ERR(0, 1212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1217
 *     except:
 *         return 0.00
 * def getTotalBalance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[2]))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_81getTotalBalance, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTotalBalance, __pyx_t_5) < 0) __PYX_ERR(0, 1217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1222
 *     except:
 *         return 0.00
 * def getTotalAmtHold(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[\$\s]','',getTotalRow(text)[3]))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_83getTotalAmtHold, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTotalAmtHold, __pyx_t_5) < 0) __PYX_ERR(0, 1222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1227
 *     except:
 *         return 0.00
 * def getPaymentToRestore(text):             # <<<<<<<<<<<<<<
 *     try:
 *         tbal = getTotalBalance(text)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_85getPaymentToRestore, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getPaymentToRestore, __pyx_t_5) < 0) __PYX_ERR(0, 1227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1239
 *         d999 = 0.0
 *     return float(tbal - d999)
 * def getShortCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_87getShortCaseNumber, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getShortCaseNumber, __pyx_t_5) < 0) __PYX_ERR(0, 1239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1244
 *     except:
 *         return ''
 * def getCounty(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_89getCounty, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCounty, __pyx_t_5) < 0) __PYX_ERR(0, 1244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1249
 *     except:
 *         return ''
 * def getCaseNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Number: (\d\d-\w+) County:', str(text)).group(1)[0:2] + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}\.\d{2})', str(text)).group()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_91getCaseNumber, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCaseNumber, __pyx_t_5) < 0) __PYX_ERR(0, 1249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1254
 *     except:
 *         return ''
 * def getCaseYear(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'\w{2}\-(\d{4})-\d{6}\.\d{2}', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_93getCaseYear, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCaseYear, __pyx_t_5) < 0) __PYX_ERR(0, 1254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1259
 *     except:
 *         return ''
 * def getLastName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[0].strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_95getLastName, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getLastName, __pyx_t_5) < 0) __PYX_ERR(0, 1259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1264
 *     except:
 *         return ''
 * def getFirstName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return getName(text).split(" ")[-1].strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_97getFirstName, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getFirstName, __pyx_t_5) < 0) __PYX_ERR(0, 1264, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1269
 *     except:
 *         return ''
 * def getMiddleName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         if len(getName(text).split(" ")) > 2:
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_99getMiddleName, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getMiddleName, __pyx_t_5) < 0) __PYX_ERR(0, 1269, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1277
 *     except:
 *         return ''
 * def getRelatedCases(text):             # <<<<<<<<<<<<<<
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_101getRelatedCases, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getRelatedCases, __pyx_t_5) < 0) __PYX_ERR(0, 1277, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1279
 * def getRelatedCases(text):
 *     return re.findall(r'(\w{2}\d{12})',str(text))
 * def getFilingDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Filing Date: ','',re.search(r'Filing Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group()).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_103getFilingDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getFilingDate, __pyx_t_5) < 0) __PYX_ERR(0, 1279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1284
 *     except:
 *         return ''
 * def getCaseInitiationDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'Case Initiation Date: ','',re.search(r'Case Initiation Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_105getCaseInitiationDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCaseInitiationDate, __pyx_t_5) < 0) __PYX_ERR(0, 1284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1289
 *     except:
 *         return ''
 * def getArrestDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arrest Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_107getArrestDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getArrestDate, __pyx_t_5) < 0) __PYX_ERR(0, 1289, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1294
 *     except:
 *         return ''
 * def getOffenseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Offense Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_109getOffenseDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getOffenseDate, __pyx_t_5) < 0) __PYX_ERR(0, 1294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1299
 *     except:
 *         return ''
 * def getIndictmentDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Indictment Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_111getIndictmentDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getIndictmentDate, __pyx_t_5) < 0) __PYX_ERR(0, 1299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1304
 *     except:
 *         return ''
 * def getYouthfulDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Youthful Date: (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_113getYouthfulDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getYouthfulDate, __pyx_t_5) < 0) __PYX_ERR(0, 1304, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1309
 *     except:
 *         return ''
 * def getRetrieved(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Alacourt\.com (\d\d?/\d\d?/\d\d\d\d)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_115getRetrieved, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getRetrieved, __pyx_t_5) < 0) __PYX_ERR(0, 1309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1314
 *     except:
 *         return ''
 * def getCourtAction(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action: (BOUND|GUILTY PLEA|WAIVED TO GJ|DISMISSED|TIME LAPSED|NOL PROSS|CONVICTED|INDICTED|DISMISSED|FORFEITURE|TRANSFER|REMANDED|WAIVED|ACQUITTED|WITHDRAWN|PETITION|PRETRIAL|COND\. FORF\.)', str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_117getCourtAction, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCourtAction, __pyx_t_5) < 0) __PYX_ERR(0, 1314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1319
 *     except:
 *         return ''
 * def getCourtActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Court Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_119getCourtActionDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCourtActionDate, __pyx_t_5) < 0) __PYX_ERR(0, 1319, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1324
 *     except:
 *         return ''
 * def getDescription(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Charge: ([A-Z\.0-9\-\s]+)', str(text)).group(1).rstrip("C").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_121getDescription, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDescription, __pyx_t_5) < 0) __PYX_ERR(0, 1324, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1329
 *     except:
 *         return ''
 * def getJuryDemand(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Jury Demand: ([A-Z]+)', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_123getJuryDemand, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getJuryDemand, __pyx_t_5) < 0) __PYX_ERR(0, 1329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1334
 *     except:
 *         return ''
 * def getInpatientTreatmentOrdered(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Inpatient Treatment Ordered: ([YES|NO]?)', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_125getInpatientTreatmentOrdered, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getInpatientTreatmentOrdered, __pyx_t_5) < 0) __PYX_ERR(0, 1334, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1339
 *     except:
 *         return ''
 * def getTrialType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[S|N]$','',re.search(r'Trial Type: ([A-Z]+)', str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_127getTrialType, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTrialType, __pyx_t_5) < 0) __PYX_ERR(0, 1339, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1344
 *     except:
 *         return ''
 * def getJudge(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Judge: ([A-Z\-\.\s]+)', str(text)).group(1).rstrip("T").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_129getJudge, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getJudge, __pyx_t_5) < 0) __PYX_ERR(0, 1344, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1349
 *     except:
 *         return ''
 * def getProbationOfficeNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(0-000000-00)','',re.search(r'Probation Office \#: ([0-9\-]+)', str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_131getProbationOfficeNumber, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getProbationOfficeNumber, __pyx_t_5) < 0) __PYX_ERR(0, 1349, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1354
 *     except:
 *         return ''
 * def getDefendantStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Defendant Status: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_133getDefendantStatus, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDefendantStatus, __pyx_t_5) < 0) __PYX_ERR(0, 1354, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1359
 *     except:
 *         return ''
 * def getArrestingAgencyType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'\n','',re.search(r'([^0-9]+) Arresting Agency Type:', str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_135getArrestingAgencyType, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getArrestingAgencyType, __pyx_t_5) < 0) __PYX_ERR(0, 1359, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1364
 *     except:
 *         return ''
 * def getArrestingOfficer(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Arresting Officer: ([A-Z\s]+)', str(text)).group(1).rstrip("S").rstrip("P").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_137getArrestingOfficer, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getArrestingOfficer, __pyx_t_5) < 0) __PYX_ERR(0, 1364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1369
 *     except:
 *         return ''
 * def getProbationOfficeName(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Probation Office Name: ([A-Z0-9]+)', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_139getProbationOfficeName, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getProbationOfficeName, __pyx_t_5) < 0) __PYX_ERR(0, 1369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1374
 *     except:
 *         return ''
 * def getTrafficCitationNumber(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Traffic Citation \#: ([A-Z0-9]+)', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_141getTrafficCitationNumber, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTrafficCitationNumber, __pyx_t_5) < 0) __PYX_ERR(0, 1374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1379
 *     except:
 *         return ''
 * def getPreviousDUIConvictions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Previous DUI Convictions: (\d{3})', str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_143getPreviousDUIConvictions, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getPreviousDUIConvictions, __pyx_t_5) < 0) __PYX_ERR(0, 1379, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1384
 *     except:
 *         return ''
 * def getCaseInitiationType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Case Initiation Type: ([A-Z\s]+)', str(text)).group(1).rstrip("J").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_145getCaseInitiationType, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCaseInitiationType, __pyx_t_5) < 0) __PYX_ERR(0, 1384, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1389
 *     except:
 *         return ''
 * def getDomesticViolence(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Domestic Violence: ([YES|NO])', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_147getDomesticViolence, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDomesticViolence, __pyx_t_5) < 0) __PYX_ERR(0, 1389, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1394
 *     except:
 *         return ''
 * def getAgencyORI(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Agency ORI: ([A-Z\s]+)', str(text)).group(1).rstrip("C").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_149getAgencyORI, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAgencyORI, __pyx_t_5) < 0) __PYX_ERR(0, 1394, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1399
 *     except:
 *         return ''
 * def getDriverLicenseNo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'Driver License N: ([A-Z0-9]+)', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_151getDriverLicenseNo, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDriverLicenseNo, __pyx_t_5) < 0) __PYX_ERR(0, 1399, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1408
 *     except:
 *         return ''
 * def getSSN(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'SSN: ([X\d]{3}\-[X\d]{2}-[X\d]{4})', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_153getSSN, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSSN, __pyx_t_5) < 0) __PYX_ERR(0, 1408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1413
 *     except:
 *         return ''
 * def getStateID(text):             # <<<<<<<<<<<<<<
 *     try:
 *         m = re.search(r'([A-Z0-9]{11}?) State ID:', str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_155getStateID, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getStateID, __pyx_t_5) < 0) __PYX_ERR(0, 1413, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1422
 *     except:
 *         return ''
 * def getWeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.search(r'Weight: (\d+)', str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_157getWeight, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWeight, __pyx_t_5) < 0) __PYX_ERR(0, 1422, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1427
 *     except:
 *         return ''
 * def getHeight(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r"Height : (\d'\d{2})", str(text)).group(1).strip() + "\""
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_159getHeight, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getHeight, __pyx_t_5) < 0) __PYX_ERR(0, 1427, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1432
 *     except:
 *         return ''
 * def getEyes(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_161getEyes, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getEyes, __pyx_t_5) < 0) __PYX_ERR(0, 1432, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1437
 *     except:
 *         return ''
 * def getHair(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Eyes/Hair: (\w{3})/(\w{3})',str(text)).group(2).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_163getHair, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getHair, __pyx_t_5) < 0) __PYX_ERR(0, 1437, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1442
 *     except:
 *         return ''
 * def getCountry(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Enforcement|Party|Country:)','',re.search(r'Country: (\w*+)',str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_165getCountry, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getCountry, __pyx_t_5) < 0) __PYX_ERR(0, 1442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1447
 *     except:
 *         return ''
 * def getWarrantIssuanceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(\d\d?/\d\d?/\d\d\d\d) Warrant Issuance Date:',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_167getWarrantIssuanceDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWarrantIssuanceDate, __pyx_t_5) < 0) __PYX_ERR(0, 1447, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1452
 *     except:
 *         return ''
 * def getWarrantActionDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_169getWarrantActionDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWarrantActionDate, __pyx_t_5) < 0) __PYX_ERR(0, 1452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1457
 *     except:
 *         return ''
 * def getWarrantIssuanceStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Issuance Status: (\w)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_171getWarrantIssuanceStatus, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWarrantIssuanceStatus, __pyx_t_5) < 0) __PYX_ERR(0, 1457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1462
 *     except:
 *         return ''
 * def getWarrantActionStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Action Status: (\w)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_173getWarrantActionStatus, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWarrantActionStatus, __pyx_t_5) < 0) __PYX_ERR(0, 1462, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1467
 *     except:
 *         return ''
 * def getWarrantLocationStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Warrant Location Status: (\w)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_175getWarrantLocationStatus, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getWarrantLocationStatus, __pyx_t_5) < 0) __PYX_ERR(0, 1467, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1472
 *     except:
 *         return ''
 * def getNumberOfWarrants(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Number Of Warrants: (\d{3}\s\d{3})',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_177getNumberOfWarrants, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getNumberOfWarrants, __pyx_t_5) < 0) __PYX_ERR(0, 1472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1477
 *     except:
 *         return ''
 * def getBondType(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type: (\w)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_179getBondType, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getBondType, __pyx_t_5) < 0) __PYX_ERR(0, 1477, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1482
 *     except:
 *         return ''
 * def getBondTypeDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bond Type Desc: ([A-Z\s]+)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_181getBondTypeDesc, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1482, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getBondTypeDesc, __pyx_t_5) < 0) __PYX_ERR(0, 1482, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1487
 *     except:
 *         return ''
 * def getBondAmt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return float(re.sub(r'[^0-9\.\s]','',re.search(r'([\d\.]+) Bond Amount:',str(text)).group(1).strip()))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_183getBondAmt, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getBondAmt, __pyx_t_5) < 0) __PYX_ERR(0, 1487, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1492
 *     except:
 *         return ''
 * def getSuretyCode(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Surety Code: ([A-Z0-9]{4})',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_185getSuretyCode, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSuretyCode, __pyx_t_5) < 0) __PYX_ERR(0, 1492, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1497
 *     except:
 *         return ''
 * def getBondReleaseDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Release Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_187getBondReleaseDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getBondReleaseDate, __pyx_t_5) < 0) __PYX_ERR(0, 1497, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1502
 *     except:
 *         return ''
 * def getFailedToAppearDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Failed to Appear Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_189getFailedToAppearDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getFailedToAppearDate, __pyx_t_5) < 0) __PYX_ERR(0, 1502, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1507
 *     except:
 *         return ''
 * def getBondsmanProcessIssuance(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Issuance: ([^\n]*?) Bondsman Process Return:',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_191getBondsmanProcessIssuance, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getBondsmanProcessIssuance, __pyx_t_5) < 0) __PYX_ERR(0, 1507, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1512
 *     except:
 *         return ''
 * def getBondsmanProcessReturn(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Bondsman Process Return: (.*?) Number of Subponeas',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_193getBondsmanProcessReturn, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1512, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getBondsmanProcessReturn, __pyx_t_5) < 0) __PYX_ERR(0, 1512, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1517
 *     except:
 *         return ''
 * def getAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s]','',re.search(r'([\n\s/\d]*?) Appeal Court:',str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_195getAppealDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAppealDate, __pyx_t_5) < 0) __PYX_ERR(0, 1517, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1522
 *     except:
 *         return ''
 * def getAppealCourt(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'([A-Z\-\s]+) Appeal Case Number',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_197getAppealCourt, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAppealCourt, __pyx_t_5) < 0) __PYX_ERR(0, 1522, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1527
 *     except:
 *         return ''
 * def getOriginOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Orgin Of Appeal: ([A-Z\-\s]+)',str(text)).group(1).rstrip("L").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_199getOriginOfAppeal, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getOriginOfAppeal, __pyx_t_5) < 0) __PYX_ERR(0, 1527, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1532
 *     except:
 *         return ''
 * def getAppealToDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To Desc: ([A-Z\-\s]+)',str(text)).group(1).rstrip("D").rstrip("T").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_201getAppealToDesc, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAppealToDesc, __pyx_t_5) < 0) __PYX_ERR(0, 1532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1537
 *     except:
 *         return ''
 * def getAppealStatus(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal Status: ([A-Z\-\s]+)',str(text)).group(1).rstrip("A").strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_203getAppealStatus, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAppealStatus, __pyx_t_5) < 0) __PYX_ERR(0, 1537, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1542
 *     except:
 *         return ''
 * def getAppealTo(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Appeal To: (\w?) Appeal',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_205getAppealTo, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAppealTo, __pyx_t_5) < 0) __PYX_ERR(0, 1542, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1547
 *     except:
 *         return ''
 * def getLowerCourtAppealDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'LowerCourt Appeal Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_207getLowerCourtAppealDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getLowerCourtAppealDate, __pyx_t_5) < 0) __PYX_ERR(0, 1547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1552
 *     except:
 *         return ''
 * def getDispositionDateOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Date Of Appeal: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_209getDispositionDateOfAppeal, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDispositionDateOfAppeal, __pyx_t_5) < 0) __PYX_ERR(0, 1552, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1557
 *     except:
 *         return ''
 * def getDispositionTypeOfAppeal(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n\s:\-]','',re.search(r'Disposition Type Of Appeal: [^A-Za-z]+',str(text)).group(1)).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_211getDispositionTypeOfAppeal, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getDispositionTypeOfAppeal, __pyx_t_5) < 0) __PYX_ERR(0, 1557, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1562
 *     except:
 *         return ''
 * def getNumberOfSubpoenas(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return int(re.sub(r'[\n\s:\-]','',re.search(r'Number of Subponeas: (\d{3})',str(text)).group(1)).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_213getNumberOfSubpoenas, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getNumberOfSubpoenas, __pyx_t_5) < 0) __PYX_ERR(0, 1562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1567
 *     except:
 *         return ''
 * def getAdminUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Updated By: (\w{3})',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_215getAdminUpdatedBy, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getAdminUpdatedBy, __pyx_t_5) < 0) __PYX_ERR(0, 1567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1572
 *     except:
 *         return ''
 * def getTransferToAdminDocDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer to Admin Doc Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_217getTransferToAdminDocDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTransferToAdminDocDate, __pyx_t_5) < 0) __PYX_ERR(0, 1572, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1577
 *     except:
 *         return ''
 * def getTransferDesc(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Transfer Desc: ([A-Z\s]{0,15} \d\d?/\d\d?/\d\d\d\d)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_219getTransferDesc, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTransferDesc, __pyx_t_5) < 0) __PYX_ERR(0, 1577, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1582
 *     except:
 *         return ''
 * def getTBNV1(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV1\): ([^\n]+)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_221getTBNV1, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTBNV1, __pyx_t_5) < 0) __PYX_ERR(0, 1582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1587
 *     except:
 *         return ''
 * def getTBNV2(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Date Trial Began but No Verdict \(TBNV2\): ([^\n]+)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_223getTBNV2, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getTBNV2, __pyx_t_5) < 0) __PYX_ERR(0, 1587, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1592
 *     except:
 *         return ''
 * def getSentencingRequirementsCompleted(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'[\n:]|Requrements Completed','', ", ".join(re.findall(r'(?:Requrements Completed: )([YES|NO]?)',str(text))))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_225getSentencingRequirementsCompleted, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentencingRequirementsComplet, __pyx_t_5) < 0) __PYX_ERR(0, 1592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1597
 *     except:
 *         return ''
 * def getSentenceDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'(Sentence Date: )(\d\d?/\d\d?/\d\d\d\d)',str(text)).group(2).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_227getSentenceDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentenceDate, __pyx_t_5) < 0) __PYX_ERR(0, 1597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1602
 *     except:
 *         return ''
 * def getProbationPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Probation Period: ([^\.]+)',str(text)).group(1).strip()).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_229getProbationPeriod, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getProbationPeriod, __pyx_t_5) < 0) __PYX_ERR(0, 1602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1607
 *     except:
 *         return ''
 * def getLicenseSuspPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.sub(r'(License Susp Period:)','',re.search(r'License Susp Period: ([^\.]+)',str(text)).group(1).strip()))
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_231getLicenseSuspPeriod, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1607, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getLicenseSuspPeriod, __pyx_t_5) < 0) __PYX_ERR(0, 1607, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1612
 *     except:
 *         return ''
 * def getJailCreditPeriod(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return "".join(re.search(r'Jail Credit Period: ([^\.]+)',str(text)).group(1).strip())
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_233getJailCreditPeriod, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getJailCreditPeriod, __pyx_t_5) < 0) __PYX_ERR(0, 1612, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1617
 *     except:
 *         return ''
 * def getSentenceProvisions(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.search(r'Sentence Provisions: ([Y|N]?)',str(text)).group(1).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_235getSentenceProvisions, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentenceProvisions, __pyx_t_5) < 0) __PYX_ERR(0, 1617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1622
 *     except:
 *         return ''
 * def getSentenceStartDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence Start Date:)','',", ".join(re.findall(r'Sentence Start Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_237getSentenceStartDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentenceStartDate, __pyx_t_5) < 0) __PYX_ERR(0, 1622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1627
 *     except:
 *         return ''
 * def getSentenceEndDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Sentence End Date:)','',", ".join(re.findall(r'Sentence End Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_239getSentenceEndDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentenceEndDate, __pyx_t_5) < 0) __PYX_ERR(0, 1627, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1632
 *     except:
 *         return ''
 * def getProbationBeginDate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Begin Date:)','',", ".join(re.findall(r'Probation Begin Date: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_241getProbationBeginDate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getProbationBeginDate, __pyx_t_5) < 0) __PYX_ERR(0, 1632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1637
 *     except:
 *         return ''
 * def getSentenceUpdatedBy(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Updated By:)','',", ".join(re.findall(r'Updated By: (\w{3}?)',str(text)))).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_243getSentenceUpdatedBy, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1637, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentenceUpdatedBy, __pyx_t_5) < 0) __PYX_ERR(0, 1637, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1642
 *     except:
 *         return ''
 * def getSentenceLastUpdate(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Last Update:)','',", ".join(re.findall(r'Last Update: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_245getSentenceLastUpdate, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getSentenceLastUpdate, __pyx_t_5) < 0) __PYX_ERR(0, 1642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1647
 *     except:
 *         return ''
 * def getProbationRevoke(text):             # <<<<<<<<<<<<<<
 *     try:
 *         return re.sub(r'(Probation Revoke:)','',", ".join(re.findall(r'Probation Revoke: (\d\d?/\d\d?/\d\d\d\d)',str(text)))).strip()
 */
  __pyx_t_5 = PyCFunction_NewEx(&__pyx_mdef_9alacorder_3cal_247getProbationRevoke, NULL, __pyx_n_s_alacorder_cal); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_getProbationRevoke, __pyx_t_5) < 0) __PYX_ERR(0, 1647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "alacorder/cal.pyx":1
 * """             # <<<<<<<<<<<<<<
 *  alacorder on polars
 * 
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init alacorder.cal", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init alacorder.cal");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (__Pyx_PyFastCFunction_Check(func)) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#if defined(__Pyx_CyFunction_USED) && defined(NDEBUG)
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* None */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunctionShared */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    if (unlikely(op == NULL))
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
#if PY_MAJOR_VERSION < 3
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
#endif
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSsize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(Py_ssize_t)*3+2];
    char *dpos, *end = digits + sizeof(Py_ssize_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    Py_ssize_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (Py_ssize_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (Py_ssize_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (Py_ssize_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    if (last_one_off) {
        assert(*dpos == '0');
        dpos++;
    }
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* None */
static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* pyobject_as_double */
static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if !CYTHON_USE_TYPE_SLOTS
    float_value = PyNumber_Float(obj);  if ((0)) goto bad;
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* PatchModuleWithCoroutine */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchInspect */
static PyObject* __Pyx_patch_inspect(PyObject* module) {
#if defined(__Pyx_Generator_USED) && (!defined(CYTHON_PATCH_INSPECT) || CYTHON_PATCH_INSPECT)
    static int inspect_patched = 0;
    if (unlikely((!inspect_patched) && module)) {
        module = __Pyx_Coroutine_patch_module(
            module, ""
"old_types = getattr(_module.isgenerator, '_cython_generator_types', None)\n"
"if old_types is None or not isinstance(old_types, set):\n"
"    old_types = set()\n"
"    def cy_wrap(orig_func, type=type, cython_generator_types=old_types):\n"
"        def cy_isgenerator(obj): return type(obj) in cython_generator_types or orig_func(obj)\n"
"        cy_isgenerator._cython_generator_types = cython_generator_types\n"
"        return cy_isgenerator\n"
"    _module.isgenerator = cy_wrap(_module.isgenerator)\n"
"old_types.add(_cython_generator_type)\n"
        );
        inspect_patched = 1;
    }
#else
    if ((0)) return __Pyx_Coroutine_patch_module(module, NULL);
#endif
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);  // XDECREF since it's only set on Py3 if cline
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* CoroutineBase */
#include <structmember.h>
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
            _PyGen_SetStopIterationValue(result);
        }
        Py_CLEAR(result);
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (Py_REFCNT(self) > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    __Pyx_SET_REFCNT(self, 1);
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(Py_REFCNT(self) > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = Py_REFCNT(self);
        _Py_NewReference(self);
        __Pyx_SET_REFCNT(self, refcnt);
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(Py_TYPE(self)) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            __pyx_d,                 /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        if (unlikely(!frame))
            return NULL;
        self->gi_frame = frame;
    }
    Py_INCREF(frame);
    return frame;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchGeneratorABC */
#ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {(char *) "gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     (char*) PyDoc_STR("Frame of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[5];
    int same=1, i, found_dot;
    const char* rt_from_call = Py_GetVersion();
    PyOS_snprintf(ctversion, 5, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    found_dot = 0;
    for (i = 0; i < 4; i++) {
        if (!ctversion[i]) {
            same = (rt_from_call[i] < '0' || rt_from_call[i] > '9');
            break;
        }
        if (rt_from_call[i] != ctversion[i]) {
            same = 0;
            break;
        }
    }
    if (!same) {
        char rtversion[5] = {'\0'};
        char message[200];
        for (i=0; i<4; ++i) {
            if (rt_from_call[i] == '.') {
                if (found_dot) break;
                found_dot = 1;
            } else if (rt_from_call[i] < '0' || rt_from_call[i] > '9') {
                break;
            }
            rtversion[i] = rt_from_call[i];
        }
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
